@@ -357,9 +357,7 @@ int irconf_Show(boolean globalMode, boolean showAll, char *szVersion, char *szIn
       if (ret == ERR_NO_MORE_DATA_epr09) {
         pr09ConfigCloseRuntimeSection(hConfig, ErrText);
         break;
-      } else if (ret == ERR_READ_VALUE_epr09 ){
-        continue;
-      } 
+      }
       if (ret == ERR_OK_epr09 )
       {
           char const *locationString;
