@@ -8,7 +8,7 @@
   description : Class declaration and definition for template ALVTree
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 #ifndef CONTAINER_AVLTREE_HPP
 #define CONTAINER_AVLTREE_HPP
@@ -314,6 +315,9 @@ private :
     SAPDB_ULong     m_ChangeCount;
 
 public :
+    class Iterator;
+    friend class Iterator;
+
     // Local class to iterate over all entries stored in the avl-tree
     class Iterator
     {
