@@ -1,16 +1,15 @@
 /*!
   @file           Container_CircularList.hpp
-  @author         ContainerMaint
+  @author         TillL, UweH
   @brief          Class declaration and definition for template list classes
-              (doubly linked circular lists)
+                  (doubly linked circular lists)
   @see            Container_DoubleNode.html
                   Container_DoubleNodeIterator.html
-  @author         Till Luhmann
 
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -129,7 +129,6 @@ public:
     typedef SAPDBMem_IRawAllocator                          Allocator;
 
 public:
-
     /* -----------------------------------------------------------------------*/
     /*! @name Construction and destruction */
      /*@{*/
@@ -144,10 +143,9 @@ public:
         (Allocator&                     alloc)
         : 
          m_Allocator (alloc), 
-         m_Anchor    (NodeType::InvalidNode),
+         m_Anchor    (0),
          m_NodeCount (0)
     {}
-
     /*!
        @brief          Copy constructor
        @param          list [in] list to be copied
@@ -169,7 +167,7 @@ public:
         SAPDBERR_ASSERT_ARGUMENT(list.IsEmpty());
         if (!list.IsEmpty())
         {
-            m_Anchor    = NodeType::InvalidNode;
+            m_Anchor    = 0;
             m_NodeCount = 0;
         }
     }
@@ -218,7 +216,7 @@ public:
 
     SAPDB_Bool IsEmpty() const
     { 
-        return m_Anchor == NodeType::InvalidNode; 
+        return m_Anchor == 0; 
     }
 
     /*!
@@ -632,7 +630,7 @@ void Container_CircularList<T>::Delete
     pos = Iterator(next.GetNode());
 
     if (--m_NodeCount == 0)
-        m_Anchor = NodeType::InvalidNode;
+        m_Anchor = 0;
 
 }
 
@@ -656,7 +654,7 @@ SAPDB_Bool Container_CircularList<T>::NodeCountConsistent() const
 {
     SizeType nodecount = 0;
     
-    if (m_Anchor != NodeType::InvalidNode)
+    if (m_Anchor != 0)
     {
         ConstIterator iter = Anchor();
         ConstIterator end  = Anchor();
@@ -688,7 +686,7 @@ SAPDB_Bool Container_CircularList<T>::CopyList
     // -------------------------------------------------------------------------
     NodeType* anchor    = m_Anchor;
     SizeType  nodecount = m_NodeCount;
-    m_Anchor            = NodeType::InvalidNode;
+    m_Anchor            = 0;
     m_NodeCount         = 0;
 
     // -------------------------------------------------------------------------
