@@ -1,14 +1,13 @@
 /*!
-  @file           Container_List.hpp
-  @author         ContainerMaint
-  @brief          Class declaration and definition for template list classes
-              (singly linked lists)
-  @author         Stefan Baier, Till Luhmann
+  @file    Container_List.hpp
+  @author  StefanB, TillL, UweH
+  @brief   Class declaration and definition for template list classes
+          (singly linked lists)
 
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,10 +25,9 @@
     ========== licence end
 
 
+
 \endif
 */
-
-
 #ifndef CONTAINER_LIST_HPP
 #define CONTAINER_LIST_HPP
 
@@ -41,452 +39,257 @@
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
 #include "Container/Container_Node.hpp"
 #include "Container/Container_NodeIterator.hpp"
-
-
-
 /*!
-  @class          Container_List
-   @brief          This class implements a doubly linked list
-   @template arguments<T>           type of the elements to be held in the list
+@class          Container_List
+@brief          This class implements a doubly linked list
 
-              T must provide the following methods:
+template arguments<T>  type of the elements to be held in the list
 
-              - Default constructor T()
-              - SAPDB_Bool operator==(const T& t) const
+T must provide the following methods:
 
+- Default constructor T()
+- bool operator==(const T& t) const
 
-   The list uses raw allocators as defined in the SAPDBMem component
-   for allocating memory for the list elements and the link pointers.
-   As of release 7.4, no exceptions are thrown.
-   Instead, SAPDB_Bool return values or invalid iterators are returned by
-   the methods where appropriate.
-
- */
-
-template <class T>
-class Container_List
+The list uses raw allocators as defined in the SAPDBMem component
+for allocating memory for the list elements and the link pointers.
+As of release 7.4, no exceptions are thrown.
+Instead, bool return values or invalid iterators are returned by
+the methods where appropriate.
+*/
+template <class T> class Container_List
 {
 private:
-
-   typedef Container_Node<T>                                NodeType;
-
-   typedef Container_List<T>                                List;
-
+   typedef Container_Node<T>                                                     NodeType;
+   typedef Container_List<T>                                                     List;
 public:
-
-    /* -----------------------------------------------------------------------*/
-    /*! @name Type definitions */
-     /*@{*/
-    /*!
-       @brief          Node content type
-
-     */
-
-    typedef T                                               ValueType;
-    /*!
-       @brief          Pointer to node
-
-     */
-
-    typedef NodeType*                                       NodePointer;
-    /*
-    typedef SAPDB_Invalidatable
-            <NodeType*, NodeType::InvalidNode>              NodePointer;
+	/// Node content type
+    typedef T                                                                    ValueType;
+	/// Pointer to node
+    typedef NodeType*                                                            NodePointer;
+	/// List iterator
+    typedef Container_NodeIterator<ValueType, ValueType, NodeType*>              Iterator;
+	/// Constant list iterator
+    typedef Container_NodeIterator<ValueType, const ValueType, const NodeType*>  ConstIterator;
+public:
+	/*!
+    @brief Constructor
+    @param alloc [in] reference to raw allocator
     */
-    /*!
-       @brief          List iterator
-
-     */
-
-    typedef Container_NodeIterator
-            <ValueType, ValueType, NodeType* >              Iterator;
-    /*!
-       @brief          Constant list iterator
-
-     */
-
-    typedef Container_NodeIterator
-            <ValueType, const ValueType, const NodeType* >  ConstIterator;
-    /*!
-       @brief          Count of nodes (elements) in a list
-
-     */
-
-    typedef SAPDB_UInt                                      SizeType;
-    /*!
-       @brief          allocator for queue entries
-
-     */
-
-    typedef SAPDBMem_IRawAllocator                          Allocator;
-    /* -----------------------------------------------------------------------*/
-    /*@}*/
-    /* -----------------------------------------------------------------------*/
-
-public:
-
-    /* -----------------------------------------------------------------------*/
-    /*! @name Construction and destruction */
-     /*@{*/
-    /*!
-       @brief          Constructor
-       @param          alloc [in] reference to raw allocator
-       @return         none
-
-     */
-
-    Container_List
-        (Allocator&                     alloc)
-        : 
-         m_Allocator(alloc), 
-         m_Head(NodeType::InvalidNode),
-         m_Last(NodeType::InvalidNode),
-         m_NodeCount(0)
+    Container_List (SAPDBMem_IRawAllocator &alloc)
+    : m_Allocator(alloc)
+    , m_Head     (0)
+    , m_Last     (0)
+    , m_NodeCount(0)
     {}
-
     /*!
-       @brief          Initializes a list
-       @param          list [in] list to be copied
-       @return         (SAPDB_Bool) true if successful
+    @brief          Initializes a list
+    @param          list [in] list to be copied
+    @return         (bool) true if successful
 
-
-       - The former list content is deleted.
-       - All elements from 'list' are copied.
-
-     */
-
-    SAPDB_Bool Initialize
-        (const List&              list)
+    - The former list content is deleted.
+    - All elements from 'list' are copied.
+    */
+    bool Initialize (const List &list)
     {
         return CopyList(list);
     }
-
-    /*!
-       @brief          Deletes the whole list
-       @return         none
-
-     */
-
+	/// Deletes the whole list
     void Delete();
-
-    /*!
-       @brief          Destructs the list and deallocates all elements
-       @return         none
-
-     */
-
+	/// Destructs the list and deallocates all elements
     ~Container_List()
     {
         Delete();
     }
-
-    /* -----------------------------------------------------------------------*/
-    /*@}*/
-    /* -----------------------------------------------------------------------*/
-
-    /* -----------------------------------------------------------------------*/
-    /*! @name Status functions */
-     /*@{*/
-    /*!
-       @brief          Checks whether list is empty
-       @return         (SAPDB_Bool) true if empty
-
-     */
-
-    SAPDB_Bool IsEmpty() const
+	/// Checks whether list is empty, returns true if empty
+    bool IsEmpty() const
     { 
-        return m_Head == NodeType::InvalidNode; 
+        return m_Head == 0; 
     }
-
     /*!
-       @brief          Returns the actual node count of the list
-       @return         (SizeType) node count
-
-     */
-
-    SizeType GetSize() const
+    @brief          Returns the actual node count of the list
+    @return         node count
+    */
+    SAPDB_UInt GetSize() const
     { 
         return m_NodeCount; 
     }
-
     /*!
-       @brief          Returns the associated allocator
-       @return         (Allocator&amp;) reference to allocator
-
-     */
-
-    Allocator& GetAllocator() const
+    @brief          Returns the associated allocator
+    @return         reference to allocator
+    */
+    SAPDBMem_IRawAllocator& GetAllocator() const
     { 
         return m_Allocator; 
     }
-
     /*!
-       @brief          Compares actual list with 'list'
-       @param          list [in] list to be compared
-       @return         (SAPDB_Bool) true if both lists have the same content
-
-     */
-
-    SAPDB_Bool operator==
-        (const List&                    list) const;
-
+    @brief          Compares actual list with 'list'
+    @param          list [in] list to be compared
+    @return         (bool) true if both lists have the same content
+    */
+    bool operator== (const List &list) const;
     /*!
-       @brief          Compares actual list with 'list'
-       @param          list [in] list to be compared
-       @return         (SAPDB_Bool) true if both lists have different content
-
-     */
-
-    SAPDB_Bool operator !=
-        (const List&                    list) const
+    @brief          Compares actual list with 'list'
+    @param          list [in] list to be compared
+    @return         (bool) true if both lists have different content
+    */
+    bool operator != (const List &list) const
     { 
         return !(this->operator==(list)); 
     }
-    /* -----------------------------------------------------------------------*/
-    /*@}*/
-    /* -----------------------------------------------------------------------*/
-
-
-    /* -----------------------------------------------------------------------*/
-    /*! @name List manipulation */
-     /*@{*/
     /*!
-       @brief          Inserts a new element at the beginning of the list
-       @param          elem [in] element to be inserted
-       @return         (Iterator) iterator pointing to inserted node;
-                         invalid iterator if insert not successful
-
-     */
-
-    Iterator InsertFront
-        (const ValueType&               elem);
-
+    @brief          Inserts a new element at the beginning of the list
+    @param          elem [in] element to be inserted
+    @return         (Iterator) iterator pointing to inserted node;
+    invalid iterator if insert not successful
+    */
+    Iterator InsertFront (const ValueType &elem);
     /*!
-       @brief          Inserts a new element at the end of the list
-       @param          elem [in] element to be inserted
-       @return         (Iterator) iterator pointing to inserted node;
-                         invalid iterator if insert not successful
-
+    @brief          Inserts a new element at the end of the list
+    @param          elem [in] element to be inserted
+    @return         (Iterator) iterator pointing to inserted node;
+    invalid iterator if insert not successful
      */
-
-    Iterator InsertEnd
-        (const ValueType&               elem);
-
+    Iterator InsertEnd (const ValueType &elem);
     /*!
-       @brief          Inserts a new element before a given iterator position
-       @param          pos [in/out] iterator insert position
-       @param          elem [in] element to be inserted
-       @return         (Iterator) iterator pointing to inserted node;
-                         invalid iterator if insert not successful
-
-
-       - After the operation, 'pos' points to the inserted node.
-       - This method is rather slow, because in order to insert a                 list element at a certain position, the predecessor of that                 position has to be found.
-
-     */
-
-    Iterator Insert
-        (Iterator&                      pos, 
-         const ValueType&               elem);
-
+    @brief          Inserts a new element before a given iterator position
+    @param          pos [in/out] iterator insert position
+    @param          elem [in] element to be inserted
+    @return         (Iterator) iterator pointing to inserted node;
+	invalid iterator if insert not successful
+    - After the operation, 'pos' points to the inserted node.
+    - This method is rather slow, because in order to insert a list element
+      at a certain position, the predecessor of that position has to be found.
+    */
+    Iterator Insert (Iterator        &pos, 
+                     const ValueType &elem);
     /*!
-       @brief          Inserts a new element behind a given iterator position
-       @param          pos [in/out] iterator insert position
-       @param          elem [in] element to be inserted
-       @return         (Iterator) iterator pointing to inserted node;
-                         invalid iterator if insert not successful
-
-
-       - After the operation, 'pos' points to the inserted node.
-
-     */
-
-    Iterator InsertBehind
-        (Iterator&                      pos, 
-         const ValueType&               elem);
-
+    @brief          Inserts a new element behind a given iterator position
+    @param          pos [in/out] iterator insert position
+    @param          elem [in] element to be inserted
+    @return         (Iterator) iterator pointing to inserted node;
+    invalid iterator if insert not successful
+	After the operation, 'pos' points to the inserted node.
+    */
+    Iterator InsertBehind  (Iterator        &pos, 
+                            const ValueType &elem);
     /*!
-       @brief          Deletes the first element of the list
-       @return         none
-
-
-       - The list must not be empty.
-
-     */
-
+    @brief Deletes the first element of the list
+    The list must not be empty.
+    */
     void DeleteFront();
-
     /*!
-       @brief          Deletes the element at a given iterator position
-       @param          pos [in/out] iterator delete position
-       @return         none
-
-
-       - This method is rather slow, because in order to delete a                list element at a certain position, the predecessor of that                position has to be found.
-       - After the operation, 'pos' points to the node behind                  the deleted one.
+    @brief          Deletes the element at a given iterator position
+    @param          pos [in/out] iterator delete position
 
+    - This method is rather slow, because in order to delete a list element at a certain position, the predecessor of that                position has to be found.
+    - After the operation, 'pos' points to the node behind the deleted one.
      */
-
-    void Delete
-        (Iterator&                      pos);
-
-    /* -----------------------------------------------------------------------*/
-    /*@}*/
-    /* -----------------------------------------------------------------------*/
-
-
-    /* -----------------------------------------------------------------------*/
-    /*! @name Iterator functions */
-     /*@{*/
+    void Delete (Iterator &pos);
     /*!
-       @brief          Returns an iterator to the first list node
-       @return         (Iterator/ConstIterator)
-
-     */
-
+    @brief          Returns an iterator to the first list node
+    @return         (Iterator/ConstIterator)
+    */
     Iterator Begin()
     { 
         return Iterator(m_Head); 
     }
-
+	/// return const iter to the list begin
     ConstIterator Begin() const
     { 
         return ConstIterator(m_Head); 
     }
-
     /*!
-       @brief          Returns an iterator to the last list node
-       @return         (Iterator/ConstIterator)
-
-     */
-
+    @brief          Returns an iterator to the last list node
+    @return         (Iterator/ConstIterator)
+    */
     Iterator Last()
     { 
         return Iterator(m_Last); 
     }
-
+    /*!
+    @brief          Returns an iterator to the last list node
+    @return         (Iterator/ConstIterator)
+    */
     ConstIterator Last() const
     { 
         return ConstIterator(m_Last); 
     }
-
     /*!
-       @brief          Returns an iterator behind the last list node
-       @return         (Iterator/ConstIterator)
-
-     */
-
+    @brief          Returns an iterator behind the last list node
+    @return         (Iterator/ConstIterator)
+    */
     Iterator End()
     { 
-        return Iterator(NodeType::InvalidNode); 
+        return Iterator(0); 
     }
-
+    /*!
+    @brief          Returns an iterator behind the last list node
+    @return         (Iterator/ConstIterator)
+    */
     ConstIterator End() const
     { 
-        return ConstIterator(NodeType::InvalidNode); 
+        return ConstIterator(0); 
     }
-
-    /* -----------------------------------------------------------------------*/
-    /*@}*/
-    /* -----------------------------------------------------------------------*/
-
     /*!
-       @brief          Checks whether actual node count is the same as m_NodeCount
-       @return         (SAPDB_Bool) true if consistent
-
-
-       - For test usage only.
-
-     */
-
-    SAPDB_Bool NodeCountConsistent() const;
+    @brief          Checks whether actual node count is the same as m_NodeCount
+    @return         (bool) true if consistent
+    - For test usage only.
+    */
+    bool NodeCountConsistent() const;
 
 private:
-
-    /*--------------------------------------------------------------------------
-    function:     Container_List()
-    description:  Copy constructor
-    arguments:    list  [in] list to be copied
-    return value: none
-    --------------------------------------------------------------------------*/
-    Container_List
-        (const List&                    list)
+	/// Copy constructor
+    Container_List (const List &list)
     { 
         // do nothing in 7.4
     }
-
-    /*--------------------------------------------------------------------------
-    function:     operator=()
-    description:  Assigns list (does not work in 7.4)
-
-                  - The content of 'list' is copied (duplicated).
-    arguments:    list [in]     list to be assigned
-    return value: (DoubleList&) *this
-    --------------------------------------------------------------------------*/
-    List& operator=
-        (const List&                    list)
+	/*!
+    @brief Assigns list (does not work in 7.4)
+    @param   list [in]     list to be assigned
+    @return (DoubleList&) *this
+    - The content of 'list' is copied (duplicated).
+    */
+    List& operator= (const List &list)
     {
         // do nothing in 7.4
         return *this;
     }
-
-    /*-----------------------------------------------------------------------
-    function:     CopyList()
-    description:  Performs an elementwise list copy
-
+    /*!
+    @brief  Performs an elementwise list copy
+    @param    list  [in] list to be copied
+    @return  (bool) true if successful
                   - The former content of the actual list is deleted.
                   - Argument list 'list' is copied element by element
                     into the actual list.
-    arguments:    list  [in] list to be copied
-    return:      (SAPDB_Bool) true if successful
-    -----------------------------------------------------------------------*/
-    SAPDB_Bool CopyList
-        (const List&                    list);
-
-    /*--------------------------------------------------------------------------
-    function:     CreateNode()
-    description:  Dynamically creates a new node
-    arguments:    elem [in]     content of the new node
-    return value: (NodeType*) pointer to node (0 if not successful)
-    --------------------------------------------------------------------------*/
+    */
+    bool CopyList (const List &list);
+    /*!
+    @brief  Dynamically creates a new node
+    @param  elem [in]     content of the new node
+    @return (NodeType*) pointer to node (0 if not successful)
+    */
     // !!! Attention: Please do not change the following lines
     // Otherwise a compiler error on linux is generated.
-    NodeType* CreateNode
-        (const ValueType&               elem)
+    NodeType* CreateNode(const ValueType&               elem)
     {
       return new(m_Allocator) NodeType(elem);
     }
     // !!! Attention: Please do not change the lines above.
-
-    /*--------------------------------------------------------------------------
-    declaration : m_Allocator
-    description:  Reference to underlying raw allocator
-    --------------------------------------------------------------------------*/
-    Allocator&                                      m_Allocator;
-    /*--------------------------------------------------------------------------
-    declaration : m_Head
-    description:  Pointer to first node in the list
-    --------------------------------------------------------------------------*/
-    NodePointer                                     m_Head;
-    /*--------------------------------------------------------------------------
-    declaration : m_Last
-    description:  Pointer to last node in the list
-    --------------------------------------------------------------------------*/
-    NodePointer                                     m_Last;
-    /*--------------------------------------------------------------------------
-    declaration : m_NodeCount
-    description:  Actual node count in the list
-    --------------------------------------------------------------------------*/
-    SizeType                                        m_NodeCount;
-
+    /// Reference to underlying raw allocator
+    SAPDBMem_IRawAllocator &m_Allocator;
+	/// Pointer to first node in the list
+    NodePointer             m_Head;
+	/// Pointer to last node in the list
+    NodePointer             m_Last;
+	/// Actual node count in the list
+    SAPDB_UInt                m_NodeCount;
 };
 
 
 // -----------------------------------------------------------------------------
 
 template <class T>
-SAPDB_Bool Container_List<T>::operator ==
-    (const List&                    list) const
+inline bool Container_List<T>::operator == (const List& list) const
 {
     // -------------------------------------------------------------------------
     // check whether lists have the same node count
@@ -520,9 +323,7 @@ SAPDB_Bool Container_List<T>::operator ==
 // -----------------------------------------------------------------------------
 
 template <class T>
-typename Container_List<T>::Iterator 
-Container_List<T>::InsertFront
-    (const ValueType&               elem)
+inline typename Container_List<T>::Iterator Container_List<T>::InsertFront (const ValueType &elem)
 {
     // -------------------------------------------------------------------------
     // create a new node
@@ -550,10 +351,7 @@ Container_List<T>::InsertFront
 // -----------------------------------------------------------------------------
 
 template <class T>
-inline
-typename Container_List<T>::Iterator 
-Container_List<T>::InsertEnd
-    (const ValueType&               elem)
+inline typename Container_List<T>::Iterator Container_List<T>::InsertEnd ( const ValueType &elem)
 {
     // -------------------------------------------------------------------------
     // create a new node
@@ -575,7 +373,7 @@ Container_List<T>::InsertEnd
     }
 
     m_Last          = node;
-    m_Last->m_Next  = NodeType::InvalidNode;
+    m_Last->m_Next  = 0;
 
     ++m_NodeCount;
 
@@ -585,10 +383,8 @@ Container_List<T>::InsertEnd
 // -----------------------------------------------------------------------------
 
 template <class T>
-typename Container_List<T>::Iterator 
-Container_List<T>::Insert
-    (Iterator&                      pos, 
-     const ValueType&               elem)
+inline typename Container_List<T>::Iterator Container_List<T>::Insert (Iterator        &pos, 
+                                                                       const ValueType &elem)
 {
     SAPDBERR_ASSERT_ARGUMENT(pos.IsValid());
 
@@ -653,10 +449,8 @@ Container_List<T>::Insert
 // -----------------------------------------------------------------------------
 
 template <class T>
-typename Container_List<T>::Iterator 
-Container_List<T>::InsertBehind
-    (Iterator&                      pos, 
-     const ValueType&               elem)
+inline typename Container_List<T>::Iterator Container_List<T>::InsertBehind (Iterator        &pos, 
+                                                                             const ValueType &elem)
 {
     SAPDBERR_ASSERT_ARGUMENT(pos.IsValid());
     SAPDBERR_ASSERT_ARGUMENT(pos != End());
@@ -690,8 +484,7 @@ Container_List<T>::InsertBehind
 // -----------------------------------------------------------------------------
 
 template <class T>
-inline
-void Container_List<T>::DeleteFront()
+inline void Container_List<T>::DeleteFront()
 {
     SAPDBERR_ASSERT_STATE(!IsEmpty());
 
@@ -709,8 +502,7 @@ void Container_List<T>::DeleteFront()
 // -----------------------------------------------------------------------------
 
 template <class T>
-void Container_List<T>::Delete
-    (Iterator&                      pos)
+inline void Container_List<T>::Delete (Iterator &pos)
 {
     SAPDBERR_ASSERT_ARGUMENT(pos.IsValid());
     SAPDBERR_ASSERT_ARGUMENT(pos != End());
@@ -762,8 +554,7 @@ void Container_List<T>::Delete
 // -----------------------------------------------------------------------------
 
 template <class T>
-inline
-void Container_List<T>::Delete()
+inline void Container_List<T>::Delete()
 {
    while (!IsEmpty()) 
    {
@@ -774,11 +565,11 @@ void Container_List<T>::Delete()
 // -----------------------------------------------------------------------------
 
 template <class T>
-bool Container_List<T>::NodeCountConsistent() const
+inline bool Container_List<T>::NodeCountConsistent() const
 {
      ConstIterator iter    = Begin();
      ConstIterator enditer = End();
-     SizeType nodecount    = 0;
+     SAPDB_UInt nodecount    = 0;
      
      while (iter != enditer)
      {
@@ -792,21 +583,20 @@ bool Container_List<T>::NodeCountConsistent() const
 // -----------------------------------------------------------------------------
 
 template <class T>
-SAPDB_Bool Container_List<T>::CopyList
-    (const List&                    list)
+inline bool Container_List<T>::CopyList (const List&                    list)
 {
     // -------------------------------------------------------------------------
     // save actual list contents:
     // -------------------------------------------------------------------------
     NodeType* head      = m_Head;
     NodeType* last      = m_Last;
-    SizeType  nodecount = m_NodeCount;
+    SAPDB_UInt  nodecount = m_NodeCount;
 
     // -------------------------------------------------------------------------
     // copy list elementwise:
     // -------------------------------------------------------------------------
-    m_Head              = NodeType::InvalidNode;
-    m_Last              = NodeType::InvalidNode;
+    m_Head              = 0;
+    m_Last              = 0;
     m_NodeCount         = 0;
     ConstIterator iter  = list.Begin();
     ConstIterator end   = list.End();
@@ -833,10 +623,5 @@ SAPDB_Bool Container_List<T>::CopyList
     del.Delete();
     return true;
 }
-
-// -----------------------------------------------------------------------------
-
-
-
 #endif // CONTAINER_LIST_HPP
 
