@@ -713,13 +713,18 @@ SAPDB_Bool Container_Vector<T>::Reserve(SizeType NewCapacity)
     if (NewArrayPtr == 0) 
         { return false; }
 
-    if (NewArrayPtr != m_ArrayPtr) {
-        if (m_ArrayPtr != 0 && m_Size != 0) {
-            // If the reallocation at the hint position didn't work...
-            // ...initialize the new vector elements with the old ones,
-            newarray(NewArrayPtr, m_Size, NewArrayPtr, m_ArrayPtr);
-            // ...and destroy the old vector.
-            destroyarray(m_ArrayPtr, m_Size, m_Allocator);
+    if (NewArrayPtr != m_ArrayPtr) 
+    {
+        if( m_ArrayPtr != 0 ) // && m_Size != 0)  // PTS 1139235 TS 2005-12-08 
+        {
+            if( 0 != m_Size ) // PTS 1139235 TS 2005-12-08 
+            {
+                // If the reallocation at the hint position didn't work...
+                // ...initialize the new vector elements with the old ones,
+                newarray(NewArrayPtr, m_Size, NewArrayPtr, m_ArrayPtr);
+            }
+            // ...and destroy the old vector, i.e. return memory to the give allocator
+            destroyarray(m_ArrayPtr, m_Size, m_Allocator); // PTS 1139235 TS 2005-12-08 
         }
         // Assign the new member.
         m_ArrayPtr = NewArrayPtr;
