@@ -60,35 +60,38 @@
  *===========================================================================*/
 
 Converter_ReturnCode
-Converter_BackUpPageNoContainer::Insert( Data_PageNo    PageNo )
+Converter_BackUpPageNoContainer::Insert( const Data_PageNo    PageNo )
 {
     /* check current state of the container */
     SAPDBERR_ASSERT_STATE (IsInitialized());
-    
+
     /* find the flag info which contains the flag to switch on for the given page number */
-    SAPDB_UInt FlagInfoBlockNo = PageNo/m_NumPageNosPerFlagInfoBlock;
-    SAPDB_UInt BlockOffset     = PageNo - FlagInfoBlockNo * m_NumPageNosPerFlagInfoBlock;
-    Converter_FlagInfo::FlagInfoData *  FlagInfoBlockPtr =  m_FlagInfoPtrVector[FlagInfoBlockNo];
+    const SAPDB_UInt FlagInfoBlockNo = CalculateFlagInfoBlockNo( PageNo );
+    const SAPDB_UInt BlockOffset     = CalculateFlagInfoBlockOffset( PageNo, FlagInfoBlockNo );
+
+    Converter_FlagInfo::FlagInfoData *  FlagInfoBlockPtr =  m_FlagInfoBlockAnchorList[FlagInfoBlockNo];
+
     if (NULL == FlagInfoBlockPtr)
     {
         SAPDBERR_ASSERT_STATE (m_NumUsedFlagInfoBlocks < m_NumFlagInfoBlocks)
-            FlagInfoBlockPtr = &(m_FlagInfoVector[m_NumUsedFlagInfoBlocks * m_SizeOfFlagInfoBlock]);
+        FlagInfoBlockPtr = &(m_FlagInfoBlocks[m_NumUsedFlagInfoBlocks * m_SizeOfFlagInfoBlock]);
         ++m_NumUsedFlagInfoBlocks;
-        m_FlagInfoPtrVector[FlagInfoBlockNo] = FlagInfoBlockPtr;
+        m_FlagInfoBlockAnchorList[FlagInfoBlockNo] = FlagInfoBlockPtr;
     }
-    
+
     Converter_FlagInfo FlagInfo (FlagInfoBlockPtr, BlockOffset);
-    
+
     /* check that  the page number is not already inserted */
     /* check if the page number is inserted at all */
-    if (FlagInfo.FlagIsSet(PageNo)) return Converter_DuplicatePageNo;
-    
+    if (FlagInfo.FlagIsSet(PageNo))
+        return Converter_DuplicatePageNo;
+
     /* insert the page number */
     FlagInfo.SetFlag(PageNo);
-    
+
     /* update number of pages in the container */
     m_PageNoCount.Increment();
-    
+
     return Converter_Ok;
 }
 
@@ -96,15 +99,15 @@ Converter_BackUpPageNoContainer::Insert( Data_PageNo    PageNo )
 
 Converter_ReturnCode
 Converter_BackUpPageNoContainer::Initialize (SAPDB_UInt  MaxPageNo,
-                                             SAPDB_UInt  NumFlagInfoBlocks,
-                                             SAPDB_UInt  NumPageNosPerFlagInfoBlock)
+        SAPDB_UInt  NumFlagInfoBlocks,
+        SAPDB_UInt  NumPageNosPerFlagInfoBlock)
 {
     /* check current state of the container */
     SAPDBERR_ASSERT_STATE (! IsInitialized());
 
     /* prmitive consistency check of  input parameter */
     SAPDBERR_ASSERT_STATE (((MaxPageNo/NumPageNosPerFlagInfoBlock)+1) >= NumFlagInfoBlocks);
-    
+
     m_NumFlagInfoBlocks          = NumFlagInfoBlocks;
     m_NumPageNosPerFlagInfoBlock = NumPageNosPerFlagInfoBlock;
 
@@ -112,52 +115,60 @@ Converter_BackUpPageNoContainer::Initialize (SAPDB_UInt  MaxPageNo,
     /* NumPageNosPerFlagInfoBlock page numbers. align the flag info blocks */
     /* to avoid inteferences during the paralell removing of page numbers  */
     m_SizeOfFlagInfoBlock = ALIGN (Converter_FlagInfo::FlagInfoBlockNo(NumPageNosPerFlagInfoBlock) + 1);
-    
+
     /* check 8 byte alignment of flag info blocks */
     SAPDBERR_ASSERT_STATE (((m_SizeOfFlagInfoBlock * sizeof (Converter_FlagInfo::FlagInfoData)) % 8) == 0);
 
-    if ((!m_FlagInfoPtrVector.Resize((MaxPageNo/NumPageNosPerFlagInfoBlock)+1, 0)) ||
-        (!m_FlagInfoVector.Resize(NumFlagInfoBlocks * m_SizeOfFlagInfoBlock, 0)))
+    const SAPDB_UInt allocSize1 = CalculateFlagInfoBlockNo( MaxPageNo )+ 1;
+    const SAPDB_UInt allocSize2 = m_NumFlagInfoBlocks * m_SizeOfFlagInfoBlock;
+
+    const bool bOkay1 = m_FlagInfoBlockAnchorList.Resize( allocSize1, 0 );
+    const bool bOkay2 = m_FlagInfoBlocks.Resize( allocSize2, 0 );
+
+    if( ! ( bOkay1 && bOkay2 ))
     {
-        /* return all resources */
         Delete();
 
-        /* write error message into knldiag */
         Converter_Exception ErrMsg( __CONTEXT__, CONVERTER_NO_MEMORY_FOR_BACKUP_CONTAINER,
-                SAPDB_ToString(MaxPageNo, _T_d),
-                SAPDB_ToString(NumFlagInfoBlocks, _T_d ),
-                SAPDB_ToString( NumPageNosPerFlagInfoBlock, _T_d ));
+                                    SAPDB_ToString(MaxPageNo, _T_d),
+                                    SAPDB_ToString(NumFlagInfoBlocks, _T_d ),
+                                    SAPDB_ToString( NumPageNosPerFlagInfoBlock, _T_d ));
         RTE_Message (ErrMsg);
 
         return Converter_MemoryAllocationFailed;
     }
-
     return Converter_Ok;
 }
 
 /*---------------------------------------------------------------------------*/
 
 SAPDB_Bool
-Converter_BackUpPageNoContainer::Remove (Data_PageNo  PageNo)
+Converter_BackUpPageNoContainer::Remove (const Data_PageNo  PageNo)
 {
     /* check current state of the container */
     SAPDBERR_ASSERT_STATE (IsInitialized());
-    
+
     /* find the flag info which contains the flag to switch on for the given page number */
-    SAPDB_UInt FlagInfoBlockNo = PageNo/m_NumPageNosPerFlagInfoBlock;
-    SAPDB_UInt BlockOffset     = PageNo - FlagInfoBlockNo * m_NumPageNosPerFlagInfoBlock;
-    Converter_FlagInfo::FlagInfoData*  FlagInfoBlockPtr =  m_FlagInfoPtrVector[FlagInfoBlockNo];
-    
-    if (NULL == FlagInfoBlockPtr) return false;
-    
+    const SAPDB_UInt FlagInfoBlockNo = CalculateFlagInfoBlockNo( PageNo );
+    const SAPDB_UInt BlockOffset     = CalculateFlagInfoBlockOffset( PageNo, FlagInfoBlockNo );
+
+    if( FlagInfoBlockNo >= m_FlagInfoBlockAnchorList.GetSize())
+        return false; // given pageNo is out of range
+
+    Converter_FlagInfo::FlagInfoData*  FlagInfoBlockPtr =  m_FlagInfoBlockAnchorList[FlagInfoBlockNo];
+
+    if (NULL == FlagInfoBlockPtr)
+        return false;
+
     Converter_FlagInfo FlagInfo (FlagInfoBlockPtr, BlockOffset);
-    
+
     /* check if the page number is inserted at all */
-    if (!FlagInfo.FlagIsSet(PageNo)) return false;
-    
+    if (!FlagInfo.FlagIsSet(PageNo))
+        return false;
+
     /* remove the page number */
     FlagInfo.DelFlag(PageNo);
-    
+
     /* update number of pages in the container */
     m_PageNoCount.Decrement();
 
