@@ -59,8 +59,8 @@ public:
     */
     void Delete()
     {
-        m_FlagInfoPtrVector.Delete();
-        m_FlagInfoVector.Delete();
+        m_FlagInfoBlockAnchorList.Delete();
+        m_FlagInfoBlocks.Delete();
         m_NumUsedFlagInfoBlocks = 0;
         m_NumFlagInfoBlocks     = 0;
         m_PageNoCount           = 0;
@@ -73,8 +73,8 @@ public:
     */
     Converter_BackUpPageNoContainer  (SAPDBMem_IRawAllocator&  Allocator)
     :
-     m_FlagInfoPtrVector(Allocator),
-     m_FlagInfoVector(Allocator)
+    m_FlagInfoBlockAnchorList(Allocator),
+    m_FlagInfoBlocks(Allocator)
     {
         Delete();
     }
@@ -90,8 +90,8 @@ public:
                        otherwise Converter_Ok
      */
     Converter_ReturnCode  Initialize (SAPDB_UInt  MaxPageNo,
-                            SAPDB_UInt  NumFlagInfoBlocks,
-                            SAPDB_UInt  NumPageNosPerFlagInfoBlock);
+                                      SAPDB_UInt  NumFlagInfoBlocks,
+                                      SAPDB_UInt  NumPageNosPerFlagInfoBlock);
 
     /*!
     @brief          inserts a page number into the container
@@ -100,7 +100,7 @@ public:
                     the value Converter_DuplicatePageNo is returned otherwise Converter_Ok.
 
     */
-    Converter_ReturnCode Insert(Data_PageNo  PageNo);
+    Converter_ReturnCode Insert( const Data_PageNo  PageNo);
 
     /*!
     @brief          Checks whether container is empty
@@ -126,7 +126,7 @@ public:
     @return         (SAPDB_Bool) true if pageno found in container and removed
     */
 
-    SAPDB_Bool Remove (Data_PageNo  PageNo);
+    SAPDB_Bool Remove ( const Data_PageNo  PageNo);
 
 private: // methods
 
@@ -136,15 +136,39 @@ private: // methods
     */
     SAPDB_Bool IsInitialized() const
     {
-        return (m_FlagInfoPtrVector.GetSize() > 0) && (m_FlagInfoVector.GetSize() > 0) ;
+        return (m_FlagInfoBlockAnchorList.GetSize() > 0) && (m_FlagInfoBlocks.GetSize() > 0) ;
+    }
+    /*!
+           @brief  Calculates the number of the FlagInfoBlock the pageNo belongs too.
+                   No validity check is executed!
+           @param  pageNo [in] page number to be used for calculation
+           @return  (SAPDB_UInt) blockNo
+       */
+
+    SAPDB_UInt CalculateFlagInfoBlockNo( const Data_PageNo  pageNo ) const{
+        return pageNo/m_NumPageNosPerFlagInfoBlock;
+    }
+    /*!
+        @brief  Calculates the offset in a given FlagInfoBlock, identified
+                by the flagInfoBlockNo. No validity check is executed!
+        @param  pageNo          [in] page number to be used for calculation
+        @param  flagInfoBlockNo [in] identifier of the FlagInfoBlock
+        @return (SAPDB_UInt) blockNo
+    */
+
+    SAPDB_UInt CalculateFlagInfoBlockOffset(
+        const Data_PageNo  pageNo,
+        const SAPDB_UInt   flagInfoBlockNo ) const
+    {
+        return pageNo - flagInfoBlockNo * m_NumPageNosPerFlagInfoBlock;
     }
 
 private: // members
 
     /// ...
-    Container_Vector<Converter_FlagInfo::FlagInfoData *>    m_FlagInfoPtrVector;
+    Container_Vector<Converter_FlagInfo::FlagInfoData *>    m_FlagInfoBlockAnchorList;
     /// ...
-    Container_Vector<Converter_FlagInfo::FlagInfoData>      m_FlagInfoVector;
+    Container_Vector<Converter_FlagInfo::FlagInfoData>      m_FlagInfoBlocks;
     /// ...
     RTESync_InterlockedCounter<SAPDB_UInt>                  m_PageNoCount;
     /// ...
