@@ -276,8 +276,14 @@ Converter_Converter::Restart(
 {
     SAPDBTRACE_ROUTINE_DEBUG( "Converter::Restart", Converter_Trace, 5 );
 
-    SAPDBTRACE_WRITELN( Converter_Trace, 5, "ConverterVersion: " << ConverterVersion );
-    SAPDBTRACE_WRITELN( Converter_Trace, 5, "SnapShotVersion : " << snapShotVersion );
+    SAPDBTRACE_WRITELN( Converter_Trace, 5, "ConverterVersion      : " << ConverterVersion );
+    SAPDBTRACE_WRITELN( Converter_Trace, 5, "SnapShotVersion       : " << snapShotVersion );
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "LastSaveDataSuccessful: " <<
+                        ( bLastSaveDataSuccessful ? "yes" : "no" ));
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "MaxDynamicPageNo      : " << MaxDynamicPageNo );
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "MaxStaticPageNo       : " << MaxStaticPageNo );
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "NumAllPages           : " << NumAllPages );
+
 
     const SAPDB_UInt numAllStaticPages = m_IsLiveCacheInstance ? NumAllPages : 0;
 
@@ -286,10 +292,12 @@ Converter_Converter::Restart(
                                          m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
         ||
         ( ! m_PermMapControl.Initialize( TaskId, SAPDB_MAX( MaxDynamicPageNo, Data_PageNo( NumAllPages )),
-                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize,
+                                         bLastSaveDataSuccessful ))
         ||
         (! m_PermStaticMapControl.Initialize( TaskId, SAPDB_MAX( MaxStaticPageNo, Data_PageNo( numAllStaticPages )),
-                                              m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+                                              m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize,
+                                              bLastSaveDataSuccessful ))
     )
     {
         Converter_Exception errMsg( __CONTEXT__, CONVERTER_MAP_INIT_FAILED1,
@@ -366,14 +374,17 @@ Converter_Converter::ReadPages(
     Converter_Pager pager( taskId, m_SnapShotVersion );
 
     // loop over all converter leaf pages located in one data volume. This
-    // will speed up the restart time of the converter. The leaf pages located
-    // in the other data volumes are read by another pager task.
+    // will speed up the restart time of the converter. Check if pager tasks
+    // is responsible for another data volume. This could happen, if more
+    // data volumes are configured than pager tasks.
 
-    while (pagerIndex < ((*m_VolumeList).GetSize())){
+
+    while (pagerIndex < ((*m_VolumeList).GetSize()))
+    {
         Converter_Index::BlockVector::Iterator        iter    = (*m_VolumeList)[pagerIndex].Begin();
         const Converter_Index::BlockVector::Iterator  iterEnd = (*m_VolumeList)[pagerIndex].End();
 
-        for( ; iter < iterEnd; iter++ )
+        for( ; iter < iterEnd; iter++ ) // read conv pages of one data volume
         {
             SAPDB_UInt NumPermPagesUpdated        = 0;
             SAPDB_UInt NumPendingUpdatedPermPages = 0;
@@ -427,24 +438,29 @@ Converter_Converter::ReadPages(
 
                 // Update the number of changed data pages since the last save data
 
-                if( leafPage.SavePagesPending( entryPos ) && !m_LastSaveDataSuccessful)
-                    ++ NumPendingUpdatedPermPages;
+                const bool bEntryIsRelevantForSavePages = leafPage.SavePagesRequested( entryPos );
 
-                if( leafPage.SavePagesRequested( entryPos ))
-                    ++ NumPermPagesUpdated;
+                if( bEntryIsRelevantForSavePages )
+                    NumPermPagesUpdated+=1;
+
+                // Do not consider pending flag if last complete backup was succesful or
+                // the data page is already modified again and therefore part of the next
+                // incremental backup
+                if( m_LastSaveDataSuccessful || bEntryIsRelevantForSavePages )
+                    continue;
+
+                if( leafPage.SavePagesPending( entryPos ))
+                    NumPendingUpdatedPermPages+=1;
             }
 
             Converter_BlockAddressIterator elements = leafPage.elements();
 
-            if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToOccupied(
-                        taskId, elements))
+            if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToOccupied(taskId, elements))
             {
-
                 Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
-                        (( Data_Dynamic == leafPage.ReadPageRecoveryMode().GetAddressingMode())
-                        ? "permanent" : "static"),
-                        SAPDB_ToString( leafPage.GetPageNo( elements.GetPosition()), _T_d ));
-
+                                            SAPDB_ToString( leafPage.GetPageNo( elements.GetPosition()), _T_d ),
+                                            (( Data_Dynamic == leafPage.ReadPageRecoveryMode().GetAddressingMode())
+                                             ? "perm" : "static"));
                 RTE_Crash( errMsg );
             }
 
@@ -468,7 +484,7 @@ Converter_Converter::ReadPages(
 void
 Converter_Converter::ReadSnapShotPages(
     const tsp00_TaskId  taskId,
-    const SAPDB_UInt    pagerIndex,
+    SAPDB_UInt          pagerIndex,
     SAPDB_UInt          &totalPages,
     SAPDB_UInt          &totalIO )
 {
@@ -489,74 +505,79 @@ Converter_Converter::ReadSnapShotPages(
     leafPage.SetFrame( frameAllocator.New());
 
     // loop over all converter leaf pages located in one data volume. This
-    // will speed up the restart time of the converter. The leaf pages located
-    // in the other data volumes are read by another pager task.
+    // will speed up the restart time of the converter. Check if pager tasks
+    // is responsible for another data volume. This could happen, if more
+    // data volumes are configured than pager tasks.
 
-    Converter_Index::BlockVector::Iterator        iter    = (*m_VolumeList)[pagerIndex].Begin();
-    const Converter_Index::BlockVector::Iterator  iterEnd = (*m_VolumeList)[pagerIndex].End();
-
-    for( ; iter < iterEnd; iter++ )
+    while (pagerIndex < ((*m_VolumeList).GetSize()))
     {
-        pager.Read( iter->GetBlockAddress(), leafPage );
+        Converter_Index::BlockVector::Iterator        iter    = (*m_VolumeList)[pagerIndex].Begin();
+        const Converter_Index::BlockVector::Iterator  iterEnd = (*m_VolumeList)[pagerIndex].End();
 
-        totalPages++;
-        totalIO++;
-
-        const Data_PageRecoveryMode recMode  = leafPage.ReadPageRecoveryMode();
-        const Data_AddressingMode   addrMode = recMode.GetAddressingMode();
-
-        SAPDBERR_ASSERT_STATE( recMode.PageIsRecoverable());
-
-        // mark all used blocks referenced by the current snapshot converter
-        // leaf page as occupied in the FBM. Note that the corresponding FBM
-        // block could be already set to occupied!
-
-        Converter_PageEntryIterator         pageEntryIter    = leafPage.Begin();
-        const Converter_PageEntryIterator   pageEntryEndIter = leafPage.End();
-
-        for( ; pageEntryIter != pageEntryEndIter; ++pageEntryIter )
+        for( ; iter < iterEnd; iter++ ) // read conv pages of one data volume
         {
-            if( ! pageEntryIter.EntryInUse())
-                continue;
+            pager.Read( iter->GetBlockAddress(), leafPage );
 
-            if( pageEntryIter.GetPackedBlockAddress().IsReserved())
-                continue;
+            totalPages++;
+            totalIO++;
 
+            const Data_PageRecoveryMode recMode  = leafPage.ReadPageRecoveryMode();
+            const Data_AddressingMode   addrMode = recMode.GetAddressingMode();
 
-            const Data_PageNo        pageNo   = leafPage.GetPageNo( pageEntryIter.GetPosition());
-            const IOMan_BlockAddress newBlock = pageEntryIter.GetBlockAddress(); // from snapShot
-            IOMan_BlockAddress       block;
+            SAPDBERR_ASSERT_STATE( recMode.PageIsRecoverable());
 
-            const Converter_ReturnCode retCode = GetPositionForReading( taskId, pageNo, recMode, block );
+            // mark all used blocks referenced by the current snapshot converter
+            // leaf page as occupied in the FBM. Note that the corresponding FBM
+            // block could be already set to occupied!
 
-            SAPDBERR_ASSERT_STATE( newBlock.IsValid());
+            Converter_PageEntryIterator         pageEntryIter    = leafPage.Begin();
+            const Converter_PageEntryIterator   pageEntryEndIter = leafPage.End();
 
-            IncrementSnapShotSize();
-
-            if(( Converter_Ok == retCode ) && ( block == newBlock ))
+            for( ; pageEntryIter != pageEntryEndIter; ++pageEntryIter )
             {
+                if( ! pageEntryIter.EntryInUse())
+                    continue;
+
+                if( pageEntryIter.GetPackedBlockAddress().IsReserved())
+                    continue;
+
+
+                const Data_PageNo        pageNo   = leafPage.GetPageNo( pageEntryIter.GetPosition());
+                const IOMan_BlockAddress newBlock = pageEntryIter.GetBlockAddress(); // from snapShot
+                IOMan_BlockAddress       block;
+
+                const Converter_ReturnCode retCode = GetPositionForReading( taskId, pageNo, recMode, block );
+
+                SAPDBERR_ASSERT_STATE( newBlock.IsValid());
+
+                IncrementSnapShotSize();
+
+                if(( Converter_Ok == retCode ) && ( block == newBlock ))
+                {
+                    SAPDBTRACE_WRITELN( Converter_Trace, 7, "Snapshot: " << ((Data_Dynamic == addrMode) ?
+                                        "Permanent" : "Static") << " pageNo: " << pageNo << " on block: " <<
+                                        block.GetDeviceNo() << "/" << block.GetBlockNo() << " not marked as used ");
+
+                    continue; // given page(block) hasn't changed since snapshot creation
+                }
+
                 SAPDBTRACE_WRITELN( Converter_Trace, 7, "Snapshot: " << ((Data_Dynamic == addrMode) ?
                                     "Permanent" : "Static") << " pageNo: " << pageNo << " on block: " <<
-                                    block.GetDeviceNo() << "/" << block.GetBlockNo() << " not marked as used ");
+                                    newBlock.GetDeviceNo() << "/" << newBlock.GetBlockNo() << " marked as used ");
 
-                continue; // given page(block) hasn't changed since snapshot creation
+                if( FBM_IManager::Instance().SetBlockStateToOccupied( taskId, newBlock ))
+                {
+                    m_NumPermPagesUsed.Increment();
+                    continue;
+                }
+
+                Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
+                                            SAPDB_ToString( pageNo, _T_d ),
+                                            (( Data_Dynamic == addrMode) ? "perm" : "static"));
+                RTE_Crash( errMsg );
             }
-
-            SAPDBTRACE_WRITELN( Converter_Trace, 7, "Snapshot: " << ((Data_Dynamic == addrMode) ?
-                                "Permanent" : "Static") << " pageNo: " << pageNo << " on block: " <<
-                                newBlock.GetDeviceNo() << "/" << newBlock.GetBlockNo() << " marked as used ");
-
-            if( FBM_IManager::Instance().SetBlockStateToOccupied( taskId, newBlock ))
-            {
-                m_NumPermPagesUsed.Increment();
-                continue;
-            }
-
-            Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
-                                        (( Data_Dynamic == addrMode) ?
-                                         "permanent" : "static"), SAPDB_ToString( pageNo, _T_d ));
-            RTE_Crash( errMsg );
         }
+        pagerIndex += g01maxdatawriter();
     }
     if( leafPage.IsAssigned()){
         frameAllocator.Free( leafPage.GetFrame());
@@ -575,14 +596,14 @@ Converter_Converter::Create(
     const SAPDB_UInt numAllStaticPages = m_IsLiveCacheInstance ? numAllPages : 0;
 
     if(
-        ( ! m_TempMapControl.Initialize( taskId, numAllPages,
-                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+        ( ! m_TempMapControl.Initialize( taskId, numAllPages, m_BaseRegionId,
+                                         m_NumRegions, m_MapBlockingSize, m_PageSize ))
         ||
-        ( ! m_PermMapControl.Initialize( taskId, numAllPages,
-                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+        ( ! m_PermMapControl.Initialize( taskId, numAllPages, m_BaseRegionId,
+                                         m_NumRegions, m_MapBlockingSize, m_PageSize, true ))
         ||
-        (! m_PermStaticMapControl.Initialize( taskId, numAllStaticPages,
-                                              m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+        (! m_PermStaticMapControl.Initialize( taskId, numAllStaticPages, m_BaseRegionId,
+                                              m_NumRegions, m_MapBlockingSize, m_PageSize, true ))
     )
     {
         Converter_Exception errMsg( __CONTEXT__, CONVERTER_MAP_INIT_FAILED2,
@@ -616,10 +637,12 @@ Converter_Converter::CreateForRestore(
                                          m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
         ||
         ( ! m_PermMapControl.Initialize( taskId, SAPDB_MAX( maxDynamicPageNo, Data_PageNo( numAllPages )),
-                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+                                         m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize,
+                                         bLastSaveDataSuccessful ))
         ||
         (! m_PermStaticMapControl.Initialize( taskId, SAPDB_MAX( maxStaticPageNo, Data_PageNo( numAllStaticPages )),
-                                              m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize ))
+                                              m_BaseRegionId, m_NumRegions, m_MapBlockingSize, m_PageSize,
+                                              bLastSaveDataSuccessful ))
     )
     {
         Converter_Exception errMsg( __CONTEXT__, CONVERTER_MAP_INIT_FAILED1,
@@ -840,7 +863,7 @@ Converter_Converter::Expand(
 
 /*---------------------------------------------------------------------------*/
 
-void
+Converter_ReturnCode
 Converter_Converter::BeginSaveData( const tsp00_TaskId  taskId )
 {
     SAPDBTRACE_ROUTINE_DEBUG( "Converter::BeginSaveData", Converter_Trace, 5 );
@@ -851,16 +874,28 @@ Converter_Converter::BeginSaveData( const tsp00_TaskId  taskId )
     SAPDBERR_ASSERT_STATE (0     == m_NumDynConvPagesForBackUp);
     SAPDBERR_ASSERT_STATE (0     == m_NumPagesForBackUp);
 
-    m_SaveDataIsActiv = true;
-    SAPDB_UInt numPagesForBackUp = 0;
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "LastSaveDataSuccessful: "
+                        << (m_LastSaveDataSuccessful ? "yes" : "no" ));
 
-    m_PermStaticMapControl.MarkPermPagesForSaveData( taskId, m_LastSaveDataSuccessful,
-            m_NumStatConvPagesForBackUp, numPagesForBackUp );
+
+    m_SaveDataIsActiv = true;
+
+    SAPDB_UInt              numPagesForBackUp = 0;
+    Converter_ReturnCode    retCode;
+
+    retCode = m_PermStaticMapControl.MarkPermPagesForSaveData( taskId,
+              m_NumStatConvPagesForBackUp, numPagesForBackUp );
+
+    if( Converter_Ok != retCode )
+        return retCode;
 
     m_NumPagesForBackUp = numPagesForBackUp;
 
-    m_PermMapControl.MarkPermPagesForSaveData( taskId, m_LastSaveDataSuccessful,
-            m_NumDynConvPagesForBackUp, numPagesForBackUp );
+    retCode = m_PermMapControl.MarkPermPagesForSaveData( taskId,
+              m_NumDynConvPagesForBackUp, numPagesForBackUp );
+
+    if( Converter_Ok != retCode )
+        return retCode;
 
     m_NumPagesForBackUp += numPagesForBackUp;
 
@@ -872,11 +907,13 @@ Converter_Converter::BeginSaveData( const tsp00_TaskId  taskId )
     }
 
     FBM_IManager::Instance().BeginReadingBlocksMarkedForBackUp( taskId );
+
+    return retCode;
 }
 
 /*---------------------------------------------------------------------------*/
 
-void
+Converter_ReturnCode
 Converter_Converter::BeginSavePages( const tsp00_TaskId  taskId )
 {
     SAPDBTRACE_ROUTINE_DEBUG( "Converter::BeginSavePages", Converter_Trace, 5 );
@@ -887,20 +924,33 @@ Converter_Converter::BeginSavePages( const tsp00_TaskId  taskId )
     SAPDBERR_ASSERT_STATE (0     == m_NumDynConvPagesForBackUp);
     SAPDBERR_ASSERT_STATE (0     == m_NumPagesForBackUp);
 
-    m_SavePagesIsActiv           = true;
-    SAPDB_UInt numPagesForBackUp = 0;
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "LastSaveDataSuccessful: "
+                        << ( m_LastSaveDataSuccessful ? "yes" : "no" ));
 
-    m_PermStaticMapControl.MarkPermPagesForSavePages( taskId, m_LastSaveDataSuccessful,
-            m_NumStatConvPagesForBackUp, numPagesForBackUp, Version() );
+    m_SavePagesIsActiv = true;
+
+    SAPDB_UInt              numPagesForBackUp = 0;
+    Converter_ReturnCode    retCode;
+
+    retCode = m_PermStaticMapControl.MarkPermPagesForSavePages( taskId,
+              m_NumStatConvPagesForBackUp, numPagesForBackUp, Version() );
+
+    if( Converter_Ok != retCode )
+        return retCode;
 
     m_NumPagesForBackUp = numPagesForBackUp;
 
-    m_PermMapControl.MarkPermPagesForSavePages( taskId, m_LastSaveDataSuccessful,
-            m_NumDynConvPagesForBackUp, numPagesForBackUp, Version());
+    retCode = m_PermMapControl.MarkPermPagesForSavePages( taskId,
+              m_NumDynConvPagesForBackUp, numPagesForBackUp, Version());
+
+    if( Converter_Ok != retCode )
+        return retCode;
 
     m_NumPagesForBackUp += numPagesForBackUp;
 
     FBM_IManager::Instance().BeginReadingBlocksMarkedForBackUp( taskId );
+
+    return retCode;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -950,18 +1000,22 @@ Converter_Converter::EndSave(
     m_NumStatConvPagesForBackUp = 0;
     m_NumPagesForBackUp         = 0;
 
-    if (m_SaveDataIsActiv)
+    if( m_SaveDataIsActiv )
     {
         m_SaveDataIsActiv = false;
 
-        if (!bBackUpSuccessfullyFinished){
+        if (! bBackUpSuccessfullyFinished )
+        {
             m_LastSaveDataSuccessful = false;
+            m_PermMapControl.SaveDataFinishedUnSuccessfuly( taskId );
+            m_PermStaticMapControl.SaveDataFinishedUnSuccessfuly( taskId );
+
         }
         else
         {
             m_LastSaveDataSuccessful = true;
-            m_PermMapControl.ResetCounterOfPagesStillMarkedForSavePages( taskId );
-            m_PermStaticMapControl.ResetCounterOfPagesStillMarkedForSavePages( taskId );
+            m_PermMapControl.SaveDataFinishedSuccessfuly( taskId );
+            m_PermStaticMapControl.SaveDataFinishedSuccessfuly( taskId );
         }
     }
     else
@@ -1407,9 +1461,11 @@ Converter_Converter::HandleDBFull (
 
 /*---------------------------------------------------------------------------*/
 
-void
-Converter_Converter::BeginColdVerify( const tsp00_TaskId    taskId )
+Converter_ReturnCode
+Converter_Converter::BeginCheckData( const tsp00_TaskId    taskId )
 {
+    SAPDBTRACE_ROUTINE_DEBUG( "Converter::BeginCheckDataWithUpdate", Converter_Trace, 5 );
+
     SAPDBERR_ASSERT_STATE (! BackUpIsActive());
     SAPDBERR_ASSERT_STATE (false == m_ColdVerifyIsActive);
     SAPDBERR_ASSERT_STATE (0     == m_NumStatConvPagesForBackUp);
@@ -1419,21 +1475,28 @@ Converter_Converter::BeginColdVerify( const tsp00_TaskId    taskId )
     m_InMaintenanceMode  = true;
     m_ColdVerifyIsActive = true;
 
-    m_PermMapControl.InitializeBackUpPageNoList( taskId );
-    m_PermStaticMapControl.InitializeBackUpPageNoList( taskId );
+    Converter_ReturnCode retCode;
+
+    retCode = m_PermMapControl.InitializeBackUpPageNoList( taskId );
+
+    if( Converter_Ok == retCode ){
+        retCode = m_PermStaticMapControl.InitializeBackUpPageNoList( taskId );
+    }
+
+    return retCode;
 }
 
 /*---------------------------------------------------------------------------*/
 
 void
-Converter_Converter::EndColdVerify(
+Converter_Converter::EndCheckData(
     const tsp00_TaskId  taskId,
     Data_PageCount      &NumStaticPermDataPages,
     Data_PageCount      &NumDynamicPermDataPages,
     Data_PageCount      &NumPermConvPages,
     Data_PageCount      &NumReleaseBlocks )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Converter::EndColdVerify", Converter_Trace, 5 );
+    SAPDBTRACE_ROUTINE_DEBUG( "Converter::EndCheckDataWithUpdate", Converter_Trace, 5 );
 
     SAPDBERR_ASSERT_STATE (! BackUpIsActive());
     SAPDBERR_ASSERT_STATE (true == m_ColdVerifyIsActive);
@@ -1451,9 +1514,8 @@ Converter_Converter::EndColdVerify(
     m_PermStaticMapControl.ReleaseUnusedPageNos( taskId, m_SnapShotVersion,
             NumStaticPermDataPages, NumPermStaticConvPages, numStaticReleasedBlocks );
 
-    m_PermMapControl.ReleaseUnusedPageNos( taskId, m_SnapShotVersion,
-                                           NumDynamicPermDataPages, NumPermDynamicConvPages,
-                                           numDynamicReleasedBlocks );
+    m_PermMapControl.ReleaseUnusedPageNos(       taskId, m_SnapShotVersion,
+            NumDynamicPermDataPages, NumPermDynamicConvPages, numDynamicReleasedBlocks );
 
     NumPermConvPages = NumPermStaticConvPages + NumPermDynamicConvPages;
     NumReleaseBlocks = numStaticReleasedBlocks + numDynamicReleasedBlocks;
@@ -1470,9 +1532,9 @@ Converter_Converter::EndColdVerify(
 /*---------------------------------------------------------------------------*/
 
 void
-Converter_Converter::EndFailedColdVerify ( const tsp00_TaskId  taskId )
+Converter_Converter::EndFailedCheckData ( const tsp00_TaskId  taskId )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Converter::EndFailedColdVerify", Converter_Trace, 5 );
+    SAPDBTRACE_ROUTINE_DEBUG( "Converter::EndFailedCheckDataWithUpdate", Converter_Trace, 5 );
 
     SAPDBERR_ASSERT_STATE (! BackUpIsActive());
     SAPDBERR_ASSERT_STATE (true == m_ColdVerifyIsActive);
@@ -1658,8 +1720,8 @@ Converter_Converter::SetBlockAddressForMigratedPage (
     // At this time the corresponding converter page entry is invalid (initialized),
     // because the converter is build up the current migration step.
 
-    m_PermMapControl.SetBlockAddressOfRestoredPage(
-        taskId, pageNo, m_SnapShotVersion, block, m_RestoreDataActive);
+    m_PermMapControl.SetBlockAddressOfRestoredPage( taskId, pageNo, m_SnapShotVersion,
+            block, m_RestoreDataActive);
 
     m_NumPermPagesUsed.Increment();
 
@@ -1675,7 +1737,7 @@ Converter_Converter::SetBlockAddressForMigratedPage (
     if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToOccupied( taskId, block ))
     {
         Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
-                                    "permanent", SAPDB_ToString( pageNo, _T_d ));
+                                    SAPDB_ToString( pageNo, _T_d ), "perm");
         RTE_Crash( errMsg );
     }
 }
@@ -1790,11 +1852,11 @@ Converter_Converter::SetNewBlockAddress(
         return( SAPDB_TRUE );
 
     if( recMode.UseStaticPageAddressing() )
-        m_PermStaticMapControl.SetBlockAddressOfRestoredPage(
-        taskId, pageNo, m_SnapShotVersion, blockAddr, m_RestoreDataActive );
+        m_PermStaticMapControl.SetBlockAddressOfRestoredPage( taskId, pageNo,
+                m_SnapShotVersion, blockAddr, m_RestoreDataActive );
     else
-        m_PermMapControl.SetBlockAddressOfRestoredPage(
-        taskId, pageNo, m_SnapShotVersion, blockAddr, m_RestoreDataActive );
+        m_PermMapControl.SetBlockAddressOfRestoredPage( taskId, pageNo,
+                m_SnapShotVersion, blockAddr, m_RestoreDataActive );
 
     return( SAPDB_TRUE );
 }
@@ -1912,9 +1974,10 @@ Converter_Converter::FreePermPageNo(
     {
         Converter_WaitQueue::WaitContext    waitContext;
 
-        mapControl.FreePageNo( taskId, pageConverterVersion, m_SnapShotVersion, pageNo,
-                               waitContext, m_FreePageNoWaitQueue, bWaitUntilSavepointFinished,
-                               bOldBlockIsUsableImmediately, bDoDecrementPermUseCount );
+        mapControl.FreePageNo( taskId, pageConverterVersion, m_SnapShotVersion,
+                               pageNo, waitContext, m_FreePageNoWaitQueue,
+                               bWaitUntilSavepointFinished, bOldBlockIsUsableImmediately,
+                               bDoDecrementPermUseCount );
 
         if( bWaitUntilSavepointFinished )
         {
