@@ -226,7 +226,7 @@ public:
 
     virtual void ReadSnapShotPages(
         const tsp00_TaskId  taskId,
-        const SAPDB_UInt    pagerIndex,
+        SAPDB_UInt          pagerIndex,
         SAPDB_UInt          &totalPages,
         SAPDB_UInt          &totalIO );
 
@@ -309,9 +309,9 @@ public:
         const RTE_VolumeAccessMode VolMode,
         const SAPDB_UInt     NumPagesAdded);
 
-    virtual void BeginSaveData( const tsp00_TaskId taskId );
+    virtual Converter_ReturnCode BeginSaveData( const tsp00_TaskId taskId );
 
-    virtual void BeginSavePages( const tsp00_TaskId taskId );
+    virtual Converter_ReturnCode BeginSavePages( const tsp00_TaskId taskId );
 
     virtual void  EndSave(
         const tsp00_TaskId  taskId,
@@ -349,12 +349,14 @@ public:
         if( Data_Dynamic == AddressingMode )
         {
             m_PermMapControl.SetBlockAddressOfRestoredPage(
-                TaskId, PageNo, m_SnapShotVersion, BlockAddress, m_RestoreDataActive );
+                TaskId, PageNo, m_SnapShotVersion, BlockAddress, 
+                m_RestoreDataActive );
         }
         else if( Data_Static == AddressingMode )
         {
             m_PermStaticMapControl.SetBlockAddressOfRestoredPage(
-                TaskId, PageNo, m_SnapShotVersion, BlockAddress, m_RestoreDataActive );
+                TaskId, PageNo, m_SnapShotVersion, BlockAddress, 
+                m_RestoreDataActive );
         }
     }
 
@@ -552,16 +554,16 @@ public:
         return m_PermStaticMapControl.MaxPageNo();
     }
 
-    virtual void BeginColdVerify( const tsp00_TaskId taskId );
+    virtual Converter_ReturnCode BeginCheckData( const tsp00_TaskId taskId );
 
-    virtual void EndColdVerify(
+    virtual void EndCheckData(
         const tsp00_TaskId  taskId,
         Data_PageCount      &NumStaticPermDataPages,
         Data_PageCount      &NumDynamicPermDataPages,
         Data_PageCount      &NumPermConvPages,
         Data_PageCount      &NumReleaseBlocks );
 
-    virtual void EndFailedColdVerify( const tsp00_TaskId  taskId );
+    virtual void EndFailedCheckData( const tsp00_TaskId  taskId );
 
     virtual void MarkPageNoAsUsed(
         const tsp00_TaskId          taskId,
