@@ -474,7 +474,8 @@ Converter_Map::FreePermPageNo(
     const Converter_Version     &snapShotVersion,
     const Data_PageNo           pageNo,
     IOMan_BlockAddress          &bladdr,
-    SAPDB_Bool                  &oldspr )
+    bool                        &bPageUpdated,
+    bool                        &bPendingPageUpdate )
 {
     SAPDB_Bool deletedPage = false;
 
@@ -487,14 +488,12 @@ Converter_Map::FreePermPageNo(
 
     SAPDBERR_ASSERT_ARGUMENT( section.GetRecoveryMode().PageIsRecoverable());
 
-    if (!page.EntryInUse( pageEntryNo )){
+    if (! page.EntryInUse( pageEntryNo )){
         return Converter_PageNoAlreadyFree;
     }
 
-    // -------------------------------------------------------------------------
-    // retrieve 'save pages requested' flag from converter page
-    // -------------------------------------------------------------------------
-    oldspr = page.SavePagesRequested( pageEntryNo );
+    bPageUpdated       = page.SavePagesRequested( pageEntryNo );
+    bPendingPageUpdate = page.SavePagesPending( pageEntryNo );
 
     page.ReadBlockAddress( pageEntryNo , bladdr);
 
@@ -650,8 +649,9 @@ Converter_Map::SetPermBlockAddress(
     const Data_PageNo           pageNo,
     const IOMan_BlockAddress    &addr,
     IOMan_BlockAddress          &oldaddr,
-    SAPDB_Bool                  &oldspr,
-    SAPDB_Bool                  bRestoreDataActive )
+    bool                        &bPageUpdated,
+    bool                        &bPendingPageUpdate,
+    bool                        bRestoreDataActive )
 {
     const Converter_PageEntryNo pageEntryNo = CalcPageEntryNo( pageNo );
     const Converter_MapEntryNo  entryNo     = CalcEntryNo( pageNo );
@@ -664,9 +664,11 @@ Converter_Map::SetPermBlockAddress(
         return( retCode );
 
     if( bRestoreDataActive )
-        oldspr = page.SavePagesRequested( pageEntryNo );
+        bPageUpdated = page.SavePagesRequested( pageEntryNo );
     else
-        oldspr = page.SetSavePagesRequested( pageEntryNo );
+        bPageUpdated = page.SetSavePagesRequested( pageEntryNo );
+    
+    bPendingPageUpdate = page.SavePagesPending( pageEntryNo );
 
     section.MarkPageAsChanged( entryNo );
 
