@@ -211,6 +211,25 @@ public:
         Converter_PermMapSection    &section,
         Converter_MapEntry          &entry );
 
+    /*!
+       @brief   Mark given converter page as changed 
+       @param   section [in|out] corresponding map section
+       @param   page    [in]     leaf page
+       @return  none
+     */
+
+    void MarkPageAsChanged(
+        Converter_PermMapSection&   section,
+        Converter_LeafPage&         leafPage )
+    {
+        SAPDBERR_ASSERT_ARGUMENT( leafPage.IsAssigned());
+        
+        const Data_PageNo           basePageNo = leafPage.ReadBasePageNo();
+        const Converter_MapEntryNo  entryNo    = CalcEntryNo( basePageNo );
+    
+        section.MarkPageAsChanged( entryNo );
+    }
+
     /* -----------------------------------------------------------------------*/
     /*! @name Pageno management                                               */
     /* -----------------------------------------------------------------------*/
@@ -264,11 +283,12 @@ public:
 
     /*!
        @brief   Puts back the given permanent pageno
-       @param   section     [in/out] corresponding map section
-       @param   snapShotVersion [in] converter version of the snapshot
-       @param   pageNo          [in] specified data pageno
-       @param   bladdr         [out] current i/o address of pageno
-       @param   oldspr         [out] true if save pages was requested for this pageno
+       @param   section          [in|out] corresponding map section
+       @param   snapShotVersion      [in] converter version of the snapshot
+       @param   pageNo               [in] specified data pageno
+       @param   bladdr              [out] current i/o address of pageno
+       @param   bPageUpdated        [out] true if save pages is requested
+       @param   bPendingPageUpdate  [out] true if save pages pending flag is set
        @return  (Converter_ReturnCode)
                 Converter_Ok,
                 Converter_PageNoAlreadyFree
@@ -279,7 +299,8 @@ public:
         const Converter_Version     &snapShotVersion,
         const Data_PageNo           pageNo,
         IOMan_BlockAddress          &bladdr,
-        SAPDB_Bool                  &oldspr );
+        bool                        &bPageUpdated,
+        bool                        &bPendingPageUpdate );
 
     /*!
        @brief   Starts recovery of used pagenos. This method must be called prior to
@@ -382,12 +403,13 @@ public:
 
     /*!
        @brief   Sets i/o address of specified permanent data page
-       @param   section        [in/out] corresponding map section
-       @param   pageNo             [in] specified data pageno
-       @param   addr               [in] block i/o address to be set
-       @param   oldaddr           [out] block i/o address currently occupied
-       @param   oldspr            [out] true if save pages already requested
-       @param   bRestoreDataActive [in] a data recovery is running
+       @param   section          [in|out] corresponding map section
+       @param   pageNo               [in] specified data pageno
+       @param   addr                 [in] block i/o address to be set
+       @param   oldaddr             [out] block i/o address currently occupied
+       @param   bPageUpdated        [out] true if save pages is requested
+       @param   bPendingPageUpdate  [out] true if save pages pending flag is set
+       @param   bRestoreDataActive   [in] a data recovery is running
        @return  (Converter_ReturnCode) Converter_Ok, Converter_PageNoNotReserved
 
        - The i/o address of a given page number 'pageno' is written
@@ -404,8 +426,9 @@ public:
         const Data_PageNo           pageNo,
         const IOMan_BlockAddress    &addr,
         IOMan_BlockAddress          &oldaddr,
-        SAPDB_Bool                  &oldspr,
-        SAPDB_Bool                  bRestoreDataActive = false );
+        bool                        &bPageUpdated,
+        bool                        &bPendingPageUpdate,
+        bool                        bRestoreDataActive = false );
 
     /* -----------------------------------------------------------------------*/
     /*! @name Statistics and info                                             */
