@@ -67,8 +67,8 @@ public:
         filename,
         linenumber,
         CONVERTER_MAP_ERROR,
-    ( recMode.PageIsRecoverable() ? ( recMode.UseDynamicPageAddressing() ? "permanent " : "static ") : "temp " ),
         SAPDB_ToString( pageNo, _T_d ),
+    ( recMode.PageIsRecoverable() ? ( recMode.UseDynamicPageAddressing() ? "perm" : "static") : "temp" ),
         GetErrorText( retCode ))
     {}
 
