@@ -44,6 +44,7 @@
 #include "Converter/Converter_Messages.hpp"
 #include "Converter/Converter_Pager.hpp"
 #include "Converter/Converter_PermMapSection.hpp"
+#include "Converter/Converter_BlockAddressIterator.hpp"
 #include "DataAccess/Data_Types.hpp"
 #include "FreeBlockManagement/FBM_IManager.hpp"
 #include "KernelCommon/Kernel_Dump.hpp"
@@ -108,7 +109,8 @@ Converter_PermMapControl::Initialize(
     const tsp00_RegionId baseRegionId,
     const SAPDB_UInt     numConverterRegions,
     const SAPDB_UInt     clusterSize,
-    const SAPDB_UInt     converterPageSize)
+    const SAPDB_UInt     converterPageSize,
+    SAPDB_Bool           bLastSaveDataSuccessful )
 {
     SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::Initialize", Converter_Trace, 5 );
 
@@ -126,7 +128,8 @@ Converter_PermMapControl::Initialize(
 
     for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
     {
-        m_SectionPermData[ sectionNo ].Initialize( m_Map, m_NumChangedConverterPages );
+        m_SectionPermData[ sectionNo ].Initialize( m_Map,
+                m_NumChangedConverterPages, bLastSaveDataSuccessful );
     }
 
     Converter_PageFrameAllocator frameAlloc;
@@ -174,6 +177,10 @@ Converter_PermMapControl::IntegratePage(
 {
     SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::IntegratePage", Converter_Trace, 5 );
 
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "freeEntryCount            : " << freeEntryCount );
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "numPermPagesUpdated       : " << numPermPagesUpdated );
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "numPendingUpdatedPermPages: " << numPendingUpdatedPermPages );
+
     const Data_PageNo   basePageNo = leafPage.ReadBasePageNo();
     const SAPDB_UInt    sectionNo  = CalculateSectionNo( basePageNo );
 
@@ -280,7 +287,6 @@ Converter_PermMapControl::Expand(
 Converter_ReturnCode
 Converter_PermMapControl::MarkPermPagesForSaveData(
     const tsp00_TaskId  taskId,
-    SAPDB_Bool          bLastSaveDataSuccessful,
     SAPDB_UInt          &numPermConvPages,
     SAPDB_UInt          &numPermPagesForBackUp )
 {
@@ -303,9 +309,8 @@ Converter_PermMapControl::MarkPermPagesForSaveData(
         Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
 
         numPermConvPages += section.GetPageCount();
-        section.IncrementPendingUpdatedPages( section.GetNumUpdatedPages());
-        section.SetNumUpdatedPages( 0 );
 
+        section.FreezeNumUpdatedPages();
 
         // iterator over partially used entry chain
 
@@ -320,8 +325,8 @@ Converter_PermMapControl::MarkPermPagesForSaveData(
         {
             SAPDBERR_ASSERT_STATE( ! (*partUsedIter).PageIsFull() );
 
-            this->MarkPermPagesForSaveData( taskId, (*partUsedIter).GetPage(),
-                                            bLastSaveDataSuccessful, numPermPagesForBackUp );
+            this->MarkPermPagesForSaveData( taskId, section, (*partUsedIter).GetPage(),
+                                            numPermPagesForBackUp );
         }
 
         // iterator over full used entry chain
@@ -337,8 +342,8 @@ Converter_PermMapControl::MarkPermPagesForSaveData(
         {
             SAPDBERR_ASSERT_STATE( (*fullUsedIter).PageIsFull() );
 
-            this->MarkPermPagesForSaveData( taskId, (*fullUsedIter).GetPage(),
-                                            bLastSaveDataSuccessful, numPermPagesForBackUp );
+            this->MarkPermPagesForSaveData( taskId, section, (*fullUsedIter).GetPage(),
+                                            numPermPagesForBackUp );
         }
     }
     return( retCode );
@@ -349,7 +354,6 @@ Converter_PermMapControl::MarkPermPagesForSaveData(
 Converter_ReturnCode
 Converter_PermMapControl::MarkPermPagesForSavePages(
     const tsp00_TaskId      taskId,
-    const SAPDB_Bool        bLastSaveDataSuccessful,
     SAPDB_UInt              &numPermConvPages,
     SAPDB_UInt              &numPermPagesForBackUp,
     const Converter_Version &converterVersion )
@@ -387,9 +391,8 @@ Converter_PermMapControl::MarkPermPagesForSavePages(
         {
             SAPDBERR_ASSERT_STATE( ! (*partUsedIter).PageIsFull() );
 
-            this->MarkPermPagesForSavePages( taskId, (*partUsedIter).GetPage(),
-                                             bLastSaveDataSuccessful, numPermPagesForBackUp,
-                                             converterVersion );
+            this->MarkPermPagesForSavePages( taskId, section, (*partUsedIter).GetPage(),
+                                             numPermPagesForBackUp, converterVersion );
         }
 
         // iterator over full used entry chain
@@ -405,9 +408,8 @@ Converter_PermMapControl::MarkPermPagesForSavePages(
         {
             SAPDBERR_ASSERT_STATE( (*fullUsedIter).PageIsFull() );
 
-            this->MarkPermPagesForSavePages( taskId, (*fullUsedIter).GetPage(),
-                                             bLastSaveDataSuccessful, numPermPagesForBackUp,
-                                             converterVersion );
+            this->MarkPermPagesForSavePages( taskId, section, (*fullUsedIter).GetPage(),
+                                             numPermPagesForBackUp, converterVersion );
         }
     }
     return( retCode );
@@ -607,8 +609,8 @@ Converter_PermMapControl::RemovePageNoFromBackUpPageNoList(
     if( !bPnoFound )
     {
         Converter_Exception errMsg(__CONTEXT__, CONVERTER_PNO_NOT_IN_BACKUP_PNO_LIST,
-                                   ((GetRecoveryMode().UseDynamicPageAddressing()) ? "Permanent" : "Static" ),
-                                   SAPDB_ToString( pageNo, _T_d));
+                                   SAPDB_ToString( pageNo, _T_d),
+                                   ((GetRecoveryMode().UseDynamicPageAddressing()) ? "perm" : "static" ));
         RTE_Message( errMsg );
     }
     return( bPnoFound );
@@ -626,7 +628,8 @@ Converter_PermMapControl::SetBlockAddressOfRestoredPage(
 {
     SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::SetBlockAddressOfRestoredPage", Converter_Trace, 5 );
 
-    SAPDB_Bool          bPageAlreadyUpdated;
+    bool                bPageUpdated;
+    bool                bPendingPageUpdate;
     IOMan_BlockAddress  oldBlock;
 
     SAPDBTRACE_WRITELN( Converter_Trace, 5, "Restore  " <<
@@ -643,7 +646,8 @@ Converter_PermMapControl::SetBlockAddressOfRestoredPage(
         if( (Converter_Ok == retCode) || (Converter_PageNoAlreadyInUse == retCode))
         {
             retCode = m_Map.SetPermBlockAddress( section, pageNo, blockAddress, oldBlock,
-                                                 bPageAlreadyUpdated, bRestoreDataActive );
+                                                 bPageUpdated, bPendingPageUpdate,
+                                                 bRestoreDataActive );
         }
 
         if( Converter_Ok != retCode )
@@ -652,13 +656,9 @@ Converter_PermMapControl::SetBlockAddressOfRestoredPage(
             RTE_Crash( mapError );
         }
 
-        if( bRestoreDataActive ){
-            SAPDBERR_ASSERT_STATE ( !bPageAlreadyUpdated );
+        if( ! bRestoreDataActive ){
+            section.IncrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
         }
-        else
-            if( !bPageAlreadyUpdated ){
-                section.IncrementUpdatedPages();
-            }
     }
 
     if( oldBlock.IsValid() ){
@@ -771,18 +771,34 @@ Converter_PermMapControl::FinishRestoreUsedPageNos(
 /*---------------------------------------------------------------------------*/
 
 void
-Converter_PermMapControl::ResetCounterOfPagesStillMarkedForSavePages(
-    const tsp00_TaskId taskId )
+Converter_PermMapControl::SaveDataFinishedSuccessfuly( const tsp00_TaskId taskId )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::ResetCounterOfPagesStillMarkedForSavePages", Converter_Trace, 5 );
+    SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::SaveDataFinishedSuccessfuly", Converter_Trace, 5 );
 
     for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
     {
         Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
 
-        section.SetNumPendingUpdatedPages( 0 );
+        section.ClearFrozenNumUpdatedPages();
+        section.SetStateOfLastSaveDataToSuccessful();
     }
 }
+
+/*---------------------------------------------------------------------------*/
+
+void
+Converter_PermMapControl::SaveDataFinishedUnSuccessfuly( const tsp00_TaskId taskId )
+{
+    SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::SaveDataFinishedUnSuccessfuly", Converter_Trace, 5 );
+
+    for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
+    {
+        Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
+
+        section.SetStateOfLastSaveDataToUnSuccessful();
+    }
+}
+
 /*---------------------------------------------------------------------------*/
 
 Data_PageNo
@@ -823,6 +839,7 @@ Converter_PermMapControl::ReSetSavepointActiveFlag (
 
 /*---------------------------------------------------------------------------*/
 
+
 void
 Converter_PermMapControl::FreePageNosAfterSavepoint(
     const tsp00_TaskId      taskId,
@@ -831,7 +848,8 @@ Converter_PermMapControl::FreePageNosAfterSavepoint(
     SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::FreePageNosAfterSavepoint", Converter_Trace, 5 );
 
     IOMan_BlockAddress  blockAddress;
-    SAPDB_Bool          bPageWasMarkedForBackUp;
+    bool                bPageUpdated       = false;
+    bool                bPendingPageUpdate = false;
 
 
     for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
@@ -850,21 +868,14 @@ Converter_PermMapControl::FreePageNosAfterSavepoint(
                                 "pageNo: " << pageNo );
 
             const Converter_ReturnCode retCode = m_Map.FreePermPageNo( section, snapShotVersion,
-                                                 pageNo, blockAddress, bPageWasMarkedForBackUp );
+                                                 pageNo, blockAddress, bPageUpdated, bPendingPageUpdate );
             if( Converter_Ok != retCode )
             {
                 Converter_MapError mapError( __CONTEXT__ , GetRecoveryMode(), pageNo, retCode );
                 RTE_Crash( mapError );
             }
 
-            if( bPageWasMarkedForBackUp )
-            {
-                SAPDBERR_ASSERT_STATE( 0 < section.GetNumUpdatedPages() );
-
-                section.DecrementUpdatedPages();
-
-                SAPDBTRACE_WRITELN( Converter_Trace, 5, "UpdatedPermPages: " << section.GetNumUpdatedPages() );
-            }
+            section.DecrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
 
             /* if the block address is not valid the page number was  */
             /* reserved but the page had not been written to a volume */
@@ -928,7 +939,8 @@ Converter_PermMapControl::GetNewPositionForWrite(
 
     // pecondition: pageConverterVersion less than current converter version or invalid
 
-    SAPDB_Bool          bPageAlreadyUpdated;
+    bool                bPageUpdated;
+    bool                bPendingPageUpdate;
     IOMan_BlockAddress  oldBlock;
     const SAPDB_UInt    sectionNo = CalculateSectionNo( pageNo );
 
@@ -939,8 +951,7 @@ Converter_PermMapControl::GetNewPositionForWrite(
         Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
 
         const Converter_ReturnCode retCode = m_Map.SetPermBlockAddress( section, pageNo,
-                                             newBlock, oldBlock, bPageAlreadyUpdated );
-
+                                             newBlock, oldBlock, bPageUpdated, bPendingPageUpdate );
         if( Converter_Ok != retCode )
         {
             Converter_MapError mapError( __CONTEXT__ , GetRecoveryMode(), pageNo, retCode);
@@ -949,9 +960,9 @@ Converter_PermMapControl::GetNewPositionForWrite(
 
         if( pageConverterVersion.IsInvalid())
         {
-            SAPDBERR_ASSERT_STATE (!oldBlock.IsValid() && !bPageAlreadyUpdated);
+            SAPDBERR_ASSERT_STATE (!oldBlock.IsValid() && !bPageUpdated);
 
-            section.IncrementUpdatedPages();
+            section.IncrementUpdatedPages( false, false );
 
             return( Converter_Ok );
         }
@@ -960,9 +971,7 @@ Converter_PermMapControl::GetNewPositionForWrite(
 
         SAPDBERR_ASSERT_STATE ( oldBlock.IsValid() );
 
-        if( ! bPageAlreadyUpdated ){
-            section.IncrementUpdatedPages();
-        }
+        section.IncrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
 
         if( snapShotVersion.IsValid() && ( pageConverterVersion <= snapShotVersion )){
 
@@ -993,7 +1002,8 @@ Converter_PermMapControl::SetPositionForWriting(
 {
     SAPDBTRACE_ROUTINE_DEBUG( "PermMapControl::SetPositionForWriting", Converter_Trace, 5 );
 
-    SAPDB_Bool          bPageAlreadyUpdated;
+    bool                bPageUpdated;
+    bool                bPendingPageUpdate;
     IOMan_BlockAddress  oldBlock;
     const SAPDB_UInt    sectionNo = CalculateSectionNo( pageNo );
 
@@ -1002,7 +1012,7 @@ Converter_PermMapControl::SetPositionForWriting(
         Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
 
         const Converter_ReturnCode retCode = m_Map.SetPermBlockAddress( section, pageNo,
-                                             block, oldBlock, bPageAlreadyUpdated );
+                                             block, oldBlock, bPageUpdated, bPendingPageUpdate );
 
         if( Converter_Ok != retCode )
         {
@@ -1012,15 +1022,12 @@ Converter_PermMapControl::SetPositionForWriting(
 
         if( pageConverterVersion.IsInvalid() )
         {
-            SAPDBERR_ASSERT_STATE (!oldBlock.IsValid() && !bPageAlreadyUpdated);
+            SAPDBERR_ASSERT_STATE (! oldBlock.IsValid() && ! bPageUpdated);
 
-            section.IncrementUpdatedPages();
+            section.IncrementUpdatedPages( false, false );
             return;
         }
-
-        if( !bPageAlreadyUpdated ){
-            section.IncrementUpdatedPages();
-        }
+        section.IncrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
     }
 
     SAPDBERR_ASSERT_STATE ( oldBlock.IsValid() );
@@ -1097,10 +1104,11 @@ Converter_PermMapControl::FreePageNo(
 
         // No Savepoint is active, therefore the given pageNo could be set to free
 
-        SAPDB_Bool  bPageWasMarkedForBackUp = false;
+        bool  bPageUpdated       = false;
+        bool  bPendingPageUpdate = false;
 
         const Converter_ReturnCode retCode = m_Map.FreePermPageNo( section, snapShotVersion,
-                                             pageNo, oldBlock, bPageWasMarkedForBackUp );
+                                             pageNo, oldBlock, bPageUpdated, bPendingPageUpdate );
         if( Converter_Ok != retCode )
         {
             Converter_MapError mapError( __CONTEXT__ , GetRecoveryMode(), pageNo, retCode );
@@ -1110,11 +1118,7 @@ Converter_PermMapControl::FreePageNo(
         if( ! oldBlock.IsValid())
             return;
 
-        if( bPageWasMarkedForBackUp )
-        {
-            SAPDBERR_ASSERT_STATE( 0 < section.GetNumUpdatedPages() );
-            section.DecrementUpdatedPages();
-        }
+        section.DecrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
 
         // Block will be set to FreeAfterSavepoint and therefore he
         // is not available in the current converter version
@@ -1291,13 +1295,17 @@ Converter_PermMapControl::NumUpdatedPermPages( const tsp00_TaskId taskId )
 
     Data_PageCount numUpdatedPermPages = 0;
 
+
     for( SAPDB_UInt sectionNo = 0; sectionNo < GetSectionCount(); ++sectionNo )
     {
         Converter_PermMapSection section( taskId, m_SectionData[ sectionNo ], m_SectionPermData[ sectionNo ]);
 
         numUpdatedPermPages += section.GetNumUpdatedPages();
-        numUpdatedPermPages += section.GetNumPendingUpdatedPages();
     }
+
+    SAPDBTRACE_WRITELN( Converter_Trace, 7, "total updated pages: " <<
+                        numUpdatedPermPages );
+
     return( numUpdatedPermPages );
 }
 
@@ -1460,13 +1468,14 @@ Converter_PermMapControl::ReleaseUnusedPageNosOfOneConverterPage(
             // therefore the entry is not needed anymore
 
             IOMan_BlockAddress  block;
-            SAPDB_Bool          bPageWasMarkedForBackUp;
+            bool                bPageUpdated       = false;
+            bool                bPendingPageUpdate = false;
 
             ++numReleasedBlocks;
 
             const Converter_ReturnCode retCode =
-                m_Map.FreePermPageNo( section, snapShotVersion,
-                                      pageNo, block, bPageWasMarkedForBackUp);
+                m_Map.FreePermPageNo( section, snapShotVersion, pageNo, block,
+                                      bPageUpdated, bPendingPageUpdate );
 
             if( Converter_Ok != retCode )
             {
@@ -1474,18 +1483,13 @@ Converter_PermMapControl::ReleaseUnusedPageNosOfOneConverterPage(
                 RTE_Crash( mapError );
             }
 
-            if( bPageWasMarkedForBackUp )
-            {
-                SAPDBERR_ASSERT_STATE( 0 < section.GetNumUpdatedPages() );
-
-                section.DecrementUpdatedPages();
-            }
+            section.DecrementUpdatedPages( bPageUpdated, bPendingPageUpdate );
 
             SAPDBERR_ASSERT_STATE( block.IsValid());
 
             Converter_Exception errMsg( __CONTEXT__, CONVERTER_PAGENO_NOT_REFERENCED,
-                                        (( bIsDynamic ) ? "permanent" : "static "),
                                         SAPDB_ToString( pageNo, _T_d ),
+                                        (( bIsDynamic ) ? "perm" : "static"),
                                         SAPDB_ToString( block.GetDeviceNo(), _T_d ),
                                         SAPDB_ToString( block.GetBlockNo(), _T_d ));
             RTE_Message( errMsg );
@@ -1522,14 +1526,27 @@ Converter_PermMapControl::ReleaseUnusedPageNosOfOneConverterPage(
 
 void
 Converter_PermMapControl::MarkPermPagesForSaveData(
-    const tsp00_TaskId  taskId,
-    Converter_LeafPage  &leafPage,
-    const SAPDB_Bool    bLastSaveDataSuccessful,
-    SAPDB_UInt          &numPermPagesForBackUp )
+    const tsp00_TaskId          taskId,
+    Converter_PermMapSection    &section,
+    Converter_LeafPage          &leafPage,
+    SAPDB_UInt                  &numPermPagesForBackUp )
 {
     SAPDBERR_ASSERT_STATE( leafPage.ReadPageRecoveryMode().PageIsRecoverable());
     SAPDBERR_ASSERT_STATE( leafPage.GetEntryCount() > 0);
 
+    const bool bLastSaveDataSuccessful = section.IsLastSaveDataSuccessful();
+    bool bConvPageUpdated              = false;
+
+    Converter_BlockAddressIterator leafIter = leafPage.elements();
+
+    if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToBackup( taskId, leafIter ))
+    {
+        Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
+                                    SAPDB_ToString( leafPage.GetPageNo( leafIter.GetPosition()), _T_d),
+                                    ((GetRecoveryMode().UseDynamicPageAddressing()) ? "perm" : "static"));
+        RTE_Crash( errMsg );
+    }
+
     Converter_PageEntryIterator       pageEntryIter    = leafPage.Begin();
     const Converter_PageEntryIterator pageEntryEndIter = leafPage.End();
 
@@ -1546,46 +1563,49 @@ Converter_PermMapControl::MarkPermPagesForSaveData(
             continue;
 
         const Converter_PageEntryNo entryPos = pageEntryIter.GetPosition();
+        const Data_PageNo           pageNo   = leafPage.GetPageNo( entryPos );
 
         SAPDBTRACE_WRITELN( Converter_Trace, 7, "Mark " <<
                             ((GetRecoveryMode().UseDynamicPageAddressing()) ? "permanent " : "static " ) <<
-                            "pageNo: " <<  leafPage.GetPageNo( entryPos ) << " for SaveData" );
+                            "pageNo: " <<  pageNo << " for SaveData" );
 
-        if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToBackup( taskId, block ))
-        {
-            Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
-                                        ((GetRecoveryMode().UseDynamicPageAddressing()) ? "permanent" : "static "),
-                                        SAPDB_ToString( leafPage.GetPageNo( entryPos ), _T_d));
-            RTE_Crash( errMsg );
-        }
-
-        m_BackUpPageNoList.Insert( leafPage.GetPageNo( entryPos ));
+        m_BackUpPageNoList.Insert( pageNo );
         ++numPermPagesForBackUp;
 
         if ( leafPage.SavePagesRequested( entryPos ))
         {
             leafPage.ClearSavePagesRequested( entryPos );
             leafPage.SetSavePagesPending( entryPos );
+            bConvPageUpdated = true;
         }
-        else if( bLastSaveDataSuccessful && leafPage.SavePagesPending( entryPos )){
+        else if( bLastSaveDataSuccessful && leafPage.SavePagesPending( entryPos ))
+        {
+            // pending flag is obsolete, because the last complete backup was successful
+            // and therefore this data page is not part of the next incremental backup
             leafPage.ClearSavePagesPending( entryPos );
+            bConvPageUpdated = true;
         }
     }
+    if( bConvPageUpdated ){
+        m_Map.MarkPageAsChanged( section, leafPage );
+    }
 }
 
 /*---------------------------------------------------------------------------*/
 
 void
 Converter_PermMapControl::MarkPermPagesForSavePages(
-    const tsp00_TaskId      taskId,
-    Converter_LeafPage      &leafPage,
-    const SAPDB_Bool        bLastSaveDataSuccessful,
-    SAPDB_UInt              &numPermPagesForBackUp,
-    const Converter_Version &converterVersion )
+    const tsp00_TaskId          taskId,
+    Converter_PermMapSection    &section,
+    Converter_LeafPage          &leafPage,
+    SAPDB_UInt                  &numPermPagesForBackUp,
+    const Converter_Version     &converterVersion )
 {
     SAPDBERR_ASSERT_STATE( leafPage.ReadPageRecoveryMode().PageIsRecoverable());
     SAPDBERR_ASSERT_STATE( leafPage.GetEntryCount() > 0);
 
+    const bool bLastSaveDataSuccessful = section.IsLastSaveDataSuccessful();
+
     Converter_PageEntryIterator       pageEntryIter    = leafPage.Begin();
     const Converter_PageEntryIterator pageEntryEndIter = leafPage.End();
 
@@ -1598,7 +1618,7 @@ Converter_PermMapControl::MarkPermPagesForSavePages(
         const Converter_PageEntryNo entryPos = pageEntryIter.GetPosition();
 
         if( leafPage.SavePagesRequested( entryPos ) ||
-                (!bLastSaveDataSuccessful && leafPage.SavePagesPending( entryPos )))
+                ( ! bLastSaveDataSuccessful && leafPage.SavePagesPending( entryPos )))
         {
             SAPDBTRACE_WRITELN( Converter_Trace, 7, "Mark " <<
                                 ((GetRecoveryMode().UseDynamicPageAddressing()) ? "permanent " : "static " ) <<
@@ -1607,8 +1627,8 @@ Converter_PermMapControl::MarkPermPagesForSavePages(
             if( SAPDB_TRUE != FBM_IManager::Instance().SetBlockStateToBackup( taskId, pageEntryIter.GetBlockAddress()))
             {
                 Converter_Exception errMsg( __CONTEXT__, CONVERTER_BAD_ENTRY_STATE,
-                                            ((GetRecoveryMode().UseDynamicPageAddressing()) ? "permanent" : "static "),
-                                            SAPDB_ToString( leafPage.GetPageNo( entryPos ), _T_d));
+                                            SAPDB_ToString( leafPage.GetPageNo( entryPos ), _T_d),
+                                            ((GetRecoveryMode().UseDynamicPageAddressing()) ? "perm" : "static "));
                 RTE_Crash( errMsg );
             }
 
