@@ -108,16 +108,17 @@ public:
     /* -----------------------------------------------------------------------*/
     /*!
        @brief   Sets all members of the map control according to the input parameters
-       @param   taskId              [in] taskid
-       @param   maxDataPnoInMap     [in] maximum page number to manage by the converter
-       @param   baseRegionId        [in] start region id of for the first section
-       @param   numConverterRegions [in] the converter is devided into  numConverterRegions
-                                         'little' converter each protected by an own region
-                                         with BaseRegionId &lt;=RegionId&lt;BaseRegionId+
-                                         NumConverterRegions. The more regions are supplied
-                                         the better parallel accesses can be handled
-       @param   clusterSize         [in] number of subsequent map entries building a lock set
-       @param   converterPageSize   [in] total size of a converter page in byte
+       @param   taskId                 [in] taskid
+       @param   maxDataPnoInMap        [in] maximum page number to manage by the converter
+       @param   baseRegionId           [in] start region id of for the first section
+       @param   numConverterRegions    [in] the converter is devided into  numConverterRegions
+                                            'little' converter each protected by an own region
+                                             with BaseRegionId &lt;=RegionId&lt;BaseRegionId+
+                                             NumConverterRegions. The more regions are supplied
+                                             the better parallel accesses can be handled
+       @param   clusterSize             [in] number of subsequent map entries building a lock set
+       @param   converterPageSize       [in] total size of a converter page in byte
+       @param   bLastSaveDataSuccessful [in] last save data finished successfully
        @return  (SAPDB_Bool) returns true if the initilization was successful
      */
 
@@ -127,7 +128,8 @@ public:
         const tsp00_RegionId baseRegionId,
         const SAPDB_UInt     numConverterRegions,
         const SAPDB_UInt     clusterSize,
-        const SAPDB_UInt     converterPageSize );
+        const SAPDB_UInt     converterPageSize,
+        SAPDB_Bool           bLastSaveDataSuccessful );
 
     /*!
        @brief   All resources held by members of the map control are returned.
@@ -246,9 +248,8 @@ public:
                 the flags in the converter which display whether a page has to
                 be included in a incremental backup or not
        @param   taskId [in] task id
-       @param   bLastSaveDataSuccessful [in] Indicates if the last save data finished successfully
-       @param   numPermConvPages        [in] Number of converter leaf pages required to
-                                             manage all permanent data pages of this map control
+       @param   numPermConvPages      [in] Number of converter leaf pages required to
+                                           manage all permanent data pages of this map control
        @param   numPermPagesForBackUp [in] number of permanent pages marked to be included
                                            in this back up (save data)
        @return  (Converter_ReturnCode) if the memory for the container cannot be allocated
@@ -257,7 +258,6 @@ public:
 
     Converter_ReturnCode MarkPermPagesForSaveData(
         const tsp00_TaskId  taskId,
-        SAPDB_Bool          bLastSaveDataSuccessful,
         SAPDB_UInt          &numPermConvPages,
         SAPDB_UInt          &numPermPagesForBackUp );
 
@@ -265,7 +265,6 @@ public:
        @brief   Marks all occupied blocks which have been changed since the last save data in the
                 FBM for back up
        @param   taskId [in] task id
-       @param   bLastSaveDataSuccessful [in] Indicates if the last save data finished successfully
        @param   numPermConvPages [in] Number of converter leaf pages required to manage all permanent
                                       data pages of this map control
        @param   numPermPagesForBackUp [in] number of permanent pages marked to be included in this
@@ -277,7 +276,6 @@ public:
 
     Converter_ReturnCode MarkPermPagesForSavePages(
         const tsp00_TaskId      taskId,
-        const SAPDB_Bool        bLastSaveDataSuccessful,
         SAPDB_UInt              &numPermConvPages,
         SAPDB_UInt              &numPermPagesForBackUp,
         const Converter_Version &converterVersion );
@@ -363,12 +361,12 @@ public:
                 this command updates the converter entry, i.e the block address of the
                 restored page is updated in the converter entry and the old blockaddress
                 is set to free
-       @param   taskId             [in] task id
-       @param   pageNo             [in] page number for which the converter entry
-                                        has to be updated
-       @param   snapShotVersion    [in] converter version of the snapshot
-       @param   blockAddress       [in] new block address to be inserted
-       @param   bRestoreDataActive [in] restore data is running
+       @param   taskId                  [in] task id
+       @param   pageNo                  [in] page number for which the converter entry
+                                             has to be updated
+       @param   snapShotVersion         [in] converter version of the snapshot
+       @param   blockAddress            [in] new block address to be inserted
+       @param   bRestoreDataActive      [in] restore data is running
        @return  none
      */
 
@@ -437,14 +435,24 @@ public:
         SAPDB_Int               &diffNumUsedPages );
 
     /*!
-       @brief   Resets the counter of pages which still need to be included in a save pages.
-                For each section the counter of those pages which were tried to be saved by
-                an earlier but failed save pages is reset.
+       @brief   Inform map control about successfuly complete data backup.
+                This is needed for maintanace of updated perm pages used
+                by the incremental data backup
        @param   taskId [in] TaskId
        @return  none
      */
 
-    void ResetCounterOfPagesStillMarkedForSavePages( const tsp00_TaskId taskId );
+    void SaveDataFinishedSuccessfuly( const tsp00_TaskId taskId );
+
+       /*!
+       @brief   Inform map control about unsuccessfuly complete data backup.
+                This is needed for maintanace of updated perm pages used
+                by the incremental data backup
+       @param   taskId [in] TaskId
+       @return  none
+     */
+
+    void SaveDataFinishedUnSuccessfuly( const tsp00_TaskId taskId );
 
     /* -----------------------------------------------------------------------*/
     /*! @name Savepoint                                                       */
@@ -510,12 +518,12 @@ public:
     /*!
        @brief   Get an i/o adress of an empty block to write a permanent page to
                 a data volume.
-       @param   taskId               [in] identification of calling task
-       @param   pageNo               [in] wanted page
-       @param   pageConverterVersion [in] converter version of the page to write
-       @param   snapShotVersion      [in] converter version of the snapshot
-       @param   bReqSequential       [in] request access mode of volume
-       @param   newBlock            [out] new block address
+       @param   taskId                  [in] identification of calling task
+       @param   pageNo                  [in] wanted page
+       @param   pageConverterVersion    [in] converter version of the page to write
+       @param   snapShotVersion         [in] converter version of the snapshot
+       @param   bReqSequential          [in] request access mode of volume
+       @param   newBlock               [out] new block address
        @return  (Converter_ReturnCode)
      */
     Converter_ReturnCode GetNewPositionForWrite(
@@ -529,14 +537,14 @@ public:
     /*!
        @brief   Updates the block address of a permanent page. The old block
                 address is set to Free or FreeAfterSavepoint.
-       @param   taskId               [in] task id
-       @param   converterVersion     [in] current converter version
-       @param   pageConverterVersion [in] version of the converter when the
-                                          page was written the last time
-       @param   snapShotVersion      [in] converter version of the snapshot
-       @param   pageNo               [in] page number for which the I/o-address hast to
-                                          be updated
-       @param   block                [in] new block address which is to insert
+       @param   taskId                  [in] task id
+       @param   converterVersion        [in] current converter version
+       @param   pageConverterVersion    [in] version of the converter when the
+                                             page was written the last time
+       @param   snapShotVersion         [in] converter version of the snapshot
+       @param   pageNo                  [in] page number for which the I/o-address hast to
+                                             be updated
+       @param   block                   [in] new block address which is to insert
        @return  none
      */
 
@@ -553,13 +561,13 @@ public:
                 the appropriate free chains and counters. The corresponding block is set
                 to freeAfterSavepoint. If the converter slot is already empty an
                 emergency shutdown is executed.
-       @param   taskId               [in] identification of the calling task
-       @param   pageConverterVersion [in] converter version of the page to be freed
-       @param   snapShotVersion      [in] converter version of the snapshot
-       @param   pageNo               [in] page number to release
-       @param   waitContext          [in] wait item
-       @param   freePageNoWaitQueue  [in|out] queue to handle wait situations caused by the
-                                              savepoint
+       @param   taskId                  [in] identification of the calling task
+       @param   pageConverterVersion    [in] converter version of the page to be freed
+       @param   snapShotVersion         [in] converter version of the snapshot
+       @param   pageNo                  [in] page number to release
+       @param   waitContext             [in] wait item
+       @param   freePageNoWaitQueue       [in|out] queue to handle wait situations caused by the
+                                                   savepoint
        @param   bWaitUntilSavepointFinished  [out] true if the action could not be performed
                                                    due to a currently active savepoint
        @param   bOldBlockIsUsableImmediately [out] true if block is set to free and usable
@@ -598,11 +606,11 @@ public:
     /*!
        @brief   Releases all perm pages which are not marked as used in the
                 backup page no container
-       @param   taskId             [in] task id
-       @param   snapShotVersion    [in] converter version of the snapshot
-       @param   numPermDataPages  [out] number of permanent data pages used
-       @param   numPermConPages   [out] number of converter pages used for permanent data pages
-       @param   numReleasesBlocks [out] number of released blocks, which were not referenced during cold verify
+       @param   taskId                  [in] task id
+       @param   snapShotVersion         [in] converter version of the snapshot
+       @param   numPermDataPages       [out] number of permanent data pages used
+       @param   numPermConPages        [out] number of converter pages used for permanent data pages
+       @param   numReleasesBlocks      [out] number of released blocks, which were not referenced during cold verify
        @return  none
      */
     void ReleaseUnusedPageNos (
@@ -711,19 +719,19 @@ protected:
     /// see public method MarkPermPagesForSaveData
 
     void MarkPermPagesForSaveData(
-        const tsp00_TaskId   taskId,
-        Converter_LeafPage   &leafPage,
-        const SAPDB_Bool     bLastSaveDataSuccessful,
-        SAPDB_UInt           &numPermPagesForBackUp );
+        const tsp00_TaskId          taskId,
+        Converter_PermMapSection    &section,
+        Converter_LeafPage          &leafPage,
+        SAPDB_UInt                  &numPermPagesForBackUp );
 
     /// see public method MarkPermPagesForSavePages
 
     void MarkPermPagesForSavePages(
-        const tsp00_TaskId      taskId,
-        Converter_LeafPage      &leafPage,
-        const SAPDB_Bool        bLastSaveDataSuccessful,
-        SAPDB_UInt              &numPermPagesForBackUp,
-        const Converter_Version &converterVersion );
+        const tsp00_TaskId          taskId,
+        Converter_PermMapSection    &section,
+        Converter_LeafPage          &leafPage,
+        SAPDB_UInt                  &numPermPagesForBackUp,
+        const Converter_Version     &converterVersion );
 
     /// see public method ReleaseUnusedPageNos
 
