@@ -223,6 +223,34 @@ public:
     SAPDB_Bool IsSavepointActive(){
         return( SAPDB_TRUE == m_pSectionPermData->m_SavepointIsActive );
     }
+    /*!
+       @brief   This method is used to inform the section about the 
+                successful end of the last complete data backup.
+       @return  none
+    */
+
+    void SetStateOfLastSaveDataToSuccessful(){
+        m_pSectionPermData->m_LastSaveDataSuccessful = SAPDB_TRUE;
+    }
+
+    /*!
+       @brief   This method is used to inform the section about the 
+                unsuccessful end of the last complete data backup.
+       @return  none
+    */
+
+    void SetStateOfLastSaveDataToUnSuccessful(){
+        m_pSectionPermData->m_LastSaveDataSuccessful = SAPDB_FALSE;
+    }
+
+    /*!
+       @brief   Returns true if last complete save data was successful
+       @return  (SAPDB_Bool)
+    */
+
+    SAPDB_Bool IsLastSaveDataSuccessful(){
+        return( SAPDB_TRUE == m_pSectionPermData->m_LastSaveDataSuccessful );
+    }
 
     /*!
        @brief   Increment the number of pending i/o orders. For further
@@ -250,86 +278,82 @@ public:
        @return  SAPDB_UInt
     */
 
-    SAPDB_UInt GetNumUpdatedPages() const{
-        return( m_pSectionPermData->m_NumUpdatedPermPages );
+    SAPDB_UInt GetNumUpdatedPages() const
+    {
+        return 
+            m_pSectionPermData->m_NumUpdatedPermPages 
+            +
+            m_pSectionPermData->m_NumPendingUpdatedPermPages;
     }
 
     /*!
-       @brief   Set the number of updated perm pages. For further information
-                see description of Converter_PermMapSectionData.
-       @param   pageCount [in] new number of updated perm pages
+       @brief   Freeze number of updated perm pages. 
        @return  none
     */
 
-    void SetNumUpdatedPages( const SAPDB_UInt pageCount ){
-        m_pSectionPermData->m_NumUpdatedPermPages = pageCount;
+    void FreezeNumUpdatedPages() 
+    {
+         m_pSectionPermData->m_NumPendingUpdatedPermPages 
+             += m_pSectionPermData->m_NumUpdatedPermPages;
+
+         m_pSectionPermData->m_NumUpdatedPermPages = 0;
     }
 
     /*!
-       @brief   Increment the number of updated perm pages by the given pageCount.
-                Default value for the pageCount is one.
-                For further information see description of Converter_PermMapSectionData.
-       @param   pageCount [in] number of updated perm pages. Default is one.
+       @brief   Clear frozen number of updated perm pages.
        @return  none
     */
 
-    void IncrementUpdatedPages( const SAPDB_UInt pageCount = 1 ){
-        m_pSectionPermData->m_NumUpdatedPermPages += pageCount;
+    void ClearFrozenNumUpdatedPages(){
+        m_pSectionPermData->m_NumPendingUpdatedPermPages = 0;
+    }
+
+    /*!
+       @brief   Increment the number of updated perm pages by one. 
+       @param   bPageIsUpdated         [in] is page marked as updated
+       @param   bPageHasPendingUpdate  [in] is page marked as a pending update, 
+                                            because of a failed complete backup
+       @return  none
+    */
+
+    void IncrementUpdatedPages( 
+        const bool bPageIsUpdated,
+        const bool bPageHasPendingUpdate )
+    {
+        // Do not increase m_NumUpdatedPermPages if page is already counted
+        // as updated or already marked as pending and the last complete 
+        // backup was not successful. In the last case the page is already
+        // counted by m_NumPendingUpdatedPermPages
+
+        if( bPageIsUpdated )
+            return;
+
+        if( this->IsLastSaveDataSuccessful() || ! bPageHasPendingUpdate )
+            m_pSectionPermData->m_NumUpdatedPermPages +=1;
     }
 
     /*!
        @brief   Decrement the number of updated perm pages by one.
-                For further information see description of Converter_PermMapSectionData.
-       @param   pageCount [in] number of updated perm pages.
+       @param   bPageIsUpdated        [in] is page marked as updated
+       @param   bPageHasPendingUpdate [in] is page marked as a pending update, 
+                                           because of a failed complete backup
        @return  none
     */
 
-    void DecrementUpdatedPages(){
-        m_pSectionPermData->m_NumUpdatedPermPages -= 1;
-    }
-
-    /*!
-       @brief   Returns the number of pending updated perm pages. For further information
-                see description of Converter_PermMapSectionData.
-       @return  SAPDB_UInt
-    */
-
-    SAPDB_UInt GetNumPendingUpdatedPages() const{
-        return( m_pSectionPermData->m_NumPendingUpdatedPermPages );
-    }
-
-    /*!
-       @brief   Set the number of pending updated perm pages. For further information
-                see description of Converter_PermMapSectionData.
-       @param   pageCount [in] new number of pending updated perm pages
-       @return  none
-    */
-
-    void SetNumPendingUpdatedPages( const SAPDB_UInt pageCount ){
-        m_pSectionPermData->m_NumPendingUpdatedPermPages = pageCount;
-    }
-
-    /*!
-       @brief   Increment the number of pending updated perm pages by the given pageCount.
-                Default value for the pageCount is one.
-                For further information see description of Converter_PermMapSectionData.
-       @param   pageCount [in] number of pending updated perm pages. Default is one.
-       @return  none
-    */
-
-    void IncrementPendingUpdatedPages( const SAPDB_UInt pageCount = 1 ){
-        m_pSectionPermData->m_NumPendingUpdatedPermPages += pageCount;
-    }
-
-    /*!
-       @brief   Decrement the number of pending updated perm pages by one.
-                For further information see description of Converter_PermMapSectionData.
-       @param   pageCount [in] number of pending updated perm pages.
-       @return  none
-    */
-
-    void DecrementPendingUpdatedPages(){
-        m_pSectionPermData->m_NumPendingUpdatedPermPages -= 1;
+    void DecrementUpdatedPages(
+        const bool bPageIsUpdated,
+        const bool bPageHasPendingUpdate )
+    {
+        if( bPageIsUpdated )
+        {
+            if( this->IsLastSaveDataSuccessful() || ! bPageHasPendingUpdate )
+                m_pSectionPermData->m_NumUpdatedPermPages -=1;
+            else
+                m_pSectionPermData->m_NumPendingUpdatedPermPages -=1;
+            return;
+        }
+        if( ! this->IsLastSaveDataSuccessful() && bPageHasPendingUpdate )
+             m_pSectionPermData->m_NumPendingUpdatedPermPages -=1;
     }
 
     /*!
@@ -385,8 +409,8 @@ public:
         else
             m_pSectionData->m_FullUsedEntryChain.InsertFront( entryNo );
 
-        IncrementUpdatedPages( numPermPagesUpdated );
-        IncrementPendingUpdatedPages( numPendingUpdatedPermPages );
+        m_pSectionPermData->m_NumUpdatedPermPages        += numPermPagesUpdated;
+        m_pSectionPermData->m_NumPendingUpdatedPermPages += numPendingUpdatedPermPages;
 
         CheckIncMaxUsedEntryNo( entryNo );
     }
