@@ -80,6 +80,7 @@ public:
     Converter_PermMapSectionData( SAPDBMem_IRawAllocator  &allocator)
     :
     m_SavepointIsActive( SAPDB_FALSE ),
+    m_LastSaveDataSuccessful( SAPDB_FALSE ),
     m_PendingIO( 0 ),
     m_NumUpdatedPermPages( 0 ),
     m_NumPendingUpdatedPermPages( 0 ),
@@ -94,12 +95,14 @@ public:
                                                   page handler
         @param  numChangedConverterPages [in|out] reference to the map control global
                                                   dirty converter page counter
+        @param   bLastSaveDataSuccessful [in]     last save data finished successfully
         @return true if execution was successful
     */
 
     SAPDB_Bool Initialize(
         Converter_Map                           &map,
-        RTESync_InterlockedCounter<SAPDB_UInt>  &numChangedConverterPages );
+        RTESync_InterlockedCounter<SAPDB_UInt>  &numChangedConverterPages,
+        const SAPDB_Bool                        bLastSaveDataSuccessful );
 
     /*!
        @brief   Dumps the map section information into the kernel dump file.
@@ -135,6 +138,10 @@ private:
 
     SAPDB_Bool  m_SavepointIsActive;
 
+    /// flag is true if last complete databackup was successful
+    
+    SAPDB_Bool m_LastSaveDataSuccessful;
+
     /// Number of pending i/o orders. If only one pager is responsible for
     /// the section, this value could be only zero or one.
 
