@@ -330,7 +330,7 @@ bd10EndColdVerify (tsp00_TaskId taskId,
     Data_PageCount       NumPermConvPages        = 0;
     Data_PageCount       ReleasedBlocks          = 0;
 
-    Converter_IVerify::Instance().EndColdVerify (
+    Converter_IVerify::Instance().EndCheckData (
         taskId,
         NumStaticPermDataPages,
         NumDynamicPermDataPages,
@@ -354,7 +354,7 @@ bd10EndColdVerify (tsp00_TaskId taskId,
 externC void
 bd10EndFailedColdVerify (tsp00_TaskId  TaskId)
 {
-    Converter_IVerify::Instance().EndFailedColdVerify (TaskId);
+    Converter_IVerify::Instance().EndFailedCheckData (TaskId);
 }
 
 /*---------------------------------------------------------------------------*/
@@ -546,9 +546,20 @@ bd10FlushConverterSerial (tgg00_TransContext  &Trans,
    @return         none
  */
 externC void
-bd10BeginColdVerify (tsp00_TaskId TaskId)
+bd10BeginColdVerify ( tgg00_TransContext  &trans )
 {
-    Converter_IVerify::Instance().BeginColdVerify (TaskId);
+    const Converter_ReturnCode retCode =
+        Converter_IVerify::Instance().BeginCheckData (trans.trTaskId_gg00);
+
+    switch( retCode )
+    {
+    case Converter_Ok:
+        return;
+    case Converter_MemoryAllocationFailed:
+        trans.trError_gg00 = e_no_more_memory;
+    default:
+        trans.trError_gg00 = e_system_error;
+    }
 }
 
 /*---------------------------------------------------------------------------*/
