@@ -511,18 +511,19 @@ int main(unsigned argc, char ** argv)
     const char * nameDB="";
     const char * nameDBA="DBA";
     const char * passwordDBA="DBA";
+	const char * node="localhost";
 
     DBMBackCertFill_Output output;
 
     char usageString[]="usage: sdbfill <DBName> (init|create|append|check|delete) [<From> <To>\n"
                        "               [<TransactionLength> [<SleepBeforeCommit> [ (q|a|b) \n"
-                       "               [<DBAUser> <DBAPassword>]]]]]\n";
+                       "               [<DBAUser> <DBAPassword>]]]]] [<node>]\n";
 
     ToolsParsers_ProgramParameterParser parser(
         argc, argv,
         "<DBName> (init|create|append|check|delete) [<From>DEF=0 <To>DEF=0 ["
         "<TransactionLength>DEF=1 [<SleepBeforeCommit>DEF=0 [ (q|a|b) [<dba>DEF=DBA "
-        "<dbapassword>DEF=DBA]]]]]");
+        "<dbapassword>DEF=DBA]]]]] [<node>DEF=localhost]");
 
     const ToolsParsers_ParseResult & parseResult=parser.parse();
 
@@ -571,6 +572,14 @@ int main(unsigned argc, char ** argv)
     }
 
     transactionLength=atoi(parseResult.getVariable("<TransactionLength>").getValue());
+
+	if(transactionLength <= 0 &&
+       (mode==Create || mode== Append || mode==Delete))
+    {
+		output.write(DBMBackCertFill_Output::Error, "<TransactionLength> should be > 0.\n");
+		return retCode;
+	}
+
     sleepToCommit=atoi(parseResult.getVariable("<SleepBeforeCommit>").getValue());
 
     if(parseResult.getKeyword("q").isSet())
@@ -585,6 +594,8 @@ int main(unsigned argc, char ** argv)
     nameDBA=parseResult.getVariable("<dba>").getValue();
     passwordDBA=parseResult.getVariable("<dbapassword>").getValue();
 
+	node=parseResult.getVariable("<node>").getValue();
+
     char errorText[200];
 
     SQLDBC_IRuntime * runtime = GetClientRuntime(errorText, sizeof(errorText));
@@ -598,7 +609,7 @@ int main(unsigned argc, char ** argv)
         SQLDBC::SQLDBC_Environment env(runtime);
 
         SQLDBC_Connection * connection = env.createConnection();
-        SQLDBC_Retcode rcSQL = connection->connect("localhost", nameDB, nameDBA, passwordDBA);
+        SQLDBC_Retcode rcSQL = connection->connect(node, nameDB, nameDBA, passwordDBA);
 
         if(SQLDBC_OK != rcSQL)
         {
