@@ -6,7 +6,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 */
 
@@ -859,15 +860,22 @@ void DBMCli_EventDispatcher::CreateEvent(
 
 
 bool DBMCli_EventDispatcher::isCrash() {
-    // try to connect to DB and check _DIAGSEM parameter    
+    // first check if the DB is online
+    bool isOffline(true);
     SAPDBErr_MessageList list;
-    list.ClearMessageList();
-    bool isOffline(GetState().Refresh(list) && (GetState().Value() == DBMCLI_DBSTATE_OFFLINE));
-    //printf("CRASHTEST dbstate:  %d\n", GetState().Value());
-    list.ClearMessageList();
-    bool isSemSet(GetParameters().Refresh(list) && (GetParameters().GetValueAsInt("_DIAG_SEM") == 1));
-    //printf("CRASHTEST semstate: %d\n", GetParameters().GetValueAsInt("_DIAG_SEM"));
-    return (isOffline && isSemSet);
+    if( DBMCli_Session::Execute("db_state", list) ) {
+        DBMCli_Result result(DBMCli_Session::GetResult());
+        DBMCli_String dbState;
+        DBMCli_Session::GetResult().GetLine(dbState); // read away the word "State"
+        DBMCli_Session::GetResult().GetLine(dbState); // read the real state
+        isOffline = (dbState == DBMCLI_DBSTATE_OFFLINE_STR);
+    }
+
+    if( !isOffline )
+        return false;
+
+    // it's offline, now check _DIAG_SEM parameter    
+    return GetParameters().GetValueAsInt("_DIAG_SEM") == 1;
 }
 
 /*! @brief dispatcher pointer used in main function */
