@@ -144,7 +144,7 @@ tcn00_Error DBMSrvCmd_Explain::runCommand(VControlDataT * vcontrol,
                 {
                     //print command info
                     if(CommandInfo.hasExplanation())
-                        Reply.appendIndentedWrappedLineN(CommandInfo.giveExplanationStart(), CommandInfo.giveExplanationLength(), 0, LineSize, 0);
+                        Reply.appendIndentedWrappedLineN(CommandInfo.giveExplanationStart(), CommandInfo.giveExplanationLength(), 0, LineSize, "<NL>", 0);
                     else
                         Reply.appendStringsAndLine("No explanation is available for command ", CommandInArray->name, ".");
 
@@ -285,13 +285,14 @@ tcn00_Error DBMSrvCmd_Explain::runCommand(VControlDataT * vcontrol,
     }
     else
     {
-        char CommandAsString[51];
+        char   commandAsString[51];
+        size_t len=(CommandEnd-Command>50?50:(CommandEnd-Command));
 
-        strncpy(CommandAsString, Command, CommandEnd-Command>50?50:(CommandEnd-Command));
-        CommandAsString[50]='\0';
+        SAPDB_strncpy(commandAsString, Command, len);
+        commandAsString[len]='\0';
 
         FUNCTION_DBG_MCN00_1("DBMSrvCmd_Explain::Explain");
-        teo200_EventList aEvent(FUNCTION_NAME_MCN00_1, ERR_COMMAND_CN00_1, CommandAsString);
+        teo200_EventList aEvent(FUNCTION_NAME_MCN00_1, ERR_COMMAND_CN00_1, commandAsString);
 
         Reply.startWithEventList(aEvent);
     }
