@@ -177,7 +177,7 @@ void DBMSrv_Command::formatExplainText(CommandT* command, DBMSrv_Reply& theReply
             {
                 //print command info
                 if(CommandInfo.hasExplanation())
-                    theReply.appendIndentedWrappedLineN(CommandInfo.giveExplanationStart(), CommandInfo.giveExplanationLength(), 0, LineSize, 0);
+                    theReply.appendIndentedWrappedLineN(CommandInfo.giveExplanationStart(), CommandInfo.giveExplanationLength(), 0, LineSize, "<NL>", 0);
                 else
                     theReply.appendStringsAndLine("No explanation available for command ", cmdName, ".");
 
