@@ -112,7 +112,8 @@ const DBMSrvMsg_ErrorText& DBMSrvMsg_ErrorTextArray::getErrorText(
 void DBMSrvMsg_ErrorTextArray::initArray() {
 
     //construct local copy of the array
-    DBMSrvMsg_ErrorText tempArray[]=
+    const int sizeTempArray=19;
+    DBMSrvMsg_ErrorText tempArray[sizeTempArray]=
     {
         DBMSrvMsg_ErrorText(DBMSrvMsg_Error::NOBRAIN,         "ERR_NOBRAIN: I know nothing"),
         DBMSrvMsg_ErrorText(DBMSrvMsg_Error::NOBEER,          "ERR_NOBEER: I want to drink %s liters"),
@@ -130,22 +131,32 @@ void DBMSrvMsg_ErrorTextArray::initArray() {
         DBMSrvMsg_ErrorText(DBMSrvMsg_Error::BHIST_EXT_WRITE, "ERR_BHIST_EXT_WRITE: could not write to external backup history file %s"),
         DBMSrvMsg_ErrorText(DBMSrvMsg_Error::MEMORY,          "ERR_MEMORY: required memory could not be allocated from operating system"),
 
+        DBMSrvMsg_ErrorText(DBMSrvMsg_Error::FORMAT_SEPARATORMISSING, "ERR_FORMAT_SEPARATORMISSING: String \"%s\" does not contain the expected separator '%s'"),
+
+        DBMSrvMsg_ErrorText(DBMSrvMsg_Error::MEFDIRTY,        "ERR_MEFDIRTY: Media file '%s' is corrupted at line %s."),
+        DBMSrvMsg_ErrorText(DBMSrvMsg_Error::FORMAT_DELIMISS, "ERR_FORMAT_DELIMISS: Could not find delimiter '%s' within string \"%s\""),
+
         DBMSrvMsg_ErrorText(DBMSrvMsg_Error::LAST_ID,         "ERR: an error occured") // :)
     };
 
     bool tempArraysEndReached=false;
     int  lastIDInTempArray=0;
-    int  i=0;
+    int  i=0,j=0;
 
     //copy temp array into the static member, if there is place
     for(; !tempArraysEndReached && i<DBMSrvMsg_Error::LAST_ID; i++)
     {
-        m_ErrorTextArray[i]=tempArray[i];
+        m_ErrorTextArray[i]=tempArray[j];
 
-        if(int(tempArray[i].getErrorID())==int(DBMSrvMsg_Error::LAST_ID))
+        if(int(tempArray[j].getErrorID())==int(DBMSrvMsg_Error::LAST_ID))
         {
             tempArraysEndReached=true;
-            lastIDInTempArray=i;
+            lastIDInTempArray=j;
+        }
+        else
+        {
+            if(i==tempArray[j].getErrorID())
+                j++;
         }
     }
 
