@@ -62,6 +62,11 @@ public:
         BHIST_EXT_WRITE,/*!< external backup history dbm.ebf could not be written */
         MEMORY,         /*!< required memory could not be allocated */
         
+        FORMAT_SEPARATORMISSING=(238-158),
+
+        MEFDIRTY               =(301-158),
+        FORMAT_DELIMISS        =(302-158),
+
         /* insert new ID one line above */
         LAST_ID         /*!< !!!! this must remain the last enum defined for DBMSrvMsg_Error::ID and must not be used as error ID !!!! */
     };
