@@ -104,10 +104,10 @@ Data_BasePage::CheckAfterRead() const
                 return( SAPDB_TRUE );
             else
             {
-                Data_Exception errMsg( __CONTEXT__, DATA_ERR_CHECKSUM_MISMATCH,
-                                       SAPDB_ToString( CalculateChecksum(), _T_d ),
-                                       SAPDB_ToString( Kernel_Page72::GetPageChecksum(), _T_d ));
-                RTE_Message( errMsg );
+                RTE_Message( Data_Exception( __CONTEXT__, DATA_ERR_BAD_CHECKSUM ));
+                RTE_Message( Data_Exception( __CONTEXT__, DATA_ERR_CHECKSUM_MISMATCH,
+                                             SAPDB_ToString( CalculateChecksum(), _T_d ),
+                                             SAPDB_ToString( Kernel_Page72::GetPageChecksum(), _T_d )));
             }
             break;
         }
@@ -117,18 +117,16 @@ Data_BasePage::CheckAfterRead() const
                 return( SAPDB_TRUE );
             else
             {
-                Data_Exception errMsg( __CONTEXT__, DATA_ERR_WRITE_COUNT_MISMATCH,
-                                       SAPDB_ToString( GetWriteCount(), _T_d ),
-                                       SAPDB_ToString( Kernel_Page72::GetPageChecksum(), _T_d ));
-                RTE_Message( errMsg );
+                RTE_Message( Data_Exception( __CONTEXT__, DATA_ERR_BAD_WRITE_CNT ));
+                RTE_Message( Data_Exception( __CONTEXT__, DATA_ERR_WRITE_CNT_MISMATCH,
+                                             SAPDB_ToString( GetWriteCount(), _T_d ),
+                                             SAPDB_ToString( Kernel_Page72::GetPageChecksum(), _T_d )));
             }
             break;
         }
     default:
         {
-            Data_Exception errMsg( __CONTEXT__, DATA_ERR_INVALID_CHECK_ALGORITHM,
-                                   SAPDB_ToString( GetPageCheck(), _T_d ));
-            RTE_Message( errMsg );
+            RTE_Message( Data_Exception( __CONTEXT__, DATA_ERR_BAD_ALGO ));
         }
     }
     return( SAPDB_FALSE );
@@ -197,7 +195,7 @@ Data_BasePage::IsForArchive() const
 
     const tbd_node *pNode =
         reinterpret_cast <const tbd_node*>(m_Frame.GetPointer( 0, m_Frame.GetLength()));
-    
+
     if( ! pNode->nd_pmode().includes( pmArchive_egg00 ))
         return( SAPDB_FALSE );
 
@@ -293,10 +291,7 @@ Data_BasePage::CheckPageForIO() const
 
     if( Kernel_DataPageType != Kernel_Page::ReadPageType() )
     {
-        Data_Exception ErrMsg( __CONTEXT__, DATA_ERR_BAD_PAGE_TYPE, Kernel_Page::ReadPageTypeName());
-
-
-        RTE_Message( ErrMsg );
+        RTE_Message( Data_Exception(  __CONTEXT__, DATA_ERR_BAD_PAGE_TYPE, Kernel_Page::ReadPageTypeName()));
 
         return( SAPDB_FALSE );
     }
