@@ -288,6 +288,18 @@ public:
         /// this is the iterators break info
         BreakInfo m_BreakInfo;
     };
+private:
+    /// Checks if the given and assumed fix space size is identical to that written into the root page.
+    void CheckFixRecordLength(PageIterator &iter)
+    {
+        if ( (*iter).GetFixRecordLength() != m_FixRecordLength )
+        {
+            this->InfoMessage("ChainFixSizeSpace");
+            RTE_Crash(Data_Exception(__CONTEXT__, DATA_ERROR_CHAIN_FIX_SIZE_MISMATCH,
+                                      SAPDB_ToString(m_FixRecordLength),
+                                      SAPDB_ToString((*iter).GetFixRecordLength()) ));
+        }
+    }
 public:
     /*!
        @param          PAM [in/out] must be used to access pages
@@ -300,11 +312,7 @@ public:
                             Data_RecordLength        FixRecordLength)
     : Data_Chain<PAGE>  (PAM, RootId),
       m_FixRecordLength (FixRecordLength)
-    {
-        #ifdef SAPDB_QUICK
-        CheckFixRecordLength(); // PTS 1114647 for better performance only check in quick
-        #endif
-    }
+    {}
     /*!
        @brief          if the rootid is valid, the given fix-record-size is checked.
        @param          PAM [in/out]  must be used to access pages
@@ -318,11 +326,7 @@ public:
                             Data_RecordLength        FixRecordLength)
     : Data_Chain<PAGE>  (PAM, RootId, LastPageNo),
       m_FixRecordLength (FixRecordLength)
-    {
-        #ifdef SAPDB_QUICK
-        CheckFixRecordLength(); // PTS 1114647 for better performance only check in quick
-        #endif
-    }
+    {}
     /// A new Chain is created. The PageIter points to the root.
     bool Create (PageIterator &RootPageIter)
     {
@@ -348,6 +352,9 @@ public:
               bool            toFirstRecord)
     {
         iter.Assign( pageno, toFirstRecord, accessmode);
+        #ifdef SAPDB_SLOW
+		CheckFixRecordLength(iter.GetPageIterator());
+	    #endif
     }
     /// The RecordIterator is set to the first record in the chain.
     void Begin (Iterator&       iter,
@@ -379,13 +386,12 @@ public:
                        "Data_ChainFixSizeSpace::ReserveSpace: Lock()") );
         }
 
-        Data_PageNo   last     = this->LastPageNo();
         PageIterator &pageiter = iter.m_PageIter;
         
-        if ( ! GetPage (last, Data_ForUpdate, pageiter) )
+        if ( ! GetPage (this->LastPageNo(), Data_ForUpdate, pageiter) )
         {    
             Kernel_VTrace() << "FixChain.reserve: root: " << this->RootId().PageNo()
-                            << ", last: " << last << NewLine;
+                            << ", last: " << this->LastPageNo() << NewLine;
             RTE_Crash( SAPDBErr_Exception(
                        __FILE__, __LINE__,
                        SAPDBERR_ASSERT_STATE_FAILED,
@@ -398,7 +404,7 @@ public:
         {
             PAGE newPage;
                         
-            (*pageiter).Append (newPage, last);
+            (*pageiter).Append (newPage, this->LastPageNo());
 
             newPage.SetFixRecordLength (m_FixRecordLength);
 
@@ -410,7 +416,7 @@ public:
             
             if ( this->m_RootPage.IsAssigned() )
             {
-                this->m_RootPage.SetLastPageNo ((*pageiter).PageNo());
+                this->m_RootPage.SetLastPageNo (this->LastPageNo());
                 this->m_RootPage.SetChanged();
             }
             
@@ -518,31 +524,6 @@ public:
     {
         return m_FixRecordLength;
     }
-private:
-    /// Checks if the given and assumed fix space size is identical to that written into the root page.
-    void CheckFixRecordLength()
-    {
-        if ( this->RootId().IsValid() )
-        {
-            PageIterator RootPageIter (this->GetPageAccessManager());
-
-            Data_Chain<PAGE>::Begin (RootPageIter, Data_ForRead);
-
-            if ( ! RootPageIter.IsValid() )
-            {
-                this->InfoMessage("ChainFixSizeSpace");
-                RTE_Crash(SAPDBErr_Exception(__CONTEXT__,SAPDBERR_ASSERT_STATE_FAILED,"accessing root"));
-            }
-
-            if ( (*RootPageIter).GetFixRecordLength() != m_FixRecordLength )
-            {
-                this->InfoMessage("ChainFixSizeSpace");
-                RTE_Crash(Data_Exception(__CONTEXT__, DATA_ERROR_CHAIN_FIX_SIZE_MISMATCH,
-                                         SAPDB_ToString(m_FixRecordLength),
-                                         SAPDB_ToString((*RootPageIter).GetFixRecordLength()) ));
-            }
-        }
-    }
 private:
     /// the internal cached fix space size
     const Data_RecordLength m_FixRecordLength;
