@@ -52,6 +52,12 @@ public:
                           SAPDB_Byte* &Value) const = 0;
     /// The sum of length of all used parts of the space is returned in bytes.
     virtual SAPDB_UInt Length() const = 0;
+    
+    /*!
+    	@return  false, if space begin is not properly aligned
+    	@brief   This checks if the split space begins at an aligned position
+    */
+    virtual bool CheckAlignment() const = 0;
 };
 /*!
    @class  Data_SplitSpaceWriter
@@ -70,7 +76,7 @@ public:
     };
     /// This is used to write to a split space. Space must be assigned.
     Data_SplitSpaceWriter (Data_ISplitSpace &Space)
-        : m_Space (Space)
+        : m_Space     (Space)
     {
         Reset();
     }
@@ -78,6 +84,7 @@ public:
     void Reset ()
     {
         m_CurrentPart = 0;
+        (void)m_Space.CheckAlignment();
         m_Space.GetPart (m_CurrentPart, m_CurrentLength, m_CurrentValue);
         m_CurrentPartRestLength = m_CurrentLength;
     }
@@ -264,8 +271,8 @@ public:
 
     Data_SplitSpaceReader (Data_ISplitSpace &Space,
                            bool              SpaceCanBeReleased = false) // PTS 1114994 UH 2002-04-17
-        : m_Space (Space),
-          m_SpaceCanBeReleased(SpaceCanBeReleased) // PTS 1114994 UH 2002-04-17
+        : m_Space             (Space)
+        , m_SpaceCanBeReleased(SpaceCanBeReleased) // PTS 1114994 UH 2002-04-17
     {
         Reset();
     }
@@ -273,6 +280,7 @@ public:
     void Reset ()
     {
         m_CurrentPart = 0;
+        (void)m_Space.CheckAlignment();
         m_Space.GetPart (m_CurrentPart, m_CurrentLength, m_CurrentValue);
         m_CurrentPartRestLength = m_CurrentLength;
     }
@@ -519,4 +527,4 @@ private:
     /// space can be released
     bool m_SpaceCanBeReleased; // PTS 1114994 UH 2002-04-17
 };
-#endif // Data_ISplitSpace_HPP
\ No newline at end of file
+#endif // Data_ISplitSpace_HPP
