@@ -42,6 +42,8 @@
 #include "SAPDBCommon/SAPDB_ToString.hpp"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_Assertions.hpp"
 #include "SAPDBCommon/SAPDB_Types.hpp"
+#include "hbd06.h" // b06dump_bad_page
+#include "heo51.h" // vgetpid
 
 /*===========================================================================*
  *  DEFINES                                                                  *
@@ -93,3 +95,16 @@ void Data_Page::Message (const SAPDB_Char *title) const
                         Data_ReleaseModeStrings    [m_ReleaseMode],
                         "0" ) );
 }
+
+//--------------------------------------------------------------------------------
+void Data_Page::Dump() const
+{
+    if ( m_pAccessManager != 0 )
+        m_pAccessManager->WriteBadFileInfo();
+
+    tsp00_TaskId taskid;
+
+    vgetpid(taskid);
+
+    b06dump_bad_page (taskid, 'p', FILE_EXT_COR_BD00, GetPageID(), const_cast<tbd_nodeptr>(NodePtr()), 1);
+}
\ No newline at end of file
