@@ -38,6 +38,7 @@
 
 #include "ggg00.h"
 #include "hbd01_1.h"    // b01nilcurrent
+#include "hbd06.h"      // b06file_opmsg
 #include "hbd13.h"
 #include "hgg01_3.h"
 #include "hgg04.h"      // g04build_temp_tree_id
@@ -430,4 +431,9 @@ void Data_PageAccessManager::FreePageNo (
                                   SAPDB_ToString(m_Current.curr_trans->trError_gg00,_T_d) ) );
 
     m_Current.curr_trans->trError_gg00 = AuxError;
+}/* --------------------------------------------------------------------------- */
+void Data_PageAccessManager::WriteBadFileInfo ()
+{
+    b06file_opmsg (0, m_Current.curr_tree_id);
+    b06write_filename_and_root (m_Current.curr_tree_id);
 }
\ No newline at end of file
