@@ -75,7 +75,7 @@
 #include "SAPDBCommon/SAPDB_ToString.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_IRawAllocator.hpp"
 #include "SQLManager/ErrorHandling/SQLManErr_Interface.hpp"
-
+#include "SAPDBCommon/Algorithms/SAPDBAlgo_QuickSort.hpp"
 
 /*===========================================================================*
  *  DEFINES                                                                  *
@@ -134,6 +134,8 @@ BasisErrorToString( const tgg00_BasisError error )
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
  *===========================================================================*/
 
+namespace {
+
 class ColumnList
 {
 public:
@@ -227,7 +229,7 @@ public:
         return( m_pRec );
     }
 
-    SAPDB_UInt4 GetFrequency() const
+    SAPDB_UInt4 GetDuplicateCount() const
     {
         SAPDBERR_ASSERT_STATE( NULL != m_pRec );
         return( m_pRec->recPno_gg00().gg90GetInt4() );
@@ -251,58 +253,471 @@ private:
 
 /*---------------------------------------------------------------------------*/
 
-class EstimateDistinctValues
+struct DuplicateFrequencyInfo
 {
+    SAPDB_Int duplicateCount;
+    SAPDB_Int frequency;
 
+    bool operator<(const DuplicateFrequencyInfo& si)
+    {
+        return this->duplicateCount < si.duplicateCount;
+    }
+};
+
+typedef Container_Vector< DuplicateFrequencyInfo > FrequencyList;
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgorithm
+{
 public:
+    virtual SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList &dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D) = 0;
 
-    // Estimation algorithm is from Thomas Theodor Koetter (SAP Labs Berlin)
-
-    EstimateDistinctValues(
-        SAPDBMem_IRawAllocator  &allocator,
-        const SAPDB_Real8       numberOfSampledRecords,
-        const SAPDB_Real8       numberOfEstimatedRecords )
-    :
-    m_ColumnList( allocator ),
-    m_SampleRecordCount( numberOfSampledRecords ),
-    m_EstimatedRecordCount( numberOfEstimatedRecords )
+    virtual ~EstimateAlgorithm()
     {}
 
-    ~EstimateDistinctValues(){ m_ColumnList.Delete(); }
-
-    SAPDB_Bool Initialize( const SAPDB_UInt columnCount );
-
-    void AddValue(
-        const SAPDB_UInt    columnId,
-        const SAPDB_UInt4   frequency );
-
-    SAPDB_Real8 Calculate(
-        const SAPDB_UInt  columnId,
-        const SAPDB_Int4  numberOfDistinctValues ) const;
-
-private:
-
-    struct ColumnDistinctValueItem
-    {
-        SAPDB_Real8 cdviTotalProbability;
-        SAPDB_Real8 cdviRecCntWithLimitedFrequency;
-        SAPDB_Real8 cdviRecCntWithLowFrequency;
-        SAPDB_Real8 cdviDistinctRecCntWithLowFrequency;
-#       ifdef SAPDB_QUICK
-        SAPDB_UInt4 cdviFrequency[11];
-#endif
-    };
-
-    typedef Container_Vector< ColumnDistinctValueItem > ColumnList;
-
-private:
-
-    ColumnList  m_ColumnList;
-
-    const SAPDB_Real8   m_SampleRecordCount;
-    const SAPDB_Real8   m_EstimatedRecordCount;
 };
 
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoOriginal : public EstimateAlgorithm
+{
+public:
+
+    virtual SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        return Data_PrimTreeStatistic::EstimateDistinctValuesPerColumn(
+            static_cast<SAPDB_Real8>( psize ),
+            static_cast<SAPDB_Real8>( ssize ),
+            static_cast<SAPDB_Real8>( D ));
+    }
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoShlosser : public EstimateAlgorithm
+{
+public:
+
+    virtual SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        SAPDB_Int8  result;
+        SAPDB_Real8 q    = ssize / (SAPDB_Real8) psize;
+        SAPDB_Real8 pj   = 1.0 - q;
+        SAPDB_Real8 p    = 1.0 - q;
+        SAPDB_Int   j    = 1;
+        SAPDB_Real8 sum1 = 0.0;
+        SAPDB_Real8 sum2 = 0.0;
+        SAPDB_Int8  m1   = 0;
+
+        if ( dl[0].duplicateCount == 1 )
+            m1 = dl[0].frequency;
+
+        for ( SAPDB_UInt i = 0; i < dl.GetSize(); i++ ) {
+            pj = nextpower( pj, j, dl[i].duplicateCount );
+            sum1 += pj * dl[i].frequency;
+
+            sum2 += dl[i].duplicateCount * q * pj/p *dl[i].frequency;
+        }
+
+        if ( sum2 != 0 ) 
+            result = (SAPDB_Int8) (D + m1 * sum1 / sum2);
+        else
+            result = D;
+
+        return result;
+    }
+
+private:
+    double nextpower (SAPDB_Real8 pj, SAPDB_Int8 j, SAPDB_Int8 base) const
+    {
+        SAPDB_Real8 result = pj;
+
+        for ( SAPDB_Int8 i = j; i < base; i++ )
+            result *= pj;
+
+        return result;
+    }
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoSpreadTTK : public EstimateAlgorithm
+{
+public:
+
+    virtual SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        const SAPDB_Int8 limit  = ssize * 5 / 100;       // 5% threshold
+        SAPDB_Int8       sum    = 0;
+        int              length = dl.GetSize();
+        SAPDB_Int8       cpsize = psize;
+        int              stop;
+        double           dist   = 0;
+        double           bucketsize;
+
+        int i;
+        for ( i = length - 1; i > 0; i-- )
+        {
+            long amount = dl[i].frequency * dl[i].duplicateCount;
+            if ( amount > limit )
+                sum += amount;
+            else
+                break;
+        }
+        stop = i+1;
+
+        if ( sum > 0 )
+            cpsize = (long) (psize * (double)(ssize-sum)/(double)ssize);
+
+        bucketsize = cpsize / (double) stop;
+
+        for ( i = 0; i < stop; i++ )
+        {
+            dist += bucketsize / dl[i].duplicateCount + dl[i].frequency;
+        }
+
+        return (SAPDB_Int8) dist;
+    }
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoHybridSO1 : public EstimateAlgorithm
+{
+public:
+
+    SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        // mix result from original algorithm with result from
+        // Shlosser algorithm
+        if ( D < ssize/1000 )
+        {
+            return m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D );
+        }
+
+        double weight1;
+        double weight2;
+
+        double ind = (double) ssize / (double) psize;
+
+        if ( ind < 0.02 )
+        {
+            weight1 = 0.57666;
+            weight2 = 0.42334;
+        }
+        else if ( ind < 0.1 )
+        {
+            weight1 = 0.32167;
+            weight2 = 0.67833;
+        }
+        else
+        {
+            weight1 = 0.11572;
+            weight2 = 0.88428;
+        }
+
+        double hybrid =
+            weight1 * m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D )
+            + weight2 * m_shlosser.EstimateDistinctValueCount(
+                dl, ssize, psize, D );
+
+        return (SAPDB_Int8) (hybrid + .5);
+    }
+private:
+    EstimateAlgoOriginal m_original;
+    EstimateAlgoShlosser m_shlosser;
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoHybridTTK1 : public EstimateAlgorithm
+{
+public:
+
+    SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        // mix result from original with result from
+        // spreadTTK algorithm
+        if ( D < ssize/1000 )
+        {
+            return m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D );
+        }
+
+        double weight1;
+        double weight2;
+
+        double ind = (double) ssize / (double) psize;
+
+        if ( ind < 0.02 )
+        {
+            weight1 = 0.57666;
+            weight2 = 0.42334;
+        }
+        else if ( ind < 0.1 )
+        {
+            weight1 = 0.32167;
+            weight2 = 0.67833;
+        }
+        else
+        {
+            weight1 = 0.11572;
+            weight2 = 0.88428;
+        }
+
+        double hybrid =
+            weight1 * m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D )
+            + weight2 * m_spreadTTK.EstimateDistinctValueCount(
+                dl, ssize, psize, D );
+
+        return (SAPDB_Int8) (hybrid + .5);
+    }
+private:
+    EstimateAlgoOriginal  m_original;
+    EstimateAlgoSpreadTTK m_spreadTTK;
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateAlgoHybridMK1 : public EstimateAlgorithm
+{
+public:
+
+    SAPDB_Int8 EstimateDistinctValueCount(
+        const FrequencyList& dl,
+        const SAPDB_Int8     ssize,
+        const SAPDB_Int8     psize,
+        const SAPDB_Int8     D)
+    {
+        // mix result from original with result from
+        // spreadTTK algorithm
+        if ( D < ssize/1000 )
+        {
+            return m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D );
+        }
+
+        double weight1;
+        double weight2;
+
+        double ind = (double) ssize / (double) psize;
+
+        if ( ind < 0.02 )
+        {
+            weight1 = 0.57666;
+            weight2 = 0.42334;
+        }
+        else if ( ind < 0.1 )
+        {
+            weight1 = 0.32167;
+            weight2 = 0.67833;
+        }
+        else
+        {
+            weight1 = 0.11572;
+            weight2 = 0.88428;
+        }
+
+        const SAPDB_Int8 distEstimateShlo =
+            m_shlosser.EstimateDistinctValueCount( dl, ssize, psize, D );
+        const SAPDB_Int8 distEstimateTTK  =
+            m_spreadTTK.EstimateDistinctValueCount( dl, ssize, psize, D );
+
+        const SAPDB_Int8 maxDistEstimate =
+            distEstimateShlo > distEstimateTTK
+            ? distEstimateShlo : distEstimateTTK;
+
+        double hybrid =
+            weight1 * m_original.EstimateDistinctValueCount(
+                dl, ssize, psize, D )
+            + weight2 * maxDistEstimate;
+
+        return (SAPDB_Int8) (hybrid + .5);
+    }
+private:
+    EstimateAlgoOriginal  m_original;
+    EstimateAlgoShlosser  m_shlosser;
+    EstimateAlgoSpreadTTK m_spreadTTK;
+};
+
+/*---------------------------------------------------------------------------*/
+
+class EstimateDistinctValues
+{
+public:
+    EstimateDistinctValues(
+        SAPDBMem_IRawAllocator& allocator,
+        const SAPDB_UInt8       sampleSize,
+        const SAPDB_UInt8       tableRecordCount)
+        : m_alloc( allocator ),
+          m_frequencyList( allocator ),
+          m_sampleSize( sampleSize ),
+          m_tableRecordCount( tableRecordCount ),
+          m_numberOfDistinctValuesFound( -1 )
+    {
+        SAPDBERR_ASSERT_ARGUMENT( m_sampleSize < m_tableRecordCount );
+
+        // take 10 percent of maximum array size determined by Gau'
+        // summation formula
+        SAPDB_UInt minArraySize = static_cast<SAPDB_UInt>(
+            (-.5 + sqrt( 1.0 + 8.0 * m_sampleSize ) * .5) * 0.1 );
+
+        minArraySize = minArraySize < 10 ? 10 : minArraySize;
+
+        m_frequencyList.Reserve( minArraySize );
+
+        switch ( g01updstatalgo )
+        {
+            case 1:
+                m_pEstimateAlgo = new ( allocator )
+                    EstimateAlgoHybridSO1();
+                break;
+            case 2:
+                m_pEstimateAlgo = new ( allocator )
+                    EstimateAlgoHybridTTK1();
+                break;
+            case 4:
+                m_pEstimateAlgo = new ( allocator )
+                    EstimateAlgoHybridMK1();
+                break;
+            case 3:
+            default:
+                m_pEstimateAlgo = new ( allocator )
+                    EstimateAlgoOriginal();
+                break;
+        }
+    }
+
+    ~EstimateDistinctValues()
+    {
+        destroy ( m_pEstimateAlgo, m_alloc );
+    }
+
+    SAPDB_Bool Initialize(
+        const SAPDB_UInt numberOfDistinctValuesFound )
+    {
+        m_frequencyList.Clear();
+        m_numberOfDistinctValuesFound = numberOfDistinctValuesFound;
+
+        return m_pEstimateAlgo != 0;
+    }
+
+    SAPDB_Bool AddValue(const SAPDB_UInt   duplicateCount)
+    {
+        SAPDB_Bool bInList = false;
+        for ( SAPDB_UInt i = 0; i < m_frequencyList.GetSize(); ++i ) {
+            if ( m_frequencyList[ i ].duplicateCount == duplicateCount ) {
+                m_frequencyList[ i ].frequency++;
+                bInList = true;
+                break;
+            }
+        }
+
+        if ( ! bInList ) {
+            DuplicateFrequencyInfo si;
+            si.duplicateCount = duplicateCount;
+            si.frequency      = 1;
+
+            if ( m_frequencyList.IsFull() ) {
+                SAPDB_Bool bResizeOk =
+                    m_frequencyList.Reserve( m_frequencyList.GetSize() * 2 );
+                // ignore if resize failed
+            }
+
+            return m_frequencyList.InsertEnd( si );
+        }
+
+        return true;
+    }
+
+    SAPDB_Int4 Calculate()
+    {
+        if ( m_sampleSize >= m_tableRecordCount )
+        {
+            // don't estimate if our data is not sound
+            if ( m_numberOfDistinctValuesFound < SAPDB_MAX_INT4 )
+                return static_cast<SAPDB_Int4>( m_numberOfDistinctValuesFound );
+            else
+                return SAPDB_MAX_INT4;
+        }
+
+        if ( m_frequencyList.GetSize() == 0 )
+            return 0;
+
+        SAPDBAlgo_QuickSort(
+            &m_frequencyList[0], m_frequencyList.GetSize() );
+
+        SAPDB_Int8 verifyCounter = 0;
+        for ( SAPDB_UInt i = 0; i < m_frequencyList.GetSize(); ++i ) {
+            verifyCounter +=
+                m_frequencyList[ i ].duplicateCount
+                * m_frequencyList[ i ].frequency;
+        }
+
+        if ( verifyCounter != m_sampleSize ) {
+
+            Kernel_VTrace() << "sampleCount not matched; is "
+                            << verifyCounter
+                            << ", should be " << m_sampleSize;
+            SAPDBERR_ASSERT_STATE( verifyCounter == m_sampleSize );
+            return -1;
+        }
+
+        SAPDB_Int8 result =
+            m_pEstimateAlgo->EstimateDistinctValueCount(
+                m_frequencyList,
+                m_sampleSize,
+                m_tableRecordCount,
+                m_numberOfDistinctValuesFound );
+
+        if ( result < m_numberOfDistinctValuesFound )
+            result = m_numberOfDistinctValuesFound;
+
+        if ( result > SAPDB_MAX_INT4 )
+            result = SAPDB_MAX_INT4;
+
+        return static_cast<SAPDB_Int4>( result );
+    }
+
+private:
+    const SAPDB_Int8        m_sampleSize;
+    const SAPDB_Int8        m_tableRecordCount;
+    SAPDB_Int8              m_numberOfDistinctValuesFound;
+    EstimateAlgorithm      *m_pEstimateAlgo;
+    SAPDBMem_IRawAllocator &m_alloc;
+    FrequencyList           m_frequencyList;
+};
+
+} // end anonymous namespace
+
 /*==========================================================================*
  *  METHODS                                                                  *
  *===========================================================================*/
@@ -322,7 +737,7 @@ Data_PrimTreeStatistic::CalculateColumnStatistic(
 
     const SAPDB_Bool                bCalculate = true;
     TempStatisticRecord             tempRecord( m_Trans );
-    Data_SerializableScanTreeAccess scanTreeAccessor( m_Current );
+    Data_SerializableScanTreeAccess scanTreeAccessor( m_Current, Data_LruMiddle );
 
     if( !tempRecord.Initialize( MAX_RECLEN_GG00 ))
         return; // e_no_more_memory is set
@@ -452,11 +867,11 @@ Data_PrimTreeStatistic::SampleNewColumnStatistic(
 
     const SAPDB_Bool bCalculate             = true;
     const SAPDB_Bool bNoDuplicates          = true;
-    SAPDB_Real8      sampledNumberOfRecords = 0;
-    SAPDB_Real8      sampledNumberOfLeaves  = 0;
+    SAPDB_Int8       sampledNumberOfRecords = 0;
+    SAPDB_Int8       sampledNumberOfLeaves  = 0;
 
     TempStatisticRecord     tempRecord( m_Trans );
-    Data_RandomTreeAccess   randomTreeAccessor( m_Trans, m_Current, leafNodesToSample, ! bNoDuplicates );
+    Data_RandomTreeAccess   randomTreeAccessor( m_Trans, m_Current, leafNodesToSample, bNoDuplicates );
 
     columnFirstPosition -= POS_OFF_DIFF_BD00; // necessary because of pascal and C++ mix
     columnLastPosition  -= POS_OFF_DIFF_BD00; // and the usage as an array index
@@ -489,32 +904,54 @@ Data_PrimTreeStatistic::SampleNewColumnStatistic(
         if( CommandCanceled())
             return;
 
-        sampledNumberOfLeaves  += 1.0;
+        sampledNumberOfLeaves  += 1;
         sampledNumberOfRecords += primPage.GetRecordCount();
     }
 
     if( e_ok == m_TrError )
     {
+        SAPDB_Bool skipEstimation = false;
+
         // estimate records and leaf nodes
-        const SAPDB_Real8 averageNumberOfRecords   = sampledNumberOfRecords / sampledNumberOfLeaves;
-        const SAPDB_Real8 estimatedNumberOfLeaves  = randomTreeAccessor.GetNumberOfEstimatedLeafNodes();
-        const SAPDB_Real8 estimatedNumberOfRecords = averageNumberOfRecords * estimatedNumberOfLeaves;
+        const SAPDB_Int8 avgRecordsPerPage   =
+            static_cast<SAPDB_Int8>(
+                .5 + static_cast<SAPDB_Real8>( sampledNumberOfRecords )
+                / static_cast<SAPDB_Real8>(sampledNumberOfLeaves )
+                );
+        SAPDB_Int8 estimatedPageCount  = randomTreeAccessor.GetNumberOfEstimatedLeafNodes();
 
-        numberOfRecords    = static_cast< Data_PageCount >( estimatedNumberOfRecords );
-        numberOfLeaves     = static_cast< Data_PageCount >( estimatedNumberOfLeaves );
+        if ( sampledNumberOfLeaves > estimatedPageCount )
+        {
+            estimatedPageCount = sampledNumberOfLeaves;
+            skipEstimation = true;
+        }
 
-        // New algorithmen from T.Koetter
+        SAPDB_Int8 estimatedTableRecordCount =
+            static_cast<SAPDB_Int8>(
+                static_cast<SAPDB_Real8>( avgRecordsPerPage )
+                * static_cast<SAPDB_Real8>( estimatedPageCount )
+                );
+        
+        if ( sampledNumberOfRecords > estimatedTableRecordCount )
+        {
+            estimatedTableRecordCount = sampledNumberOfRecords;
+            skipEstimation = true;
+        }
 
-        // estimate distinct values for given columns
-        // Note that the first parameter sampledNumberOfLeaves specifies the numbers of
-        // records used by the prior ColumnStatisticForSinglePage method call. In case of
-        // an estimation only one record of each page is used!
+        if ( ! skipEstimation )
+            NewEstimateNumberOfDistinctValues(
+                estimatedPageCount,
+                estimatedTableRecordCount,
+                sampledNumberOfRecords,
+                columnCount, tempCurrent, distinctValues );
 
-        EstimateNumberOfDistinctValues( sampledNumberOfLeaves, estimatedNumberOfRecords,
-                                        columnCount, tempCurrent, distinctValues );
+        numberOfLeaves = static_cast<SAPDB_Int4>( estimatedPageCount );
 
-        //EstimateNumberOfDistinctValues( sampledNumberOfRecords, estimatedNumberOfRecords,
-        //                                columnCount, tempCurrent, distinctValues );
+        if ( estimatedTableRecordCount < SAPDB_MAX_INT4 )
+            numberOfRecords =
+                static_cast<SAPDB_Int4>( estimatedTableRecordCount );
+        else
+            numberOfRecords = SAPDB_MAX_INT4;
     }
 }
 
@@ -525,9 +962,9 @@ Data_PrimTreeStatistic::CalculateRecordsAndLeaves(
     Data_PageCount  &numberOfLeaves,
     Data_PageCount  &numberOfRecords )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::CalculateRecordsAndLeaves", DataTree_Trace, 5 );
+    SAPDBTRACE_METHOD_DEBUG( "Data_PrimTreeStatistic::CalculateRecordsAndLeaves", DataTree_Trace, 5 );
 
-    Data_SerializableScanTreeAccess scanTreeAccessor( m_Current );
+    Data_SerializableScanTreeAccess scanTreeAccessor( m_Current, Data_LruLast );
 
     numberOfLeaves    = 0;
     numberOfRecords   = 0;
@@ -555,7 +992,7 @@ Data_PrimTreeStatistic::SampleRecordsAndLeaves(
     Data_PageCount          &numberOfLeaves,
     Data_PageCount          &numberOfRecords )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::SampleRecordsAndLeaves", DataTree_Trace, 5 );
+    SAPDBTRACE_METHOD_DEBUG( "Data_PrimTreeStatistic::SampleRecordsAndLeaves", DataTree_Trace, 5 );
 
     SAPDB_Real8 sampledNumberOfRecords = 0;
     SAPDB_Real8 sampledNumberOfLeaves  = 0;
@@ -598,7 +1035,7 @@ Data_PrimTreeStatistic::CalculateTableStatistic(
     const SAPDB_UInt        numberOfLongColumns,
     Kernel_TableStatistic   &tableStatistic )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::SampleRecordsAndLeaves", DataTree_Trace, 5 );
+    SAPDBTRACE_METHOD_DEBUG( "Data_PrimTreeStatistic::SampleRecordsAndLeaves", DataTree_Trace, 5 );
 
     Data_TraverseTreeAccess   traverseTreeAccessor( m_Current );
 
@@ -644,9 +1081,9 @@ Data_PrimTreeStatistic::ColumnStatisticForSinglePage(
     const tgg00_StEntryAddr      pColumnDescription,
     tgg00_ColumnDistinctValues   &distinctValues )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::ColumnStatisticForSinglePage", DataTree_Trace, 6 );
+    SAPDBTRACE_METHOD_DEBUG( "Data_PrimTreeStatistic::ColumnStatisticForSinglePage", DataTree_Trace, 6 );
 
-    const SAPDB_Bool1       bCountDuplicates   = g01newupdstat;
+    const SAPDB_Bool1       bCountDuplicates   = g01updstatalgo > 0;
     const Data_PageCount    recordCount        = primPage.GetRecordCount();
     SAPDB_Int4              currLength;
     SAPDB_Int4              currPosition;
@@ -662,13 +1099,6 @@ Data_PrimTreeStatistic::ColumnStatisticForSinglePage(
             return( SAPDB_FALSE );
     }
 
-    if(( g01newupdstat ) && ( ! bCalculate ) && ( 0 < recordCount ))
-    {
-        // determine one random record for estimation
-        startRecordIndex = rand() % recordCount -1;
-        stopRecordIndex  = startRecordIndex +1;
-    }
-
     for( ; currColumnPosition <= columnLastPosition; currColumnPosition++, currColumnId++ )
     {
         if( IsColumnUnique( pColumnDescription + currColumnPosition ))
@@ -850,35 +1280,34 @@ Data_PrimTreeStatistic::TableStatisticForSingleNonLeafPage(
 /*---------------------------------------------------------------------------*/
 
 void
-Data_PrimTreeStatistic::EstimateNumberOfDistinctValues(
-    const SAPDB_Real8            numberOfRecords,
-    const SAPDB_Real8            estimatedNumberOfRecords,
+Data_PrimTreeStatistic::NewEstimateNumberOfDistinctValues(
+    const SAPDB_Int8             estimatedNumberOfLeafPages,
+    const SAPDB_Int8             estimatedNumberOfTableRecords,
+    const SAPDB_Int8             sampleSize,
     const SAPDB_Int2             columnCount,
     tbd_current_tree             &tempCurrent,
     tgg00_ColumnDistinctValues   &distinctValues )
 {
-    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::EstimateNumberOfDistinctValues", DataTree_Trace, 6 );
+    SAPDBTRACE_ROUTINE_DEBUG( "Data_PrimTreeStatistic::NewEstimateNumberOfDistinctValues", DataTree_Trace, 6 );
 
-    SAPDB_Int2              currColumnId = 0;
-    SAPDB_UInt4             frequency    = 0;
-    Data_ScanTreeAccess     scanTreeAccessor( tempCurrent );
+    Data_ScanTreeAccess     scanTreeAccessor( tempCurrent, Data_LruMiddle );
     TempStatisticRecord     tempRecord( m_Trans );
-    EstimateDistinctValues  estimateDistinctValues( GetAllocator( m_Trans ), numberOfRecords, estimatedNumberOfRecords );
 
-    if( ! estimateDistinctValues.Initialize( columnCount ))
-    {
-        m_TrError = e_no_more_memory;
-        return;
-    }
-#   ifdef SAPDB_QUICK
+    EstimateDistinctValues  estimateDistinctValues(
+        GetAllocator( m_Trans ),
+        sampleSize,
+        estimatedNumberOfTableRecords );
+
+#   ifdef SAPDB_SLOW
     if( DataTree_Trace.TracesLevel( 6 ))
     {
         Kernel_VTrace() << "ESTIMATE DISTINCT VALUES " << NewLine <<
-        "#sampled records (n): " << numberOfRecords <<
-        " estimated records (N): " << estimatedNumberOfRecords << NewLine;
+        "#sampled records (n): " << sampleSize <<
+        " estimated records (N): " << estimatedNumberOfTableRecords << NewLine;
     }
 #   endif
 
+    SAPDB_Int curColumnId = -1;
     while( e_ok == m_TrError )
     {
         Data_PrimPage &tempPage = scanTreeAccessor.GetLeafNode();
@@ -888,31 +1317,56 @@ Data_PrimTreeStatistic::EstimateNumberOfDistinctValues(
 
         const Data_PageCount recordCount = tempPage.GetRecordCount();
 
-        for( Data_RecordIndex recordIndex = FIRST_REC_INDEX_BD00; recordIndex < recordCount; recordIndex++ )
+        for( Data_RecordIndex recordIndex = FIRST_REC_INDEX_BD00;
+             recordIndex < recordCount;
+             recordIndex++ )
         {
             tgg00_Rec* pTempRecord = tempPage.GetRecord( recordIndex );
 
             tempRecord.AssignRecord( pTempRecord );
 
-            currColumnId  = tempRecord.GetColumnId();
-            frequency     = tempRecord.GetFrequency();
+            SAPDB_Int columnId       = tempRecord.GetColumnId();
+            SAPDB_Int duplicateCount = tempRecord.GetDuplicateCount();
 
-            estimateDistinctValues.AddValue( currColumnId, frequency );
+            if ( columnId != curColumnId ) {
+                if ( curColumnId != -1 ) {
+                    distinctValues[ curColumnId ] =
+                        estimateDistinctValues.Calculate();
+                    if ( distinctValues[ curColumnId ] == -1 )
+                        m_TrError = e_system_error;
+
+#                   ifdef SAPDB_SLOW
+                    if( DataTree_Trace.TracesLevel( 6 ))
+                    {
+                        Kernel_VTrace()
+                            << "Distinct value: "
+                            << distinctValues[ curColumnId ] << NewLine;
+                    }
+#                   endif
+                }
+
+                curColumnId = columnId;
+
+                estimateDistinctValues.Initialize(
+                    distinctValues[ curColumnId ] );
+            }
+
+            if ( ! estimateDistinctValues.AddValue( duplicateCount ) )
+                m_TrError = e_no_more_memory;
         }
     }
 
-    SAPDBERR_ASSERT_STATE( estimatedNumberOfRecords >= numberOfRecords );
-
-    for( currColumnId = 0; currColumnId < columnCount; currColumnId++ )
-    {
-        distinctValues[ currColumnId ] = static_cast< SAPDB_Int4 >
-                                         ( estimateDistinctValues.Calculate( currColumnId, distinctValues[ currColumnId ] ));
-#   ifdef SAPDB_QUICK
+    if ( curColumnId != -1 ) {
+        distinctValues[ curColumnId ] =
+            estimateDistinctValues.Calculate();
+        if ( distinctValues[ curColumnId ] == -1 )
+            m_TrError = e_system_error;
+#       ifdef SAPDB_SLOW
         if( DataTree_Trace.TracesLevel( 6 ))
         {
-            Kernel_VTrace() << "Distinct value: " << distinctValues[ currColumnId ] << NewLine;
+            Kernel_VTrace() << "Distinct value: " << distinctValues[ curColumnId ] << NewLine;
         }
-#   endif
+#       endif
     }
 }
 
@@ -1190,8 +1644,9 @@ TempStatisticRecord::AssignKey(
     SAPDBERR_ASSERT_STATE( NULL != m_pRec );
     SAPDBERR_ASSERT_STATE( 0 != m_Capacity );
 
-    if( keyLength > MAX_KEYLEN_GG00 )
-        keyLength = MAX_KEYLEN_GG00; // TODO LATER handle columns longer than 1024
+    const SAPDB_Int cMaxRecKeyLength = MAX_KEYLEN_GG00 - sizeof( columnId );
+    if( keyLength > cMaxRecKeyLength )
+        keyLength = cMaxRecKeyLength; // TODO LATER handle columns longer than 1024
 
     m_pRec->recLen_gg00()          = cgg_rec_key_offset + sizeof( columnId ) + keyLength;
     m_pRec->recKeyLen_gg00()       =  sizeof( columnId ) + keyLength;
@@ -1262,106 +1717,6 @@ TempStatisticRecord::Delete()
 /*---------------------------------------------------------------------------*/
 /*---------------------------------------------------------------------------*/
 
-SAPDB_Bool
-EstimateDistinctValues::Initialize( const SAPDB_UInt    columnCount )
-{
-    if( ! m_ColumnList.Initialize( columnCount ))
-        return( false );
-
-    ColumnList::Iterator iter    = m_ColumnList.Begin();
-    ColumnList::Iterator endIter = m_ColumnList.End();
-
-    while( iter != endIter )
-    {
-        ( *iter ).cdviTotalProbability               = 0; // SUM( P(i) * I( n*P(i)*(1-P(i))<9.0 ))
-        ( *iter ).cdviRecCntWithLimitedFrequency     = 0; // SUM( P(i)*I( n*P(i)*(1-p(i)) < 9.0) * I(m(i)>2))
-        ( *iter ).cdviRecCntWithLowFrequency         = 0; // n~
-        ( *iter ).cdviDistinctRecCntWithLowFrequency = 0; // m~
-#       ifdef SAPDB_QUICK
-        for( SAPDB_UInt i = 0; i < 11; i++ )
-            ( *iter ).cdviFrequency[i] = 0;
-#       endif
-        iter++;
-    }
-    return( true );
-}
-
-/*---------------------------------------------------------------------------*/
-
-void
-EstimateDistinctValues::AddValue(
-    const SAPDB_UInt    columnId,
-    const SAPDB_UInt4   frequency )
-{
-    SAPDBERR_ASSERT_STATE( m_ColumnList.GetSize() > columnId  );
-
-    const SAPDB_Real8 probability = frequency / m_SampleRecordCount;
-
-    if(( m_SampleRecordCount * probability * ( 1.0 - probability )) < 9.0 )
-    {
-        m_ColumnList[ columnId ].cdviTotalProbability += probability;
-
-        if( 2 < frequency )
-            m_ColumnList[ columnId ].cdviRecCntWithLimitedFrequency += probability;
-
-        m_ColumnList[ columnId ].cdviRecCntWithLowFrequency +=frequency; // n~
-        m_ColumnList[ columnId ].cdviDistinctRecCntWithLowFrequency++;   // m~
-
-#       ifdef SAPDB_QUICK
-        if(( 0 < frequency ) && (11 > frequency ))
-            m_ColumnList[ columnId ].cdviFrequency[ frequency ]++;
-#endif
-    }
-}
-
-/*---------------------------------------------------------------------------*/
-
-SAPDB_Real8
-EstimateDistinctValues::Calculate(
-    const SAPDB_UInt  columnId,
-    const SAPDB_Int4  numberOfDistinctValues ) const
-{
-    SAPDBERR_ASSERT_STATE( m_ColumnList.GetSize() > columnId  );
-
-    /* r = SUM( P(i) * I( n*P(i)*(1-P(i))<9.0)) - 0.5*SUM( P(i)*I( n*P(i)*(1-p(i)) < 9.0) * I(m(i)>2))   */
-    const SAPDB_Real8 tempResult1 =
-        m_ColumnList[ columnId ].cdviTotalProbability - 0.5 * m_ColumnList[ columnId ].cdviRecCntWithLimitedFrequency;
-
-    /* m~ DIV n~ */
-
-    SAPDB_Real8 tempResult2 = 0;
-    if( 0 < m_ColumnList[ columnId ].cdviRecCntWithLowFrequency )
-        tempResult2 = ( m_ColumnList[ columnId ].cdviDistinctRecCntWithLowFrequency / m_ColumnList[ columnId ].cdviRecCntWithLowFrequency );
-
-    /* M = (m - m~) + N * r * (m~ DIV n~) */
-    const SAPDB_Real8 result =
-        ( numberOfDistinctValues - m_ColumnList[ columnId ].cdviDistinctRecCntWithLowFrequency ) +
-        m_EstimatedRecordCount * tempResult1 * tempResult2;
-
-#   ifdef SAPDB_QUICK
-    if( DataTree_Trace.TracesLevel( 6 ))
-    {
-        Kernel_VTrace() <<
-        "ColumnId: " << columnId << NewLine <<
-        " m  : "  << numberOfDistinctValues <<
-        " m~ : " << m_ColumnList[ columnId ].cdviDistinctRecCntWithLowFrequency <<
-        " n~ : " << m_ColumnList[ columnId ].cdviRecCntWithLowFrequency <<
-        " r  : " << tempResult1 << NewLine <<
-        " n(1) : " << m_ColumnList[ columnId ].cdviFrequency[1]   << NewLine <<
-        " n(2) : " << m_ColumnList[ columnId ].cdviFrequency[2]   << NewLine <<
-        " n(3) : " << m_ColumnList[ columnId ].cdviFrequency[3]   << NewLine <<
-        " n(4) : " << m_ColumnList[ columnId ].cdviFrequency[4]   << NewLine <<
-        " n(5) : " << m_ColumnList[ columnId ].cdviFrequency[5]   << NewLine <<
-        " n(6) : " << m_ColumnList[ columnId ].cdviFrequency[6]   << NewLine <<
-        " n(7) : " << m_ColumnList[ columnId ].cdviFrequency[7]   << NewLine <<
-        " n(8) : " << m_ColumnList[ columnId ].cdviFrequency[8]   << NewLine <<
-        " n(9) : " << m_ColumnList[ columnId ].cdviFrequency[9]   << NewLine <<
-        " n(10) : " << m_ColumnList[ columnId ].cdviFrequency[10] << NewLine;
-    }
-#   endif
-
-    return( result );
-}
 
 /*===========================================================================*
  *  END OF CODE                                                              *
