@@ -81,7 +81,9 @@
  *===========================================================================*/
 
 
-class TempStatisticRecord;
+namespace {
+    class TempStatisticRecord;
+}
 
 /*!*****************************************************************************
 
@@ -281,6 +283,11 @@ public:
         const SAPDB_UInt        numberOfLongColumns,
         Kernel_TableStatistic   &tableStatistic );
 
+    static SAPDB_Int4 EstimateDistinctValuesPerColumn(
+        const SAPDB_Real8   estimatedNumberOfRecords,
+        const SAPDB_Real8   sampledNumberOfRecords,
+        const SAPDB_Real8   distinctInSample );
+
     /* -----------------------------------------------------------------------*/
     /*! endchapter: Determine statistics                                      */
     /* -----------------------------------------------------------------------*/
@@ -318,9 +325,10 @@ private:
         Data_PrimPage           &primPage,
         Kernel_TableStatistic   &tableStatistic );
 
-    void EstimateNumberOfDistinctValues(
-        const SAPDB_Real8            numberOfRecords,
-        const SAPDB_Real8            estimatedNumberOfRecords,
+    void NewEstimateNumberOfDistinctValues(
+        const SAPDB_Int8             estimatedNumberOfLeafPages,
+        const SAPDB_Int8             estimatedNumberOfTableRecords,
+        const SAPDB_Int8             sampleSize,
         const SAPDB_Int2             columnCount,
         tbd_current_tree             &tempCurrent,
         tgg00_ColumnDistinctValues   &distinctValues );
@@ -331,11 +339,6 @@ private:
         const SAPDB_Int2             columnCount,
         tgg00_ColumnDistinctValues   &distinctValues );
 
-    SAPDB_Int4 EstimateDistinctValuesPerColumn(
-        const SAPDB_Real8   estimatedNumberOfRecords,
-        const SAPDB_Real8   sampledNumberOfRecords,
-        const SAPDB_Real8   distinctInSample );
-
     SAPDB_Bool DataBaseFull( const Data_PageCount   numPagesRequested );
 
     SAPDB_Bool CommandCanceled();
