@@ -256,7 +256,7 @@ inline void TestBackwardChainSplitSpaceNegative
     // PTS 1117126 UH 2002-08-07 new
     SAPDBTRACE_ROUTINE_DEBUG ("Data_Test::TestBackwardChainSplitSpaceNegative", DataChain_Trace, 5);
 
-    SAPDB_Byte                    Block [65536-1];
+    SAPDB_Byte                    Block [65536];
     Data_SplitSpaceWriter::Result WriteResult;
 
     Iter.WriteToTrace ("TestBackwardChainSplitSpaceNegative1");
@@ -439,62 +439,43 @@ inline void StartTestFixSizeChain (tgg00_TransContext &Trans)
 
 
 /* --------------------------------------------------------------------------- */
-inline void TestTempFile (tgg00_TransContext     &trans,
-                          SAPDBMem_IRawAllocator &allocator)
+inline void TestTempFile (tgg00_TransContext &trans)
 {
-    SAPDB_UInt4   record       = 4711;
-    SAPDB_Byte   *recordSpace  = reinterpret_cast<SAPDB_Byte*>(&record);
-    bool          result       = true;
-    Data_TempFile                 file1 (trans, sizeof(record) );
-    Data_TempFile                 file2 (trans, sizeof(record) );
-    Data_TempFile::RecordIterator iter1 (file1.PageAccessManager());
-    Data_TempFile::RecordIterator iter2 (file1.PageAccessManager());
+    const int     MaxLoopCount = 10000;
+    SAPDB_UInt4   record;
+    bool          result = true;
+    int           loop; 
+    Data_TempFile file (trans, sizeof(record) );
+    //-----------------------------------------------------------------------
+    result = file.Create();
+    Check ("file.Create()", result);
+    //-----------------------------------------------------------------------
+    for ( loop = 0; loop < MaxLoopCount; ++loop )
+    {
+        record = loop;
+        result = file.Append (reinterpret_cast<const SAPDB_Byte*>(&record));
+        Check ("file.Append()", result);
+    }
+    //-----------------------------------------------------------------------
+    result = file.Verify(Kernel_IAdminInfo::Instance().KernelStateIsAdmin());
+    Check ("file.Verify()", result);
+    //-----------------------------------------------------------------------
+    Data_TempFile::RecordIterator iter (file.PageAccessManager());
 
-    result = file1.Create();
-    Check ("file1.Create()", result);
-    result = file2.Create();
-    Check ("file2.Create()", result);
-
-    result = file1.Append (recordSpace);
-    Check ("file1.Append()", result);
-
-    record = 4712;
-    
-    result = file2.Append (recordSpace);
-    Check ("file2.Append()", result);
-
-    result = file1.GetFirst (iter1);
-    Check ("file1.GetFirst()",  result);
-    Check ("iter1.IsValid()", iter1.IsValid());
-    iter1.WriteToTrace("iter1 is ok");
-    Check ("*iter1 == 4711", *(reinterpret_cast<SAPDB_UInt4*>(*iter1)) == 4711 );
-
-    result = file2.GetFirst (iter2);
-    Check ("file2.GetFirst()",  result);
-    Check ("iter2.IsValid()", iter2.IsValid());
-    iter2.WriteToTrace("iter2 is ok");
-    Check ("*iter2 == 4711", *(reinterpret_cast<SAPDB_UInt4*>(*iter2)) == 4712 );
-
-    iter1.Invalidate();
-    iter2.Invalidate();
-
-    result = file1.Verify(Kernel_IAdminInfo::Instance().KernelStateIsAdmin());
-    Check ("file1.Verify()", result);
-    result = file2.Verify(Kernel_IAdminInfo::Instance().KernelStateIsAdmin());
-    Check ("file2.Verify()", result);
-    
-    file1.Drop();
-    Check ("! file1.IsCreated()", ! file1.IsCreated());
-    file2.Drop();
-    Check ("! file2.IsCreated()", ! file2.IsCreated());
-
-    Data_TempFile copiedFile (file1);
-
-    Container_Vector<Data_TempFile>                 files     (allocator);
-    Container_Vector<Data_TempFile::RecordIterator> iterators (allocator);
-
-    files.InsertEnd(file1);
-    iterators.InsertEnd(iter1);
+    result = file.GetFirst (iter);
+    Check ("file.GetFirst()",  result);
+ 
+    for ( loop = 0; loop < MaxLoopCount; ++loop )
+    {
+        Check ("iter.IsValid()", iter.IsValid());
+        Check ("*iter == loop", *(reinterpret_cast<SAPDB_UInt4*>(*iter)) == loop );
+        ++iter;
+    }
+    Check ("! iter.IsValid()", ! iter.IsValid());
+    // iter.Invalidate();
+    //-----------------------------------------------------------------------
+    file.Drop();
+    Check ("! file.IsCreated()", ! file.IsCreated());
 }
 
 /* --------------------------------------------------------------------------- */
@@ -502,20 +483,13 @@ externCpp void Data_Test (tgg00_TransContext& Trans)
 {
     SAPDBTRACE_ROUTINE_DEBUG ("Data_Test", DataChain_Trace, 5);
 
-    // SAPDBMem_DougLeaAllocator
-    // SAPDBMem_IncrementalRawAllocator& Allocator =
-    SAPDBMem_IRawAllocator& Allocator =
-        *( REINTERPRET_CAST(SAPDBMem_IRawAllocator*, Trans.trAllocator_gg00) );
-
-    // Initialize the personell data cache interface.
+    SAPDBMem_IRawAllocator& Allocator = *( REINTERPRET_CAST(SAPDBMem_IRawAllocator*, Trans.trAllocator_gg00) );
 
     ChainTest                        (Trans);
     StartTestBackwardChainSplitSpace (Trans, Allocator);
     StartTestForwardChainSplitSpace  (Trans, Allocator);
     StartTestFixSizeChain            (Trans);
-    
-    // fast compiler and linker test of new primary file implementation
-    Data_PrimaryFile file (Trans);
-    
-    // TestTempFile (Trans, Allocator);
+    TestTempFile                     (Trans);
+
+    Data_PrimaryFile file (Trans); // fast compiler and linker test of new primary file implementation
 }
