@@ -212,6 +212,27 @@ private:
     /// recovery mode
     Data_Recoverability     m_Recoverability;
 };
+/// get page recovery mode strings for given recoveryMode
+inline const SAPDB_Char*
+Data_PageRecModeStrings( const Data_PageRecoveryMode   &recMode )
+{
+    if( Data_Static      == recMode.GetAddressingMode() && 
+        Data_Recoverable == recMode.GetRecoverability())
+    {
+        return(( SAPDB_Char* )"static" );
+    }
+    if( Data_Dynamic     == recMode.GetAddressingMode() &&
+        Data_Recoverable == recMode.GetRecoverability())
+    {
+        return(( SAPDB_Char* )"perm" );
+    }
+    if( Data_Dynamic        == recMode.GetAddressingMode() &&
+        Data_NotRecoverable == recMode.GetRecoverability())
+    {
+        return(( SAPDB_Char* )"temp" );
+    }
+    return(( SAPDB_Char* )"unknown" );
+}
 /*!
     @class  Data_PageId
     @brief  page no plus recoverymode
