@@ -51,7 +51,7 @@ SAPDBERR_DEFINE_COMPONENT_EXCEPTION_CLASS( FBM );
   @brief          FBM exception for illegal state transistions
  */
 
-class FBM_IllegalTransition : public FBM_Exception 
+class FBM_IllegalTransition : public FBM_Exception
 {
 public:
     /*!
@@ -67,28 +67,28 @@ public:
        @return         none
 
        - Constructor of an error message. The error occurs when the FBM is ask to
-	     change the state of a block in a way which is not permitted
+      change the state of a block in a way which is not permitted
      */
     FBM_IllegalTransition
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               BlockNo,
-         const FBM_BlockState           OldBlockState,
-         const FBM_BlockState           OldBackUpBlockState,
-         const FBM_BlockState           NewBlockState,
-         const FBM_BlockState           NewBackUpBlockState
-         )
-        :
-        FBM_Exception
-            (filename, linenumber,
-             FBM_ILLEGAL_TRANSITION,
-             SAPDB_ToString(DevNo, _T_d),
-             SAPDB_ToString(BlockNo, _T_d),
-             SAPDB_ToString(OldBlockState, _T_d),
-             SAPDB_ToString(OldBackUpBlockState, _T_d),
-             SAPDB_ToString(NewBlockState, _T_d),
-             SAPDB_ToString(NewBackUpBlockState, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               BlockNo,
+     const FBM_BlockState           OldBlockState,
+     const FBM_BlockState           OldBackUpBlockState,
+     const FBM_BlockState           NewBlockState,
+     const FBM_BlockState           NewBackUpBlockState
+    )
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_ILLEGAL_TRANSITION,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(BlockNo, _T_d),
+     FBM_BlockStateStrings( OldBlockState ),
+     FBM_BlockStateStrings( OldBackUpBlockState ),
+     FBM_BlockStateStrings( NewBlockState ),
+     FBM_BlockStateStrings( NewBackUpBlockState ))
     {}
 };
 
@@ -98,7 +98,7 @@ public:
 
  */
 
-class FBM_IllegalRestoreAfterCompression : public FBM_Exception 
+class FBM_IllegalRestoreAfterCompression : public FBM_Exception
 {
 public:
     /*!
@@ -113,25 +113,25 @@ public:
 
 
        - Constructor of an error message. The error  occurs when the FBM is ask to
-	     restore the original state of a block marked for compression, but the block
-		 is not at all marked for compression
+      restore the original state of a block marked for compression, but the block
+    is not at all marked for compression
      */
     FBM_IllegalRestoreAfterCompression
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               BlockNo,
-         const FBM_BlockState           BlockState,
-         const FBM_BlockState           BackUpBlockState
-         )
-        :
-        FBM_Exception
-            (filename, linenumber,
-             FBM_ILLEGAL_RESTORE_AFTER_COMPRESSION,
-             SAPDB_ToString(DevNo, _T_d),
-             SAPDB_ToString(BlockNo, _T_d),
-             SAPDB_ToString(BlockState, _T_d),
-             SAPDB_ToString(BackUpBlockState, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               BlockNo,
+     const FBM_BlockState           BlockState,
+     const FBM_BlockState           BackUpBlockState
+    )
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_ILLEGAL_RESTORE_AFTER_COMPRESSION,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(BlockNo, _T_d),
+     FBM_BlockStateStrings( BlockState ),
+     FBM_BlockStateStrings( BackUpBlockState ))
     {}
 };
 
@@ -142,7 +142,7 @@ public:
 
  */
 
-class FBM_IllegalTransitionToFreeAfterSVP : public FBM_Exception 
+class FBM_IllegalTransitionToFreeAfterSVP : public FBM_Exception
 {
 public:
     /*!
@@ -156,25 +156,25 @@ public:
        @return         none
 
        - Constructor of an error message. The error  occurs when the FBM is ask to
-	     change the state of a block to 'free after savepoint' but the current state
-		 does not allow this transition
+      change the state of a block to 'free after savepoint' but the current state
+    does not allow this transition
      */
     FBM_IllegalTransitionToFreeAfterSVP
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               BlockNo,
-         const FBM_BlockState           BlockState,
-         const FBM_BlockState           BackUpBlockState
-         )
-        :
-        FBM_Exception
-            (filename, linenumber,
-             FBM_ILLEGAL_TRANS_TO_FREE_AFTER_SVP,
-             SAPDB_ToString(DevNo, _T_d),
-             SAPDB_ToString(BlockNo, _T_d),
-             SAPDB_ToString(BlockState, _T_d),
-             SAPDB_ToString(BackUpBlockState, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               BlockNo,
+     const FBM_BlockState           BlockState,
+     const FBM_BlockState           BackUpBlockState
+    )
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_ILLEGAL_TRANS_TO_FREE_AFTER_SVP,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(BlockNo, _T_d),
+     FBM_BlockStateStrings( BlockState ),
+     FBM_BlockStateStrings( BackUpBlockState ))
     {}
 };
 
@@ -183,7 +183,7 @@ public:
   @interface      FBM_IllegalRestoreAfterBackup
 
  */
-class FBM_IllegalRestoreAfterBackup : public FBM_Exception 
+class FBM_IllegalRestoreAfterBackup : public FBM_Exception
 {
 public:
     /*!
@@ -198,25 +198,25 @@ public:
 
 
        - Constructor of an error message. The error occurs when the FBM is ask to
-	     restore the original state of a block marked for backup, but the block
-		 is not at all marked for backup
+      restore the original state of a block marked for backup, but the block
+    is not at all marked for backup
      */
     FBM_IllegalRestoreAfterBackup
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               BlockNo,
-         const FBM_BlockState           BlockState,
-         const FBM_BlockState           BackUpBlockState
-         )
-        :
-        FBM_Exception
-            (filename, linenumber,
-             FBM_ILLEGAL_RESTORE_AFTER_BACKUP,
-             SAPDB_ToString(DevNo, _T_d),
-             SAPDB_ToString(BlockNo, _T_d),
-             SAPDB_ToString(BlockState, _T_d),
-             SAPDB_ToString(BackUpBlockState, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               BlockNo,
+     const FBM_BlockState           BlockState,
+     const FBM_BlockState           BackUpBlockState
+    )
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_ILLEGAL_RESTORE_AFTER_BACKUP,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(BlockNo, _T_d),
+     FBM_BlockStateStrings( BlockState ),
+     FBM_BlockStateStrings( BackUpBlockState ))
     {}
 };
 
@@ -227,7 +227,7 @@ public:
 
  */
 
-class FBM_NoMoreMemoryForNewDevice : public FBM_Exception 
+class FBM_NoMoreMemoryForNewDevice : public FBM_Exception
 {
 public:
     /*!
@@ -241,16 +241,16 @@ public:
      */
 
     FBM_NoMoreMemoryForNewDevice
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               DevSize)
-         :
-          FBM_Exception
-             (filename, linenumber,
-              FBM_NO_MORE_MEMORY_FOR_NEW_DEVICE,
-              SAPDB_ToString(DevNo, _T_d),
-              SAPDB_ToString(DevSize, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               DevSize)
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_NO_MORE_MEMORY_FOR_NEW_DEVICE,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(DevSize, _T_d))
     {}
 };
 
@@ -261,7 +261,7 @@ public:
 
  */
 
-class FBM_WrongDevNo : public FBM_Exception 
+class FBM_WrongDevNo : public FBM_Exception
 {
 public:
     /*!
@@ -276,18 +276,18 @@ public:
      */
 
     FBM_WrongDevNo
-        (const SAPDB_Char*              filename,
-         const SAPDB_UInt4              linenumber,
-         const SAPDB_UInt               DevNo,
-         const SAPDB_UInt               MinDevNo,
-         const SAPDB_UInt               MaxDevNo)
-         :
-          FBM_Exception
-             (filename, linenumber,
-              FBM_WRONG_DEVNO,
-              SAPDB_ToString(DevNo, _T_d),
-              SAPDB_ToString(MinDevNo, _T_d),
-              SAPDB_ToString(MaxDevNo, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               DevNo,
+     const SAPDB_UInt               MinDevNo,
+     const SAPDB_UInt               MaxDevNo)
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_WRONG_DEVNO,
+     SAPDB_ToString(DevNo, _T_d),
+     SAPDB_ToString(MinDevNo, _T_d),
+     SAPDB_ToString(MaxDevNo, _T_d))
     {}
 };
 
@@ -298,7 +298,7 @@ public:
 
  */
 
-class FBM_IllegalState : public FBM_Exception 
+class FBM_IllegalState : public FBM_Exception
 {
 public:
     /*!
@@ -313,18 +313,18 @@ public:
      */
 
     FBM_IllegalState
-        (const SAPDB_Char*              filename,
-		 const SAPDB_UInt4              linenumber,
-		 const SAPDB_UInt               BlockNo,
-		 const FBM_BlockState           BlockState,
-		 const FBM_BlockState           BackUpBlockState)
-         :
-          FBM_Exception
-             (filename, linenumber,
-              FBM_ILLEGAL_STATE,
-              SAPDB_ToString(BlockNo, _T_d),
-              SAPDB_ToString(BlockState, _T_d),
-              SAPDB_ToString(BackUpBlockState, _T_d))
+    (const SAPDB_Char*              filename,
+     const SAPDB_UInt4              linenumber,
+     const SAPDB_UInt               BlockNo,
+     const FBM_BlockState           BlockState,
+     const FBM_BlockState           BackUpBlockState)
+    :
+    FBM_Exception
+    (filename, linenumber,
+     FBM_ILLEGAL_STATE,
+     SAPDB_ToString(BlockNo, _T_d),
+     FBM_BlockStateStrings( BlockState ),
+     FBM_BlockStateStrings( BackUpBlockState ))
     {}
 };
 
