@@ -343,7 +343,6 @@ FBM_Manager::SetBlockStateToOccupied (
 
     return SAPDB_TRUE;
 }
-
 SAPDB_Bool
 FBM_Manager::SetBlockStateToOccupied(
     const tsp00_TaskId        TaskId,
@@ -416,9 +415,44 @@ FBM_Manager::SetBlockStateToOccupiedUnsynched (
 
 /*---------------------------------------------------------------------------*/
 
+SAPDB_Bool
+FBM_Manager::SetBlockStateToBackup(
+    const tsp00_TaskId        TaskId,
+    const IOMan_BlockAddress &BlockAddress,
+    const SAPDB_Bool          bAbortIfErrorOccured)
+{
+    FBM_SynchObject SynchronizeFBM (TaskId);
+    return SetBlockStateToBackupUnsynched ( BlockAddress, bAbortIfErrorOccured);
+}
+
+/*---------------------------------------------------------------------------*/
+
 SAPDB_Bool
 FBM_Manager::SetBlockStateToBackup (
     const tsp00_TaskId        TaskId,
+    IOMan_IBlockAddressIterator &BlockIterator,
+    const SAPDB_Bool          bAbortIfErrorOccured)
+{
+    SAPDBTRACE_ROUTINE_DEBUG ("FBM_Manager::SetBlockStateToBackup", FBM_Trace, 5);
+
+    FBM_SynchObject SynchronizeFBM (TaskId);
+
+    while (BlockIterator.hasMoreElements()){
+        IOMan_BlockAddress BlockAddress = BlockIterator.getNextElement();
+
+        if (!SetBlockStateToBackupUnsynched ( BlockAddress, bAbortIfErrorOccured))
+        {
+            return SAPDB_FALSE;
+        }
+    }
+    return SAPDB_TRUE;
+}
+
+/*---------------------------------------------------------------------------*/
+
+
+SAPDB_Bool
+FBM_Manager::SetBlockStateToBackupUnsynched (
     const IOMan_BlockAddress &BlockAddress,
     const SAPDB_Bool          bAbortIfErrorOccured )
 {
@@ -429,8 +463,6 @@ FBM_Manager::SetBlockStateToBackup (
 
     SAPDBTRACE_WRITELN( FBM_Trace, 5, "SetBackU DevNo " << DevNo << " BlockNo: " << BlockNo );
 
-    FBM_SynchObject SynchronizeFBM (TaskId);
-
     /* check that the block containing the restart record is never set to backup */
     SAPDBERR_ASSERT_STATE ( ! m_ReservedBlocks.IsMember( BlockAddress ));
 
