@@ -44,13 +44,13 @@
 #define FBM_UNDEFINED          -1
 #define FBM_ABORT_IF_ERROR      true
 
- /*===========================================================================*
- *  MACROS                                                                   *
- *===========================================================================*/
+/*===========================================================================*
+*  MACROS                                                                   *
+*===========================================================================*/
 
- /*===========================================================================*
- *  EXTERNAL VARIABLES                                                       *
- *===========================================================================*/
+/*===========================================================================*
+*  EXTERNAL VARIABLES                                                       *
+*===========================================================================*/
 
 extern SAPDBDiag_CheckTopic FBM_Check;
 extern SAPDBTrace_Topic     FBM_Trace;
@@ -60,8 +60,26 @@ extern SAPDBTrace_Topic     FBM_Trace;
  *===========================================================================*/
 
 enum FBM_BlockState {BlockState_Free         = 0,
-                     BlockState_Occupied     = 1, 
+                     BlockState_Occupied     = 1,
                      BlockState_FreeAfterSVP = 2,
                      BlockState_BackUp       = 3};
 
+/// get block states as strings for diagnostic output
+inline const SAPDB_Char*
+FBM_BlockStateStrings( const FBM_BlockState  blockState )
+{
+    switch( blockState )
+    {
+    case BlockState_Free:
+        return(( SAPDB_Char* )"Free" );
+    case BlockState_Occupied:
+        return(( SAPDB_Char* )"Occupied" );
+    case BlockState_FreeAfterSVP:
+        return(( SAPDB_Char* )"FreeAfterSvp" );
+    case BlockState_BackUp:
+        return(( SAPDB_Char* )"Backup" );
+    default:
+        return(( SAPDB_Char* )"Unknown" );
+    }
+}
 #endif //FBM_TYPES_HPP
