@@ -6,7 +6,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -143,7 +144,7 @@ public:
     /*!
        @brief   This method returns the name of the log volume identified
                 by the given logical identifier.
-       @param   devNo [in ] Logical volume identifier
+       @param   devNo   [in ] Logical volume identifier
        @param   devName [out] Name of a data volume
        @return  true if volume name was found
      */
@@ -152,6 +153,20 @@ public:
     virtual bool GetLogVolumeName(
         const IOMan_DeviceNo        devNo,
         tsp00_VFilename             &devName ) const = 0;
+    /* -----------------------------------------------------------------------*/
+    /*!
+       @brief   This method returns the name of the mirrored log volume 
+                identified by the given logical identifier. This method 
+                is only available if log mode dual is configured.
+       @param   devNo   [in ] Logical volume identifier
+       @param   devName [out] Name of a data volume
+       @return  true if volume name was found
+     */
+    /* -----------------------------------------------------------------------*/
+
+    virtual bool GetMirrLogVolumeName(
+        const IOMan_DeviceNo        devNo,
+        tsp00_VFilename             &devName ) const = 0;
 
     /* -----------------------------------------------------------------------*/
     /*!
