@@ -40,6 +40,7 @@
 #include "hgg01_3.h"
 #include "vsp002.h"
 #include "heo58.h"   // vget_uniqe_id
+#include "heo56.h"   // RTE   : Vsleep
 
 #include "FreeBlockManagement/FBM_Types.hpp"
 #include "FreeBlockManagement/FBM_IManager.hpp"
@@ -437,7 +438,7 @@ IOMan_Manager::AddLogVolume(
     const bool  bLogAreaRestarted = m_LogArea.ConfiguredVolumes() == m_LogArea.UsedVolumes();
 
 
-   if( ! bLogAreaRestarted )
+    if( ! bLogAreaRestarted )
         retCode = m_LogArea.OpenAll( taskId, SAPDB_TRUE );
 
     if( retCode )
@@ -449,7 +450,7 @@ IOMan_Manager::AddLogVolume(
             newLogSize = m_LogArea.TotalUsableLogPages();
     }
 
-   if( ! bLogAreaRestarted )
+    if( ! bLogAreaRestarted )
         m_LogArea.CloseAll( taskId ); // PTS 1112474 TS 2001-11-07
 
     return( retCode );
@@ -531,39 +532,47 @@ IOMan_Manager::ReadDataPage(
 
     SAPDBERR_ASSERT_STATE( block.IsValid() );
 
-    if(! m_DataArea.Get( block.GetDeviceNo() ).ReadPage( taskId, page, block ))
+    const SAPDB_Int  cMaxRetries  = 3;
+    SAPDB_Int        retryCount   = 0;
+    do
     {
+        if( ! m_DataArea.Get( block.GetDeviceNo() ).ReadPage( taskId, page, block ))
+        {
+            RTE_Message( IOMan_Exception( __CONTEXT__, IOMAN_BAD_DATA_PAGE,
+                                          SAPDB_ToString( pageNo, _T_d ),                 // requested pageNo
+                                          Data_PageRecModeStrings( page.RecoveryMode()),  // requested recMode
+                                          SAPDB_ToString( page.PageNo(), _T_d )));        // read pageNo
+            return IOMan_BadDataPage;
+        }
 
-        IOMan_Exception errMsg( __CONTEXT__, IOMAN_BAD_PAGENO,
-                                SAPDB_ToString( page.PageNo(), _T_d ));
-        RTE_Message( errMsg );
+        if( g01vtrace.vtrAll_gg00 || g01vtrace.vtrIoTrace_gg00 )
+        {
+            tgg00_TransContext auxTrans = BuildAuxTrans( taskId );
+            Trace_ReadDataPageEntry( auxTrans, page.ReadPageType2(), page.PageNo(), block );
+        }
+        //	Check given	pno	against	the	pno	within the obtained	buffer
+        if(	pageNo == page.PageNo()){
+            return IOMan_Okay;
+        }
+        { // page is correct, but it is not the requested one!
+            RTE_Message( IOMan_Exception( __CONTEXT__, IOMAN_WRONG_PAGENO,
+                                          SAPDB_ToString( block.GetDeviceNo(), _T_d	),
+                                          SAPDB_ToString( block.GetBlockNo(), _T_d )));
 
-        return( IOMan_BadDataPage );
-    }
+            RTE_Message( IOMan_Exception( __CONTEXT__, IOMAN_WRONG_PAGENO2,
+                                          SAPDB_ToString( pageNo, _T_d ),                 // requested pageNo
+                                          Data_PageRecModeStrings( page.RecoveryMode()),  // requested recMode
+                                          SAPDB_ToString( page.PageNo(), _T_d )));        // read pageNo
 
-    if( g01vtrace.vtrAll_gg00 || g01vtrace.vtrIoTrace_gg00 )
-    {
-        tgg00_TransContext auxTrans = BuildAuxTrans( taskId );
-        Trace_ReadDataPageEntry( auxTrans, page.ReadPageType2(), page.PageNo(), block );
-    }
+            Kernel_FileIO	dumpFile( KERNEL_DATA_FILE,	KERNEL_BAD_FILE_EXTENSION,
+                                    SAPDB_ToString( pageNo, _T_d ));
+            dumpFile.Write(	page );
+        }
+        retryCount+=1;
+        vsleep( taskId, 1 );
+    }while( retryCount < cMaxRetries );
 
-    // Check given pno against the pno within the obtained buffer
-    if( pageNo != page.PageNo() )
-    {
-
-        IOMan_Exception errMsg( __CONTEXT__, IOMAN_WRONG_PAGENO,
-                                SAPDB_ToString( pageNo, _T_d ), KERNEL_DATA_FILE,
-                                SAPDB_ToString( block.GetDeviceNo(), _T_d ),
-                                SAPDB_ToString( block.GetBlockNo(), _T_d ));
-        RTE_Message( errMsg );
-
-        Kernel_FileIO   dumpFile( KERNEL_DATA_FILE, KERNEL_BAD_FILE_EXTENSION,
-                                  SAPDB_ToString( pageNo, _T_d ));
-        dumpFile.Write( page );
-
-        return( IOMan_BadDataPage );
-    }
-    return( IOMan_Okay );
+    return IOMan_BadDataPage;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -636,7 +645,7 @@ void IOMan_Manager::ReadLogPageWithoutCheck(
     const IOMan_BlockAddress  block = m_LogArea.GetBlockAddress( address.GetOffset() );
 
     if(! m_LogArea.Get( block.GetDeviceNo() ).ReadSimple( taskId,
-            tsp00_PageAddr( page.GetFramePtr()), block.GetBlockNo(), false ))
+            tsp00_PageAddr( page.GetFramePtr()), block.GetBlockNo(), true ))
     {
         Kernel_FileIO   dumpFile( m_LogArea.Get( block.GetDeviceNo() ).GetTypeName(),
                                   KERNEL_BAD_FILE_EXTENSION,
