@@ -6,23 +6,24 @@
                   OLTP releases 7.2 and 7.3 to 7.4
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -174,10 +175,10 @@ private:
                   configured data devspaces. true is returned if the open
                   was successfully.
     arguments:    none
-    return value: SAPDB_Bool
+    return value: none
     --------------------------------------------------------------------------*/
 
-    SAPDB_Bool OpenSystemAndDataDevSpaces();
+    void OpenSystemAndDataDevSpaces();
 
     /*--------------------------------------------------------------------------
     function:     CloseSystemAndDataDevSpaces
@@ -195,10 +196,10 @@ private:
                   identified by the given parameters.
     arguments:    devSpace [in/out] handle for the devspace
                   type     [in]     type of the devspace, for example sys or data
-    return value: SAPDB_Bool
+    return value: none
     --------------------------------------------------------------------------*/
 
-    SAPDB_Bool OpenDevSpace(
+    void OpenDevSpace(
         DevSpace                &devSpace,
         const tsp2_dev_type     type );
 
