@@ -433,13 +433,13 @@ public:
         switch( m_Type )
         {
         case sp2dt_log:
-            return ( SAPDB_Char* )"Log";
+            return ( SAPDB_Char* )"log";
         case sp2dt_mirr_log:
-            return ( SAPDB_Char* )"MLog";
+            return ( SAPDB_Char* )"mlog";
         case sp2dt_data:
-            return ( SAPDB_Char* )"Data";
+            return ( SAPDB_Char* )"data";
         case sp2dt_trace:
-            return ( SAPDB_Char* )"Trace";
+            return ( SAPDB_Char* )"trace";
         default:
             return ( SAPDB_Char* )"UNDEF";
         }
@@ -457,11 +457,11 @@ public:
         switch( m_State )
         {
         case IOMan_Offline:
-                return ( SAPDB_Char* )"Offline";
+                return ( SAPDB_Char* )"offline";
         case IOMan_Read:
-            return ( SAPDB_Char* )"Read";
+            return ( SAPDB_Char* )"read";
         case IOMan_ReadWrite:
-            return ( SAPDB_Char* )"ReadWrite";
+            return ( SAPDB_Char* )"readWrite";
         default:
             return ( SAPDB_Char* )"UNDEF";
         }
