@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,12 +26,14 @@
     ========== licence end
 
 
+
 \endif
 */
 #include "Interfaces/Runtime/IFR_Common.h"
 #include "Interfaces/Runtime/Conversion/IFRConversion_NumericConverter.h"
 #include "Interfaces/Runtime/Util/IFRUtil_VDNNumber.h"
 #include "Interfaces/Runtime/Util/IFRUtil_SQLNumeric.h"
+#include "Interfaces/Runtime/IFR_Connection.h"
 
 #include <math.h>
 #include <stdlib.h>
@@ -100,9 +102,12 @@ static inline IFR_size_t compute_input_datalength(IFR_size_t datalength,
 
 //----------------------------------------------------------------------
 IFRConversion_NumericConverter::IFRConversion_NumericConverter(IFR_ShortInfo &shortinfo,
-                                                               SAPDBMem_IRawAllocator& allocator)
+                                                               SAPDBMem_IRawAllocator& allocator,
+                                                               IFR_Connection& connection)
 :IFRConversion_Converter(shortinfo, allocator)
-{}
+{
+    m_noscientific = connection.numbersWithoutExponent();
+}
 
 //----------------------------------------------------------------------
 IFRConversion_NumericConverter::~IFRConversion_NumericConverter()
@@ -684,7 +689,7 @@ IFRConversion_NumericConverter::translateCharacterOutput(IFRPacket_DataPart& dat
 
     // unfortunately, we must possibly report the original length to the
     // caller. So for now we will copy the result anyway ...
-    char tmp_data[92]; // 38 digits, "-0." is worst case prefix, -E63 is worst case suffix.
+    char tmp_data[140]; // 64 digits (E64), '.' and '-', if no scientific ... makes 132 (plus some safety)
     const char *numstr; 
     IFR_size_t numlength;
     if(*(vdn - 1) == csp_oflw_byte) {
@@ -704,9 +709,10 @@ IFRConversion_NumericConverter::translateCharacterOutput(IFRPacket_DataPart& dat
                                               tmp_data,
                                               sizeof(tmp_data),
                                               encoding,
-                                              !m_shortinfo.isFloat(),
+                                              m_noscientific || !m_shortinfo.isFloat(),
                                               m_shortinfo.length,
                                               m_shortinfo.frac);
+        
         if(rc!=IFR_OK) {
             DBUG_RETURN(IFR_NOT_OK);
         }
