@@ -10,7 +10,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 
 
 
+
 \endif
 */
 #ifndef IFRCONVERSION_NUMERICCONVERTER_H
@@ -55,7 +56,8 @@ public:
      * @param allocator The allocator to be used.
      */
     IFRConversion_NumericConverter(IFR_ShortInfo& shortinfo,
-                                   SAPDBMem_IRawAllocator& allocator);
+                                   SAPDBMem_IRawAllocator& allocator,
+                                   IFR_Connection& connection);
     
     /**
      * Destructor.
@@ -356,6 +358,9 @@ private:
                                          IFR_StringEncoding encoding,
                                          IFR_Bool terminate);
 
+private:
+    IFR_Bool m_noscientific; // Scientific rep ignored?
+    
 };
 
 #endif //IFRCONVERSION_NUMERICCONVERTER_H
