@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 // Prevents a Warning 5004 Uninitialized variable "static_i"
@@ -686,7 +687,7 @@ IFR_Connection::connect(const char *p_servernode,
     replypacket.setPacket((tsp1_packet *)sessionInfoReply, 0);
 
     IFR_PACKET_TRACE << replypacket << endl;
-    
+
     IFRPacket_ReplySegment connectreply(replypacket);
     if(connectreply.getSQLError(error(), allocator)) {
         release();
@@ -747,7 +748,7 @@ IFR_Connection::connect(const char *p_servernode,
         error().setMemoryAllocationFailed();
         DBUG_RETURN(IFR_NOT_OK);
     }
-    
+
     runtime.releaseMutex(m_status_lock);
 
     //>>> SQL TRACE
@@ -764,18 +765,18 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
     DBUG_METHOD_ENTER(IFR_ConnectProperties, checkProperties);
     IFR_Bool memory_ok=true;
     IFR_Bool isSAPR3 = false;
-    
+
     const char *sqlmode = properties.getProperty(IFR_CONNECTPROPERTY_SQLMODE, "INTERNAL");
     if(strcmp(sqlmode, "SAPR3") == 0) {
         isSAPR3 = true;
     }
-    
+
     // look for application and version, and check them for correctness.
     if(!properties.containsProperty(IFR_CONNECTPROPERTY_APPLICATION)) {
         properties.setProperty(IFR_CONNECTPROPERTY_APPLICATION, "ODB", memory_ok);
     }
     if(!properties.containsProperty(IFR_CONNECTPROPERTY_APPVERSION)) {
-        properties.setProperty(IFR_CONNECTPROPERTY_APPVERSION, "70403", memory_ok);
+        properties.setProperty(IFR_CONNECTPROPERTY_APPVERSION, "70500", memory_ok);
     }
     if(!properties.containsProperty(IFR_CONNECTPROPERTY_SQLMODE)) {
         properties.setProperty(IFR_CONNECTPROPERTY_SQLMODE, "INTERNAL", memory_ok);
@@ -800,10 +801,15 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
         properties.setProperty("IGNORE_COLUMNNAMES", "1", memory_ok);
         properties.setProperty("CACHE_ALL_STATEMENTS", "1", memory_ok);
         properties.setProperty("SELECTFETCHOPTIMIZE", "1", memory_ok);
+        properties.setProperty("NUMBERS_WITHOUT_EXPONENT", "1", memory_ok);
         if(!properties.containsProperty("OPTIMIZEDSTREAMS")) {
             properties.setProperty("OPTIMIZEDSTREAMS", "1", memory_ok);
         }
     }
+
+    if(!properties.containsProperty("SELECTFETCHOPTIMIZE")) {
+        properties.setProperty("SELECTFETCHOPTIMIZE", "1", memory_ok);
+    }
     
     if(!memory_ok) {
         error().setMemoryAllocationFailed();
@@ -857,7 +863,7 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
     } else {
         m_connectionflags.clientunicode = 0;
     }
-    
+
     //----------------------------------------------------------------------
     // Workaround-and-optimization properties
     const char *binary_as_encoded_str = properties.getProperty("TRANSLATE_BINARY_AS_ENCODED", "0");
@@ -867,13 +873,37 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
         m_connectionflags.binary_as_encoded = 0;
     }
 
+    const char *producer_str = properties.getProperty("PRODUCER", "0");
+    if (strcmp(producer_str, "0") != 0) {    // producer set at all?
+      if (strcmp(producer_str, "NIL") == 0) {
+        m_producer = sp1pr_nil;
+      } else if (strcmp(producer_str, "USER") == 0) {
+        m_producer = sp1pr_user_cmd;
+      } else if (strcmp(producer_str, "INTERNAL") == 0) {
+        m_producer = sp1pr_internal_cmd;
+      } else if (strcmp(producer_str, "KERNEL") == 0) {
+        m_producer = sp1pr_kernel;
+      } else if (strcmp(producer_str, "INSTALLATION") == 0) {
+        m_producer = sp1pr_installation;
+      } else {
+        error().setRuntimeError(IFR_ERR_INVALID_CONNECT_PROPERTY_S, "PRODUCER");
+        DBUG_RETURN(false);
+      }
+    }
+
     const char *chop_blanks_str = properties.getProperty("CHOPBLANKS", "0");
     if(atoi(chop_blanks_str)) {
         m_connectionflags.chop_blanks = 1;
     } else {
         m_connectionflags.chop_blanks = 0;
     }
-    
+
+    const char *numbers_wo_exp_str = properties.getProperty("NUMBERS_WITHOUT_EXPONENT", "0");
+    if(atoi(numbers_wo_exp_str)) {
+        m_connectionflags.numbers_without_exponent = 1;
+    } else {
+        m_connectionflags.numbers_without_exponent = 0;
+    }
     const char *cache_all_statements = properties.getProperty("CACHE_ALL_STATEMENTS", "0");
     if(atoi(cache_all_statements)) {
         m_connectionflags.cache_all_statements = 1;
@@ -884,16 +914,16 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
     const char *select_fetch_strategy = properties.getProperty("SELECTFETCHOPTIMIZE", "0");
     if(atoi(select_fetch_strategy)==1) {
         m_connectionflags.selectfetchstrategy = SelectFetchScrollable_C;
-    } 
+    }
 #if SELECT_FETCH_FETCH_IMMEDIATE
     else if(atoi(select_fetch_strategy)==2) {
         m_connectionflags.selectfetchstrategy = SelectFetchFetchImmediate_C;
-    } 
+    }
 #endif
     else {
         m_connectionflags.selectfetchstrategy = SelectFetchNone_C;
     }
-    
+
     if(m_connectionflags.selectfetchstrategy == SelectFetchScrollable_C) {
         properties.setProperty(IFR_CONNECTPROPERTY_CHECKSCROLLABLE, "1", memory_ok);
     } else {
@@ -903,9 +933,9 @@ IFR_Connection::checkProperties(IFR_ConnectProperties& properties)
         error().setMemoryAllocationFailed();
         DBUG_RETURN(false);
     }
-    
+
     //----------------------------------------------------------------------
-    
+
 
     const char *packetcount_str=properties.getProperty(IFR_CONNECTPROPERTY_PACKETCOUNT, "UNLIMITED");
     int packetcount=1;
@@ -1020,7 +1050,7 @@ IFR_Connection::createConnectURL(IFR_String& url,
     memset(lvcbuf, 0, sizeof(lvcbuf));
     strncpy(maxdbbuf, servernode, 6);
     strncpy(lvcbuf, servernode, 10);
-    
+
     if(STRICMP(maxdbbuf, "maxdb:")==0 || STRICMP(lvcbuf, "livecache:")==0) {
         servernode_is_url=true;
         for(IFR_Int4 i=servernodeLength-1; i>=0; --i) {
@@ -1035,29 +1065,29 @@ IFR_Connection::createConnectURL(IFR_String& url,
     } else {
         if(strlen(servernode) == 0) {
             url.append("maxdb://./database/", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
-            url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);            
+            url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);
         } else {
             // detect a SAP router string, and construct the URL accordingly
             if(servernode[0]=='/' &&
                (servernode[1]=='H' || servernode[1]=='h')) {
                 url.append("maxdb:sapni:", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
                 url.append(servernode, IFR_StringEncodingAscii, servernodeLength, memory_ok);
-                url.append("/:inpas/database/", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
-                url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);            
+                url.append(":inpas/database/", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
+                url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);
             } else {
                 url.append("maxdb:remote://", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
                 url.append(servernode, IFR_StringEncodingAscii, servernodeLength, memory_ok);
                 url.append("/database/", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
-                url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);            
+                url.append(serverdb, IFR_StringEncodingAscii, serverdbLength, memory_ok);
             }
         }
     }
-        
+
     if(!memory_ok) {
         error().setMemoryAllocationFailed();
         DBUG_RETURN(false);
     }
-    
+
     if(strlen(properties.getParameterString())!=0) {
         if(servernode_url_hasparameters) {
             url.append("&", IFR_StringEncodingAscii, IFR_NTS, memory_ok);
@@ -1164,7 +1194,8 @@ IFR_Connection::IFR_Connection(IFR_Environment& environment,
  m_status_lock(0),
  m_packetcache_lock(0),
  m_mingetvalsize(1),
- m_packetcache(0)
+ m_packetcache(0),
+ m_producer(sp1pr_user_cmd)
 {
     if(IFR_MEM_OK) {
         initializeMembers(memory_ok);
@@ -1292,10 +1323,10 @@ IFR_Retcode IFR_Connection::close(IFR_Bool commit, IFR_Bool sessionclosed)
         m_internalstatement=0;
         IFRUtil_Delete(m_requestpacket, allocator);
         IFRUtil_Delete(m_parseinfocache, allocator);
-        
+
         IFRUtil_Delete(m_specialparameters[0], allocator);
         IFRUtil_Delete(m_specialparameters[1], allocator);
-        
+
         runtime.releaseMutex(m_status_lock);
         runtime.lockMutex(m_sqlaexecute_lock);
         rc = release();
@@ -1370,10 +1401,10 @@ IFR_Connection::setAutoCommit(IFR_Bool autocommit)
     DBUG_PRINT(autocommit);
     clearError();
     if(autocommit) {
-        IFR_SQL_TRACE << "::SET AUTOCOMMIT ON " << currenttime << " [0x" << (void*)this << "]" << endl; 
+        IFR_SQL_TRACE << "::SET AUTOCOMMIT ON " << currenttime << " [0x" << (void*)this << "]" << endl;
         m_connectionflags.autocommit = 1;
     } else {
-        IFR_SQL_TRACE << "::SET AUTOCOMMIT OFF " << currenttime << " [0x" << (void*)this << "]" << endl; 
+        IFR_SQL_TRACE << "::SET AUTOCOMMIT OFF " << currenttime << " [0x" << (void*)this << "]" << endl;
         m_connectionflags.autocommit = 0;
     }
 }
@@ -1489,8 +1520,38 @@ IFR_Retcode IFR_Connection::commit()
     runtime.releaseMutex(m_status_lock);
     DBUG_RETURN(rc);
 }
+//----------------------------------------------------------------------
+IFR_Retcode IFR_Connection::stopKerneltrace()
+{
+    DBUG_METHOD_ENTER(IFR_Connection, stopKerneltrace);
 
+    clearError();
 
+    IFR_SQL_TRACE << endl << "::stopKerneltrace " << currenttime
+                  << " [0x" << (void*)this << "]" << endl;
+    if(!isConnected()) {
+        error().setRuntimeError(IFR_ERR_SESSION_NOT_CONNECTED);
+        DBUG_RETURN(IFR_NOT_OK);
+    }
+    runtime.lockMutex(m_status_lock);
+    m_internalstatement->clearError();
+    IFR_Bool memory_ok=true;
+    IFR_String commit_statement("DIAGNOSE VTRACE DEFAULT OFF",
+                                IFR_StringEncodingAscii,
+                                allocator,
+                                memory_ok);
+    if(!memory_ok) {
+        runtime.releaseMutex(m_status_lock);
+        error().setMemoryAllocationFailed();
+        DBUG_RETURN(IFR_NOT_OK);
+    }
+    IFR_Retcode rc=m_internalstatement->execute(commit_statement);
+    if(rc != IFR_OK) {
+        error() = m_internalstatement->error();
+    }
+    runtime.releaseMutex(m_status_lock);
+    DBUG_RETURN(rc);
+}
 //----------------------------------------------------------------------
 IFR_Retcode IFR_Connection::rollback()
 {
@@ -1705,10 +1766,10 @@ IFR_Connection::sqlaexecute(IFRPacket_RequestPacket &requestPacket,
     // communicate synchronized on the connection3
     {
         runtime.lockMutex(m_sqlaexecute_lock);
-        // For multi-threading, this is enough, anyone who wants the root packet 
+        // For multi-threading, this is enough, anyone who wants the root packet
         // will lock here. Single-Threaded stuff will jump nicely through this stuff
         m_sqlaexecute_executing = 1;
-        
+
         // we put the trace into the synchronized range so that it is not shredded
 
         IFR_PACKET_TRACE << requestPacket << endl;
@@ -1835,7 +1896,7 @@ IFR_Connection::evalFeaturePart(IFRPacket_FeaturePart& featurepart)
     for(IFR_Int2 i=0; i<featurecount; ++i, data+=2) {
         switch(data[0]) {
         case IFRPacket_Feature::MultipleDropParseID_C:
-            m_connectionflags.multipleparseiddrop = data[1]; 
+            m_connectionflags.multipleparseiddrop = data[1];
             if(m_connectionflags.multipleparseiddrop) {
                 IFR_SQL_TRACE << "MULTIPLE PARSE ID DROP ENABLED" << endl;
             } else {
