@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #ifndef IFR_CONNECTION_H
@@ -426,6 +427,15 @@ public:
         return m_packetsize;
     }
 
+    /**
+     * Get the producer flag of the connection.
+     * @return The procucer that can be set via the connect properties.
+     */
+    inline tsp1_producer_Enum getProducer() const
+    {
+        return m_producer;
+    }
+
    /**
      * Returns true if the with info flag was set.
      * @return <code>true</code> if the with info flag was set.
@@ -478,7 +488,16 @@ public:
     {
         return m_connectionflags.chop_blanks==1 ? true : false;
     }
-
+    
+    /**
+     * Flag check, whether numbers shall be formatted always without
+     * exponent.
+     */
+    inline IFR_Bool numbersWithoutExponent() const
+    {
+        return m_connectionflags.numbers_without_exponent==1 ? true : false;
+    }
+    
     /**
      * Flag check, whether even statements with application parameter
      * descriptions shall be cached.
@@ -528,6 +547,15 @@ public:
     {
         return (SelectFetchStrategy) m_connectionflags.selectfetchstrategy;
     }
+
+    /**
+     * Switches off the kernel trace.
+     * @return IFR_OK if the kernel trace stop command has been sent,
+     *   IFR_NOT_OK if the kernel trace stop command could not be
+     *   sent, because of an error or timeout.
+     */
+    IFR_Retcode stopKerneltrace();
+
 private:
 
     IFR_Retcode executeInternalCommand(const char *command);
@@ -652,6 +680,7 @@ private:
         unsigned scrollable          : 1;
         unsigned selectfetchstrategy : 2;
         unsigned chop_blanks         : 1;
+        unsigned numbers_without_exponent : 1;
     };
     
     IFR_Environment&              m_environment;       //!< The environment under which the connection is created.
@@ -686,6 +715,7 @@ private:
     IFR_Int4            m_mingetvalsize;         //!< Minimum size of a GETVAL operation.
     void               *m_packetcache;           //!< Pointer to list of allocated but released packets.
     ConnectionFlags     m_connectionflags;       //!< Various flags for various purposes.
+    tsp1_producer_Enum  m_producer;              //!< producer label in segment
 
     IFRUtil_Vector<IFR_ParseID> m_garbageparseids; //!< The parse ids which are to be dropped are collected here.
     IFRUtil_Vector<IFR_String>  m_garbagecursors;  //!< The cursor names which are to be dropped are collected here.
