@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #ifndef IFR_ERRORCODE_H
@@ -146,8 +147,10 @@ enum IFR_ErrorCode
     IFR_ERR_STREAM_NO_DATA_I,                  //!< Data for an output stream was expected, but not found.
     IFR_ERR_NULL_STREAMPARAM_I,                //!< The stream parameter of the stream descriptor is null.
     IFR_ERR_STREAM_MEMBERCOUNT_MISMATCH_III,   //!< Member count for structured streams does not match the database information.
+    IFR_ERR_STREAM_NO_FUNCTION,                //!< No function provided for ABAP stream parameter.         
     IFR_ERR_STREAM_OUTPUT_SEQUENCE_ERROR,      //!< The output sequence was not sent correctly by the kernel.
     IFR_ERR_STREAM_OVERFLOW_III,               //!< The read procedure reported that it wrote to much.
+    IFR_ERR_STREAM_NO_FUNCTION_I,              //!< No function supplied for ABAP stream.
     IFR_ERR_ROWSET_IS_READ_ONLY,               //!< result set type UPDATABLE does not match to row set type READ_ONLY
     IFR_ERR_ROWSET_IS_UPDATABLE,               //!< result set type READ_ONLY does not match to row set type UPDATABLE
     IFR_ERR_ROWSET_NO_METADATA,                //!< Internal error - no meta data available for row set operation.
