@@ -10,7 +10,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 
 
 
+
 \endif
 */
 #include "SAPDB/Interfaces/Runtime/IFR_FetchChunk.h"
@@ -104,6 +105,7 @@ IFR_FetchChunk::IFR_FetchChunk (int type,
             }
         }
     }
+    m_replypacket.releaseLock(); 
 }
 
 //----------------------------------------------------------------------
@@ -147,6 +149,7 @@ IFR_FetchChunk::IFR_FetchChunk(PIn_ReplySegment& replysegment,
             }
         }
     }
+    m_replypacket.releaseLock(); 
 }
 
 
@@ -181,7 +184,6 @@ IFR_Retcode IFR_FetchChunk::init ()
                   << "FETCH BUFFER END  : " << m_EndIndex << endl;
     //<<< SQL TRACE
     determineFlags (m_MaxRows);
-    m_replypacket.releaseLock(); // last point of use for original packet
     DBUG_RETURN(rc);
 }
 
