@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 // Prevents a Warning 5004 Uninitialized variable "static_#classcvt#693
@@ -58,6 +59,7 @@ IFR_Statement::IFR_Statement (IFR_Connection &conn, IFR_Bool& memory_ok)
  m_MaxRows (0),
  m_QueryTimeout (0),
  m_CursorName(allocator),
+ m_commandInfoState(CommandInfoNotSet_C),
  m_commandInfo(allocator),
  m_TableName(allocator),
  m_resultset(NULL), 
@@ -205,6 +207,8 @@ IFR_Statement::sendCommand (IFRPacket_RequestPacket &requestPacket,
           : IFRPacket_CommandMessageType::Dbs_C;
       IFRPacket_RequestSegment segment(requestPacket, messagetype);      
       
+      segment.setProducer (m_Connection->getProducer());
+
       /* set masscommand */
       if(masscommand) {
           requestPacket.setMassCommand();
@@ -389,6 +393,12 @@ IFR_Statement::parseResult (IFRPacket_ReplyPacket &replyPacket,
         part.parseShortFields(infos, *this);
         break;
     }
+    case (IFRPacket_PartKind::VarDataShortInfo_C): {
+        IFRPacket_VarDataShortInfoPart part;
+        partEnum.getPart(part);
+        part.parseShortFields(infos, *this);
+        break;
+    }
     case (IFRPacket_PartKind::Resultcount_C): {
         IFR_Int4 ResCount;
         if (segm.getResultCount(ResCount) == IFR_OK)
@@ -509,7 +519,6 @@ IFR_Statement::parseResult (IFRPacket_ReplyPacket &replyPacket,
 
   // we KNOW that this is the last time we need the reply packet.
   DBUG_PRINT(rowNotFound);
-
   replyPacket.releaseLock();
   IFR_Bool cursorwasused = (m_cursorstate == CursorStateUsed_C); // was the cursor used before this statement
   if (((rc == IFR_OK) || (rc == IFR_NO_DATA_FOUND)) && isQuery) {
@@ -772,6 +781,7 @@ IFR_Retcode IFR_Statement::setCommandInfo(const char *_commandInfo,
 
     DBUG_PRINT(m_commandInfo);
     m_commandLineNumber=lineNumber;
+    m_commandInfoState = CommandInfoSet_C;
     clearError();
     DBUG_RETURN(IFR_OK);
 }               
