@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #ifndef IFR_STATEMENT_H
@@ -660,6 +661,13 @@ protected:
         CursorStateUsedClosed_C  = 2  //!< Used and implicitely closed (Oracle, SELECT FETCH Optimization)
     };
 
+    enum CommandInfoState {
+        CommandInfoNotSet_C   = 0,
+        CommandInfoSet_C      = 1,
+        CommandInfoPrepared_C = 2,
+        CommandInfoError_C    = 3,
+        CommandInfoExecuted_C = 4
+    };
 
     IFR_Int4 m_RowsAffected;                  //!< Number of rows affected by last command (-1 for unknown).
     ResultSetType m_ResultSetType;        //!< Sensitivity of the result set (changes are visible or not, use 
@@ -670,8 +678,12 @@ protected:
     IFR_Int4 m_FetchSize;                     //!< Number of rows to fetch at once (performance hint).
     IFR_Int4 m_MaxRows;                       //!< Maximum number of rows in the result set (fetch will be limited). 
     IFR_Int4 m_QueryTimeout;   //!< Execution time out for sql command    
+
+    
+    IFR_Int4         m_commandInfoState;   //!< Status of command info for disposal.
     IFR_Int4         m_commandLineNumber; //!< line number used in command info.    
     IFR_String       m_commandInfo;//!< command info of the statement.
+
     IFR_String       m_CursorName; //!< Cursor name of the statement.
     IFR_String       m_TableName;  //!< Table name of the statement.
     IFR_ResultSet   *m_resultset;  //!< Result set of this statement.
@@ -685,6 +697,8 @@ protected:
     IFRUtil_Vector<IFR_String>   *m_batchelements;  //!< Elements of batch execution, if any.
     
     CopiedDataPart               *m_lastserial;     //!< Last inserted serials, if any.
+
+    friend class ClearCommandInfo;
 };
 
 /**
