@@ -10,7 +10,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 
 
 
+
 \endif
 */
 #include "Interfaces/Runtime/IFR_Common.h"
@@ -282,6 +283,14 @@ IFRPacket_RequestSegment::setCommitImmediately()
     return;
 }
 
+//----------------------------------------------------------------------
+void
+IFRPacket_RequestSegment::setProducer(const tsp1_producer_Param & oProducer)
+{
+    m_segment.SetProducer (oProducer);
+    return;
+}
+
 //----------------------------------------------------------------------
 void
 IFRPacket_RequestSegment::setParseWithPrepare()
