@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 #include "Interfaces/Runtime/IFR_Common.h"
@@ -297,7 +298,7 @@ IFR_Retcode integer_to_number(Integer number,
 
     // simple case - zero
     if(number==0) {
-        memcpy(result, zero_vdnnumber, digits_bytelength+1);
+        memcpy(result, zero_vdnnumber, digits_bytelength);
         return IFR_OK;
     }
     
@@ -1383,11 +1384,10 @@ IFRUtil_VDNNumber::stringToNumberAscii(char              *buffer,
                 --remaining;
                 if ((*buffer) != '0')
                     break;
-            } while (remaining);
-        }
+            } while (remaining);        }
         // We have a zero.
         if(!remaining) {
-            memcpy(number, zero_vdnnumber, digits_bytelength + 1);
+            memcpy(number, zero_vdnnumber, digits_bytelength);
             return IFR_OK;
         }
     }
@@ -1440,7 +1440,7 @@ IFRUtil_VDNNumber::stringToNumberAscii(char              *buffer,
                     --exponent;
                     ++frac_zeros;
                     if(remaining==1) {
-                        memcpy(number, zero_vdnnumber, digits_bytelength + 1);
+                        memcpy(number, zero_vdnnumber, digits_bytelength);
                         return IFR_OK;
                     }
                 }
@@ -1524,7 +1524,7 @@ IFRUtil_VDNNumber::stringToNumberAscii(char              *buffer,
     // and now insert it !
 
     if(lastnonzero == 0 && digits[0]==0) {
-        memcpy(number, zero_vdnnumber, digits_bytelength + 1);
+        memcpy(number, zero_vdnnumber, digits_bytelength);
         return IFR_OK;
     }
     memset(number, 0, digits_bytelength);
