@@ -68,19 +68,30 @@ if ($opt_addfiles) {
 
 my $found=0;
 my $versionok=0;
-foreach my $ver (@doxyversions) {
-    foreach my $dir (@doxygendirs) {
-        $doxygen="${dir}doxygen$dotexe";
-        if (-x "$doxygen") {
-            if (checkDoxygenVersion($doxygen, $ver)) {
-                $found=1;
-                $versionok=1;
-                last;
+
+# find doxygen 
+$dir="$ENV{OWN}/tool/bin/";
+$doxygen="${dir}doxygen$dotexe";
+if (-x "$doxygen") {
+    checkDoxygenVersion($doxygen, $ver);
+    $found=1;
+    $versionok=1;
+}
+else {
+    foreach my $ver (@doxyversions) {
+        foreach my $dir (@doxygendirs) {
+            $doxygen="${dir}doxygen$dotexe";
+            if ($dir eq "" || -x "$doxygen") {
+                if (checkDoxygenVersion($doxygen, $ver)) {
+                    $found=1;
+                    $versionok=1;
+                    last;
+                }
             }
         }
-    }
-    if ($found) {
-        last;
+        if ($found) {
+            last;
+        }
     }
 }
 
