@@ -643,7 +643,7 @@ SQLDBC_Bool IFTools_sqlcliMetaData::displayListDBProcs(){
                 "SUBSTR(decode(package,NULL,'',package), 1, %d) \"Package\" " 
 //                "SUBSTR(Language, 1, %d) \"Language\" "   
                 "FROM DOMAIN.DBPROCEDURES "
-                "WHERE package <>  'SYS_PACKAGE' or package is null "
+                "WHERE (package <>  'SYS_PACKAGE' or package is null) "
                 "AND %s LIKE '%s' "
                 "AND dbprocname LIKE '%s' "  
                 "ORDER BY \"Schema\", \"Package\",\"Name\" ";
