@@ -16,6 +16,7 @@ see also    :
 
 -------------------------------------------------------------------------
 
+copyright:    Copyright (c) 2003-2005 SAP AG
 
 
     ========== licence begin  GPL
@@ -88,48 +89,51 @@ IFTools_sqlcliInput::cmdKeywordTable IFTools_sqlcliInput::connectKeywordTab [ ]=
 };
 
 IFTools_sqlcliInput::cmdKeywordTable IFTools_sqlcliInput::mycmdKeywordTab [ ]= {
-  { cmdtype_exit,       {{"EXIT"        ,0},{"",0},{"",0}} },
-  { cmdtype_help,       {{"HELP"        ,0},{"",0},{"",0}} },
-  { cmdtype_exit,       {{"QUIT"        ,0},{"",0},{"",0}} },
-  { cmdtype_shellcmd,   {{"\\!"         ,0},{"",0},{"",0}} },
-  { cmdtype_help,       {{"\\?"         ,0},{"",0},{"",0}} },
-  { cmdtype_autocommit, {{"\\A"         ,0},{"",0},{"",0}} },
-  { cmdtype_alignment,  {{"\\AL"        ,0},{"",0},{"",0}} },
-  { cmdtype_alignment,  {{"\\ALIGN"     ,0},{"",0},{"",0}} },
-  { cmdtype_autocommit, {{"\\AUTOCOMMIT",0},{"",0},{"",0}} },
-  { cmdtype_connect,    {{"\\C"         ,0},{"",0},{"",0}} },
-  { cmdtype_connect,    {{"\\CONNECT"   ,0},{"",0},{"",0}} },
-  { cmdtype_showColumns,{{"\\DC"        ,0},{"",0},{"",0}} },
-  { cmdtype_showIndices,{{"\\DE"        ,0},{"",0},{"",0}} },
-  { cmdtype_disconnect, {{"\\DI"        ,0},{"",0},{"",0}} },
-  { cmdtype_disconnect, {{"\\DISCONNECT",0},{"",0},{"",0}} },
-  { cmdtype_showProcs,  {{"\\DP"        ,0},{"",0},{"",0}} },
-  { cmdtype_showSchemas,{{"\\DS"        ,0},{"",0},{"",0}} },
-  { cmdtype_showTables, {{"\\DT"        ,0},{"",0},{"",0}} },
-  { cmdtype_showUsers,  {{"\\DU"        ,0},{"",0},{"",0}} },
-  { cmdtype_showViews,  {{"\\DV"        ,0},{"",0},{"",0}} },
-  { cmdtype_edit,       {{"\\E"         ,0},{"",0},{"",0}} },
-  { cmdtype_edit,       {{"\\EDIT"      ,0},{"",0},{"",0}} },
-  { cmdtype_fieldsep,   {{"\\F"         ,0},{"",0},{"",0}} },
-  { cmdtype_fieldsep,   {{"\\FIELDSEP"  ,0},{"",0},{"",0}} },
-  { cmdtype_help,       {{"\\H"         ,0},{"",0},{"",0}} },
-  { cmdtype_help,       {{"\\HELP"      ,0},{"",0},{"",0}} },
-  { cmdtype_input,      {{"\\I"         ,0},{"",0},{"",0}} },
-  { cmdtype_input,      {{"\\INPUT"     ,0},{"",0},{"",0}} },
-  { cmdtype_sqlmode,    {{"\\M"         ,0},{"",0},{"",0}} },
-  { cmdtype_sqlmode,    {{"\\MODE"      ,0},{"",0},{"",0}} },
-  { cmdtype_outfile,    {{"\\O"         ,0},{"",0},{"",0}} },
-  { cmdtype_outfile,    {{"\\OUTPUT"    ,0},{"",0},{"",0}} },
-  { cmdtype_print,      {{"\\P"         ,0},{"",0},{"",0}} },
-  { cmdtype_usePreparedStmt, {{"\\PREPARED"  ,0},{"",0},{"",0}} },
-  { cmdtype_print,      {{"\\PRINT"     ,0},{"",0},{"",0}} },
-  { cmdtype_usePreparedStmt, {{"\\PS"        ,0},{"",0},{"",0}} },
-  { cmdtype_exit,       {{"\\Q"         ,0},{"",0},{"",0}} },
-  { cmdtype_exit,       {{"\\QUIT"      ,0},{"",0},{"",0}} },
-  { cmdtype_reset,      {{"\\R"         ,0},{"",0},{"",0}} },
-  { cmdtype_reset,      {{"\\RESET"     ,0},{"",0},{"",0}} },
-  { cmdtype_status,     {{"\\S"         ,0},{"",0},{"",0}} },
-  { cmdtype_status,     {{"\\STATUS"    ,0},{"",0},{"",0}} }
+  { cmdtype_shellcmd,   {{"!"         ,0},{"",0},{"",0}} },
+  { cmdtype_help,       {{"?"         ,0},{"",0},{"",0}} },
+  { cmdtype_autocommit, {{"A"         ,0},{"",0},{"",0}} },
+  { cmdtype_alignment,  {{"AL"        ,0},{"",0},{"",0}} },
+  { cmdtype_alignment,  {{"ALIGN"     ,0},{"",0},{"",0}} },
+  { cmdtype_autocommit, {{"AUTOCOMMIT",0},{"",0},{"",0}} },
+  { cmdtype_connect,    {{"C"         ,0},{"",0},{"",0}} },
+  { cmdtype_connect,    {{"CONNECT"   ,0},{"",0},{"",0}} },
+  { cmdtype_showColumns,{{"DC"        ,0},{"",0},{"",0}} },
+  { cmdtype_showIndices,{{"DE"        ,0},{"",0},{"",0}} },
+  { cmdtype_disconnect, {{"DI"        ,0},{"",0},{"",0}} },
+  { cmdtype_disconnect, {{"DISCONNECT",0},{"",0},{"",0}} },
+  { cmdtype_showProcs,  {{"DP"        ,0},{"",0},{"",0}} },
+  { cmdtype_showSchemas,{{"DS"        ,0},{"",0},{"",0}} },
+  { cmdtype_showTables, {{"DT"        ,0},{"",0},{"",0}} },
+  { cmdtype_showUsers,  {{"DU"        ,0},{"",0},{"",0}} },
+  { cmdtype_showViews,  {{"DV"        ,0},{"",0},{"",0}} },
+  { cmdtype_edit,       {{"E"         ,0},{"",0},{"",0}} },
+  { cmdtype_edit,       {{"EDIT"      ,0},{"",0},{"",0}} },
+  { cmdtype_shellcmd,   {{"EXEC"      ,0},{"",0},{"",0}} },
+  { cmdtype_exit,       {{"EXIT"      ,0},{"",0},{"",0}} },
+  { cmdtype_fieldsep,   {{"F"         ,0},{"",0},{"",0}} },
+  { cmdtype_fieldsep,   {{"FIELDSEP"  ,0},{"",0},{"",0}} },
+  { cmdtype_help,       {{"H"         ,0},{"",0},{"",0}} },
+  { cmdtype_help,       {{"HELP"      ,0},{"",0},{"",0}} },
+  { cmdtype_input,      {{"I"         ,0},{"",0},{"",0}} },
+  { cmdtype_input,      {{"INPUT"     ,0},{"",0},{"",0}} },
+  { cmdtype_sqlmode,    {{"M"         ,0},{"",0},{"",0}} },
+  { cmdtype_sqlmode,    {{"MODE"      ,0},{"",0},{"",0}} },
+  { cmdtype_multiline,  {{"MU"        ,0},{"",0},{"",0}} },
+  { cmdtype_multiline,  {{"MULTILINE" ,0},{"",0},{"",0}} },
+  { cmdtype_outfile,    {{"O"         ,0},{"",0},{"",0}} },
+  { cmdtype_outfile,    {{"OUTPUT"    ,0},{"",0},{"",0}} },
+  { cmdtype_print,      {{"P"         ,0},{"",0},{"",0}} },
+  { cmdtype_pager,      {{"PA"        ,0},{"",0},{"",0}} },
+  { cmdtype_pager,      {{"PAGER"     ,0},{"",0},{"",0}} },
+  { cmdtype_usePreparedStmt, {{"PREPARED"  ,0},{"",0},{"",0}} },
+  { cmdtype_print,      {{"PRINT"     ,0},{"",0},{"",0}} },
+  { cmdtype_usePreparedStmt, {{"PS"        ,0},{"",0},{"",0}} },
+  { cmdtype_exit,       {{"Q"         ,0},{"",0},{"",0}} },
+  { cmdtype_exit,       {{"QUIT"      ,0},{"",0},{"",0}} },
+  { cmdtype_reset,      {{"R"         ,0},{"",0},{"",0}} },
+  { cmdtype_reset,      {{"RESET"     ,0},{"",0},{"",0}} },
+  { cmdtype_status,     {{"S"         ,0},{"",0},{"",0}} },
+  { cmdtype_status,     {{"STATUS"    ,0},{"",0},{"",0}} }
 };
 
 const char * IFTools_sqlcliInput::getshortcutHelp(){
@@ -142,6 +146,7 @@ const char * IFTools_sqlcliInput::getshortcutHelp(){
     "                connecting to the database\n"
     " \\di[sconnect]  disconnecting from the database\n"
     "\n"
+    " \\mu[ltiline]   [ON|OFF] toggle the multiline mode on or off\n"
     " \\a[utocommit]  [ON|OFF] switch autocommit mode on or off\n"
     " \\m[ode]        [INTERNAL|ORACLE|ANSI|DB2] change SQL mode\n"
     " \\ps            [ON|OFF] toggle the usage of prepared statements on or off\n"
@@ -154,9 +159,10 @@ const char * IFTools_sqlcliInput::getshortcutHelp(){
     " \\g             send query buffer to server (and print out the results)\n"
     "\n"
     " \\al[ign]       [ON|OFF] toggle the aligned output on or off\n"
+    " \\pa[ger]       [ON|OFF] toggle page by page scroll output on or off\n"
     " \\f[ieldsep]    <separator> use <separator> as the field separator\n"
     " \\s[tatus]      print out host, database, user etc.\n"
-    " \\!<command>    execute <command> in shell\n"
+    " \\! <command>   execute <command> in shell\n"
     "\n"
     " \\dc [PATTERN]  list columns\n"
     " \\de [PATTERN]  list indices\n"
@@ -181,6 +187,77 @@ static void initCMDKeywordTable (IFTools_sqlcliInput::cmdKeywordTable *keywordTa
   cmdKeywordTabIsInit = SQLDBC_TRUE;
 }
 //----------------------------------------------------------------------
+
+
+
+SQLDBC_Bool IFTools_sqlcliInput::startprocess (const char **args) {
+
+
+
+   SQLDBC_Int4 pos = 0;
+   char                  cmdline[1024];
+   char *space = (char *)"";
+
+# if defined(_WIN32) /*------- _WIN32 -------------------*/
+   STARTUPINFO             StartupInfo;
+   BOOL                    Ok;
+   PROCESS_INFORMATION     m_ProcInfo;
+ 
+   GetStartupInfo (&StartupInfo);
+   memset ( &m_ProcInfo, 0, sizeof(m_ProcInfo) );
+
+   StartupInfo.lpTitle = cmdline;
+   StartupInfo.dwFlags = 0;
+#else
+   pos = sp77sprintf(&cmdline[pos], sizeof(cmdline)-pos,"exec ");
+#endif
+   
+   for (int i = 0; args[i] != 0 ; i++){
+     pos += sp77sprintf(&cmdline[pos], sizeof(cmdline)-pos,"%s\"%s\"", space, args[i]);
+     space = (char *)" ";
+   }
+   cmdline[pos] = 0;
+   
+# if defined(_WIN32) /*------- _WIN32 -------------------*/
+   Ok = CreateProcess ( 0, cmdline, 0, 0, TRUE, CREATE_NO_WINDOW,
+                        0, 0, &StartupInfo, &m_ProcInfo);
+   if (Ok == 0){
+      LPVOID lpMsgBuf;
+      DWORD dw = GetLastError(); 
+
+      FormatMessage(
+        FORMAT_MESSAGE_ALLOCATE_BUFFER | 
+        FORMAT_MESSAGE_FROM_SYSTEM,
+        NULL,
+        dw,
+        MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+        (LPTSTR) &lpMsgBuf,
+        0, NULL );
+      fprintf(m_sqlcliProp->geterrfile(),"could not execute command \"%s\" Error: %d: %s\n", cmdline, dw, lpMsgBuf);
+      LocalFree(lpMsgBuf);
+      return SQLDBC_FALSE;
+   }
+   // Wait until child process exits.
+   WaitForSingleObject( m_ProcInfo.hProcess, INFINITE );
+
+   // Close process and thread handles. 
+   CloseHandle( m_ProcInfo.hProcess );
+   CloseHandle( m_ProcInfo.hThread );
+
+
+# else  /*--------------------- UNIX --------------------*/
+
+   errno = 0;
+   int erg = system(cmdline);
+   if (errno != 0){
+     fprintf(m_sqlcliProp->geterrfile(),"could not execute command \"%s\" Error: %d: %s\n", cmdline, errno, strerror(errno));
+     return SQLDBC_FALSE;
+   }
+#endif /*----------------- _WIN32/UNIX -----------------*/
+   return SQLDBC_TRUE;
+}
+
+//----------------------------------------------------------------------
 void IFTools_sqlcliInput::printSplashScreen(FILE * out){
 
   fprintf(out,"%s%s",
@@ -244,7 +321,7 @@ public:
       SQLDBC_Bool editQueryBuffer(){
         char* filename = m_sqlcliProp->geteditfilename();
         char* editorName;
-        char* editcmd;
+        char* editcmd[3];
         FILE* tmpFile = 0;
         if ( (tmpFile = fopen(filename,"w")) == 0) {
           fprintf(m_sqlcliProp->geterrfile(),"open of %s failed: %d %s\n", m_sqlcliProp->geteditfilename(), errno ,strerror( errno ) );
@@ -262,20 +339,14 @@ public:
 	      if (!editorName)
 		      editorName = m_sqlcliProp->getdefaulteditor();
 
-	      editcmd  = new char[strlen(editorName) + strlen(filename) + 10 + 1];
-#ifdef WIN32
-      	sprintf(editcmd, "%s \"%s\"", editorName, filename);
-#else
-      	sprintf(editcmd, "exec  %s '%s'", editorName, filename);
-#endif
-        errno = 0;
-      	int erg = system(editcmd);
-	      if (errno != 0){
-		      fprintf(m_sqlcliProp->geterrfile(),"could not start editor %s Error: %s\n", editorName, strerror(errno));
-          delete [] editcmd;
+          editcmd [0]   = editorName;
+          editcmd [1]   = filename;
+          editcmd [2]   = 0;
+
+        if (this->startprocess ((const char**)editcmd)== SQLDBC_FALSE){
           return SQLDBC_FALSE;
         }
-        delete [] editcmd;
+          
         tmpFile = fopen(filename, "r");
 		    if (!tmpFile) {
 			    fprintf(m_sqlcliProp->geterrfile(),ERR_OPEN_FILE, filename, strerror(errno));
@@ -451,46 +522,50 @@ public:
 
   ~IFTools_sqlcliInputFromFile   (){}
 
-  virtual char* getnextCMD(){
-    char* eof, *cmdsep = m_sqlcliProp->getcmdsep();
+ virtual char* getnextCMD(){
+    char* eof, *seppos, *cmdsep = m_sqlcliProp->getcmdsep();
     int cmdsepLen= strlen (cmdsep), tmpLen=0;
     m_curLen = 0;
     m_stmt[0]='\0';
     while(SQLDBC_TRUE){
-      eof = fgets(m_stmt+m_curLen,sizeof(m_stmt)-2-m_curLen,m_sqlcliProp->getinfile()) ; 
+      eof = fgets(m_stmt+m_curLen,sizeof(m_stmt)-2-m_curLen,m_sqlcliProp->getinfile()) ;
       tmpLen= strlen (m_stmt+m_curLen);
-      if (tmpLen >= cmdsepLen && !strncmp(&m_stmt[m_curLen],cmdsep, cmdsepLen)){
+      seppos = strstr( &m_stmt[m_curLen], cmdsep );
+      if (tmpLen >= cmdsepLen && seppos){
+        m_curLen = (int)(seppos - m_stmt);
         break;
       }
       m_curLen += tmpLen;
       while ( m_curLen &&
-              (   m_stmt[m_curLen-1] == '\n' 
-               || m_stmt[m_curLen-1] == '\r' 
+              (   m_stmt[m_curLen-1] == '\n'
+               || m_stmt[m_curLen-1] == '\r'
                ||  m_stmt[m_curLen-1] == '\0'
                ||  m_stmt[m_curLen-1] == ' '
+               ||  m_stmt[m_curLen-1] == '\\'
               )
              ) {m_curLen-- ;}
 
       if (eof == NULL){
         if (m_curLen){
-          if (m_curLen >= cmdsepLen && !strncmp(&m_stmt[m_curLen-cmdsepLen],cmdsep, cmdsepLen)){
-            m_curLen -= cmdsepLen; 
+          seppos = strstr( &m_stmt[m_curLen], cmdsep );
+          if (m_curLen >= cmdsepLen && seppos){
+             m_curLen = (int)(seppos - m_stmt);
           }
           break;
-        }    
+        }
         m_cmdtype = cmdtype_exit;
         return (char*)"";
       }
-      m_stmt[m_curLen++]=' '; 
+      m_stmt[m_curLen++]=' ';
     }
-    m_stmt[m_curLen]='\0';       
+    m_stmt[m_curLen]='\0';
     m_cmdtype = this->analyzeSQL(m_stmt);
-    
+
       return m_stmt;
   }
   protected:
     char m_stmt[32000];
-    int  m_curLen;      
+    int  m_curLen;
 };
 //----------------------------------------------------------------------
 
@@ -519,6 +594,20 @@ IFTools_sqlcliInput* IFTools_sqlcliInput::getNewInputHandler(
     } 
     pIdentifier = IFTools_sqlcliProperties::trimString(pIdentifier);
     symbolLen = this->nextSymbol(pIdentifier, &currPos);
+    if (! this->isInternalCMD(&pIdentifier[currPos], &currPos, &symbolLen)){
+      this->m_cmdtype = (IFTools_sqlcliInput::sqlcliInput_cmdtype) this->analyzeKeyword(&pIdentifier[currPos], symbolLen, mycmdKeywordTab, CMDKEYWORDTABLESIZE); 
+      switch (this->m_cmdtype){
+         /*allow only internal commands that doesn't start with '\' or ':'*/
+         case(IFTools_sqlcliInput::cmdtype_help):
+         case(IFTools_sqlcliInput::cmdtype_exit):{
+           break;
+         }
+         default: {
+          this->m_cmdtype = cmdtype_unknown;
+         } 
+      }
+      return this->m_cmdtype;
+    }
     this->m_cmdtype = (IFTools_sqlcliInput::sqlcliInput_cmdtype) this->analyzeKeyword(&pIdentifier[currPos], symbolLen, mycmdKeywordTab, CMDKEYWORDTABLESIZE); 
     switch (this->m_cmdtype){
       case(IFTools_sqlcliInput::cmdtype_sqlmode):{
@@ -636,6 +725,28 @@ IFTools_sqlcliInput* IFTools_sqlcliInput::getNewInputHandler(
         }
         break;
       } 
+     case(IFTools_sqlcliInput::cmdtype_pager):{
+        currPos+=symbolLen+1;
+        symbolLen = this->nextSymbol(&pIdentifier[currPos], &currPos);
+        if (! symbolLen){
+			m_sqlcliProp->setNoPager();
+        } else {
+          sqlcliInput_autocommittype actyp = (IFTools_sqlcliInput::sqlcliInput_autocommittype)this->analyzeKeyword(&pIdentifier[currPos],symbolLen, autocommitKeywordTab, AUTOCOMMITKEYWORDTABLESIZE);        
+          m_sqlcliProp->setNoPager((actyp == IFTools_sqlcliInput::autocommit_on)?SQLDBC_TRUE:SQLDBC_FALSE);
+        }
+        break;
+      } 
+     case(IFTools_sqlcliInput::cmdtype_multiline):{
+        currPos+=symbolLen+1;
+        symbolLen = this->nextSymbol(&pIdentifier[currPos], &currPos);
+        if (! symbolLen){
+			m_sqlcliProp->setMultiline();
+        } else {
+          sqlcliInput_autocommittype actyp = (IFTools_sqlcliInput::sqlcliInput_autocommittype)this->analyzeKeyword(&pIdentifier[currPos],symbolLen, autocommitKeywordTab, AUTOCOMMITKEYWORDTABLESIZE);        
+          m_sqlcliProp->setMultiline((actyp == IFTools_sqlcliInput::autocommit_on)?SQLDBC_TRUE:SQLDBC_FALSE);
+        }
+        break;
+      } 
       case(IFTools_sqlcliInput::cmdtype_status):{
         currPos+=symbolLen+1;
         symbolLen = this->nextSymbol(&pIdentifier[currPos], &currPos);
@@ -733,6 +844,19 @@ IFTools_sqlcliInput* IFTools_sqlcliInput::getNewInputHandler(
     }
     return IdentLength;
   }
+  //--------------------------------------------------------------------------
+  SQLDBC_Int4 IFTools_sqlcliInput::isInternalCMD(char* pIdentifier, int* currPos, int* identLen){
+    char internCMDPraefix[] ={'\\',':'};
+    if (! strlen (pIdentifier)) return 0;
+    for (SQLDBC_Int4 i=0; i < sizeof(internCMDPraefix); i++) {   
+      if (pIdentifier[0]== internCMDPraefix[i]) {
+         (*currPos)++;
+         (*identLen)--;
+         return 1;
+      }
+    } 
+    return 0;
+  }
 
   //--------------------------------------------------------------------------
 	SQLDBC_SQLMode IFTools_sqlcliInput::getSQLModeFromString(char* sqlmode){
