@@ -64,11 +64,12 @@ const teo81_EvalProgArgs::teo81_OptionDesc IFTools_sqlcliProperties::Options[] =
     { option_cmdseparator    , _T('c'), _T("cmdseparator"),    true,  true, _T("\"<separator>\""),                                 _T("Use separator to separate comamnds in batch files.") },
     { option_dbname          , _T('d'), _T("dbname") ,         true,  true, _T("\"<database name>\""),                             _T("Specifies the name of the database to connect to.") },
     { option_dateformat      , _T('D'), _T("dateformat") ,     true,  true, _T("\"[INTERNAL|ISO|USA|EUR|JIS]\""),                  _T("Use this date and/or time format instead of the one specified in the database set command. Possible options are INTERNAL, ISO, USA, EUR or JIS") },
-    { option_stopOnError      , _T('E'), _T("stoponerror") ,   true,  true, _T("exit code"),                  _T("exit sqlcli returning <exit code> in case of an error") },
-    { option_writeCmdProt    , _T('f'), _T("cmdtrace") ,       false,  true, _T("\"<protocol name>\""),                            _T("Printout the SQL commands") },
+    { option_stopOnError     , _T('E'), _T("stoponerror") ,    true,  true, _T("exit code"),                                       _T("exit sqlcli returning <exit code> in case of an error") },
+    { option_writeCmdProt    , _T('f'), _T("cmdtrace") ,       false, true, _T("\"<protocol name>\""),                             _T("Printout the SQL commands") },
     { option_separator       , _T('F'), _T("fieldseparator") , true,  true, _T("\"<separator>\""),                                 _T("Use separator as the field separator.") },
     { option_nullval         , _T('g'), _T("null") ,           true,  true, _T("\"<null string>\""),                               _T("The argument is a string that should be printed whenever a field is null. The default is '?'.") },
     { option_batch           , _T('i'), _T("input") ,          true,  true, _T("\"<input file>\""),                                _T("Use file <input file> as the source of queries") },
+    { option_nopager         , _T('j'), _T("nopager")         ,false, true, _T("\"Do not use a pager for output.\""),              _T("Do not use a pager for output..") },
     { option_rollbackOnError , _T('k'), _T("rollbackonerror") ,false, true, _T("\"Rollback work in case of an error.\""),          _T("Rollback work in case of an error.") },
     { option_logo            , _T('l'), _T("logo")            ,true,  true, _T(""),                                                _T("") },
     { option_multilinemode   , _T('m'), _T("multilinemode")   ,false, true, _T("\"Activates the multiline mode.\""),               _T("Activates the multiline mode.") },
@@ -132,6 +133,7 @@ void IFTools_sqlcliProperties::eo80_vHelp ( const TCHAR*         OptionArgument
 	puts(("  -p <prefix>     use <prefix> as row prefix for printing (default: '|'"));
 	puts(("  -P <suffix>     use <suffix> as row suffix for printing (default: '|'"));
 	puts(("  -A              switch to unaligned output mode."));
+	puts(("  -j              switch the page by page scroll output off."));
 	puts(("  -Q              show each column on a separate line"));
 	puts(("  -a              do not print any header for SELECT commands"));
 	puts(("  -f              printout the SQL commands"));
@@ -179,7 +181,8 @@ static char Utfmap[] ={  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x5F, 0x5F, 0
 //-----------------------------------------------------------------------
 SQLDBC_Bool IFTools_sqlcliProperties::openResultOutput(){
   FILE* out=NULL;
-  if (this->isInteractive()){
+  if ( !this->m_noPager &&
+       this->isInteractive()){
 		char *pager = getenv("PAGER");
   	if (!pager){
 			pager = (char*)DEFAULT_PAGER;
@@ -247,6 +250,7 @@ IFTools_sqlcliProperties::IFTools_sqlcliProperties ( int argc, TCHAR** argv )
         m_batch     (SQLDBC_FALSE),          
         m_rollbackOnError (SQLDBC_FALSE),
         m_noComment(SQLDBC_FALSE),
+        m_noPager(SQLDBC_FALSE),
         m_multilinemode(SQLDBC_FALSE),
         m_alignedOutput(SQLDBC_TRUE),
         m_maxLongLenth(10),
@@ -287,10 +291,12 @@ IFTools_sqlcliProperties::IFTools_sqlcliProperties ( int argc, TCHAR** argv )
  m_ifrprops.setProperty("SQLMODE", "INTERNAL");
  m_ifrprops.setProperty("STATEMENTCACHESIZE", "0");
  m_ifrprops.setProperty("SELECTFETCHOPTIMIZE", "1");
+ m_ifrprops.setProperty("CHOPBLANKS", "1"); 
 
- if (m_environment == 0) 
-     m_environment=new SQLDBC_Environment(SQLDBC_ClientRuntimeInit());
- 
+ if (m_environment == 0){ 
+     char errorText[256];
+     m_environment=new SQLDBC_Environment(SQLDBC::GetClientRuntime(errorText, sizeof(errorText)));
+ }
 //  m_properties.setProperty  ("COMPNAME",  "CLI"  ); 
   if(this->eo80_ParseArguments() == SQLDBC_OK) {}
 };
@@ -356,6 +362,10 @@ bool IFTools_sqlcliProperties::eo80_vNextValidOption ( const int            Opti
       m_noComment = true;
       break;
     }
+    case option_nopager           : { 
+      m_noPager = true;
+      break;
+    }
     case option_outputfile      : { 
       setoutfile(OptionArgument);
       break;
@@ -386,7 +396,7 @@ bool IFTools_sqlcliProperties::eo80_vNextValidOption ( const int            Opti
       break;
     }
     case option_timeout        : {
-      this->m_ifrprops.setProperty("TIMEOUT ", OptionArgument);
+      this->m_ifrprops.setProperty("TIMEOUT", OptionArgument);
       break;
     }
     case option_dbhost          : {
@@ -394,7 +404,7 @@ bool IFTools_sqlcliProperties::eo80_vNextValidOption ( const int            Opti
       break;
     }  
     case option_sqlmode          : {
-      this->m_ifrprops.setProperty("SQLMODE", OptionArgument);
+      this->m_ifrprops.setProperty("SQLMODE", OptionArgument); 
       break;
     }  
     case option_sqlcmd          : {
@@ -796,6 +806,35 @@ void IFTools_sqlcliProperties::exitProgram(){
 	exit(this->m_exitCode);
 }
 //--------------------------------------------------------------------------
+#ifdef _WIN32
+#define POPEN(a) _popen (a, "rt")
+#define PCLOSE _pclose
+#else
+#include <errno.h>
+#define POPEN(a) popen (a, "r")
+#define PCLOSE pclose
+#endif
+
+int IFTools_sqlcliProperties::executeCommand (char* cmd){
+   char   psBuffer[128];
+   FILE   *pPipe;
+
+  if( (pPipe = POPEN(cmd)) == NULL ){
+     fprintf(m_errfile,ERR_EXEC_CMD, cmd, strerror( errno ) );
+     return 1;
+  }
+
+   while( !feof( pPipe ) )
+   {
+       if( fgets( psBuffer, 128, pPipe ) != NULL ){
+         fprintf(m_outfile,"%.*s", sizeof(psBuffer), psBuffer );
+       }
+   }
+
+   return PCLOSE( pPipe );
+}
+
+
 /*
 #SQLDBC_Int4 IFTools_sqlcliProperties::getConsoleScreenSize(){
 #ifdef WIN32 
