@@ -7,7 +7,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
  *
  * @sa Join_AccessDesc.hpp
  */
@@ -102,27 +102,41 @@ m_subqfile_id( acv.GetAllocator() )
             } else if ( strat_key_subq == m_strategy->str_strategy || 
                         strat_inv_subq == m_strategy->str_strategy ) 
             {
+
                 if ( m_subqfile_id.SetPtr( reinterpret_cast<tgg00_FileId*>( m_acv.GetAllocator().Allocate( sizeof(tgg00_FileId) )))
                      &&
                      m_segment_ptr2.SetPtr( reinterpret_cast<tgg00_Lkey*>( m_acv.GetAllocator().Allocate( sizeof(tgg00_Lkey) ))) )
                 {
+                    
+                    tsp00_Int2 _InSubqStackPos; 
+                    if ( strat_key_subq == m_strategy->str_strategy )
+                        _InSubqStackPos = m_strategy->str_key_in_range().skir_IN_SUBQ_stpos;
+                    else
+                        _InSubqStackPos = m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos;  
+                    
                     m_segment_ptr2->keyLen_gg00() = 0;
-                    if ( st_dummy == (*m_mblock.mb_st())[ m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + 1 - 1 ].etype()
+                    if ( st_dummy == (*m_mblock.mb_st())[ _InSubqStackPos + 1 - 1 ].etype()
                          &&
-                         st_bool == (*m_mblock.mb_st())[ m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + 2 - 1 ].etype() )
+                         st_bool == (*m_mblock.mb_st())[ _InSubqStackPos + 2 - 1 ].etype() )
                     {
                         SAPDBTRACE_WRITELN( Join_Trace, 3, "empty subquery file!" );
                         m_strategy->str_res_possible = false;
-                    }
-                    if ( st_subquery == (*m_mblock.mb_st())[ m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + 1 - 1 ].etype() )
+                    } 
+                    else if ( st_subquery == (*m_mblock.mb_st())[ _InSubqStackPos + 1 - 1 ].etype() )
                     {
                         // get subquery file ID
                         SAPDB_MemCopyNoCheck( m_subqfile_id.GetPtr(), 
                                 (SAPDB_Byte*) m_mblock.mb_data() 
-                                + (*m_mblock.mb_st())[ m_strategy->str_key_in_range().skir_IN_SUBQ_stpos + 1 - 1 ].epos() - 1,
+                                + (*m_mblock.mb_st())[ _InSubqStackPos + 1 - 1 ].epos() - 1,
                                 FILE_ID_MXGG00 );
                         SAPDBTRACE_IF( Join_Trace, 3, 
                                 t01treeid( td_always, "subq file ID", *m_subqfile_id ));
+                    } 
+                    else
+                    {
+                        _b_err = e_stack_type_illegal;
+                        g01opmsg( sp3p_knldiag, sp3m_error, csp3_ak_msg,
+                              csp3_n_join, "INVALID STRATEGY INFO   ", 0 );
                     }
                 }
                 else
@@ -233,6 +247,7 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                         stopkey.reckey, _use_stopkeys, 
                         m_strategy->str_key_in_range().skir_IN_SUBQ_stpos, 
                         m_segment_ptr1++ );
+                    _b_err = m_mblock.mb_trns()->trError_gg00;
                 }
                 else
                 {
@@ -261,11 +276,24 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                               *_rec,
                               m_strategy->str_key_in_range().skir_keystart,
                               startkey.reckey, _use_stopkeys );
-                        _use_stopkeys = true;
-                        gg04one_subq_limitprimkey( m_mblock, 
-                              *_rec,
-                              m_strategy->str_key_in_range().skir_keystop,
-                              stopkey.reckey, _use_stopkeys );
+                        _b_err = m_mblock.mb_trns()->trError_gg00;
+                        if ( (e_ok == _b_err) || (e_key_not_found == _b_err) ) 
+                        {
+                            _use_stopkeys = true;
+                            gg04one_subq_limitprimkey( m_mblock, 
+                                  *_rec,
+                                  m_strategy->str_key_in_range().skir_keystop,
+                                  stopkey.reckey, _use_stopkeys );
+                            _b_err = m_mblock.mb_trns()->trError_gg00;
+                        }
+                    }
+                    else
+                    {
+                        if ( e_ok == _b_err ) 
+                        {
+                            _b_err = m_mblock.mb_trns()->trError_gg00;
+                        }
+                            
                     }
                 }
                 else
@@ -279,6 +307,7 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                     m_strategy->str_key_in_range().skir_keystop,
                     stopkey.reckey, _use_stopkeys, 
                     IS_UNDEFINED_GG07, -1 /* use an IN as range */ );
+            _b_err = m_mblock.mb_trns()->trError_gg00;
             }
             // create index keys 
             if ( e_ok == _b_err && IsIndexAccess() )
@@ -307,6 +336,7 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                                     startkey.listkey, stopkey.listkey, 
                                     m_strategy->str_inv_in_range().siir_IN_SUBQ_stpos,
                                     m_segment_ptr1++ );
+                            _b_err = m_mblock.mb_trns()->trError_gg00;
                         }
                         else
                         {
@@ -333,10 +363,23 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                                       *_rec,
                                       m_strategy->str_inv_in_range(),
                                       startkey.listkey, false );
-                                gg04one_subq_limitinvkey( m_mblock, 
-                                      *_rec,
-                                      m_strategy->str_inv_in_range(),
-                                      stopkey.listkey, true );
+                                _b_err = m_mblock.mb_trns()->trError_gg00;
+                                if ( (e_ok == _b_err) || (e_key_not_found == _b_err) )
+                                {
+                                    gg04one_subq_limitinvkey( m_mblock, 
+                                          *_rec,
+                                          m_strategy->str_inv_in_range(),
+                                          stopkey.listkey, true );
+                                    _b_err = m_mblock.mb_trns()->trError_gg00;
+                                }
+                            }
+                            else
+                            {
+                                if ( e_ok == _b_err ) 
+                                {
+                                    _b_err = m_mblock.mb_trns()->trError_gg00;
+                                }
+                                    
                             }
                         }
                         else
@@ -349,6 +392,7 @@ tgg00_BasisError Join_AccessDesc::CreateKeys(
                             startkey.listkey, stopkey.listkey, 
                             IS_UNDEFINED_GG07,
                             -1 /* use an IN as range */ );
+                    _b_err = m_mblock.mb_trns()->trError_gg00;
                 }
                 }
                 else
