@@ -7,7 +7,7 @@
  *
  * \par last changed by:
  * 
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
  *
  */
 /*
@@ -255,7 +255,7 @@ tgg00_BasisError new_group(
  */
 tgg00_BasisError update_group( 
         Join_AggregationContext &context,
-        tgg00_Rec &record, tgg00_Rec &group_rec )
+        tgg00_Rec &record, tgg00_Rec &group_rec, SAPDB_Bool SourceIsPartialAggregate )
 {
     SAPDBTRACE_ROUTINE_DEBUG( "Join_Aggregation::update_group", Join_Trace, 3 );
     tgg00_BasisError _b_err = e_ok;
@@ -264,6 +264,7 @@ tgg00_BasisError update_group(
     bool _null_found = false;
     tgg00_StackOpFunc _operator;
     context.m_grouprec_changed = false;
+    SAPDBTRACE_WRITELN( Join_Trace, 3, "merge of aggregate: " << SourceIsPartialAggregate );
     SAPDBTRACE_WRITELN( Join_Trace, 3, "input record:" );
         SAPDBTRACE_IF( Join_Trace, 3, 
         t01buf( td_always, &record, 1, record.recLen_gg00() <= 300 ? record.recLen_gg00() : 300 ));
@@ -578,6 +579,7 @@ tgg00_BasisError update_group(
                             {
                                 SAPDB_UInt4 _pos;
                                 SAPDB_Int4  _cnt; 
+                                SAPDB_Int4  _offset = 1; 
                                 
                                 context.m_grouprec_changed = true;
                                 if ( op_f_avg == _operator )
@@ -586,9 +588,22 @@ tgg00_BasisError update_group(
                                     _pos = context.m_RecordDesc[ _out_pos - 1 ].epos() + 1;
                                 // get old aggregate value
                                 s40g4int( &group_rec, _pos, _cnt, _numerr );
+#ifdef                          SAPDB_SLOW
+                                if ( num_ok != _numerr )
+                                    RTE_Crash( SAPDBErr_Exception( __CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "(VDN conversion failed)"));
+#endif
+                                if ( SourceIsPartialAggregate )
+                                {
+                                    s40g4int( &record, _pos, _offset, _numerr );
+                                    SAPDBTRACE_WRITELN( Join_Trace, 3, "old aggregate: " << _offset );
+#ifdef                              SAPDB_SLOW
+                                    if ( num_ok != _numerr )
+                                        RTE_Crash( SAPDBErr_Exception( __CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "(VDN conversion failed)"));
+#endif
+                                }
                                 SAPDBTRACE_WRITELN( Join_Trace, 3, "pos for VDN(): " << _pos << " old value: " << _cnt );
                                 if ( num_ok == _numerr )
-                                    s41p4int( &group_rec, _pos, _cnt + 1, _numerr );
+                                    s41p4int( &group_rec, _pos, _cnt + _offset, _numerr );
                             }
                             if ( _get_act_value )
                             {
@@ -857,7 +872,8 @@ tgg00_BasisError initialize(
                     _b_err = m_acv.TransContext().trError_gg00;
                     if ( distinct_fileroot.IsFull() ) 
                         distinct_fileroot.Reserve( 2*distinct_fileroot.GetSize() );
-                    distinct_fileroot.InsertEnd( Join_RootPair(_htree.fileRoot_gg00(), _htree.fileRootCheck_gg00()) );
+                    if ( !distinct_fileroot.InsertEnd( Join_RootPair(_htree.fileRoot_gg00(), _htree.fileRootCheck_gg00()) ) )
+                        return e_no_more_memory;
                 }
                 _out_pos = k721out_entry( (tgg00_StackList*) &record_desc, _func_pos );
                 if ( op_o_output_hold == record_desc[ _out_pos - 1 ].eop_out() &&
