@@ -9,7 +9,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
  *
  */
 /*
@@ -72,23 +72,25 @@ public:
     //@}
     
     void MergeData(
-            const SAPDB_Byte    *data,
+            const SAPDB_Byte    *src_data,
             SAPDB_Byte          *new_or_act_data,
             SAPDB_UInt2         length,
-            SAPDB_Bool          found )
+            SAPDB_Bool          found,
+            SAPDB_Bool          SourceIsPartialAggregate)
     {
         if ( ! found )
         {
-            SAPDBTRACE_WRITELN( Join_Trace, 3, "length: " << length << "\trecLen_gg00: " << ((tgg00_Rec*)data)->recLen_gg00() );
-            SAPDBERR_ASSERT_STATE( length >= ((tgg00_Rec*)data)->recLen_gg00() );
-            SAPDB_MemCopyNoCheck( new_or_act_data, data, length );
+            SAPDBTRACE_WRITELN( Join_Trace, 3, "length: " << length << "\trecLen_gg00: " << ((tgg00_Rec*)src_data)->recLen_gg00() );
+            SAPDBERR_ASSERT_STATE( length >= ((tgg00_Rec*)src_data)->recLen_gg00() );
+            SAPDB_MemCopyNoCheck( new_or_act_data, src_data, length );
             Join_Aggregation::new_group( m_AggrContext, 
                        *(tgg00_Rec*)new_or_act_data );
         }
         else
             Join_Aggregation::update_group( m_AggrContext,
-                          *(tgg00_Rec*)data,
-                          *(tgg00_Rec*)new_or_act_data );
+                          *(tgg00_Rec*)src_data,
+                          *(tgg00_Rec*)new_or_act_data,
+                          SourceIsPartialAggregate );
     }
 
 private:
