@@ -10,7 +10,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
  */
 /*!
  * @addtogroup SQLManager
@@ -364,6 +364,7 @@ Join_IResultSetOperator*
     Table_FixSizeEntry_FieldDescription _field_desc( acv.GetAllocator() );
     Table_FixSizeEntry_KeyNoList _key_desc( acv.GetAllocator() );
     _field_desc.Reserve(10); _key_desc.Reserve(5);
+    bool _mem_ok = true;
 
     for ( SAPDB_Int4 _i = 1; _i <= (*rec_desc)[ 0 ].epos() - 1; ++_i )
     {
@@ -376,12 +377,17 @@ Join_IResultSetOperator*
                 if  ( op_o_output_later == (*rec_desc)[ _i - 1 ].eop_out() )
                     _one_result = true;
 
-                _field_desc.InsertEnd( 
+                _mem_ok = _mem_ok && _field_desc.InsertEnd( 
                         Table_OffsetLengthTuple( (*rec_desc)[ _i - 1 ].epos()-1, 
                                                  (*rec_desc)[ _i - 1 ].elen_var() ));
                 if  ( (*rec_desc)[ _i - 1].epos() < 
                        cgg_rec_key_offset + top_operator.GetKeyLength() )
-                    _key_desc.InsertEnd( _field_desc.GetSize() - 1 );
+                    _mem_ok = _mem_ok && _key_desc.InsertEnd( _field_desc.GetSize() - 1 );
+                if ( !_mem_ok )
+                {
+                    a07_b_put_error( acv, e_no_more_memory, 1 );
+                    return 0;
+                }
             }
         }
     }
@@ -413,7 +419,7 @@ Join_IResultSetOperator*
                         top_operator );
             if ( acv.IsOk() ) 
                 return _p;
-            else
+            else if ( a07_return_code( e_no_more_memory, acv.a_sqlmode ) == acv.ReturnCode())
             {
                 // we can't construct Join_ResultSetAggregator2
                 destroy( _p, acv.GetAllocator() );
@@ -423,7 +429,8 @@ Join_IResultSetOperator*
                             "JOIN", __FILE__, __LINE__, 
                             SAPDBErr_MessageList::Info, csp3_ak_msg, 
                             "Join_ResultSetAggregator2 failed - fall back to Join_ResultSetAggregator", 0) );
-            }
+            } else
+                return 0; // any other error
         }
     
         if ( _one_result )
