@@ -9,7 +9,7 @@
  *
  * @par last changed by:
  * <br>
- * $Author: d024980 $ $DateTime: 2005/06/23 17:29:07 $
+ * $Author: d024980 $ $DateTime: 2006/02/08 14:05:41 $
  *
  * @sa Join_IndexAccessOperator.hpp
  */
@@ -39,10 +39,12 @@
 #include "Join/Join_IndexAccessOperator.hpp"
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "ggg00.h"
+#include "hak01.h"
 #include "hak07.h"
 #include "hbd03.h"
 #include "hbd21.h"
 #include "hta01.h"
+#include "hkb720.h"
 
 class SQLMan_Context;
 
@@ -123,6 +125,9 @@ protected:
 #ifdef SAPDB_SLOW
             t01buf( td_always, &m_Actualkeys.listkey.k(), 1, m_Actualkeys.listkey.len());
 #endif
+            m_SelFields.sfp_rows_read() = 0;
+            m_SelFields.sfp_rows_qual() = 0;
+
             b03select_invrec(
                 m_acv.TransContext(),
                 m_AccessDesc.FileIDs(),
@@ -137,13 +142,21 @@ protected:
                 true );
             _bdState = m_acv.TransContext().trError_gg00;
 
-            if ( m_acv.TransContext().trBdTcachePtr_gg00 != 0 )
-            {
-                b21mp_rows_read_put (m_acv.TransContext().trBdTcachePtr_gg00, m_SelFields.sfp_rows_read());
-                b21mp_rows_qual_put (m_acv.TransContext().trBdTcachePtr_gg00, m_SelFields.sfp_rows_qual());
-            }
             _recordsRead += m_SelFields.sfp_m_result_cnt();
 
+            if  ( a01diag_monitor_on || a01diag_analyze_on )  
+            {
+                if ( (GetOpenCnt() == 1 ) && (NIL_PAGE_NO_GG00 != m_AccessDesc.FileIDs().inv_id.fileRoot_gg00()) )
+                {
+                    b21mp_root_put (m_AccessDesc.MBlock().mb_trns()->trBdTcachePtr_gg00,
+                       m_AccessDesc.FileIDs().inv_id.fileRoot_gg00());
+
+                    k720diagmon_strat_put (*m_AccessDesc.MBlock().mb_trns(), *m_AccessDesc.GetStrategyPtr());
+                }
+                b21mp_rows_read_put (m_AccessDesc.MBlock().mb_trns()->trBdTcachePtr_gg00, m_SelFields.sfp_rows_read());
+                b21mp_rows_qual_put (m_AccessDesc.MBlock().mb_trns()->trBdTcachePtr_gg00, m_SelFields.sfp_rows_qual());
+            }
+
             if ( (e_ok != _bdState) && (e_no_next_record != _bdState) )
                 // error has occured
                 break;
