@@ -34,6 +34,7 @@
 #include "hbd02.h"
 #include "hbd03.h"
 #include "hbd21.h"
+#include "hbd73.h"
 #include "hgg01.h"
 #include "hgg01_3.h"
 #include "hgg04.h"
@@ -57,6 +58,8 @@
 
 extern SAPDBTrace_Topic Join_Trace;   //!< join tracing
 
+static const int c_max_server_tasks = 64;
+
 struct Join_ServerStatistics
 {
     Join_ServerStatistics()
@@ -100,7 +103,7 @@ void Join_ServerStatistics::Trace(int serverId)
 
 //-------------------------------------------------------------------------------
 
-static Join_ServerStatistics g_serverStatistics[16];
+static Join_ServerStatistics g_serverStatistics[c_max_server_tasks];
 
 /*!
    @brief defines the interface of a server task of the Join_InvSelectIterator iterator
@@ -456,6 +459,7 @@ Join_InvSelectIterator::Join_InvSelectIterator
  , m_stop(false)
  , m_suspended(false)
  , m_isOpen(false)
+ , m_countStatistics(true)
  , m_error(e_ok)
  , m_bdInvSet()
  , m_maxServers(maxServerTasks)
@@ -524,6 +528,12 @@ bool Join_InvSelectIterator::FillKeyBuffer()
             }
             if ((m_maxServers > 1) && (m_keyCount > 4) && CreatedParallelServers())
             {
+                b73cmd_count(iget_inv_parallel);
+                if (m_countStatistics)
+                {
+                    m_countStatistics = false;
+                    b73cmd_count(ijoin_parallel);
+                }
                 this->EnterRequest (m_keyCount);
             }
             else
@@ -575,22 +585,22 @@ bool Join_InvSelectIterator::CreatedParallelServers()
     const bool c_inRegion = true; 
     int availableServers = bd01UsableServerForParallelExecution (m_coordinatorTrans.trTaskId_gg00,
                 m_select_row, !c_inRegion);
-    if (availableServers < m_maxServers)
+    if (availableServers <= 1)
     {
         // not enough servers available
         m_serversInUse = false;
         return false;
     }
     // try parallel execution
-    if (!m_servers.Initialize(m_maxServers))
+    if (!m_servers.Initialize(availableServers))
     {
         // no memory to initialize vector
         m_serversInUse = false;
         return false;
     }
-    SAPDBTRACE_WRITELN( Join_Trace, 1, "starting " << m_maxServers << " servers");
+    SAPDBTRACE_WRITELN( Join_Trace, 1, "starting " << availableServers << " servers");
     int serverId;
-    for (serverId = 0; serverId < m_maxServers; ++serverId)
+    for (serverId = 0; serverId < availableServers; ++serverId)
     {
         m_servers[serverId] = new(m_allocator) Join_InvSelectServer(*this, serverId);
         if (!m_servers[serverId])
@@ -602,7 +612,7 @@ bool Join_InvSelectIterator::CreatedParallelServers()
             return false;
         }
     }
-    for (serverId = 0; serverId < m_maxServers; ++serverId)
+    for (serverId = 0; serverId < availableServers; ++serverId)
     {
         this->StartServer(serverId);
         if (this->NoError())
@@ -980,6 +990,10 @@ void Join_InvSelectIterator::SetMaxServerTasks(SAPDB_Int4 max)
     {
         m_maxServers = max;
     }
+    if (m_maxServers > c_max_server_tasks)
+    {
+        m_maxServers = c_max_server_tasks;
+    }
     SAPDBTRACE_WRITELN( Join_Trace, 1, "max Servers " << m_maxServers );
 }
 
