@@ -265,10 +265,6 @@ private:
 	/// After data loading the database is set to readonly. A data backup resets this flag.
     /// If the backup was done in admin mode the next restart will reset the flag.
     bool CheckAndResetReadOnlyState       (tgg00_TransContext &trans);
-    /// If an until timestamp is given it is check with this.
-    /// If the current db state is younger then the given date then false is returned.
-    bool CheckUntilTimeStamp              (Kernel_Date         untildate,
-                                           Kernel_Time         untiltime);
     /// This scans the log volume and determines all parameters. firstKnown, lastKnown, ...
     bool RestartLog                          (tsp00_TaskId          taskid,
                                               RestartKind           reason,
