@@ -29,9 +29,6 @@
 #define KERNEL_PAGE74_HPP
 
 #include "KernelCommon/Kernel_Page.hpp"
-#include "KernelCommon/Kernel_Exception.hpp"
-#include "KernelCommon/Kernel_Messages.hpp"  
-#include "RunTime/RTE_Message.hpp"
 
 /*!
 @class          Kernel_Page74
@@ -116,38 +113,8 @@ public:
     with parity bytes kept in page header and trailer
     Applicable immediately after a page is read from device
     */
-    virtual SAPDB_Bool CheckAfterRead() const
-    {
-        const ParityAlgorithm   algorithm  = ReadParityAlgorithm();
-        const Parity            parity     = CalcParity();
-
-        switch( algorithm )
-        {
-        case Kernel_CheckSumAlgorithmen:
-            {
-                if(( parity == ReadParityFromHeader()) && ( parity == ReadParityFromTrailer()))
-                    return true;
-                break;
-            }
-        case Kernel_HeaderTrailerAlgorithm:
-            {
-                if( ReadParityFromHeader() == ReadParityFromTrailer() )
-                    return true;
-                break;
-            }
-        default:
-            ;
-        }
-
-        Kernel_Exception errMsg( __CONTEXT__, KERNEL_ERR_PAGE_BAD_INPUT,
-                                 SAPDB_ToString( algorithm, _T_d ),
-                                 SAPDB_ToString( parity, _T_d ),
-                                 SAPDB_ToString( ReadParityFromHeader(), _T_d ),
-                                 SAPDB_ToString( ReadParityFromTrailer(), _T_d ));
-        RTE_Message( errMsg );
-
-        return false;
-    }
+    virtual bool CheckAfterRead() const;
+   
     /*!
     @brief          Prepares page for output to device
     @return         (SAPDB_Bool) true if check successful
@@ -156,37 +123,14 @@ public:
     Updates parity information with actual frame contents
     Applicable immediately before a page is written to device
     */
-    virtual SAPDB_Bool PrepareForWrite()
-    {
-        if( ReadParityFromHeader() != ReadParityFromTrailer() )
-        {
-            Kernel_Exception errMsg( __CONTEXT__, KERNEL_ERR_PAGE_BAD_OUTPUT,
-                                     SAPDB_ToString( ReadParityFromHeader(), _T_d ),
-                                     SAPDB_ToString( ReadParityFromTrailer(), _T_d ));
-            RTE_Message( errMsg );
-
-            return false;
-        }
-        UpdateParity();
-        return true;
-    }
+    virtual bool PrepareForWrite();
+   
     /*!
     @brief          Verifies consistency of page contents
     @return         (SAPDB_Bool) true if verify successful
     */
-    virtual SAPDB_Bool Verify() const
-    {
-        if( ReadParityFromHeader() != ReadParityFromTrailer() )
-        {
-            Kernel_Exception errMsg( __CONTEXT__, KERNEL_ERR_PAGE_BAD_VERIFY,
-                                     SAPDB_ToString( ReadParityFromHeader(), _T_d ),
-                                     SAPDB_ToString( ReadParityFromTrailer(), _T_d ));
-            RTE_Message( errMsg );
-
-            return false;
-        }
-        return true;
-    }
+    virtual SAPDB_Bool Verify() const;
+    
 	/// Reads parity check algorithm number from frame
     ParityAlgorithm ReadParityAlgorithm() const
     {
