@@ -297,9 +297,7 @@ public:
 
             m_MinLongColumnLength   = shortColStat.m_MinRecordLength -  metaDataLength;
             m_MaxLongColumnLength   = shortColStat.m_MaxRecordLength - metaDataLength;
-            m_TotalLongColumnLength =
-                static_cast<SAPDB_Int4>(( shortColStat.m_TotalRecordLength / shortColStat.m_RecordCount ) -
-                                        ( shortColStat.m_RecordCount * metaDataLength ));
+            m_TotalLongColumnLength = shortColStat.m_TotalRecordLength - ( shortColStat.m_RecordCount * metaDataLength );
         }
     }
 
