@@ -38,6 +38,7 @@
 #include "SAPDBCommon/Tracing/SAPDBTrace_Stream.hpp"
 #include "SAPDBCommon/SAPDB_sprintf.h"
 #include "KernelCommon/Kernel_VTrace.hpp"
+#include "SQLManager/ErrorHandling/SQLManErr_Interface.hpp"
 
 /*----------------------------------------------------------------------------------------------------*/
 Kernel_BasisErrorTracer::Kernel_BasisErrorTracer ( tgg00_BasisError &berror,
@@ -190,3 +191,21 @@ externCpp void Kernel_TraceBuffer ( const void       *buffer,
         currentOffset += offsetInLine;
     }
 }
+/* --------------------------------------------------------------------------- */
+externCpp SAPDB_Int2 Kernel_BasisErrorToResultCode (const tgg00_BasisError berr)
+{
+    return SQLManErr_Interface::GetInstance().GetReturnCode(berr,sqlm_internal);
+}
+
+/* --------------------------------------------------------------------------- */
+externCpp const SAPDB_Char *  Kernel_BasisErrorToResultString (const tgg00_BasisError berr)
+{
+    return SQLManErr_Interface::GetInstance().GetErrorText(Kernel_BasisErrorToResultCode(berr));
+}
+
+/* --------------------------------------------------------------------------- */
+externCpp const SAPDB_Char *  Kernel_BasisErrorToString (const tgg00_BasisError berr)
+{
+    return SQLManErr_Interface::GetInstance().GetBaseErrorText(berr);
+}
+
