@@ -97,4 +97,11 @@ externCpp void Kernel_TraceBuffer ( const void       *buffer,
                                     SAPDB_UInt        length,
                                     const SAPDB_Char *title   = NULL,
                                     SAPDB_UInt        size    = 0 );
+/// converts an internal basis error into an externally known return code
+externCpp SAPDB_Int2 Kernel_BasisErrorToResultCode (const tgg00_BasisError berr);
+/// converts an internal basis error into a short explanation string
+externCpp const SAPDB_Char *  Kernel_BasisErrorToResultString (const tgg00_BasisError berr);
+/// converts an internal basis error into a basis error string
+externCpp const SAPDB_Char *  Kernel_BasisErrorToString (const tgg00_BasisError berr);
+
 #endif // KERNEL_TRACE_H
