@@ -81,6 +81,7 @@ SAPDBDiag_CheckTopic Runtime_Check       ("RUNTIME","Checks for runtime environm
 SAPDBDiag_CheckTopic SQLManager_Check    ("SQLMANAGER","Checks for the SQL manager component");
 SAPDBDiag_CheckTopic SharedSQL_Check     ("SHAREDSQL","Checks for the SharedSQL component");  
 SAPDBDiag_CheckTopic Table_Check         ("TABLE","Checks for the new table handling");
+SAPDBDiag_CheckTopic HashedResultSet_Check         ("HASHED_RESULTSET","Checks for the haseh resultset");
 
 /* ------------------------------------------------------------------ */
 
@@ -112,6 +113,7 @@ SAPDBDiag_CheckTopic * const Kernel_AllCheckSwitches [] = {
     &SQLManager_Check,
     &SharedSQL_Check, 
     &Table_Check,
+    &HashedResultSet_Check,
     0
 };
 
