@@ -326,6 +326,10 @@
 #define KERNELPARAM_FORBID_LOAD_BALANCING   (SAPDB_UTF8 *)"FORBID_LOAD_BALANCING"
 /*! cserv name of the configuration parameter EXTERNAL_DUMP_REQUEST */
 #define KERNELPARAM_EXTERNAL_DUMP_REQUEST (SAPDB_UTF8 *)"EXTERNAL_DUMP_REQUEST"
+/*! cserv name of the configuration parameter SYMBOL_RESOLUTION */
+#define KERNELPARAM_SYMBOL_RESOLUTION (SAPDB_UTF8 *)"SYMBOL_RESOLUTION"
+/*! cserv name of the configuration parameter PREALLOCATE_IOWORKER */
+#define KERNELPARAM_PREALLOCATE_IOWORKER   (SAPDB_UTF8 *)"PREALLOCATE_IOWORKER"
 /*++++++++++++++++*OS DEPENDEND PARAMETERS *+++++++++++++++++++*/
 /***************************************************************/
 #if defined(_WIN32)
@@ -345,6 +349,9 @@
 #define KERNELPARAM_USE_MEM_ENHANCE (SAPDB_UTF8 *)"USE_MEM_ENHANCE"
 /*! cserv name of the configuration parameter USE_FIBERS */
 #define KERNELPARAM_USE_FIBERS (SAPDB_UTF8 *)"USE_FIBERS"
+/*! cserv name of the configuration parameter MINI_DUMP */
+#define KERNELPARAM_MINI_DUMP (SAPDB_UTF8 *)"MINI_DUMP"
+
 
 /***************************************************************/
 #else
