@@ -108,6 +108,15 @@ public:
 
     virtual void DeregisterAllocator(RTEMem_AllocatorInfo& allocatorInfo);
 
+  /*!
+   * \brief check if OneDB system
+   *
+   * Tells whether liveCache is a OneDB system.
+   *
+   * \return true, if liveCache is a OneDB system, false otherwise
+   */
+    virtual bool IsOneDBSystem();
+
 	/*!-------------------------------------------------------------------------
 	function:	  GetOmsAllocator
 	description:  returns a pointer to the global liveCache oms allocator 
@@ -352,6 +361,8 @@ public:
   virtual bool UseReaderWriterLocks();
 
   virtual void SetErrorCallback(DbpErrorCallbackInterface *cb);
+
+  virtual RTE_IInterface &GetKernelRunTimeInterface();
 protected:
   friend class LVCSim_liveCacheSink;
 
