@@ -145,6 +145,9 @@ private:
 	/// Create underlying raw allocator for session-specific allocators.
     void createRawAllocator();
 
+    tsp00_TaskId         m_taskId;
+    static tsp00_TaskId  m_taskIdCnt;
+
 protected:
 	/// Lock for transaction-specific variables.
 	static RTESync_Spinlock						txCounterLock; 
