@@ -644,8 +644,9 @@ void Log_History::RegisterUndoFile (tgg00_TransContext &trans,
 
 	Log_HistoryFile histfile ( trans, info.root, Data_PageNo() );
 
+    trans.trState_gg00.addElement ( tsDbFullNowait_egg00 ); // PTS 1135886 mb 2005-06-01
     histfile.AppendUndoFile (file);
-
+    trans.trState_gg00.delElement ( tsDbFullNowait_egg00 ); // PTS 1135886 mb 2005-06-01
     m_Directory.UpdateInfoAfterRegisterNewUndoFile
                 ( trans.trTaskId_gg00,
                   fileno,
@@ -1314,7 +1315,25 @@ Log_History::GetBeforeImage
         return;
     }
     
-    Data_SplitSpaceReader reader (*iter);
+    Log_UndoFile::EntrySpace &space = *iter;
+    
+    if ( ! space.CheckAlignment() )
+    {
+        if ( LogHistory_Trace.TracesLevel(6) )
+        {
+            Kernel_VTrace() << "GetBeforeImage() history get: " << pageno << "." << offset
+                            << " for oid: " << TestOid.gg92GetPno() << "." << TestOid.gg92GetPos()
+                            << " with view: " << Trans.trConsistView_gg00.gg90GetInt4()
+                            << NewLine;
+            Kernel_VTrace() << "GetBeforeImage() could not read image because wrong ALIGNMENT" << NewLine;
+        }
+        Trans.trError_gg00 = e_obj_history_not_found;
+        iter.Invalidate();
+        file.Invalidate();
+        return;
+    }
+    
+    Data_SplitSpaceReader reader (space);
     Log_BeforeImage       image;
     bool                  isOK = true;
     
