@@ -82,6 +82,21 @@ public:
                ? Log_IOSequenceNo(NodePtr()->ndInvUsageCnt_bd00())
                : Log_IOSequenceNo();
     }
+    
+    /// sets a flag which indicates that this open trans file was created during redo
+    /// and not in online mode
+    void SetCreatedDuringRedo(bool isCreatedDuringSavepoint)
+    {
+        SAPDBERR_ASSERT_STATE(IsAssigned());
+        NodePtr()->nd_sorted() = isCreatedDuringSavepoint ? 1 : 0;
+    }
+    
+    /// returns true if this open trans file was created during redo and in online mode
+    bool GetCreatedDuringRedo()
+    {
+        SAPDBERR_ASSERT_STATE(IsAssigned());
+        return NodePtr()->nd_sorted() != 0;
+    }
 };
 
 
@@ -108,13 +123,15 @@ public:
 
 public:
 
-    /// This constructs an Redo log handle for the given transaction.
-    /// If the RootPageNo is valid, an existing file is assumed.
-    /// If the SavepointSequence is given this is written to a newly created root page.
+    /// This is used to create a new open trans file
     Log_OpenTransFile (tgg00_TransContext          &Trans,
-                       const Data_PageNo            Root,
-                       const Log_SavepointSequence  SavepointSequence = Log_SavepointSequence());
-              
+                       const Log_SavepointSequence  SavepointSequence,
+                       bool                         bIsRedoSavepoint);
+
+    /// This is used for reading
+    Log_OpenTransFile (tgg00_TransContext  &Trans,
+                       const Data_PageNo    Root);
+
     /// A new RedoLogfile is created.
     virtual bool Create ();
     virtual void Drop ();
@@ -139,6 +156,12 @@ public:
         return m_Container.GetSpaceSize();
     }
 
+    /// returns true if this file belongs to a redo savepoint
+    bool CreatedDuringRedo() const
+    {
+        return m_CreatedDuringRedo;
+    }
+    
 private:
 
     /// The container for this file.
@@ -150,6 +173,9 @@ private:
 	/// This sequence is written into the root during Create().
     Log_SavepointSequence m_SavepointSequence;
 
+    /// if this is true the transactions within this file were last executed during redo.
+    bool m_CreatedDuringRedo;
+
     /// The allocator is only used by the verify method to construct an undo file.
     SAPDBMem_IRawAllocator &m_Allocator;
 };
