@@ -158,17 +158,22 @@ void Log_Page::WriteToTrace() const
 }
 
 //------------------------------------------------------------------------------
-
-void Log_Page::Truncate (Log_IOSequenceNo newLastIOSeq)
+void Log_Page::Truncate(Log_IOSequenceNo newLastIOSeq)
 {
     while (!IsEmpty() && (ReadLastWriterIOSequenceNo() != newLastIOSeq))
     {
-        PersistentHeaderPtr()->m_OffsetCount -= 1;
-        WriteWriterIOSequenceNo(ReadLastWriterIOSequenceNo() - 1 );
+        if ( ReadOffsetCount() > 1 )
+        {
+            PersistentHeaderPtr()->m_OffsetCount -= 1;
+            WriteWriterIOSequenceNo(ReadLastWriterIOSequenceNo() - 1 );
+        }
+        else
+        {
+            ResetOffsetCount();
+        }
     }
     WriteQueueIOSequenceNo( 0 );
     UpdateParity();
 }
 
 
-
