@@ -18,23 +18,24 @@
 
   ------------------------------------------------------------------------------
 
-  ========== licence begin  GPL
-  Copyright (c) 2000-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2000-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *******************************************************************************/
 
@@ -47,6 +48,8 @@
 #include "SAPDBCommon/SAPDB_ToString.hpp"
 #include "KernelCommon/Kernel_VTrace.hpp"
 #include "Logging/Log_Exceptions.hpp"
+#include "Logging/Log_Savepoint.hpp"
+#include "Logging/Log_Volume.hpp"
 
 // -----------------------------------------------------------------------------
 // Suspend reasons for log queue:
@@ -241,7 +244,7 @@ void Log_Queue::ReserveSpace ( TaskID                            usertaskid,
 
         available = page.FreeSpaceAvailable();
 
-        if ( LogVolume_Trace.TracesLevel(6) )
+        if ( LogVolume_Trace.TracesLevel(7) )
         {
             Kernel_VTrace() << "wanted: " << wanted << ", available: " << available;
             WriteEntryToTrace( *m_CurrentAppend,
@@ -326,6 +329,19 @@ void Log_Queue::WaitUntilSpaceIsAvailable ( tsp00_TaskId                      us
         if ( LogVolume_Trace.TracesLevel(6) )
             Kernel_VTrace() << "LOG_DEVICE IS FULL: task " << usertaskid << " is suspended";
         RTE_Message(Log_Exception(__CONTEXT__,LOG_DEVICE_FULL,SAPDB_ToString(usertaskid)));
+        if ( Log_Volume::Instance().IsAutomaticOverwrite(usertaskid) )
+        {
+            // expensive but log is full, so system stopps anyway
+            tgg00_TransContext  trans;
+        
+            trans.trTaskId_gg00 = usertaskid;
+            trans.trSessionId_gg00.becomes( cgg_nil_session );
+            trans.trTransId_gg00.becomes( cgg_nil_trans );
+            trans.trWriteTransId_gg00.becomes( cgg_nil_trans );
+            trans.trSubtransId_gg00 = cgg_zero_subtrans;
+        
+            Log_SavepointManager.StartSavepoint (trans, Log_SVPReasonLogWriter);
+        }
         vsuspend(usertaskid, LOG_DEVICE_FULL_SUSPEND);
     }
 }
@@ -338,7 +354,7 @@ void Log_Queue::UserTaskReady
 
     EnterRegion(usertaskid); 
     
-    if ( LogVolume_Trace.TracesLevel(6) )
+    if ( LogVolume_Trace.TracesLevel(7) )
         WriteEntryToTrace(space.GetPartEntry(0), "UserTaskReady");
 
     // decrease busy task count
@@ -378,7 +394,7 @@ void Log_Queue::UserTaskEOTReady
                                       "Log_Queue::UserTaskEOTReady: RegisterForIOWait() failed") );
     }
 
-    if ( LogVolume_Trace.TracesLevel(6) )
+    if ( LogVolume_Trace.TracesLevel(7) )
         WriteEntryToTrace(entry, "UserTaskEOTReady");
 
     // decrease busy task count
@@ -518,7 +534,7 @@ void Log_Queue::GetOutput (TaskID          writertaskid,
         output.Add(page);
         ++pagecount;
 
-        if ( LogVolume_Trace.TracesLevel(6) )
+        if ( LogVolume_Trace.TracesLevel(7) )
             WriteEntryToTrace ( *iter,
                                 "GetOutput",
                                 pagecount,iter==m_CurrentAppend,
@@ -576,7 +592,7 @@ void Log_Queue::WriterTaskReady
     SAPDB_UInt count = 0;
     while (count < pagecount)
     {
-        if ( LogVolume_Trace.TracesLevel(6) )
+        if ( LogVolume_Trace.TracesLevel(7) )
             WriteEntryToTrace( *m_CurrentOutput,
                                "WriterTaskReady",
                                count,
@@ -627,6 +643,7 @@ void Log_Queue::CopyCurrentAppend()
 {
     Log_Page& page      = m_CurrentAppend->GetPage();
     ++m_CurrentAppend;
+    ++m_PagesUsed;  // PTS 1135588 mb 1005-05-08
     Log_Page& nextpage  = m_CurrentAppend->GetPage();
     PageFrame destframe = nextpage.GetFrame();
     PageFrame srcframe  = page.GetFrame();
@@ -647,7 +664,7 @@ void Log_Queue::CopyCurrentAppend()
     nextpage.WriteQueueID(m_QueueID);
     nextpage.PrepareForWrite();//+++++ expensive => should be only resetted
 
-    if ( LogVolume_Trace.TracesLevel(6) )
+    if ( LogVolume_Trace.TracesLevel(7) )
         WriteEntryToTrace( *m_CurrentAppend,
                            "CopyCurrentAppend",
                            1,
