@@ -494,9 +494,10 @@ void Log_Savepoint::Coordinator (tgg00_TransContext &Trans)
         k51enter_all_trans_regions (Trans.trTaskId_gg00);
         SAPDBTRACE_WRITELN (LogTrans_Trace, 6, "SVP: no new write transaction can be started or removed now");
 
+        const bool bIsRedoSavepoint = ! m_LogWriteEnabled;
+
         DetermineRedoStartPositions ( Trans,
                                       *reinterpret_cast<SAPDBMem_IRawAllocator*>(Trans.trAllocator_gg00),
-                                      Reason,
                                       saveptParam);
 
         SAPDBTRACE_WRITELN (LogTrans_Trace, 6, "SVP: savepoint logentries were written to the archive logs. ");
@@ -505,7 +506,7 @@ void Log_Savepoint::Coordinator (tgg00_TransContext &Trans)
         // PTS ? UH 2003-05-07 moved k57end_flush_sequences() directly after DetermineRedoStartPositions()
         k57end_flush_sequences (Trans.trTaskId_gg00);
 
-        CreateOpenTransFile (Trans, saveptParam);
+        CreateOpenTransFile (Trans, saveptParam, bIsRedoSavepoint);
         SAPDBTRACE_WRITELN (LogTrans_Trace, 6, "SVP: open trans file was created.");
 
         if( TRUE == g01is_livecache() )
@@ -559,11 +560,21 @@ void Log_Savepoint::Coordinator (tgg00_TransContext &Trans)
        
         // Prepare converter for backup. Note that this will change converter pages
         // and this pages have to be flushed with the current savepoint.
-        if( Log_SVPReasonSaveData == Reason )
-            Converter_IBackUp::Instance().BeginSaveData( Trans.trTaskId_gg00 );
-        else 
-            if( Log_SVPReasonSavePages == Reason )
-                Converter_IBackUp::Instance().BeginSavePages( Trans.trTaskId_gg00 );
+        if( Log_SVPReasonSaveData == Reason  || Log_SVPReasonSavePages == Reason)
+        {   
+            Converter_ReturnCode retCode = Converter_Ok;
+            if( Log_SVPReasonSaveData == Reason ){
+                retCode = Converter_IBackUp::Instance().BeginSaveData( Trans.trTaskId_gg00 );
+            }
+            else{ 
+                retCode = Converter_IBackUp::Instance().BeginSavePages( Trans.trTaskId_gg00 );
+            }
+            if( Converter_Ok != retCode )
+            {   // TODO TorstenS/Uwe system shall not crash (KERNEL_DATA_BACKUP_FAILED)
+                RTE_Crash( SAPDBErr_Exception(__CONTEXT__,SAPDBERR_ASSERT_STATE_FAILED, 
+                    "BeginSaveData/Pages because of exhausted memory"));
+            }
+        }
 
         IOMan_PackedBlockAddress  packedRootBlockAddr;
         Data_PageNo               maxDynamicPageNo;
@@ -636,19 +647,20 @@ void Log_Savepoint::Coordinator (tgg00_TransContext &Trans)
 void Log_Savepoint::DetermineRedoStartPositions
     (tgg00_TransContext     &CoordinatorTrans,
      SAPDBMem_IRawAllocator &Allocator,
-     Log_SavepointReason     Reason,
      tkb00_SaveptParam      &saveptParam)
 {
     SAPDBTRACE_METHOD_DEBUG ("Log_Savepoint::DetermineRedoStartPositions", LogTrans_Trace, 5);
 
     if (!m_LogWriteEnabled)                     // PTS 1115875 mb 2002-05-28
     {
-        if ( Reason == Log_SVPReasonRestart )
+        if ( Log_SVPReasonRestart == saveptParam.svpReason_kb00 )
             m_LogWriteEnabled = true; // PTS 1126112 UH 2003-12-09 
         else
         {
             Log_EntryInfo entryInfo;
             Kernel_IAdminRestartShutdown::Instance().GetLastEntryRead (entryInfo);
+            if ( entryInfo.iosequence.IsInvalid() )
+                RTE_Crash( SAPDBErr_Exception(__CONTEXT__,SAPDBERR_ASSERT_STATE_FAILED, "Savepoint IOSequence must be valid") );
             saveptParam.svpIOsequence_kb00       = entryInfo.iosequence.RawValue();
             saveptParam.svpStartOffset_kb00      = entryInfo.pageoffset;
             saveptParam.svpStartEntryOffset_kb00 = entryInfo.entryoffset;
@@ -660,9 +672,9 @@ void Log_Savepoint::DetermineRedoStartPositions
     }
     
     Log_AfterImage      AfterImage;
-    Log_ActionSavepoint Action (Reason);
+    Log_ActionSavepoint Action (Log_SavepointReason(saveptParam.svpReason_kb00));
 
-    if ( Reason == Log_SVPReasonRestart )
+    if ( saveptParam.svpReason_kb00 == Log_SVPReasonRestart )
         AfterImage.SetActionType(Log_FinishOpenTrans);
     else
         AfterImage.SetActionType(Log_SavepointEntry);
@@ -769,6 +781,7 @@ void Log_Savepoint::FlushRestartRecordAndLogInfoPages
     if ( ! Kernel_IAdminHotStandby::Instance().IsStandby() )
         log.WriteSavepointValuesAndFlushInfoPage
                     (coordinatorTrans.trTaskId_gg00,
+                     Log_SVPReasonRestart == saveptParam.svpReason_kb00, // PTS 1137938
                      k57restartrec->rstReleaseVersion_kb00(),
                      SAPDBFields_Field(svpValue, sizeof(saveptParam)));
 }
@@ -779,38 +792,46 @@ void Log_Savepoint::FlushCompleted (tsp00_TaskId            TaskId,
 {
     SAPDBTRACE_METHOD_DEBUG ("Log_Savepoint::FlushCompleted", LogTrans_Trace, 5);
 
-    // increment converter version. At this time all savepoint relevant data
-    // pages and the converter pages are written to the data area.
-    // The data pages written next, will get the incremented converter version!
-    Converter_Version newConverterVersion;
-    Converter_ISavePoint::Instance().EndSavepoint( TaskId, newConverterVersion );
-
-    // Set all blocks from state free after savepoint to free. Note that this
-    // has to take place before the data cache is informed about the savepoint end
-    // situation, because this guarantees that blocks which are written after the 
-    // savepoint won't be set to free, because of the following call. 
-    // PTS 1132143 TS 2004-10-26
+    // Set all blocks from state FreeAfterSavepoint to Free. Note that this
+    // has to take place BEFORE the data cache AND the converter are informed 
+    // about the savepoint end situation, because: 
+    // 
+    // First: this guarantees that blocks which are written after the data cache and 
+    // converter flush initiated by the savepoint won't be set to FreeAfterSavepoint
+    // resp. Free immediately. (PTS 1132143)
+    // 
+    // Second: this guarantees that the blocks of the pageNo's which are released at 
+    // the end of the savepoint won't be set to FreeAfterSavepoint resp. Free 
+    // immediately. (PTS 1137294)
 
     FBM_IManager::Instance().SetAllBlocksMarkedAsFreeAfterSVPToFree( TaskId );
 
+    // Increment converter version. At this time all savepoint relevant data
+    // pages and the converter pages are written to the data area.
+    // The data pages written next, will get the incremented converter version!
+    // At this point the converter is not in savepoint mode, which means that there
+    // is no special handling for pageNo's and the corresponding blocks to be released!
+
+    Converter_Version newConverterVersion;
+    Converter_ISavePoint::Instance().EndSavepoint( TaskId, newConverterVersion );
+
     // Reset savepoint state and enable data cache to write non 
     // savepoint relevant data pages to the data area
+
     bd20SavepointCompleted( TaskId, converterVersion );
 
-    // Set all blocks from state free after savepoint to free  
-    //FBM_IManager::Instance().SetAllBlocksMarkedAsFreeAfterSVPToFree( TaskId ); PTS 1132143 TS 2004-10-26
-    
     // Free pnos removed during prepare phase 
     Converter_ISavePoint::Instance().FreePageNosAfterSavepoint( TaskId );
 }
 
 /*---------------------------------------------------------------------------*/
 void Log_Savepoint::CreateOpenTransFile (tgg00_TransContext &CoordinatorTrans,
-                                         tkb00_SaveptParam  &saveptParam)
+                                         tkb00_SaveptParam  &saveptParam,
+                                         bool                bIsRedoSavepoint)
 {
     SAPDBTRACE_METHOD_DEBUG ("Log_Savepoint::CreateOpenTransFile", LogTrans_Trace, 5);
 
-    Log_OpenTransFile File             (CoordinatorTrans, Data_PageNo(), saveptParam.svpId_kb00);
+    Log_OpenTransFile File             (CoordinatorTrans, saveptParam.svpId_kb00, bIsRedoSavepoint);
     Log_OpenTransFile OldOpenTransFile (CoordinatorTrans, saveptParam.svpOpenTransRoot_kb00);
     tgg00_TransIndex  WriteTransIndex = cgg_nil_transindex;
     Log_Transaction  *pLogTrans       = NULL;
