@@ -626,7 +626,9 @@ void Log_Transaction::EndOfTransHandling (TransState State)
 
     if ( online == m_TransType
          &&
-         m_Context.LastRedoEntrySequence.IsValid() )
+         (m_Context.LastRedoEntrySequence.IsValid()
+         ||
+         m_Context.LastUndoEntrySequence.IsValid()) ) // PTS 1136623 UH 2005-08-29
     {
         if ( ! WriteEndOfTransEntry (State) )
             RTE_Crash( SAPDBErr_Exception(__FILE__, __LINE__,
@@ -2105,18 +2107,6 @@ bool Log_Transaction::IsSavepointRelevant()
     return isRelevant;
 }
 
-/* -------------------------------------------------------------------------------- */
-bool Log_Transaction::IsRedoRelevant()
-{
-    SAPDBTRACE_METHOD_DEBUG ("Log_Transaction::IsRedoRelevant", LogTrans_Trace, 5);
-    
-    bool isRelevant = ! GetRedoTransNo().gg90IsNil();
-
-    SAPDBTRACE_WRITELN (LogTrans_Trace, 6, "isRelevant: " << isRelevant);
-    
-    return isRelevant;
-}
-
 /* -------------------------------------------------------------------------------- */
 void Log_Transaction::GiveUndoFileToHistory()
 {
