@@ -11,7 +11,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 /*===========================================================================*
@@ -45,7 +46,7 @@
  *  EXTERNAL VARIABLES                                                       *
  *===========================================================================*/
 
-const char* Log_ActionTypeStrings [] =
+static const char* ActionTypeStrings [] = // PTS 1134693 UH 2005-04-06 changed to static(local)
 {
     "NoOp",
     "Commit",
@@ -83,9 +84,21 @@ const char* Log_ActionTypeStrings [] =
     "ReloadFile",
     "UnloadFile",
     "SetFileState",
-    "MultipleActions"
+    "MultipleActions",
+    "+++IllegalType+++" // PTS 1134693 UH 2005-04-06
 };
 
+/*---------------------------------------------------------------------------*/
+
+const char* Log_GetActionTypeString(const Log_ActionType type)
+{
+    // PTS 1134693 UH 2005-04-06 new
+    if ( type > Log_IllegalType )
+        return ActionTypeStrings[Log_IllegalType];
+	else
+        return ActionTypeStrings[type];
+}
+
 /*---------------------------------------------------------------------------*/
 const char * Log_ErrorStateStrings [] =
 {
@@ -178,7 +191,7 @@ void Log_EntryInfo::WriteToTrace(const char *title)
         trace << title << ": ";
     trace << pageoffset << "." << entryoffset
           << " [" << iosequence << "] '"
-          << Log_ActionTypeStrings[entrytype]
+          << Log_GetActionTypeString(entrytype)
           << "' " << entrydate << "-" << entrytime;
     #endif
 }
@@ -198,7 +211,7 @@ void Log_EntryInfo::Message (const char *title,
                   SAPDB_ToString(iosequence,_T_d),
                   SAPDB_ToString(pageoffset,_T_d),
                   SAPDB_ToString(entryoffset,_T_d),
-                  Log_ActionTypeStrings[entrytype],
+                  Log_GetActionTypeString(entrytype),
                   SAPDB_ToString(entrydate,_T_d),
                   SAPDB_ToString(entrytime,_T_d) ) );
     #endif
