@@ -6,7 +6,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 #ifndef LOG_TYPES_HPP
@@ -358,7 +359,7 @@ enum Log_ErrorState
     Log_LogAndSoftwareIncompatible      = 12,
     Log_ErrorState_DO_NOT_USE           = 13
 };
-/// for tracing the action types
+/// for tracing the error states
 extern const char* Log_ErrorStateStrings[Log_ErrorState_DO_NOT_USE];
 /// All actions which can be un- and normally re-done are listed here.
 enum Log_ActionType
@@ -417,10 +418,11 @@ enum Log_ActionType
     //
     Log_MultipleActions = 36,
     //
-    Log_ActionType_DO_NOT_USE = 37
+    Log_IllegalType    = 37,
+    Log_ActionType_DO_NOT_USE = 38
 };
 /// for tracing the action types
-extern const char* Log_ActionTypeStrings[Log_ActionType_DO_NOT_USE];
+const char* Log_GetActionTypeString(const Log_ActionType type);
 /// This differs the reasons to trigger a savepoint.
 enum Log_SavepointReason
 {
