@@ -7,23 +7,24 @@
   @brief          Log writer
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2000-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2000-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 #ifndef LOG_WRITER_HPP
@@ -292,8 +293,8 @@ public:
      */
     Log_DeviceBlockCount CalculateReservedPages(SAPDB_UInt numPagesInQueues)
     {
-        m_PagesNotAvailableForUsers = numPagesInQueues + g01maxuser() + 1;
-        return m_PagesNotAvailableForUsers + LOG_RESTART_RESERVE_SPACE;
+        m_PagesNotAvailableForUsers = numPagesInQueues + g01maxuser() + 1 + LOG_RESTART_RESERVE_SPACE;
+        return m_PagesNotAvailableForUsers; // PTS 1134810 UH 2005-04-12
     }
 
     /*!
@@ -342,6 +343,9 @@ public:
 		// PTS 1124876 UH 2003-10-23 new
         return m_LogUsageEvents.GetEventSet (events, true);
     }
+    
+    /// write internal information to the knltrace
+    void WriteToTrace (const char * title = 0) const;
 
 private:
     
