@@ -140,7 +140,7 @@ inline void OMS_ClassIdEntry::DeleteSelf(OMS_Context* pContext)
   }
   
   // release reference to global container dictionary 
-  OMS_Globals::DetachContainerInfo(pContext->LcSink(), m_containerInfo);
+  OMS_Globals::DetachContainerInfo(pContext->LcSink(), GetContainerInfoPtr());
   // destroy self
   pContext->deallocate(this);
 }
@@ -149,52 +149,71 @@ inline void OMS_ClassIdEntry::DeleteSelf(OMS_Context* pContext)
 
 inline const OMS_ClassInfo* OMS_ClassIdEntry::GetClassInfoPtr() const 
 {
-  return m_containerInfo->GetClassInfoPtr();
+  return GetContainerInfoPtr()->GetClassInfoPtr();
 }
 
 /*----------------------------------------------------------------------*/
 
 inline OMS_ContainerInfo* OMS_ClassIdEntry::GetContainerInfoPtr() const 
 {
+  if (m_containerInfo->m_eyeCatcher != 0xabcdabcd){
+    pasbool     *pToCancel;
+    tsp00_TaskId taskId;
+    OMS_Session *pSession;
+
+    IliveCacheSink *pSink = OMS_Globals::GetCurrentLcSink();
+    pSink->GetDefaultContext(reinterpret_cast<void**>(&pSession), &pToCancel, taskId);
+
+    // Remove entry out of the local container directory and delete it
+    pSession->m_context->m_containerDir.HashDelete_Slow(const_cast<OMS_ClassIdEntry*>(this));
+    pSession->m_context->deallocate(const_cast<OMS_ClassIdEntry*>(this));
+
+    char buf[128];
+    sprintf (buf, "Eye-Catcher has wrong value : %#X", m_containerInfo->m_eyeCatcher);
+    DbpBase b(pSink);
+    b.dbpOpError(buf);
+    OMS_Globals::Throw(DbpError (DbpError::DB_ERROR, e_unknown_guid, buf, __MY_FILE__, __LINE__)); 
+  }
+
   return m_containerInfo;
 }
 
 /*----------------------------------------------------------------------*/
 
 inline tsp00_Uint4 OMS_ClassIdEntry::GetContainerHandle() const {
-  return m_containerInfo->GetContainerHandle();
+  return GetContainerInfoPtr()->GetContainerHandle();
 }
 
 /*----------------------------------------------------------------------*/
 
 inline OmsContainerNo OMS_ClassIdEntry::GetContainerNo() const {
-  return m_containerInfo->m_ContainerNo;
+  return GetContainerInfoPtr()->m_ContainerNo;
 }
 
 /*----------------------------------------------------------------------*/
 
 inline tgg00_FileId& OMS_ClassIdEntry::GetFileId() const { 
-  return m_containerInfo->m_ContainerId;
+  return GetContainerInfoPtr()->m_ContainerId;
 }
 
 /*----------------------------------------------------------------------*/
 
 inline const ClassIDRef OMS_ClassIdEntry::GetGuid() const {
-  return m_containerInfo->GetGuid();
+  return GetContainerInfoPtr()->GetGuid();
 }
 
 
 /*----------------------------------------------------------------------*/
 
 inline int OMS_ClassIdEntry::GetKeyLen() const {         
-  return m_containerInfo->GetKeyDesc().GetLen();      
+  return GetContainerInfoPtr()->GetKeyDesc().GetLen();      
 }
 
 /*----------------------------------------------------------------------*/
 
 
 inline const OMS_KeyDesc& OMS_ClassIdEntry::GetKeyDesc() const { // PTS 1122540
-  return m_containerInfo->GetKeyDesc();
+  return GetContainerInfoPtr()->GetKeyDesc();
 }
 
 /*----------------------------------------------------------------------*/
@@ -209,44 +228,44 @@ inline unsigned char* OMS_ClassIdEntry::GetKeyPtr(OmsObjectContainer* p) {
 /*----------------------------------------------------------------------*/
 
 inline tsp00_Int4 OMS_ClassIdEntry::GetObjectSize() const {
-  return m_containerInfo->GetObjectSize();
+  return GetContainerInfoPtr()->GetObjectSize();
 }
 
 /*----------------------------------------------------------------------*/
 
 inline tsp00_Int4 OMS_ClassIdEntry::GetPersistentSize() const {
-  return (tsp00_Int4) m_containerInfo->m_PersistentSize;
+  return (tsp00_Int4) GetContainerInfoPtr()->m_PersistentSize;
 }
 
 /*----------------------------------------------------------------------*/
 
 inline OmsContainerNo OMS_ClassIdEntry::GetSchema() const {
-  return m_containerInfo->m_schema;
+  return GetContainerInfoPtr()->m_schema;
 }
 
 /*----------------------------------------------------------------------*/
 
 inline void* OMS_ClassIdEntry::GetVirtualTablePtr() const {
-   return m_containerInfo->GetVirtualTablePtr();
+   return GetContainerInfoPtr()->GetVirtualTablePtr();
 }
 
 /*----------------------------------------------------------------------*/
 
 inline bool OMS_ClassIdEntry::IsDerivedClassOf(const ClassIDRef guid) const {
-  return m_containerInfo->m_clsInfo->IsDerivedClassOf(guid);
+  return GetContainerInfoPtr()->m_clsInfo->IsDerivedClassOf(guid);
 }
 
 /*----------------------------------------------------------------------*/
 
 inline bool OMS_ClassIdEntry::IsKeyedObject() const {  
   //return  m_containerInfo->m_clsInfo->IsKeyedObject();
-  return  m_containerInfo->GetKeyDesc().IsKeyed();
+  return  GetContainerInfoPtr()->GetKeyDesc().IsKeyed();
 }
 
 /*----------------------------------------------------------------------*/
 
 inline bool OMS_ClassIdEntry::IsVarObject() {
-  return m_containerInfo->m_clsInfo->IsVarObject();
+  return GetContainerInfoPtr()->m_clsInfo->IsVarObject();
 }
 
 /*----------------------------------------------------------------------*/
