@@ -113,7 +113,7 @@ void OMS_ClassIdHash::Clean() {
   while (iter) {
     OMS_ClassIdEntry* curr = iter();
     ++iter;
-    if (curr->m_containerInfo->IsDropped()) {
+    if (curr->GetContainerInfoPtr()->IsDropped()) {
       this->HashDelete(curr);
     }
   }
@@ -214,7 +214,7 @@ void OMS_ClassIdHash::Dump(OMS_DumpInterface& dumpObj) const
       clsIdEntryDumpInfo.m_this          = curr;
       clsIdEntryDumpInfo.m_clsidHashNext = curr->m_clsidHashNext;
       clsIdEntryDumpInfo.m_guidHashNext  = curr->m_guidHashNext;
-      clsIdEntryDumpInfo.m_containerInfo = curr->m_containerInfo;
+      clsIdEntryDumpInfo.m_containerInfo = curr->GetContainerInfoPtr();
       clsIdEntryDumpInfo.m_freeHead      = curr->m_freeHead;
       clsIdEntryDumpInfo.m_freeHeadInVersion = curr->m_freeHeadInVersion;
       dumpObj.Dump(&clsIdEntryDumpInfo, sizeof(clsIdEntryDumpInfo));
@@ -230,7 +230,7 @@ void OMS_ClassIdHash::Dump(OMS_DumpInterface& dumpObj) const
       clsIdEntryDumpInfo.m_this          = curr;
       clsIdEntryDumpInfo.m_clsidHashNext = curr->m_clsidHashNext;
       clsIdEntryDumpInfo.m_guidHashNext  = curr->m_guidHashNext;
-      clsIdEntryDumpInfo.m_containerInfo = curr->m_containerInfo;
+      clsIdEntryDumpInfo.m_containerInfo = curr->GetContainerInfoPtr();
       clsIdEntryDumpInfo.m_freeHead      = curr->m_freeHead;
       clsIdEntryDumpInfo.m_freeHeadInVersion = curr->m_freeHeadInVersion;
       dumpObj.Dump(&clsIdEntryDumpInfo, sizeof(clsIdEntryDumpInfo));
@@ -298,6 +298,48 @@ void OMS_ClassIdHash::HashDelete (OMS_ClassIdEntry* containerInfo) {
 
 /*----------------------------------------------------------------------*/
 
+// Method is doing the same as HashDelete with the exception, that the whole
+// hash-array is searched instead of only a single hash-slot. This method is
+// needed if the pointer to the global directory entry is not longer accessible
+// (see PTS 1137709)
+void OMS_ClassIdHash::HashDelete_Slow (OMS_ClassIdEntry *pDel) 
+{
+  // remove from ContainerHandle Hash 
+  for (int i=0; i<headentries; ++i){
+    OMS_ClassIdEntryPtr *prev = &m_clsidHead[i];
+    OMS_ClassIdEntryPtr  curr = *prev;
+    while (curr) {
+      if (curr == pDel) {
+        --m_count;
+        *prev = curr->m_clsidHashNext;
+        break;
+      }
+      else {
+        prev = &curr->m_clsidHashNext;
+        curr = curr->m_clsidHashNext;
+      }
+    }
+  }
+
+  // remove from Guid,Schema,ContainerNo Hash
+  for (int j=0; j<headentries; ++j){
+    OMS_ClassIdEntryPtr *prev     = &m_guidHead[j];
+    OMS_ClassIdEntryPtr  curr     = *prev;
+    while (curr) {
+      if (curr == pDel) {
+        *prev = curr->m_guidHashNext;
+        break;
+      }
+      else {
+        prev = &curr->m_guidHashNext;
+        curr = curr->m_guidHashNext;
+      }
+    }
+  }
+}
+
+/*----------------------------------------------------------------------*/
+
 bool OMS_ClassIdHash::IsBaseClassOf(const ClassIDRef baseGuid, const ClassIDRef derivedGuid) {
   return  IsDerivedClassOf(baseGuid, derivedGuid);
 }
@@ -482,5 +524,3 @@ OMS_ClassIdHash::~OMS_ClassIdHash ()
 
 // end destructor
 
-// end Guid HashFind
-
