@@ -234,11 +234,16 @@ void OMS_ContainerDictionary::MarkDropped (const ClassIDRef guid,
   OMS_ContainerDictionary::DropContainer or OMS_ContainerDictionary::DropSchema
   within RGN_CLASS_DIR region                     */ 
 
-  OMS_ContainerInfo* p = 
-    OMS_Globals::m_globalsInstance->m_classDictionary.FindGuid(guid, sh, cno);
+  OMS_ContainerInfo* p = OMS_Globals::m_globalsInstance->m_classDictionary.FindGuid(guid, sh, cno);
   if (NULL != p) {
-    p->MarkDropped();
-    ++m_dropId;   
+    if (p->m_refCnt > 0){
+      p->MarkDropped();
+      ++m_dropId;   
+    }
+    else {
+      IliveCacheSink *pSink = OMS_Globals::GetCurrentLcSink();
+      Delete(pSink, p);
+    }
   }
 }; 
 
