@@ -35,6 +35,7 @@
 #include "Oms/OMS_Session.hpp"
 #include "Oms/OMS_ObjectContainer.hpp"
 #include "hsp77.h"
+#include "geo573.h"
 
 #define REGISTER_ALLOCATOR true
 
@@ -45,6 +46,10 @@ tsp00_Uint4 co10_GetLastDropId()
   return OMS_Globals::m_globalsInstance->m_classDictionary.GetLastDropId();
 }
 
+#define OMS_NO_ERROR   0
+#define OMS_EXCEPTION  1
+#define OMS_BAD_ALLOC  2
+
 /*----------------------------------------------------------------------*/
 
 static
@@ -487,7 +492,8 @@ void OMS_Context::FlushObjCache(bool emptyObjCache,
   bool               errorOccured  = false;
   int                newObjFlushed = 0;
   int                errCnt        = 0;
-  DbpError           error(0);
+  int                errorKind     = OMS_NO_ERROR;
+  DbpError           dbpError(0);
   OmsObjectContainer *pFlushVarHead             = NULL;
   OmsObjectContainer *pFlushVarHeadOtherClasses = NULL;
   OmsObjectContainer *pDelVarHead               = NULL;
@@ -687,54 +693,71 @@ void OMS_Context::FlushObjCache(bool emptyObjCache,
 
     // Flush variable sized objects
     if (pFlushVarHead)
-      FlushVarObjMass(pFlushVarHead, pFlushVarHeadOtherClasses, &pFreeHead);
+      FlushVarObjMass(pFlushVarHead, pFlushVarHeadOtherClasses, pFreeHead);
 
     // Delete variable sized objects
     if (pDelVarHead)
-      DeleteVarObjMass(pDelVarHead, &pFreeHead);
+      DeleteVarObjMass(pDelVarHead, pFreeHead);
 
-  }catch (DbpError &e){
-    error = e;
-    OMS_DETAIL_TRACE(omsTrFlushCache, m_session->m_lcSink, " Error catched: " << e.m_errorNo << e.m_errorText);
-
-    if (emptyObjCache) {
-      // Append objects, which haven't been considered so far, to the list of
-      // objects for which memory should be freed
-      while (iter){
-        OmsObjectContainer *curr = iter();
-        ++iter;
+  }
+  catch (DbpError &e){
+    // No call of dbpCaughtException() needed, as exception is thrown again later
+    errorKind = OMS_EXCEPTION;
+    dbpError  = e;
+    OMS_TRACE(omsTrFlushCache, m_session->m_lcSink, " Error caught: " << e.m_errorNo << e.m_errorText);
+  }
+  catch (BAD_ALLOC_GEO573&){
+    // No call of dbpCaughtBadAlloc() needed, as exception is thrown again later
+    errorKind = OMS_BAD_ALLOC;
+    OMS_TRACE(omsTrFlushCache, m_session->m_lcSink, " Bad-Alloc caught");
+  }
+   
+  if (errorKind != OMS_NO_ERROR){
+    // Append objects, which haven't been considered so far, to the list of
+    // objects for which memory should be freed
+    while (iter){
+      OmsObjectContainer *curr = iter();
+      ++iter;
+      if (emptyObjCache || curr->VarObjFlag()) {
         curr->SetNext(pFreeHead);
         pFreeHead = curr;
         OMS_DETAIL_TRACE(omsTrFlushCache, m_session->m_lcSink, " Object " << curr->m_oid << " appended to free list");
       }
     }
+
+    // In case of an exception these lists might not be empty
+    while (pFlushVarHead){
+      OmsObjectContainer *next = pFlushVarHead->GetNext();
+      pFlushVarHead->SetNext(pFreeHead);
+      pFreeHead = pFlushVarHead;
+      pFlushVarHead = next;
+    }
+    while (pFlushVarHeadOtherClasses){
+      OmsObjectContainer *next = pFlushVarHeadOtherClasses->GetNext();
+      pFlushVarHeadOtherClasses->SetNext(pFreeHead);
+      pFreeHead = pFlushVarHeadOtherClasses;
+      pFlushVarHeadOtherClasses = next;
+    }
+    while (pDelVarHead){
+      OmsObjectContainer *next = pDelVarHead->GetNext();
+      pDelVarHead->SetNext(pFreeHead);
+      pFreeHead = pDelVarHead;
+      pDelVarHead = next;
+    }
   }
 
-  if (emptyObjCache) {
-    if (pFreeHead) {
-      OMS_DETAIL_TRACE(omsTrFlushCache, m_session->m_lcSink, " Free memory of all objects");
+  // Release all memory of objects  
+  while (pFreeHead){
+    OMS_DETAIL_TRACE(omsTrFlushCache, m_session->m_lcSink, " Free memory of object: " << pFreeHead->m_oid);
+    OmsObjectContainer *pNext = pFreeHead->GetNext();
+    if (pFreeHead->VarObjFlag()){
+      reinterpret_cast<OMS_VarObjInfo*>(&pFreeHead->m_pobj)->freeVarObj(this);
     }
-    
-    // Release all memory of objects  
-    while (pFreeHead){
-      OmsObjectContainer *pNext = pFreeHead->GetNext();
+    if (emptyObjCache) {
       OMS_ClassIdEntry *pClsInfo = pFreeHead->GetContainerInfoNoCheck(this);
       pClsInfo->chainFree(*this, pFreeHead, 4);
-      pFreeHead = pNext;
-    }
-  }
-  else {
-    if (pFreeHead) {
-      OMS_DETAIL_TRACE(omsTrFlushCache, m_session->m_lcSink, " Free memory of var objects");
-    }
-
-    // Free only the in-memory representation of the var-objects.
-    // All other memory is freed when the corresponding context is dropped.
-    while (pFreeHead){
-      OmsObjectContainer *pNext = pFreeHead->GetNext();
-      reinterpret_cast<OMS_VarObjInfo*>(&pFreeHead->m_pobj)->freeVarObj(this);
-      pFreeHead = pNext;
     }
+    pFreeHead = pNext;
   }
 
   // Clear structures
@@ -744,15 +767,18 @@ void OMS_Context::FlushObjCache(bool emptyObjCache,
   m_oidDir.SetEmpty(adaptOidHash);
   m_newObjCache.SetEmpty();
 
-  if (error.m_errorNo != 0) {
-    // Throw error if one has occured
+  if (errorKind == OMS_EXCEPTION) {
     m_cntNewObjectsToFlush = 0;
-    OMS_Globals::Throw(error);
+    throw dbpError;
+  }
+  else if (errorKind == OMS_BAD_ALLOC){
+    m_cntNewObjectsToFlush = 0;
+    throw BAD_ALLOC_GEO573();
   }
   else if ((!IsVersion()) && (newObjFlushed != m_cntNewObjectsToFlush)){
     // Check whether number of new flushed objects match the expected number,
     // which is stored as variable in the context 
-    OMS_DETAIL_TRACE(omsTrFlushCache | omsTrNewObj, m_session->m_lcSink, 
+    OMS_TRACE(omsTrFlushCache | omsTrNewObj, m_session->m_lcSink, 
       "OMS_Context::FlushObjCache : flushed new objects: "
       << newObjFlushed << ", expected to flush: " << m_cntNewObjectsToFlush);
     DbpBase b(m_currLcSink);
@@ -766,8 +792,8 @@ void OMS_Context::FlushObjCache(bool emptyObjCache,
 
 /*----------------------------------------------------------------------*/
 // PTS 1121449
-void OMS_Context::DeleteVarObjMass(OmsObjectContainer  *pHead,
-                                   OmsObjectContainer **ppFreeList)
+void OMS_Context::DeleteVarObjMass(OmsObjectContainer  *&pHead,
+                                   OmsObjectContainer  *&pFreeList)
 {
   const char *msg = "OMS_Context::DeleteVarObjMass ";
 
@@ -832,8 +858,8 @@ void OMS_Context::DeleteVarObjMass(OmsObjectContainer  *pHead,
         OmsObjectContainer *pNext = pHead->GetNext();
         
         // Append object to list for later freeing of memory
-        pHead->SetNext(*ppFreeList);
-        *ppFreeList = pHead;
+        pHead->SetNext(pFreeList);
+        pFreeList = pHead;
 
         pHead = pNext;
       }
@@ -902,17 +928,21 @@ void OMS_Context::DeleteVarObjMass(OmsObjectContainer  *pHead,
 **    All objects in this list must belong to the same schema and container number.
 ** \param pHeadOtherClasses If there are objects which belong to other classes than the
 **    objects of the list pHeadOneClass, then these objects are listed in this list.
-** \param ppFreeList All processed objects are linked to this list. So this list can be 
+** \param pFreeList All processed objects are linked to this list. So this list can be 
 **    used to free the memory which is allocated by the corresponding objects.
 **
 ** \assumption All objects in the list, headed by pHead, belong to the same
 ** schema, class, and container
 **
+** \attention After normal execution the lists pHeadOneClass and pHeadOtherClasses should
+** be empty. But in case of an exception, this might not be true, and therefore they are 
+** passed as reference.
+**
 ** \since PTS 1121449
 */
-void OMS_Context::FlushVarObjMass (OmsObjectContainer  *pHeadOneClass, 
-                                   OmsObjectContainer  *pHeadOtherClasses,
-                                   OmsObjectContainer **ppFreeList) 
+void OMS_Context::FlushVarObjMass (OmsObjectContainer  *&pHeadOneClass, 
+                                   OmsObjectContainer  *&pHeadOtherClasses,
+                                   OmsObjectContainer  *&pFreeList) 
 {
   const char *msg = "OMS_Context::FlushVarObjMass ";
 
@@ -1032,6 +1062,7 @@ void OMS_Context::FlushVarObjMass (OmsObjectContainer  *pHeadOneClass,
             pHeadOneClass             = pNext;
           else
             pPrev->SetNext(pNext);
+
           pObjContainer->SetNext(pUnfinishedObjs);
           pUnfinishedObjs             = pObjContainer;
           neededInfoNodeCnt          += (pagesNeeded-pagesCurr);
@@ -1258,10 +1289,11 @@ void OMS_Context::FlushVarObjMass (OmsObjectContainer  *pHeadOneClass,
           pNext = pObjContainer->GetNext();
 
           // Append object to list for later freeing of memory
-          pObjContainer->SetNext(*ppFreeList);
-          *ppFreeList               = pObjContainer;
+          pObjContainer->SetNext(pFreeList);
+          pFreeList     = pObjContainer;
 
           pObjContainer = pNext;  
+          pHeadOneClass = pObjContainer;
         }
       }
 
@@ -1603,7 +1635,7 @@ void OMS_Context::ReleaseAllUnchanged()   // PTS 1128262
     OmsObjectContainer *pObj = iter();
 
     ++iter;
-    m_session->ReleaseObj(pObj);
+    m_session->ReleaseObj(pObj, /*unchangedOnly=*/true);
   }
 }
 
