@@ -89,42 +89,98 @@ inline void OMS_Context::CheckIfContainerNotDropped(OMS_ClassIdEntry* pContainer
 
 inline bool OMS_Context::CheckOid (const OmsObjectId& oid, const ClassIDRef guid) 
 {
+  const char msg[] = "OMS_Context::CheckOid";
+
   if (oid) {
-    try {
-      OmsObjectContainerPtr pObj = this->FindObjInContext (&oid);
-      if (NULL != pObj) {
-        if (pObj->DeletedFlag()) {
-          return false;
-        } 
-        CheckCompatibility(guid, pObj);  // PTS 1121442
-      }
-      else {
-        if ((!this->IsVersion() || !this->IsUnloaded()) && (OMS_VERSION_OBJ_PAGE_NO == oid.getPno()))
-        {
-          return false;
-        }
-        const bool mayBeVarObject = true;
-        pObj = GetObjFromLiveCacheBase(oid, OMS_Context::NoLock, !mayBeVarObject);
-        if (NULL == pObj) {
-          return false;
-        }
-        CheckCompatibility(guid, pObj); // PTS 1121442
-      }
+    OMS_ClassIdEntry* pContainerInfo = NULL;
+    OmsObjectContainer *pObj = FindObjInContext (&oid, /*ignoreGeneration=*/false);
+    if (NULL != pObj) {
+      // Object exits already in the liboms-cache
+      if (pObj->DeletedFlag()) {
+        // Object is marked as deleted
+        return false;
+      } 
+
+      pContainerInfo = pObj->GetContainerInfoNoCheck(this);
     }
-    catch (DbpError& e) {
-        if ((-102 == e.dbpError()) && OMS_Globals::m_globalsInstance->IsOmsTestLib())
-        {
-            throw;
+    else {
+      // Object does not exist in the liboms-cache. 
+
+      if ((!IsVersion() || !IsUnloaded()) && (OMS_VERSION_OBJ_PAGE_NO == oid.getPno())){
+        // Oid corresponds to an object which has been created in a version. As either no version is
+        // active or version is not unloaded the object must have been found in the liboms-cache
+        // if it exists.
+        return false;
+      }
+
+      m_session->m_currVarObjChunk.Clear();
+      m_session->m_currVarObjChunk.m_seq.gg91SetNilRef();  
+
+      // Try to read object from the kernel.
+      int              objLen;
+      int              objHistReadCount;
+      tgg00_BasisError DBError;
+      OMS_UnknownContainerId FileId;
+      OMS_HResult hr = m_currLcSink->GetObj (
+        m_consistentView,
+        FileId,
+        m_pVersionContext,
+        *REINTERPRET_CAST(OmsTypeOid*, CONST_CAST(OmsObjectId*, &oid)),
+        false,  // doLock  
+        m_session->m_currVarObjChunk.m_seq,
+        sizeof(m_session->m_currVarObjChunk.m_container), 
+        ((unsigned char*) &m_session->m_currVarObjChunk.m_container), 
+        objLen,
+        objHistReadCount,
+        DBError);
+
+      if (0 == DBError) {
+        // Object was found in the kernel
+        m_session->IncLogHop(objHistReadCount);
+
+        if (FileId.IsVarObjFile()) {
+          // Specified oid corresponds to a var-object although a normal object is expected
+          return false;
         }
         else {
-          DbpErrorCallbackInterface *pCBInterface = DbpError::dbpGetCallback();  // PTS 1127871
-          if (pCBInterface){
-            pCBInterface->dbpCaughtError(e);
-          }
+          pContainerInfo = GetContainerInfo(FileId.GetContainerHandle());
+          pObj = m_session->GetMemory (*pContainerInfo);
+          SAPDB_MemCopyNoCheck (REINTERPRET_CAST(unsigned char*, &pObj->m_pobj) + sizeof(void*), &m_session->m_currVarObjChunk.m_container,
+            pContainerInfo->GetPersistentSize());
+          pObj->m_oid    = oid;
+          pObj->m_objseq = m_session->m_currVarObjChunk.m_seq;
+          PutObjectIntoContext(pObj, FileId.GetContainerHandle());
         }
-        return false;
+      }
+      else {
+        // transform basis error into sql return code
+        tsp00_Int2  SqlError;
+        tsp00_Int4  len = sizeof(DBError);
+        m_session->m_lcSink->MultiPurpose (m_change, mm_nil, &len, (unsigned char*) &DBError, &SqlError);
+
+        if (SqlError != -102){
+          return false;
+        }
+        else {
+          throw DbpError (DbpError::DB_ERROR, SqlError, msg, oid, __MY_FILE__, __LINE__);
+          return false;
+        }
+      }
     }
+
+    // Check whether container is dropped
+    if (pContainerInfo->GetContainerInfoPtr()->IsDropped()){
+      return false;
+    }
+
+    // Check whether given guid is compatible with the guid of the object.
+    const OMS_ClassInfo *pClassInfo = pContainerInfo->GetContainerInfoPtr()->GetClassInfoPtr();
+    if (  !omsIsCompatibleGuid(pClassInfo->GetGuid(), guid)
+      && !pClassInfo->IsDerivedClassOf(guid)) {
+        return false;
+      }
   }
+
   return true;
 }
 
@@ -132,47 +188,91 @@ inline bool OMS_Context::CheckOid (const OmsObjectId& oid, const ClassIDRef guid
 
 inline bool OMS_Context::CheckOid (const OmsVarOid& oid)
 {
+  const char msg[] = "OMS_Context::CheckOid (VAR)";
+
   if (oid) {
-    try {
-      OMS_ClassIdEntry* pContainerInfo;
-      OmsObjectContainerPtr pObj = this->FindObjInContext (&oid);
-      if (NULL != pObj) {
-        if (pObj->DeletedFlag()) {
-          return false;
-        } 
-        pContainerInfo = pObj->GetContainerInfo(this);
-        if (!pContainerInfo->IsVarObject()) {
+    OMS_ClassIdEntry* pContainerInfo = NULL;
+    OmsObjectContainer *pObj = FindObjInContext (&oid, /*ignoreGeneration=*/false);
+    if (NULL != pObj) {
+      // Object exists in the OMS-cache
+      if (pObj->DeletedFlag()) {
+        return false;
+      } 
+
+      pContainerInfo = pObj->GetContainerInfoNoCheck(this);
+    }
+    else {
+      // Object does not exist in the OMS-Cache
+
+      if ((!IsVersion() || !IsUnloaded()) && (OMS_VERSION_OBJ_PAGE_NO == oid.getPno())){
+        // Oid corresponds to an object which has been created in a version. As either no version is
+        // active or version is not unloaded the object must have been found in the liboms-cache
+        // if it exists.
+        return false;
+      }
+
+      m_session->m_currVarObjChunk.Clear();
+      m_session->m_currVarObjChunk.m_seq.gg91SetNilRef(); 
+
+      int              objLen;
+      int              objHistReadCount;
+      tgg00_BasisError DBError;
+      OMS_UnknownContainerId FileId;
+      OMS_HResult hr = m_currLcSink->GetObj (
+        m_consistentView,
+        FileId,
+        m_pVersionContext,
+        *REINTERPRET_CAST(OmsTypeOid*, CONST_CAST(OmsVarOid*, &oid)),
+        false,  // doLock  
+        m_session->m_currVarObjChunk.m_seq,
+        sizeof(m_session->m_currVarObjChunk.m_container), 
+        ((unsigned char*) &m_session->m_currVarObjChunk.m_container), 
+        objLen,
+        objHistReadCount,
+        DBError);
+
+      if (0 == DBError) {
+        if (!FileId.IsVarObjFile()) {
+          // Specified oid corresponds to a normal object although a var-object is expected
           return false;
         }
+        else {
+          pContainerInfo = GetContainerInfo(FileId.GetContainerHandle());
+          m_session->m_currVarObjChunk.m_containerHandle = FileId.GetContainerHandle();
+          if (objLen <= VAR_OBJ_CHUNK_SIZE) {
+            m_session->m_currVarObjChunk.m_container.m_vobjSize = objLen;
+          }
+          pObj = LoadVarObject (*REINTERPRET_CAST(const OmsVarOid*, &oid), VarObjNoLock, 
+            m_session->m_currVarObjChunk.m_container.m_vobjSize, m_session->m_currVarObjChunk, NULL);
+        }
       }
       else {
-        if (!this->IsVersion() && (OMS_VERSION_OBJ_PAGE_NO == oid.getPno()))
-        {
-          return false;
+        // transform basis error into sql return code
+        tsp00_Int2  SqlError;
+        tsp00_Int4  len = sizeof(DBError);
+        m_session->m_lcSink->MultiPurpose (m_change, mm_nil, &len, (unsigned char*) &DBError, &SqlError);
+
+        if (SqlError != -102) {
+           return false;
         }
-        pObj = GetObjFromLiveCacheBase(oid, OMS_Context::NoLock);
-        if (NULL == pObj) {
-          return false;
-        }
-        if (!pObj->VarObjFlag()) {
+        else {          
+          throw DbpError (DbpError::DB_ERROR, SqlError, msg, oid, __MY_FILE__, __LINE__);
           return false;
         }
       }
     }
-    catch (DbpError& e) {
-        if ((-102 == e.dbpError()) && OMS_Globals::m_globalsInstance->IsOmsTestLib())
-        {
-            throw;
-        }
-        else {
-          DbpErrorCallbackInterface *pCBInterface = DbpError::dbpGetCallback();  // PTS 1127871
-          if (pCBInterface){
-            pCBInterface->dbpCaughtError(e);
-          }
-        }
-        return false;
+
+    // Check whether container is dropped
+    if (pContainerInfo->GetContainerInfoPtr()->IsDropped()){
+      return false;
+    }
+
+    // Check whether the object is a var-object
+    if (!pContainerInfo->GetContainerInfoPtr()->GetClassInfoPtr()->IsVarObject()) {
+      return false;
     }
   }
+
   return true;  
 }
 
@@ -560,7 +660,7 @@ inline int OMS_Context::LoadBaseClsObjsFromLiveCacheBase(int                 noO
     }
     else {
       OMS_ClassIdEntry* pClsIdEntry = m_containerDir.HashFindViaContainerHandle(pContainerId[i].fileObjFileNo_gg00());
-      ppClassInfo[i] = m_containerDir.GetClassInfo(pClsIdEntry->m_containerInfo->m_clsInfo->GetGuid());
+      ppClassInfo[i] = m_containerDir.GetClassInfo(pClsIdEntry->GetContainerInfoPtr()->m_clsInfo->GetGuid());
     }
   }
 
@@ -1059,7 +1159,10 @@ inline int OMS_Context::GetVarObjFromLiveCacheBase(const OmsObjectId& oid, bool
   OMS_UnknownContainerId FileId;
   const char* msg = "OMS_Context::GetVarObjFromLiveCacheBase";
   m_session->IncLoadVarObjLC();
+
   m_session->m_currVarObjChunk.m_seq.gg91SetNilRef();  // PTS 1121449
+  m_session->m_currVarObjChunk.m_container.m_vobjNext.setNil();
+  m_session->m_currVarObjChunk.m_container.m_vobjSize = 0;
 
   OMS_HResult hr = m_currLcSink->GetObj (
     m_consistentView,
@@ -1212,10 +1315,20 @@ inline OmsObjectContainerPtr OMS_Context::LoadVarObject (const OmsVarOid& oid, O
   try {
     bool overflow = false;                            // PTS 1121449
     OMS_VarObjInfoNode *pFirstInfoNode = pInfoNode;   // PTS 1121449
+
     while (objSize > 0) {
       nextOid = chunk.m_container.m_vobjNext;
+      m_session->Set_OidOfLastObject(nextOid);
+
+      if (!nextOid){
+        m_session->ThrowDBError(e_invalid_oid, "Error dereferencing continuation object-1-", oid, __MY_FILE__, __LINE__);
+      }
+
       moveLen = OMS_Globals::Min(objSize, VAR_OBJ_CHUNK_SIZE);
       chunk.m_seq.gg91SetNilRef();             // PTS 1121449
+      chunk.m_container.m_vobjNext.setNil();
+      chunk.m_container.m_vobjSize = 0;
+
       OMS_HResult hr = m_currLcSink->GetObj (
         m_consistentView,
         FileId,
@@ -1229,6 +1342,11 @@ inline OmsObjectContainerPtr OMS_Context::LoadVarObject (const OmsVarOid& oid, O
         ObjHistReadCount,
         DBError);
       this->CheckDBError(DBError, msg, oid);
+
+      if (moveLen > objLen){
+        m_session->ThrowDBError(e_invalid_oid, "Error dereferencing continuation object-2-", oid, __MY_FILE__, __LINE__);
+      }
+
       SAPDB_MemCopyNoCheck (p, &chunk.m_container, moveLen);
       p       += moveLen;
       objSize -= moveLen;
