@@ -109,9 +109,9 @@ public :
   void                  FlushVarObject (OmsObjectContainerPtr p); 
   // Begin PTS 1121449
   void                  FlushObjCacheMass(bool emptyObjectCache, bool adaptOidHash); 
-  void                  FlushVarObjMass(OmsObjectContainer* pHeadOneClass, OmsObjectContainer* pHeadOtherClasses, 
-                                        OmsObjectContainer** ppFreeList);
-  void                  DeleteVarObjMass(OmsObjectContainer* pHead, OmsObjectContainer** ppFreeList);
+  void                  FlushVarObjMass(OmsObjectContainer*& pHeadOneClass, OmsObjectContainer*& pHeadOtherClasses, 
+                                        OmsObjectContainer*& pFreeList);
+  void                  DeleteVarObjMass(OmsObjectContainer*& pHead, OmsObjectContainer*& pFreeList);
   // End PTS 1121449
   void                  FlushVersionObjCache();  // PTS 1122280
   inline void           deallocate(void* p);
