@@ -195,6 +195,15 @@ class OMS_KernelDefaultInterface : public LVC_KernelInterface
  
   virtual void IncOmsVersionUnloadCounter();
 
+  /*!
+   * \brief check if OneDB system
+   *
+   * Tells whether liveCache is a OneDB system.
+   *
+   * \return true, if liveCache is a OneDB system, false otherwise
+   */
+  virtual bool IsOneDBSystem();
+
   /*!-----------------------------------------------------------------------
    function:     IsUnicodeInstance
    description:  tells whether liveCache is runnung in UNICODE mode
@@ -356,7 +365,6 @@ class OMS_KernelDefaultInterface : public LVC_KernelInterface
 
   static LVC_KernelInterface& Instance();
 
-
   /*!-------------------------------------------------------------------------
 	function:     SetErrorCallback
 	description:  Set the error callback interface in the kernel (new with PTS 1133630)
@@ -367,6 +375,15 @@ class OMS_KernelDefaultInterface : public LVC_KernelInterface
 
   virtual void SetErrorCallback(DbpErrorCallbackInterface *cb);
 
+  /*!
+   * \brief Get kernel runtime interface
+   *
+   * Returns a pointer to the liveCache kernel runtime interface
+   *
+   * \return pointer to the liveCache kernel runtime interface
+   */
+  virtual RTE_IInterface &GetKernelRunTimeInterface();
+
 private :
   static OMS_KernelDefaultInterface* m_instance;
 };
