@@ -7,7 +7,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -96,12 +97,7 @@ OMS_KernelKeyIter::OMS_KernelKeyIter
   OmsObjectContainer* pObj=NULL;
   if (m_noMassOperation){
     // Get memory to store the object. 
-    if (pSession->InVersion()) {
-      pObj = m_pSession->GetMemoryInVersion(*m_pContainerInfo);
-    } 
-    else {
-      pObj = m_pSession->GetMemory(*m_pContainerInfo);
-    }
+    pObj = m_pSession->GetMemory(*m_pContainerInfo);
   }
 
   // Create iterator in kernel 
