@@ -6,7 +6,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2002-2004 SAP AG
+    Copyright (c) 2002-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
     ========== licence end
 
 
+
 */
 
 
@@ -327,7 +328,7 @@ class OMS_LibOmsInterface
   return value: none
   -------------------------------------------------------------------------*/
 
-  virtual void SetDumpError(tsp00_Int4 errorNo) = 0;
+  virtual void SetDumpError(tsp00_Int4 errorNo, OMS_DiagnoseAction action) = 0;
   
 
   /*!-----------------------------------------------------------------------
@@ -410,10 +411,41 @@ class OMS_LibOmsInterface
 
   virtual bool GetNextClassInfo(OMS_LibOmsInterfaceClassInfo &info) = 0;
 
-  /*-------------------------------------------------------------------------*/
+   /*!-----------------------------------------------------------------------
+  
+  function : CancelVersion
+
+  description : if a "consistent view" belonging to an OmsVersion is cancelled,
+                the corresponding OmsVersion is dropped or "marked for drop"
+                
+             
+  parameters :  
+        ConsistViewNo [in] consistent view, which has been cancelled
+
+  return value: true, if there was a class info to return
+
+  -------------------------------------------------------------------------*/
 
   virtual void CancelVersion(tgg91_TransNo &ConsistViewNo) = 0;
 
+ /*!-----------------------------------------------------------------------
+
+  function : MarkContainerDropped
+
+  description : callback use containers as dropped during the execution
+                of omsDropSchema or omsDropContainer
+             
+  parameters :  
+        guid      [in] guid of the container class
+        schema    [in] schemaid of schema holding the container
+        container [in] containerid
+                
+
+  return value: true, if there was a class info to return
+
+  -------------------------------------------------------------------------*/
+  virtual void MarkContainerDropped(GUID &guid, int schema, int container) = 0;
+
   /*-------------------------------------------------------------------------*/
 };
 
