@@ -42,6 +42,7 @@
 #include "liveCache/LVC_LockRequest.hpp"
 #include "hsp77.h"
 #include "hsp78_0.h"
+#include "RunTime/RTE_IInterface.hpp"
 
 /*---------------------------------------------------------------------------*/
 /*  external Globals                                                         */
@@ -57,11 +58,17 @@ const char* VAR_OBJ_CLASS_NAME_CO10 = "VarObjContainer";
 
 static bool                    m_mallocMonitor  = false;  // PTS 1110287
 
+RTE_IInterface *RTE_IInterface::it;
+RTE_IInterface *RTE_IInterface::Initialize() { return it; }
+
 /*----------------------------------------------------------------------*/
 
 void OMS_LibOmsInterfaceInstance::AdviseKernelInterface(LVC_KernelInterface& knlInterface, bool isKernel)
 {
     OMS_Globals::KernelInterfaceInstance = &knlInterface;
+
+    RTE_IInterface::it = &knlInterface.GetKernelRunTimeInterface();
+
     if (!OMS_Globals::m_globalsInstance) 
       OMS_Globals::InitSingletons();
     OMS_Globals::m_globalsInstance->SetHost(isKernel);    
@@ -281,6 +288,7 @@ tsp00_Bool OMS_LibOmsInterfaceInstance::GetNextVersion(IliveCacheSink*     lcSin
           }
           pContext = pNext;
         }
+        OMS_Globals::m_globalsInstance->m_versionIter.ReleaseSlot();
       }
  
       if (pSession != NULL){
@@ -492,6 +500,8 @@ void OMS_LibOmsInterfaceInstance::CancelVersion(
 
     while (pContext)
     {
+      OMS_Context *pNext = VersionIter.GetNextInSlot();
+
       if (pContext->m_consistentView == ConsistViewNo)
       {
         IliveCacheSink* pSink = OMS_Globals::m_globalsInstance->GetCurrentLcSink();
@@ -530,10 +540,10 @@ void OMS_LibOmsInterfaceInstance::CancelVersion(
         }
       }
 
-      pContext = VersionIter.GetNextInSlot();
+      pContext = pNext; 
     }
   }
-};
+}
 
 /*-------------------------------------------------------------------------*/
 /* *new* PTS 1134184 ff */
