@@ -577,7 +577,8 @@ bool OMS_Session::HistoryInUse(const OmsObjectId& oid)
 void OMS_Session::LockObjMass (OmsIOidReadIterator &oids, 
                                short               &timeout, 
                                OmsIOidAppender     &errOids,
-                               bool                 newConsistentView)
+                               bool                 newConsistentView,
+                               cgg250AvlTree<OmsObjectId,OmsObjectId,OMS_Session> *pUnlockedObjects)
 {
   const char * msg = "OMS_Session::LockObjMass ";
 
@@ -712,6 +713,10 @@ void OMS_Session::LockObjMass (OmsIOidReadIterator &oids,
               ThrowDBError(pDBError[i], msg, pOid[i], __MY_FILE__, __LINE__);
           }
           else {
+            if (pUnlockedObjects != NULL){
+              pUnlockedObjects->Insert(pOid[i]);
+            }
+
             // Object has been appended to the error-list
             pDBError[i] = e_ok;
             --errCnt;
@@ -1416,11 +1421,21 @@ void OMS_Session::NewConsistentView (OmsIOidReadIterator& oids, short timeout, O
 
   CurrentContext()->RemoveUnlockedObjFromCache();
  
+  // All objects, which can not be locked in the kernel are inserted into a tree. Later
+  // only those objects, which are not found in this tree are dereferenced for update 
+  // to ensure a pseudo update (see below).
+  OmsObjectId cmp;
+  cgg250AvlTree<OmsObjectId,OmsObjectId,OMS_Session> unlockedObjects;
+  unlockedObjects.AdviseAllocator(this);
+  unlockedObjects.AdviseCompare(&cmp);
+
+
+
   try {
     // Try to get a lock for each of the objects in pOid. timeout specifies the maximal time
     // for getting all locks. After the execution timeout contains the time needed to process
     // the call
-    LockObjMass(oids, timeout, errOids, true);
+    LockObjMass(oids, timeout, errOids, true, &unlockedObjects);
   }
   catch (OmsLockTimeout&){ 
     // Write statistics
@@ -1440,7 +1455,10 @@ void OMS_Session::NewConsistentView (OmsIOidReadIterator& oids, short timeout, O
   // possible, this should be replaced here.
   oids.omsReset();
   while (bool(oids)) {
-    m_context->GetObj(oids.omsGet(), true);
+    const OmsObjectId &oid = oids.omsGet();
+    if (!unlockedObjects.Find(oid)){
+      m_context->GetObj(oid, true);
+    }
     ++oids;
   }
 
