@@ -1061,7 +1061,7 @@ inline void OMS_Session::ReleaseObj(const OmsObjectId& oid)
 
 /*----------------------------------------------------------------------*/
 
-inline void OMS_Session::ReleaseObj(OmsObjectContainerPtr p)
+inline void OMS_Session::ReleaseObj(OmsObjectContainerPtr p, bool unchangedOnly)
 {
   // Objects are NOT released from the cache if:
   // 1)  the object is 'changed' AND
@@ -1074,7 +1074,9 @@ inline void OMS_Session::ReleaseObj(OmsObjectContainerPtr p)
   // * the object is marked as to be deleted OR
   // * a before-image of this object exists (omsForUpd)  // PTS 1128262
 
-  const bool releaseUpdatedObj = ((!m_context->IsVersion()) && (!this->IsSubtransOpen()));
+  const bool releaseUpdatedObj 
+    =  (unchangedOnly ? false
+                      : (!m_context->IsVersion() && !IsSubtransOpen()));
 
   m_monitor.OmsIncOmsRelease(); // PTS 1133312
 
