@@ -194,7 +194,8 @@ public:
   inline void                  LockObj(OmsObjectContainer* p);
   inline bool                  TryLockObj(OmsObjectContainer* p);
   void                         LockObjMass(OmsIOidReadIterator& oids, short& timeout, 
-                                           OmsIOidAppender& errOids, bool newConsistentView = false);  // PTS 1121449
+                                           OmsIOidAppender& errOids, bool newConsistentView = false,
+                                           cgg250AvlTree<OmsObjectId,OmsObjectId,OMS_Session> *pUnlockedObjects = NULL);  // PTS 1121449
   inline void*                 allocate(size_t sz);
   inline void                  MonitorVarObjSize(tsp00_Int4);
   inline void                  MonitorWaitNewConsistentView(tsp00_Int4);
@@ -223,7 +224,7 @@ public:
   inline void                  ReleaseAllUnchanged();    // PTS 1128262
   void                  ReleaseCallbackInterface();
   inline void                  ReleaseObj(const OmsObjectId& oid);
-  inline void                  ReleaseObj(OmsObjectContainer* p);
+  inline void                  ReleaseObj(OmsObjectContainer* p, bool unchangedOnly = false);
   inline void                  ReleaseObjUnconditional(const OmsObjectId& oid);
   void                  ReleaseVarObject(const OmsVarOid& oid);
   inline void                  Reschedule(); /* PTS 1107849 */  
@@ -257,6 +258,11 @@ public:
 
   inline bool IsDataChanged() const { return m_isDataChanged; }
   inline void SetDataChanged() { m_isDataChanged = true; }
+
+  void         Set_OidOfLastObject (const OmsObjectId &varOid){ m_varOid = varOid; }
+  OmsObjectId  Get_OidOfLastObject ()                         { return m_varOid;   }            
+
+
 public:
   // GUID of the callback interface
   ClassID					          m_callbackInterfaceGuid;
@@ -375,6 +381,8 @@ private :
   bool                     m_requiredExceptionThrown; 
   //@}
 
+  OmsObjectId    m_varOid;
+
   void  ReleaseLocks (OmsIOidReadIterator &oids, int cnt);  // PTS 1121449
 };
 
