@@ -207,8 +207,14 @@ SAPDB_Bool GetExecDirectory( char           *cmdArg,
 #ifdef WIN32
     DWORD DumpException( LPEXCEPTION_POINTERS ec )
     {
+        eo670TraceContext traceContext;
+
         WriteLog("EXECPTION OCCURED:", SAPDB_TRUE);
-        eo670_CTraceContextStackOCB(ec->ContextRecord, WriteException, NULL);
+
+        traceContext.threadHandle   = GetCurrentThread();
+        traceContext.pThreadContext = ec->ContextRecord;
+        eo670_CTraceContextStackOCB(&traceContext, WriteException, NULL);
+
         return EXCEPTION_CONTINUE_SEARCH;
     }
 #else
