@@ -8,7 +8,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
  */
 #ifndef RST_IREDO_TRAFFIC_CONTROL_H
 #define RST_IREDO_TRAFFIC_CONTROL_H
@@ -33,6 +34,7 @@
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "Logging/Log_Types.hpp"
 #include "Logging/Log_Transaction.hpp"
+#include "Restart/Rst_Types.hpp"
 #include "gsp00.h"
 #include "ggg00.h"
 /*!
@@ -80,9 +82,14 @@ public:
     virtual void SetEndOfLogRead (tsp00_TaskId LogReaderTaskId) = 0;
     /// The log reader calls this after recreation of all open transactions from last savepoint
     virtual void EnableRedoProcessing (tsp00_TaskId LogReaderTaskId) = 0;
-	/// writes some basic information into the trace 
-	virtual void WriteToTrace (const char *title = 0) const = 0;
-	/// This returns the youngest iosequence inserted to the redo list
-	virtual Log_IOSequenceNo GetLastIOSequence (tsp00_TaskId taskid) const = 0;
+    /// writes some basic information into the trace 
+    virtual void WriteToTrace (const char *title = 0) const = 0;
+    /// This returns the youngest iosequence inserted to the redo list
+    virtual Log_IOSequenceNo GetLastIOSequence (tsp00_TaskId taskid) const = 0;
+    /// maximum number of transactions which are configure
+    virtual SAPDB_UInt GetMaximumNumberOfTransactions() const = 0; // PTS 1134103 UH 2005-03-07 new
+    /// a list of transno's is returned, which is currently known by redo traffic control
+    virtual bool GetTransactions (tsp00_TaskId            taskid,
+                                  Rst_Transactions       &listOfTransToSkip) const = 0; // PTS 1134103 UH 2005-03-07 new
 };
-#endif  /* RST_IREDO_TRAFFIC_CONTROL_H */
\ No newline at end of file
+#endif  /* RST_IREDO_TRAFFIC_CONTROL_H */
