@@ -45,6 +45,7 @@
 #include "KernelCommon/Kernel_IAdminConfig.hpp"
 #include "KernelCommon/Kernel_Migration.hpp"
 #include "KernelCommon/Kernel_Version.hpp"
+#include "KernelCommon/Kernel_OpMsg.hpp"
 #include "Restart/Rst_RedoReadTask.hpp"
 #include "Restart/Rst_IRedoTrafficControl.hpp"
 #include "Restart/Rst_Exceptions.hpp"
@@ -102,6 +103,25 @@ public:
     {
         return m_Value != 0;
     }
+    /*!
+    @return false, if space begin is not properly aligned
+    @brief  This checks if the split space begins at an aligned position
+    */
+    virtual bool CheckAlignment() const
+    {
+         if ( ! IsAssigned() )
+             return true;
+             
+         SAPDB_UInt8 address =
+                         #ifdef BIT64
+                         reinterpret_cast<SAPDB_UInt8>(m_Value);
+                         #else
+                         reinterpret_cast<SAPDB_UInt4>(m_Value);
+                         #endif
+         
+         return address % LOG_PAGE_ALIGNMENT == 0;
+    }
+
     /// default constructor
     Log_AfterImageHeadSpace ()
     : m_Value       (NULL),
@@ -573,6 +593,13 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
         RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "m_TransactionsToSkip.Init() failed") );
     }
 
+    const Kernel_Migration::ChangeInfo &repeatedRedoFlag = Kernel_IAdminConfig::Instance().MigrationHandler().SearchForChangeInfo ("RepeatedRedoFlagInOpenTransFile");
+    const bool lastSavepointDoneDuringRedo               = repeatedRedoFlag.IsEnabled() ? false : file.CreatedDuringRedo();
+          bool dontReadLogOfTransAgain;
+          
+    if ( lastSavepointDoneDuringRedo )
+        Kernel_OpInfo (csp3_n_restart) << "Previous restart was interrupted.";
+
     while ( iter.IsValid() )
     {
         Log_Transaction* newtrans = new (allocator) Log_Transaction ();
@@ -582,33 +609,43 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
 
         newtrans->ReadPersistentFormat( *iter, file.GetSpaceSize() );
 
-        if ( ! newtrans->IsRedoRelevant()
-             ||
-             Log_Transaction::committed == newtrans->GetTransState() ) // PTS 1134103 UH 2005-03-07
+        if ( newtrans->GetRedoTransNo().gg90IsNil() )
         {
-            if ( newtrans->IsRedoRelevant() ) // PTS 1134103 UH 2005-03-07
-            {
-                if ( ! m_TransactionsToSkip.Add ( newtrans->GetRedoTransNo() ) ) // PTS 1134103 UH 2005-03-07
-                {
-                    RTE_Crash ( Restart_Exception(__CONTEXT__, SAPDBERR_ASSERT_STATE_FAILED, "m_TransactionsToSkip.Add() failed") );
-                }
-            }
-            // The transaction entry can be deleted with all its empty root pages.
-            if ( ! newtrans->InitializeForRedo (redoReaderTrans) )
-                CRASH("InitializeForRedo for delete failed");
-            redoReaderTrans.trWriteTransId_gg00 = newtrans->GetRedoTransNo(); // PTS 1135443 UH 09-05-2005
-            newtrans->DeleteAfterRedo();
-            redoReaderTrans.trWriteTransId_gg00.gg90SetNil();                 // PTS 1135443 UH 09-05-2005
+            // the savepoint may collect such trans entries
             destroy (newtrans, allocator);
             ++iter;
             continue;
         }
+        
+        dontReadLogOfTransAgain = ! lastSavepointDoneDuringRedo && newtrans->GetTransState() == Log_Transaction::committed;
+        
+        if ( dontReadLogOfTransAgain )
+        {
+            // This trans is definitly complety done so ignore every log entry which is found in the future
+            if ( ! m_TransactionsToSkip.Add ( newtrans->GetRedoTransNo() ) ) // PTS 1134103 UH 2005-03-07
+                CRASH("m_TransactionsToSkip.Add() failed");
 
+            // The transaction is prepared to be completly removed with all its files
+            if ( ! newtrans->InitializeForRedo (redoReaderTrans) )
+                CRASH("InitializeForRedo for delete failed");
+
+            // delete the log transaction context
+            redoReaderTrans.trWriteTransId_gg00 = newtrans->GetRedoTransNo();
+            newtrans->DeleteAfterRedo();
+            redoReaderTrans.trWriteTransId_gg00.gg90SetNil();
+
+            destroy (newtrans, allocator);
+
+            // skip to next open trans entry
+            ++iter;
+            continue;
+        }
+        
         if ( ! newtrans->InitializeForRedoCopy (redoReaderTrans,
                                                 newtrans->GetRedoTransNo(),
                                                 allocator) )
             CRASH("InitializeForRedoCopy failed");
-        
+
         newtrans->UpdateUndoRedoInfoForRestart(m_OldestKnownEOTSequence);
         
         kb51GetRedoTransIndex (redoReaderTrans.trTaskId_gg00,
@@ -626,17 +663,12 @@ void Rst_RedoReadTask::ReCreateOpenTransactions (tgg00_TransContext     &redoRea
         kb57RedoTransNoIncrement ( redoReaderTrans.trTaskId_gg00, // PTS 1127838 UH 2004-02-20 added
                                    newtrans->GetRedoTransNo() );
 
-        if ( // newtrans->GetRedoEotSequence().IsValid() // PTS 1134103 UH 2005-03-07
-             // && // PTS 1114946 UH 2002-03-20
-             newtrans->GetTransState() != Log_Transaction::opened )
+        if ( dontReadLogOfTransAgain // PTS 1138299 UH 2005-10-12
+             ||
+             (newtrans->GetTransState() != Log_Transaction::opened
+              &&
+              newtrans->GetRedoEotSequence().IsValid()) )
         {
-            // The transaction was collected during savepoint before the commit/rollback was written.
-            // Between setting TransState and writing eot logentry may the trans been collected by savepoint.
-            // Then the trans has a TransState which says that the transaction has ended, but the eot
-            // logentry must be found after the savepoint entry.
-            // This assumes a fixed sequence of operations in the Log_Savepoint::Coordinator().
-            // First Savepoint Entry writing, then transactions collecting.
-
             EndOfTransaction ( redoReaderTrans.trTaskId_gg00,
                                allocator,
                                newtrans,
