@@ -71,7 +71,7 @@ public:
     /// return true, if the value is valid
     SAPDB_Bool IsValid() { return m_Value != RST_INVALID_SYNC_OFFSET; };
     /// assignment of an RawDeviceOffset
-    SAPDB_Bool operator = (const Log_RawDeviceOffset newValue) 
+    SAPDB_UInt4 operator = (const Log_RawDeviceOffset newValue) 
         { return m_Value = newValue(); }
     /// check for equality with an RawDeviceValue
     SAPDB_Bool operator == (const Log_RawDeviceOffset operand) 
