@@ -12,7 +12,7 @@
                 The following class is used to separate this URI ASCII
                 string in particular unescaped UTF8 parts.
 
-  @since        2005-01-13  14:55
+  @since        2005-04-28  17:58
   @sa           
 
   ==========================================================================
@@ -20,7 +20,7 @@
   \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     ========== licence end
 
 
+
   \endif
  ============================================================================*/
 
@@ -97,7 +98,7 @@
 
 
 #if !defined (WIN32) || (defined (WIN32) && defined (AMD64))
-#if defined (LINUX) && defined (X86_64)
+#if defined (LINUX) && (defined (X86_64) || (defined (IA64) && SLES_VER >= 9))
 #include "sap/700/saptype.h"	/* nocheck */
 #include "sap/700/saptypeb.h"	/* nocheck */
 #include "sap/700/saptypec.h"	/* nocheck */
