@@ -92,7 +92,7 @@ typedef struct
 {
   SAPDB_UTF8         *xparamFilename;
   RTE_Filename        diagFilename;
-  SAPDB_Bool          movefile;   /* true: move file    false: copy file */ /* 1110186 */
+  SAPDB_Bool          movefile;       /* true: move file    false: copy file */ /* 1110186 */
 /*  SAPDB_Bool          compress; */
 } DIAGNOSTIC_FILE;
 
@@ -105,9 +105,14 @@ static  DIAGNOSTIC_FILE   diag_file_table[] =
     {(SAPDB_UTF8*)"\0",             "AK.dmp",             true },
     {(SAPDB_UTF8*)"\0",             "AK.buf",             true },
     {(SAPDB_UTF8*)"\0",             "AK.stm",             true },
+#if defined(_WIN32)
+    {(SAPDB_UTF8*)"\0",             SAPDB_KNL_MINI_DUMP,  true }   /*--- Windows mini dump */
+#else
     {(SAPDB_UTF8*)"\0",             "core",               true }   /*--- UNIX DB-core */  /* PTS 1109821 */
+#endif
 };                                                                
 
+
 #define NUM_DIAG_FILES 	(sizeof(diag_file_table)/sizeof(DIAGNOSTIC_FILE))
 
 
@@ -341,8 +346,8 @@ static  SAPDB_Bool  RTEDiag_GenerateNewHistDir (RTE_Filename  dirname,
  *===========================================================================*/
     
     RTE_Filename      tmpDirname;
-    tsp00_Date          date;
-    tsp00_Time          time;
+    tsp00_Date          dateValue;
+    tsp00_Time          timeValue;
 
     #define     VDATTIME_OFF_YEAR       0
     #define     VDATTIME_OFF_MONTH      4
@@ -380,14 +385,14 @@ static  SAPDB_Bool  RTEDiag_GenerateNewHistDir (RTE_Filename  dirname,
 
     strcpy (tmpDirname, HIST_NAME_SKEL); 
             
-    vdattime (date, time);  /* date: YYYYMMDD     time:   00HHTTSS */
+    vdattime (dateValue, timeValue);  /* date: YYYYMMDD     time:   00HHTTSS */
 
-    PUTDATETIME (HIST_YEAR, HIST_LEN_YEAR, date, VDATTIME_OFF_YEAR);
-    PUTDATETIME (HIST_MONTH, HIST_LEN_MONTH, date, VDATTIME_OFF_MONTH);
-    PUTDATETIME (HIST_DAY, HIST_LEN_DAY, date, VDATTIME_OFF_DAY);
-    PUTDATETIME (HIST_HOUR, HIST_LEN_HOUR, time, VDATTIME_OFF_HOUR);
-    PUTDATETIME (HIST_MINUTE, HIST_LEN_MINUTE, time, VDATTIME_OFF_MINUTE);
-    PUTDATETIME (HIST_SECOND, HIST_LEN_SECOND, time, VDATTIME_OFF_SECOND);
+    PUTDATETIME (HIST_YEAR, HIST_LEN_YEAR, dateValue, VDATTIME_OFF_YEAR);
+    PUTDATETIME (HIST_MONTH, HIST_LEN_MONTH, dateValue, VDATTIME_OFF_MONTH);
+    PUTDATETIME (HIST_DAY, HIST_LEN_DAY, dateValue, VDATTIME_OFF_DAY);
+    PUTDATETIME (HIST_HOUR, HIST_LEN_HOUR, timeValue, VDATTIME_OFF_HOUR);
+    PUTDATETIME (HIST_MINUTE, HIST_LEN_MINUTE, timeValue, VDATTIME_OFF_MINUTE);
+    PUTDATETIME (HIST_SECOND, HIST_LEN_SECOND, timeValue, VDATTIME_OFF_SECOND);
 
     strcpy (dirname, dbname);
     strcat (dirname, tmpDirname);
