@@ -582,6 +582,16 @@ RTEHSS_ApiDll::GetMapping(
                                         this->Perror(apiResult) );
         return false;
     }
+    else
+    {
+        /* If mapping returned empty buffer, fill a single '0' as dummy mapping... */
+        if ( (mappingBuffer.bufferGiven > 0) 
+          && (0 == mappingBuffer.bytesUsedOrNeeded) )
+        {
+            mappingBuffer.bytesUsedOrNeeded = 1;
+            ((char *)mappingBuffer.buffer)[0] = 0;
+        }
+    }
     return true;
 }
 
