@@ -176,6 +176,26 @@ public:
    */
   virtual void * Allocate(SAPDB_ULong BlockCount);
 
+  /*! 
+    Function: Allocate
+
+    Description: Allocates contiguous memory for 'count' blocks of memory.
+
+      An implementation grants that a pointer returned will be an
+      integral multiple of the system page size.
+
+      The memory is not initialised.  
+
+      If compiled with -DSAPDB_COMPILE_WITHOUT_EXCEPTION_HANDLING a (void *)0 is returned on failure.
+
+      If compiled without this switch an SAPDBMem_BadAllocException exception is thrown on failure.
+
+    Arguments: BlockCount [ in ] Number of blocks (NOT bytes!) to allocate.
+               messageList [out] filled if memory not available    
+    Return value: pointer to the block allocated
+   */
+  virtual void * Allocate(SAPDB_ULong BlockCount, SAPDBErr_MessageList &messageList);
+
   /*! 
     Function: Deallocate
     
