@@ -529,10 +529,11 @@ SAPDB_Bool RTE_ActiveDatabase::OpenKernel
     SAPDBErr_MessageList    &messageList
 )
 {
-
     //Open KSS
     RTEIPC_NamedSharedMemory::SHMRet rc;
 
+    dbState = SERVER_UNDEFINED;
+
     PSECURITY_ATTRIBUTES    pSA = (RTE_SecurityAttributes::Instance()).GetWorldSA();
     rc = m_kss.Open( CONCATENATED_STRING (SHM_KSS,m_dbName),
                     NULL,
@@ -627,6 +628,15 @@ SAPDB_Bool RTE_ActiveDatabase::OpenKernel
         return false;
     }
 
+    DWORD procState = WaitForSingleObject (m_hKernel, 0);
+
+    //WAIT_TIMEOUT == rc: Process is still alive 
+    if (WAIT_TIMEOUT != procState)
+    {
+        dbState = SERVER_OFFLINE;
+        CloseKernel ();
+    }
+
     return true;
 }
 
@@ -1071,6 +1081,14 @@ SAPDB_Bool RTE_ActiveDatabase::updateEnvironment(
 #  endif
 #endif
 
+#if defined(LINUX) && defined(SDBonPPC64)
+    if ( putenv("LD_BIND_NOW=1") != 0 )
+    {
+        SAPDB_sprintf(errorText,maxErrorTextLengthInBytes,"start:   Cannot putenv LD_BIND_NOW=1" );
+        return false;
+    }
+#endif
+
 #if defined(LINUX)
     /* enforce linuxthread compatibility mode for non NPTL supporting database kernel */
     /* for detailed description see http://people.redhat.com/drepper/assumekernel.html */
@@ -1551,11 +1569,13 @@ SAPDB_Bool RTE_ActiveDatabase::getDbPidStateFromShm (
     SAPDB_UInt4 *pState,
     SAPDB_Bool *pWantDump,
     SAPDB_Bool *pGracefully,
+    RTE_SpeedInfo *pActiveSpeed,
     SAPDBErr_MessageList &errList)
 {
     key_t commonRTEKey;
 
     SAPDB_Bool dbRunning;
+
     errList.ClearMessageList();
     // first check if the kernel is running at all - if it wasn't, looking in the shared memory would not make any sense
     if(!checkForRunningProcesses( dbRunning,errList ))
@@ -1610,10 +1630,6 @@ SAPDB_Bool RTE_ActiveDatabase::getDbPidStateFromShm (
             }
             return true;
         }
-        if ( errno == EPERM || errno == EACCES )
-        {
-            return false;
-        }
         return false;
     }
 
@@ -1622,42 +1638,72 @@ SAPDB_Bool RTE_ActiveDatabase::getDbPidStateFromShm (
      */
     struct  KERNEL_GLOBAL_SECTION  *KgsNotRemapped;
     KgsNotRemapped = sql34MapKgsNotRemapped ( shmid, pWantDump != 0);
-    if ( !KgsNotRemapped )
+    if ( !KgsNotRemapped )  // if attaching the shared memory failed although the shmget() worked, the shared memory may have been removed in the meantime...
     {
-        return false;
+        errList = SAPDBErr_MessageList(RTE_CONTEXT, RTEERR_DBREG_DB_NOT_STARTED, m_dbName);
+        if ( pState )
+        {
+            *pState = SERVER_OFFLINE;
+        }
+        return true;
     }
-    if ( IsEqual_esp100 != sp100_CompareVersionIDs ( &KgsNotRemapped->RTEVersionID ) )
+    if( KgsNotRemapped->state ) // if there is no valid state in the kss, any other information may not be usable
     {
-		tsp00_Versionc currentVersion;
+        if(pActiveSpeed)
+        {
+            if(0 == strncmp(KgsNotRemapped->KernelVersion,COMP_NAME_KERNEL_SP100,strlen(COMP_NAME_KERNEL_SP100)))
+            {
+                *pActiveSpeed = speedFast;
+            }
+            else if(0 == strncmp(KgsNotRemapped->KernelVersion,COMP_NAME_QUICKKNL_SP100,strlen(COMP_NAME_QUICKKNL_SP100)))
+            {
+                *pActiveSpeed = speedQuick;
+            }
+            else if(0 == strncmp(KgsNotRemapped->KernelVersion,COMP_NAME_SLOWKNL_SP100,strlen(COMP_NAME_SLOWKNL_SP100)))
+            {
+                *pActiveSpeed = speedSlow;
+            }
+            else if(0 == strncmp(KgsNotRemapped->KernelVersion,COMP_NAME_OMSTSTKNL_SP100,strlen(COMP_NAME_OMSTSTKNL_SP100)))
+            {
+                *pActiveSpeed = speedTest;
+            }
+            else
+            {
+                *pActiveSpeed = speedNone;
+            }
+        }
+        if ( IsEqual_esp100 != sp100_CompareVersionIDs ( &KgsNotRemapped->RTEVersionID ) )
+        {
+		    tsp00_Versionc currentVersion;
 
-		sp100_GetVersionString( COMP_NAME_RTE_SP100,
-								s100buildnumber,
-								currentVersion);
-        errList = SAPDBErr_MessageList(RTE_CONTEXT, RTEERR_DBREG_WRONG_DB_VERSION, KgsNotRemapped->RTEVersion, currentVersion );
-        sql34UnmapKgsNotRemapped(KgsNotRemapped);
-        return false;
-    }
-
-    if ( pParentPid )
-    {
-        *pParentPid = KgsNotRemapped->parentPid;
-    }
-    if ( pPid )
-    {
-        *pPid = KgsNotRemapped->pid;
+		    sp100_GetVersionString( COMP_NAME_RTE_SP100,
+								    s100buildnumber,
+								    currentVersion);
+            errList = SAPDBErr_MessageList(RTE_CONTEXT, RTEERR_DBREG_WRONG_DB_VERSION, KgsNotRemapped->RTEVersion, currentVersion );
+            sql34UnmapKgsNotRemapped(KgsNotRemapped);
+            return false;
+        }
+        if ( pParentPid )
+        {
+            *pParentPid = KgsNotRemapped->parentPid;
+        }
+        if ( pPid )
+        {
+            *pPid = KgsNotRemapped->pid;
+        }
+        SAPDB_Int rc = kill ( KgsNotRemapped->pid, 0 );
+        if ( rc != 0 && errno == ESRCH )
+        {
+            errList = SAPDBErr_MessageList(RTE_CONTEXT, RTEERR_DBREG_DB_NOT_STARTED, m_dbName);
+	        sql34UnmapKgsNotRemapped(KgsNotRemapped);
+            *pState = SERVER_OFFLINE;
+            return true;
+        }
     }
     if ( pState )
     {
         *pState = KgsNotRemapped->state;
     }
-    SAPDB_Int rc = kill ( KgsNotRemapped->pid, 0 );
-    if ( rc != 0 && errno == ESRCH )
-    {
-        errList = SAPDBErr_MessageList(RTE_CONTEXT, RTEERR_DBREG_DB_NOT_STARTED, m_dbName);
-	    sql34UnmapKgsNotRemapped(KgsNotRemapped);
-        *pState = SERVER_OFFLINE;
-        return true;
-    }
     if ( pWantDump )
     {
         KgsNotRemapped->wantDump = *pWantDump;
@@ -1666,12 +1712,23 @@ SAPDB_Bool RTE_ActiveDatabase::getDbPidStateFromShm (
     {
         KgsNotRemapped->gracefully = *pGracefully;
     }
+
 	/* PTS 1113038 */
 	sql34UnmapKgsNotRemapped(KgsNotRemapped);
 
     return true;
 }
 
+//-----------------------------------------------------------
+
+const RTE_SpeedInfo &RTE_ActiveDatabase::GetActiveSpeed()
+{
+    RTE_SpeedInfo &activeSpeed = speedNone;
+    SAPDBErr_MessageList errList;
+    getDbPidStateFromShm(NULL,NULL,NULL,0,0,&activeSpeed,errList);
+    return activeSpeed;
+}
+
 //---------------------
 
 bool
@@ -1794,7 +1851,7 @@ RTE_ActiveDatabase::Start( RTE_SpeedInfo &speed
         http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1122382    
     */  
     SAPDB_UInt4 dbState;
-    getDbPidStateFromShm(NULL,NULL,&dbState,0,0,errList);
+    getDbPidStateFromShm(NULL,NULL,&dbState,0,0,NULL,errList);
     if(SERVER_COLD != dbState && SERVER_WARM != dbState )
     {
         errList = SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_KERNEL_DIED_BEFORE_ADMIN);
@@ -1851,7 +1908,7 @@ RTE_ActiveDatabase::Stop(SAPDBErr_MessageList &errList,SAPDB_UInt4 offlineTimeOu
 
     pid_t                  kernelParentPid ;
     pid_t                  kernelPid ;
-    if(!getDbPidStateFromShm(&kernelParentPid, &kernelPid, NULL, &dump, &gracefully, errList) )
+    if(!getDbPidStateFromShm(&kernelParentPid, &kernelPid, NULL, &dump, &gracefully, NULL,errList) )
     {
         return false;
     }
@@ -1896,7 +1953,7 @@ RTE_ActiveDatabase::Stop(SAPDBErr_MessageList &errList,SAPDB_UInt4 offlineTimeOu
 bool RTE_ActiveDatabase::UpdateStatus(SAPDBErr_MessageList &errList)
 {
     SAPDB_UInt4 dbState;
-    if(!getDbPidStateFromShm( NULL, NULL, &dbState, 0, 0, errList ))
+    if(!getDbPidStateFromShm( NULL, NULL, &dbState, 0, 0,NULL, errList ))
     {
         errList = errList + SAPDBErr_MessageList (RTE_CONTEXT, RTEERR_DBREG_COULD_NOT_GET_KERNEL_STATE,sqlerrs());
         dbState = 0;
