@@ -160,7 +160,7 @@ private:
     SAPDB_Bool checkForDbStartable (RTE_Path &full_knl_path, RTE_Path &rundir, SAPDBErr_MessageList &errList);
     SAPDB_Bool checkForRunningProcesses (SAPDB_Bool &dbRunning,SAPDBErr_MessageList &errList); 
     SAPDB_Bool updateEnvironment(SAPDB_Char *errorText, SAPDB_Int4 maxErrorTextLengthInBytes);
-    SAPDB_Bool getDbPidStateFromShm (pid_t *pParentPid,pid_t *pPid,SAPDB_UInt4 *pState,SAPDB_Bool *pWantDump,SAPDB_Bool *pGracefully, SAPDBErr_MessageList &errList);
+    SAPDB_Bool getDbPidStateFromShm (pid_t *pParentPid,pid_t *pPid,SAPDB_UInt4 *pState,SAPDB_Bool *pWantDump,SAPDB_Bool *pGracefully, RTE_SpeedInfo *pActiveSpeed, SAPDBErr_MessageList &errList);
     SAPDB_Bool doWaitForPid( pid_t kernelPid,SAPDB_UInt4 offlineTimeOut,SAPDBErr_MessageList &errList );
     SAPDB_Bool checkFileDoesNotExist ( SAPDB_Char *path );
     SAPDB_Bool checkFileAccess ( SAPDB_Char *path, SAPDB_Int mode );
