@@ -109,6 +109,7 @@
 #define CON_REQ_DIAGNOSE_PAGECACHE     52
 
 #define CON_REQ_RWREGIONS              53
+#define CON_REQ_MINI_DUMP              55 | SECURITY_CHECK_ACCESS_RIGHTS
 
 #define CON_REQUEST(_request)              ((_request) & ~SECURITY_CHECK_ACCESS_RIGHTS)  
 #define CON_REQUEST_SECURITY(_request)     ((_request) != CON_REQUEST (_request))
@@ -388,7 +389,7 @@ typedef struct cons_single_task_counts_record
     SAPDB_ULong                     ulTaskIndex;
     UINT1                           TaskType;           // - task type (TT_US,...)
     PID                             ApplPid;            // - process id of connected user process
-    SQL_NODEIDC                     szClientNode;
+    RTE_Nodename                    szClientNode;
     SAPDB_ULong                     ulSelfSuspCount;
     SAPDB_ULong                     ulBegExclCalls;
     teo52_TaskPrioStatistic         PrioStat;
@@ -471,6 +472,7 @@ typedef struct cons_total_counts_info_record
     SAPDB_ULong                     ulTotalBegExclTasCount;
     SAPDB_ULong                     ulTotalEndExclTasCount;
     teo52_TaskPrioStatistic         TotalPrioStat;
+    SAPDB_UInt8                     ulTotalSymbolResolutionLocks;
 } CONS_TOTAL_COUNTS_INFO_REC;
 
 typedef CONS_TOTAL_COUNTS_INFO_REC  *PCONS_TOTAL_COUNTS_INFO_REC;
@@ -644,7 +646,7 @@ typedef struct cons_single_connection_info_record
     time_t                          connectTime;       /* Connect time in seconds */
     PID                             peerPid;           /* Local connected pid */
     PID                             remotePid;         /* Remote client pid */
-    SQL_NODEIDC                     clientNode;        /* Client node */
+    RTE_Nodename                    clientNode;        /* Client node */
 } CONS_SINGLE_CONNECTION_INFO_REC;
 
 typedef CONS_SINGLE_CONNECTION_INFO_REC  *PCONS_SINGLE_CONNECTION_INFO_REC;
@@ -666,7 +668,7 @@ typedef struct cons_single_task_info_record
     SAPDB_ULong                     ulTaskIndex;
     TID                             Tid;
     PID                             ApplPid;            // - process id of connected user procces
-    SQL_NODEIDC                     szClientNode;
+    RTE_Nodename                    szClientNode;
     SAPDB_ULong                     ulStateReason;      // - more state infos
     tsp00_Longuint                  ulTaskTimeOut;      // - time for task's timeout if still in VRECEIVE
     REGION_ID                       Sid;
@@ -689,6 +691,7 @@ typedef struct cons_single_task_info_record
     SAPDB_Long                      WaitTime;           /* CR 1115172 */
     SAPDB_ULong                     ulDynPrio;          /* CR 1115172 */
     void                           *RWRegion;
+    SAPDB_Char                      NameOfSpinlockYieldingFor[20];
     UINT1                           WaitingForExclusiveAccess;
 } CONS_SINGLE_TASK_INFO_REC;
 
@@ -795,13 +798,28 @@ typedef struct cons_rwregion_info_record
 {
     union
     {
-        SAPDB_ULong ulInfoNum;
+        struct
+        {
+            SAPDB_ULong ulInfoNum;
+            SAPDB_ULong numberOfSpinlockPools;
+        }
+        outParams;
         SAPDB_Bool  showAll;
     };
 } CONS_RWREGION_INFO_REC;
 
 typedef CONS_RWREGION_INFO_REC        *PCONS_RWREGION_INFO_REC;
 
+/*!
+  show single SpinlockPool
+ */
+typedef struct cons_single_spinlockpool_info_record
+{
+    SAPDB_UTF8  m_Name[40+1];
+} CONS_SINGLE_SPINLOCKPOOL_INFO_REC;
+
+typedef CONS_SINGLE_SPINLOCKPOOL_INFO_REC        *PCONS_SINGLE_SPINLOCKPOOL_INFO_REC;
+
 typedef struct cons_single_rwregion_info_record
 {
     void        *pAddress;
@@ -820,6 +838,7 @@ typedef struct cons_single_rwregion_info_record
     SAPDB_UInt4 nonExclusiveAccessCounter;
     SAPDB_UInt4 waitCounter;
     SAPDB_UInt4 tasCounter;
+    SAPDB_UInt4 spinlockPoolIndex;
 } CONS_SINGLE_RWREGION_INFO_REC;
 
 typedef CONS_SINGLE_RWREGION_INFO_REC        *PCONS_SINGLE_RWREGION_INFO_REC;
