@@ -46,6 +46,18 @@
  --- XCONS standard output ---
 */
 
+#if defined(_WIN32)
+#define SAPDB_UINT8_FORMAT "I64u"
+#define SAPDB_INT8_FORMAT "I64d"
+#else
+#if defined(BIT64)
+#define SAPDB_UINT8_FORMAT "lu"
+#define SAPDB_INT8_FORMAT "ld"
+#else
+#define SAPDB_UINT8_FORMAT "llu"
+#define SAPDB_INT8_FORMAT "lld"
+#endif
+#endif
 
 #define XCONS_SERVERDB                     "\nSERVERDB: %s\n"
 #define XCONS_GATEWAY                      "\nGateway: %s\n"
@@ -380,6 +392,9 @@
 #define XCONS_SHOW_TOTAL_KT_PRIO_CNT               "total_prio_calls    :"
 #define XCONS_SHOW_TOTAL_KT_PRIO_OTHER             "total_prio_other    :"
 
+#define XCONS_SHOW_TOTAL_SYMBOL_RESOLUTION_LOCKS   "%30s %-10" SAPDB_UINT8_FORMAT "\n"
+#define XCONS_SHOW_TOTAL_SYMBOL_RESOLUTION_LOCK_CNT "total_symbol_resolution_locks:"
+
 #define XCONS_SHOW_UKT_SLEEP_STAT_HEADER \
                                                    "\n%s\n            Idle   dd:hh:mm:ss             I/O Wait   dd:hh:mm:ss         RQlen\n%s\n", \
                                                    XCONS_INFO_LINE , \
@@ -490,6 +505,7 @@
 #define XCONS_TSK_STATE_VCOPYVOLUME        "Vcopyvolume   "
 #define XCONS_TSK_STATE_VENTERRWREGION     "VenterRWRegion"
 #define XCONS_TSK_STATE_VLEAVERWREGION     "VleaveRWRegion"
+#define XCONS_TSK_STATE_YIELDING           "Yielding      "
 #define XCONS_TSK_STATE_UNKNOWN            "UNKNOWN       "
 
 
