@@ -68,6 +68,9 @@
 #elif defined(PA20W) || defined(PA11)
 #  define SAPDB_STACK_SKIP 12
 #  define HAS_INVERTED_STACK_GROW
+#elif defined(OSF1)
+#  define SAPDB_STACK_SKIP 16
+#  undef  HAS_INVERTED_STACK_GROW
 #else
 #  define SAPDB_STACK_SKIP 8
 #  undef  HAS_INVERTED_STACK_GROW
@@ -203,7 +206,13 @@
 #  else
 /*UNIX*/   /* Machine stack grows from high to low addresses */
 /*UNIX*/   pFirstUsedOfStack = (SAPDB_UInt4*)(pTaskCtrl->StackChunkEnd);
-/*UNIX*/   pLastUsedOfStack = (SAPDB_UInt4*)(pTaskCtrl->StackChunkStart + SAPDB_STACK_SKIP);
+#    if defined (IA64) || defined (HP_IA64)
+/*UNIX IA64 */  /* On IA 64 Unix machines (HPUX and Linux), not the beginning of the allocated area but */
+/*UNIX IA64 */  /* the top of the backing store marks the beginning of the free stack area              */
+/*UNIX IA64 */  pLastUsedOfStack = (SAPDB_UInt4*)RTE_IA64GetBsp();
+#    else
+/*sane UNIX*/   pLastUsedOfStack = (SAPDB_UInt4*)(pTaskCtrl->StackChunkStart + SAPDB_STACK_SKIP);
+#    endif
 #  endif
 #endif
 /*ALL*/
@@ -271,6 +280,11 @@
 /*ALL*/       pStackImage = (SAPDB_UInt4 *)pTaskCtrl->pCurrStackPointer;
 /*ALL*/   }
 /*ALL*/
+/*ALL*/   if ( 0 == pStackImage )   /* http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1139265 Since PTS 112501 it is possible that tasks never enter the dispatcher. In this case, pTaskCtrl->maxStackPointer and pTaskCtrl->pCurrStackPointer are 0 */
+/*ALL*/   {
+/*ALL*/       return 0;
+/*ALL*/   }
+/*ALL*/
 /*ALL*/   if ( pFirstUsedOfStack > pLastUsedOfStack )
 /*ALL*/   {
 /*ALL*/       do {
