@@ -38,6 +38,7 @@
 #include "SAPDBCommon/SAPDB_sprintf.h"
 #include "RunTime/Communication/RTEComm_PacketHeader.h"
 #include "RunTime/RTE_DiagPipe.h"
+#include "heo07.h"
 
 #define RTE_DIAGPIPE_PROTOCOL_VERSION   1
 
@@ -45,7 +46,8 @@
 #define RTE_DIAGPIPE_KERNEL_REF         1
 #define RTE_DIAGPIPE_DBM_REF            2
 
-static tRTESys_IOHandle pipeFileDes = RTE_UNDEF_HANDLE;
+static volatile tRTESys_IOHandle pipeFileDes = RTE_UNDEF_HANDLE;
+static teo07_Mutex diagPipeMutex;
 
 #ifdef _WIN32
 #define _PIPE_PREFIX "\\\\.\\pipe\\"
@@ -68,6 +70,7 @@ pipePacket;
 externC void RTE_ConnectToDiagPipe(SAPDB_Char *dbName)
 {
     tRTESys_IOHandle diagPipe;
+    sqlcreatemutex(&diagPipeMutex);
 #ifdef _WIN32   /* Windows only. On Unix, the kernel inherits a handle to the pipe from the dbm */
     tsp00_VfReturn_Param returnStatus;
 
@@ -92,24 +95,30 @@ externC void RTE_ConnectToDiagPipe(SAPDB_Char *dbName)
 /* write to the pipe if it's open */
 externC void RTE_WriteToDiagPipe( SAPDB_Char *message, SAPDB_Int length )
 {
-    tRTESys_IOPosition written;
-    tsp00_VfReturn_Param returnStatus;
-    
-    void *spaceForPipePacket = alloca(PACKET_HEADER_BUFFER_SIZE + length);
-
-    RTEComm_PacketHeader header(spaceForPipePacket) ;
-    header.Set( RTE_DIAGPIPE_DATA_PACKET,
-                RTE_DIAGPIPE_KERNEL_REF,
-                RTE_DIAGPIPE_DBM_REF,
-                length,
-                Prot_DiagPipe,
-                RTE_DIAGPIPE_PROTOCOL_VERSION);
-
-    memcpy(((pipePacket *)spaceForPipePacket)->data,message,length);
-
-    if(RTE_UNDEF_HANDLE != pipeFileDes)
+    // a dirty read: the dangerous case is some other thread closing the handle while we are in this routine
+    if( RTE_UNDEF_HANDLE != pipeFileDes )   
     {
-        RTESys_IOWrite ( pipeFileDes, spaceForPipePacket, PACKET_HEADER_BUFFER_SIZE + length, written, returnStatus );
+        tRTESys_IOPosition written;
+        tsp00_VfReturn_Param returnStatus;
+        
+        sqlbeginmutex(&diagPipeMutex);
+        if(RTE_UNDEF_HANDLE != pipeFileDes) // make sure that the handle is really open - it won't change between sqlbeginmutex() and sqlendmutex(), but might have changed before the sqlbeginmutex()
+        {
+            void *spaceForPipePacket = alloca(PACKET_HEADER_BUFFER_SIZE + length);
+
+            RTEComm_PacketHeader header(spaceForPipePacket) ;
+            header.Set( RTE_DIAGPIPE_DATA_PACKET,
+                        RTE_DIAGPIPE_KERNEL_REF,
+                        RTE_DIAGPIPE_DBM_REF,
+                        length,
+                        Prot_DiagPipe,
+                        RTE_DIAGPIPE_PROTOCOL_VERSION);
+
+            memcpy(((pipePacket *)spaceForPipePacket)->data,message,length);
+
+            RTESys_IOWrite ( pipeFileDes, spaceForPipePacket, PACKET_HEADER_BUFFER_SIZE + length, written, returnStatus );
+        }
+        sqlendmutex(&diagPipeMutex);
     }
 }
 
@@ -118,6 +127,7 @@ externC void RTE_WriteToDiagPipe( SAPDB_Char *message, SAPDB_Int length )
 /* close the pipe and invalidate the file descriptor */
 externC void RTE_CloseDiagPipe(void)
 {
+    sqlbeginmutex(&diagPipeMutex);
     tsp00_VfReturn_Param returnStatus;
 
     if(RTE_UNDEF_HANDLE != pipeFileDes)
@@ -125,11 +135,15 @@ externC void RTE_CloseDiagPipe(void)
         RTESys_IOClose(pipeFileDes,returnStatus );
         pipeFileDes = RTE_UNDEF_HANDLE;
     }
+    sqlendmutex(&diagPipeMutex);
 }
 
 externC SAPDB_Bool RTE_DiagPipeIsOpen(void)
 {
-    return ( RTE_UNDEF_HANDLE != pipeFileDes );
+    sqlbeginmutex(&diagPipeMutex);
+    SAPDB_Bool retval = ( RTE_UNDEF_HANDLE != pipeFileDes );
+    sqlendmutex(&diagPipeMutex);
+    return retval ;
 }
 
 // implementation of methods of the class that is used by the clients
