@@ -53,6 +53,7 @@ extern "C" {
 
 /*! ErrText will never die ;-) */
 typedef SAPDB_Char RTE_IniFileErrtext[40];
+typedef SAPDB_Char RTE_IniFileErrtextc[41];
 
 /*! Result codes and errors */
 typedef SAPDB_Byte RTE_IniFileResult;
@@ -625,6 +626,22 @@ SAPDB_Bool RTE_GetCommonConfigPath ( RTE_Path           VAR_ARRAY_REF ConfigPath
 SAPDB_Bool RTE_GetCommonDataPath ( RTE_Path           VAR_ARRAY_REF ConfigPath,
                                    SAPDB_Bool                       TerminateWithDelimiter,
                                    RTE_IniFileErrtext VAR_ARRAY_REF ErrText );
+
+/*!
+  @brief Gets the common path for the application data. (Windows only)
+
+         "C:\Documents and Settings\All Users\Application Data\sdb" on Windows is used as path 
+         for the 'Application Data'.
+
+  @param applicationDataPath    [out]   the returned application data path
+                                        applicationDataPath is a C ( null terminated ) string  
+  @param terminateWithDelimiter [in]    Forces to terminate path with path delimiter '/'
+  @param ErrText                [out]   In case of problems filled with error text
+  @return                               True if call succeeded, false if call failed
+ */
+SAPDB_Bool RTE_GetCommonApplicationDataPath         ( RTE_Path            VAR_ARRAY_REF ConfigPath,
+                                                      SAPDB_Bool                        TerminateWithDelimiter,
+                                                      RTE_IniFileErrtextc VAR_ARRAY_REF ErrTextc );
 #ifdef __cplusplus
 }
 #endif
