@@ -57,6 +57,7 @@
 #include "heo01.h"                                          /* nocheck */
 #include "RunTime/RTE_IniFileHandling.h"                    /* nocheck */
 #include "gen41.h"                                          /* nocheck */ // for en41Get*FromFile()
+#include "RunTime/System/RTESys_IO.h"                       /* nocheck */
 #else
 #include "gos00.h"                                          /* nocheck */
 #include "RunTime/RTE_NTService.hpp"                        /* nocheck */
@@ -495,7 +496,56 @@ void RTE_Installation::FillPidList(const SAPDB_Char *pExecutableName,PidList &pi
     }
 }
 
-SAPDB_Bool RTE_Installation::dbHasRunningProcess ( RTE_DBName &dbname,RTE_SpeedInfo speed,PidList &pidsRunningKernel)
+SAPDB_Bool RTE_Installation::MatchInProcFS(RTE_DBName &dbname,RTE_SpeedInfo speed,tsp00_TaskId pid)
+{
+    RTE_Path entryInProcFS;
+    SAPDB_sprintf(entryInProcFS,sizeof(RTE_Path),"/proc/%d/cmdline",pid);
+    SAPDB_Char contentsOfProcFSEntry[sizeof(RTE_Path)+1+sizeof(RTE_DBName)+1];
+    RTE_FileHandle hendl;
+    tsp00_VfReturn_Param ReturnStatus;
+    RTESys_IOOpen ( hendl,
+                    entryInProcFS,
+                    RTESys_IOReadOnly,
+                    false,
+                    0,
+                    ReturnStatus );
+    if( vf_ok == ReturnStatus )
+    {
+        tRTESys_IOPosition BytesRead;
+        RTESys_IORead(  hendl,
+                        contentsOfProcFSEntry,
+                        sizeof(contentsOfProcFSEntry),
+                        BytesRead,
+                        ReturnStatus );
+        RTESys_IOClose(hendl,ReturnStatus);
+        RTE_Path expectedExecutablePath;
+        SAPDB_sprintf(expectedExecutablePath,sizeof(RTE_Path),"%s/pgm/%s",m_dbRoot,speed.ExecutableName());
+        SAPDB_Char *dbNameFromProcFS = contentsOfProcFSEntry+strlen(contentsOfProcFSEntry)+1;
+        if( ( 0 == strcmp(expectedExecutablePath,contentsOfProcFSEntry)) 
+         && ( 0 == strcmp(dbname,dbNameFromProcFS)))
+        {
+           return true;
+        }
+    }
+    else    // if the open() of the entry in the /proc/ file system fails, fall back to the fuser method. 
+    {
+        if(!m_fuserHasBeenCalled)
+        {
+            // m_fuserState has been set to noAccess in the constructor, so its existence is checked here
+            m_fuserState = RTE_FuserAccess::GetAccess();
+            // Because of m_fuserState==noAccess, the pid list has not been filled in GetDatabases(), so this must be done here
+            FillPidList(speedFast.ExecutableName(),*m_pPidList);
+            FillPidList(speedQuick.ExecutableName(),*m_pPidList);
+            FillPidList(speedSlow.ExecutableName(),*m_pPidList);
+            FillPidList(speedTest.ExecutableName(),*m_pPidList);
+            m_fuserHasBeenCalled = true;
+        }
+        return true;    // return true in order to force the check of the pid list in dbHasRunningProcess() !!
+    }
+    return false;
+}
+
+SAPDB_Bool RTE_Installation::dbHasRunningProcess ( RTE_DBName &dbname,RTE_SpeedInfo speed )
 {
     SAPDB_UTF8 speedFromFile[RTE_DBREGISTRATION_MAX_SPEED_NAME_LENGTH];
 
@@ -506,9 +556,13 @@ SAPDB_Bool RTE_Installation::dbHasRunningProcess ( RTE_DBName &dbname,RTE_SpeedI
       || 0 != en41GetPIDFromFile(dbname, &pid)  // does the pid file exist?
       || pid == 0                               // does the pid file contain a pid?
       || 0 != kill(pid,0)                       // is the process with that pid alive?
-      || !((RTE_FuserAccess::noAccess == m_fuserState) || pidsRunningKernel.Contains(pid))
+#ifdef LINUX    // PTS 1137490: use /proc/ file system entries rather than fuser on linux, because fuser calls are expensive
+      || !MatchInProcFS(dbname,speed,pid)
+#endif
+      || !((RTE_FuserAccess::noAccess == m_fuserState) || m_pPidList->Contains(pid))
       || 0 != en41GetDbSpeedFromFile(dbname, (char *)speedFromFile, RTE_DBREGISTRATION_MAX_SPEED_NAME_LENGTH)   // does the speed file exist?
-      || 0 != strcasecmp((const char *)speedFromFile, (const char *)speed.Name() ) )
+      || 0 != strcasecmp((const char *)speedFromFile, (const char *)speed.Name() ) 
+       )
     {                                           // any of conditions above not true --> not running
         return false;
     }
@@ -556,6 +610,7 @@ Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageLis
         RTE_Database  *currentDataBase = NULL;
 
         PidList pidsRunningKernel;
+        m_pPidList = &pidsRunningKernel;
 
         FillPidList(speedFast.ExecutableName(),pidsRunningKernel);
         FillPidList(speedQuick.ExecutableName(),pidsRunningKernel);
@@ -593,7 +648,7 @@ Container_List<RTE_Database>* RTE_Installation::GetDatabases(SAPDBErr_MessageLis
                         }
                         else
                         {
-                            running = dbHasRunningProcess (dbname,*speedIterator,pidsRunningKernel);
+                            running = dbHasRunningProcess (dbname,*speedIterator);
                         }
                         if(running)
                         {
