@@ -122,6 +122,54 @@ int main(int argc, char *argv[])
 /* i.e. AIX adds to directories to 0242000 instead of 040000... 0200000 is not defined in sys/mode.h... */
 #define MODE_TYPE_MASK (S_IFMT|S_ISUID|S_ISGID|S_IRWXU|S_IRWXG|S_IRWXO)
 
+typedef char ModeMaskAsString[11]; /* 11 == strlen("drwxrwxrwx") + 1]; */
+
+static void BuildModeMask(int mode, ModeMaskAsString &output)
+{
+    memset(&output[0], '-', sizeof(ModeMaskAsString)-1);
+    output[sizeof(ModeMaskAsString)-1] = 0;
+
+    if ( S_ISFIFO(mode) )
+        output[0] = 'p';
+    if ( S_ISCHR(mode) )
+        output[0] = 'c';
+    if ( S_ISBLK(mode) )
+        output[0] = 'b';
+    if ( S_ISDIR(mode) )
+        output[0] = 'd';
+    if ( S_ISLNK(mode) )
+        output[0] = 'l';
+
+    if ( mode & S_IRUSR )
+        output[1] = 'r';
+    if ( mode & S_IWUSR )
+        output[2] = 'w';
+    if ( mode & S_IXUSR )
+        output[3] = 'x';
+    if ( (mode & (S_IXUSR|S_ISUID)) == (S_IXUSR|S_ISUID) )
+        output[3] = 's';
+    if ( (mode & (S_IXUSR|S_ISUID)) == (S_ISUID) )
+        output[3] = 'S';
+
+    if ( mode & S_IRGRP )
+        output[4] = 'r';
+    if ( mode & S_IWGRP )
+        output[5] = 'w';
+    if ( mode & S_IXGRP )
+        output[6] = 'x';
+    if ( (mode & (S_IXGRP|S_ISGID)) == (S_IXGRP|S_ISGID) )
+        output[6] = 's';
+    if ( (mode & (S_IXGRP|S_ISGID)) == (S_ISGID) )
+        output[6] = 'l';
+
+    if ( mode & S_IROTH )
+        output[7] = 'r';
+    if ( mode & S_IWOTH )
+        output[8] = 'w';
+    if ( mode & S_IXOTH )
+        output[9] = 'x';
+}
+
 /*
   Check ownership against given user id , group id and minimum wanted mode.
   The modeWanted is the minimum restriction enforced. I.e. if a read access for world is granted, this
@@ -142,14 +190,24 @@ static SAPDB_Bool CheckOwnership(char const *absolutePath, int userWanted, int g
       ||  ((int)statusBuffer.st_gid)  != groupWanted
       ||  (((int)statusBuffer.st_mode)&(~modeWanted)&MODE_TYPE_MASK) != 0 )
     {
-        fprintf(stderr, "Bad %s Wanted (%d,%d,%o) got (%d,%d,%o)\n",
+        ModeMaskAsString wantedModeMask;
+        ModeMaskAsString gotModeMask;
+
+        BuildModeMask((int)modeWanted, wantedModeMask);
+        BuildModeMask((int)statusBuffer.st_mode, gotModeMask);
+
+        fprintf(stderr, "Bad path '%s'\n"
+                        " Wanted (UserId %5d, GroupId %5d, Mode %6o '%s')\n"
+                        " Got    (UserId %5d, GroupId %5d, Mode %6o '%s')\n",
                 absolutePath,
                 userWanted,
                 groupWanted,
                 modeWanted,
+                &wantedModeMask[0],
                 (int)statusBuffer.st_uid,
                 (int)statusBuffer.st_gid,
-                (int)statusBuffer.st_mode );
+                (int)statusBuffer.st_mode,
+                &gotModeMask[0] );
         return false;
     }
 
