@@ -86,12 +86,18 @@ public:
 
   virtual void * AllocSystemPages(SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * AllocSystemPages(SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * UncachedAllocSystemPagesAtFixedAddress(void *FixedAddr, SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * UncachedAllocSystemPagesAtFixedAddress(void *FixedAddr, SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * ReserveSystemPages(SAPDB_ULong SizeInBytes);
 
   virtual void * AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * CommitSystemPages(void *FirstPagePointer, SAPDB_ULong NumberOfBytes);
 
   virtual bool   FreeSystemPages(void *FirstPagePointer, SAPDB_ULong NumberOfBytes);
@@ -326,6 +332,13 @@ void * RTE_SystemNT::AllocSystemPages(SAPDB_ULong SizeInBytes, bool DoCommit)
 
 /*---------------------------------------------------------------------------*/
 
+void * RTE_SystemNT::AllocSystemPages(SAPDB_ULong SizeInBytes, bool doCommit, SAPDBErr_MessageList &messageList) // Uncommitted pages unsupported
+{
+  return AllocSystemPagesAtFixedAddress((void *)0, SizeInBytes, doCommit, messageList);
+}
+
+/*---------------------------------------------------------------------------*/
+
 void * RTE_SystemNT::ReserveSystemPages(SAPDB_ULong SizeInBytes)
 {
     return (void *)0; /* not supported */
@@ -343,7 +356,29 @@ void * RTE_SystemNT::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_UL
 
 /*---------------------------------------------------------------------------*/
 
-void * RTE_SystemNT::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit)
+void * RTE_SystemNT::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList)
+{
+    SAPDB_ULong SystemPages = ((SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1)))
+                              / GetSystemPageSize();
+
+    return RTEMem_SystemPageCache::Instance().Allocate(FixedAddress, SystemPages, DoCommit, messageList);
+}
+
+/*---------------------------------------------------------------------------*/
+
+void * RTE_SystemNT::UncachedAllocSystemPagesAtFixedAddress( void *FixedAddress
+                                                           , SAPDB_ULong SizeInBytes
+                                                           , bool DoCommit
+                                                           , SAPDBErr_MessageList &messageList)
+{
+    return UncachedAllocSystemPagesAtFixedAddress( FixedAddress, SizeInBytes, DoCommit);
+}
+
+/*---------------------------------------------------------------------------*/
+
+void * RTE_SystemNT::UncachedAllocSystemPagesAtFixedAddress( void *FixedAddress
+                                                           , SAPDB_ULong SizeInBytes
+                                                           , bool DoCommit)
 {
   SAPDB_ULong SystemSize = (SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1));
   void *ChunkAddress = NULL;
