@@ -105,12 +105,18 @@ public:
 
   virtual void * AllocSystemPages(SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * AllocSystemPages(SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * UncachedAllocSystemPagesAtFixedAddress(void *FixedAddr, SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * UncachedAllocSystemPagesAtFixedAddress(void *FixedAddr, SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * ReserveSystemPages(SAPDB_ULong SizeInBytes);
 
   virtual void * AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit=true);
 
+  virtual void * AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit, SAPDBErr_MessageList &messageList);
+
   virtual void * CommitSystemPages(void *StartPageAddress, SAPDB_ULong SizeInBytes);
 
   virtual bool   FreeSystemPages(void *StartPageAddress, SAPDB_ULong SizeInBytes);
@@ -130,6 +136,12 @@ public:
 
   virtual SAPDB_Char const * GetLocalNodeName();
 
+  SAPDB_Bool PseudoAllocMemory(SAPDB_ULong SizeInBytes);
+
+  void PseudoFreeMemory(SAPDB_ULong SizeInBytes);
+
+  static RTE_SystemUNIX * m_Instance; // The singleton instance
+
 private:
 
   RTE_SystemUNIX(SAPDB_ULong MemoryLimitInBytes);
@@ -149,8 +161,6 @@ private:
 
   SAPDB_ULong m_PhysicalMemorySize;
   
-  static RTE_SystemUNIX * m_Instance; // The singleton instance
-
 #ifdef USE_FIXED_MMAP_ADDRESS
   static SAPDB_Char *m_nextMmapAddress;
   RTE_Lock m_nextMmapAddressLock;  // Used for locking mmap start address
@@ -341,9 +351,16 @@ void   RTE_SystemUNIX::DecrementUsedMemory(SAPDB_ULong SizeInBytes)
 
 /*---------------------------------------------------------------------------*/
 
-void * RTE_SystemUNIX::AllocSystemPages(SAPDB_ULong SizeInBytes, bool) // Uncommitted pages unsupported
+void * RTE_SystemUNIX::AllocSystemPages(SAPDB_ULong SizeInBytes, bool doCommit) // Uncommitted pages unsupported
 {
-  return AllocSystemPagesAtFixedAddress((void *)0, SizeInBytes);
+  return AllocSystemPagesAtFixedAddress((void *)0, SizeInBytes, doCommit);
+}
+
+/*---------------------------------------------------------------------------*/
+
+void * RTE_SystemUNIX::AllocSystemPages(SAPDB_ULong SizeInBytes, bool doCommit, SAPDBErr_MessageList &messageList) // Uncommitted pages unsupported
+{
+  return AllocSystemPagesAtFixedAddress((void *)0, SizeInBytes, doCommit, messageList);
 }
 
 /*---------------------------------------------------------------------------*/
@@ -371,7 +388,7 @@ void * RTE_SystemUNIX::ReserveSystemPages(SAPDB_ULong SizeInBytes)
 
 /*---------------------------------------------------------------------------*/
 
-void * RTE_SystemUNIX::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool) // Uncommitted pages unsupported
+void * RTE_SystemUNIX::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool doCommit) // Uncommitted pages unsupported
 {
     SAPDB_ULong SystemPages = ((SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1)))
                               / GetSystemPageSize();
@@ -381,6 +398,16 @@ void * RTE_SystemUNIX::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_
 
 /*---------------------------------------------------------------------------*/
 
+void * RTE_SystemUNIX::AllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool doCommit, SAPDBErr_MessageList &messageList) // Uncommitted pages unsupported
+{
+    SAPDB_ULong SystemPages = ((SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1)))
+                              / GetSystemPageSize();
+
+    return RTEMem_SystemPageCache::Instance().Allocate(FixedAddress, SystemPages, true, messageList);
+}
+
+/*---------------------------------------------------------------------------*/
+
 void RTE_SystemUNIX::ShowAllocationFailedMessage(SAPDBErr_MessageList &messageList)
 {
     static SAPDB_UInt8 lastSuccessfullAllocs = 0;
@@ -483,7 +510,60 @@ void RTE_SystemUNIX::AddMemoryStatistic(SAPDBErr_MessageList &messageList)
 
 /*---------------------------------------------------------------------------*/
 
-void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress, SAPDB_ULong SizeInBytes, bool DoCommit)
+void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress( void *FixedAddress
+                                                             , SAPDB_ULong SizeInBytes
+                                                             , bool DoCommit)
+{
+    SAPDBErr_MessageList tmpMessageList;
+    void *ptr = UncachedAllocSystemPagesAtFixedAddress(FixedAddress, SizeInBytes, DoCommit, tmpMessageList);
+    if ( ptr )
+    {
+        return ptr;
+    }
+
+    // only output if meanwhile an allocation succeeded...
+    ShowAllocationFailedMessage( tmpMessageList );
+
+    return 0;
+}
+
+/*---------------------------------------------------------------------------*/
+
+SAPDB_Bool RTE_SystemUNIX::PseudoAllocMemory(SAPDB_ULong SizeInBytes)
+{
+    SAPDB_ULong SystemSize = (SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1));
+
+    bool  DoAllocate = IncrementUsedMemory(SystemSize);
+
+    if ( DoAllocate )
+    {
+        IncrementCallCounter(m_SuccessfullAllocCalls);
+    } 
+    else
+    {
+        IncrementCallCounter(m_FailedAllocCalls);
+    }
+
+    return DoAllocate;
+}
+
+/*---------------------------------------------------------------------------*/
+
+void RTE_SystemUNIX::PseudoFreeMemory(SAPDB_ULong SizeInBytes)
+{
+    SAPDB_ULong SystemSize = (SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1));
+
+    IncrementCallCounter(m_FreeCalls);
+
+    DecrementUsedMemory(SystemSize);
+}
+
+/*---------------------------------------------------------------------------*/
+
+void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress( void *FixedAddress
+                                                             , SAPDB_ULong SizeInBytes
+                                                             , bool DoCommit
+                                                             , SAPDBErr_MessageList &messageList)
 {
     // Round up to Systempage size
     SAPDB_ULong SystemSize = (SizeInBytes + GetSystemPageSize() - 1) & (~(GetSystemPageSize()-1));
@@ -521,7 +601,7 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
             }
             DecrementUsedMemory(SystemSize);
 
-            SAPDBErr_MessageList messageList( RTE_CONTEXT,
+            messageList = SAPDBErr_MessageList ( RTE_CONTEXT,
                                 RTEERR_RTEMEM_NO_MORE_SYSTEM_PAGES,
 	                            SAPDB_ToString(SizeInBytes),
 	                            SAPDB_ToString(GetSystemPageSize()),
@@ -534,9 +614,6 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
 
             
             AddMemoryStatistic(messageList);
-
-            // only output if meanwhile an allocation succeeded...
-            ShowAllocationFailedMessage( messageList );
         }
 
 #else /* not USE_VMALLOC_NOT_MMAP */
@@ -585,7 +662,7 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
               }
               DecrementUsedMemory(SystemSize);
 
-              SAPDBErr_MessageList messageList( RTE_CONTEXT,
+              messageList = SAPDBErr_MessageList( RTE_CONTEXT,
                                     RTEERR_RTEMEM_NO_MORE_SYSTEM_PAGES,
 	                                SAPDB_ToString(SizeInBytes),
 	                                SAPDB_ToString(GetSystemPageSize()),
@@ -593,9 +670,6 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
 	                                SAPDB_ToString(errorText) );
               AddMemoryStatistic(messageList);
 
-              // only output if meanwhile an allocation succeeded...
-              ShowAllocationFailedMessage( messageList );
-
               ChunkAddress = (void *)0;
         }
 
@@ -603,7 +677,7 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
           && 0 != FixedAddress 
           && FixedAddress != ChunkAddress )
         {
-            SAPDBErr_MessageList messageList( RTE_CONTEXT,
+            messageList = SAPDBErr_MessageList( RTE_CONTEXT,
                                               RTEERR_RTEMEM_OUT_OF_RESERVABLE_SYSTEM_PAGES,
                                               SAPDB_ToString(SizeInBytes),
                                               SAPDB_ToString(FixedAddress) );
@@ -625,9 +699,6 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
                                SAPDB_ToString(mmapAddress) );
             messageList.AppendNewMessage( info );
 #endif
-            // only output if meanwhile an allocation succeeded...
-            ShowAllocationFailedMessage( messageList );
-
             // Only wanted address is acceptable...
             UncachedFreeSystemPages(ChunkAddress, SizeInBytes);
 
@@ -649,13 +720,11 @@ void * RTE_SystemUNIX::UncachedAllocSystemPagesAtFixedAddress(void *FixedAddress
  
         RTE_ISystem::Unlock(m_MemoryUsageLock);
 
-        SAPDBErr_MessageList messageList( RTE_CONTEXT,
+        messageList = SAPDBErr_MessageList( RTE_CONTEXT,
                             RTEERR_RTEMEM_MEMORY_LIMIT_REACHED,
 	                        SAPDB_ToString(MemoryLimitInBytes),
 	                        SAPDB_ToString("Systemheap"),
 	                        SAPDB_ToString(SizeInBytes) );
-        // only output if meanwhile an allocation succeeded...
-        ShowAllocationFailedMessage( messageList );
     }
 
     if ( ChunkAddress == 0 )
@@ -817,13 +886,17 @@ void RTE_ISystem::Unlock( RTE_Lock & lock )
 void RTE_ISystem::GetLocalDateTime( RTE_ISystem::DateTime  &LocalDateTime )
 {
   time_t          DateTime;
-  struct tm       tm_buffer;
   struct tm       *pDateTime_tm;
 
   time ( &DateTime );
 
+#ifdef _REENTRANT
+  struct tm tm_buffer;
   pDateTime_tm = localtime_r ( &DateTime, &tm_buffer );
-  
+#else
+  pDateTime_tm = localtime( &DateTime );
+#endif
+
   LocalDateTime.Year         = pDateTime_tm->tm_year + 1900;
   LocalDateTime.Month        = pDateTime_tm->tm_mon + 1;
   LocalDateTime.DayOfWeek    = pDateTime_tm->tm_wday;
@@ -856,6 +929,21 @@ void RTE_ISystem::DoSleep( SAPDB_UInt4 NumberOfMilliseconds )
   }
 }
 
+/*---------------------------------------------------------------------------*/
+
+SAPDB_Bool RTE_PseudoAllocMemory(SAPDB_ULong SizeInBytes)
+{
+   return RTE_SystemUNIX::m_Instance->PseudoAllocMemory(SizeInBytes);
+}
+
+/*---------------------------------------------------------------------------*/
+
+void RTE_PseudoFreeMemory(SAPDB_ULong SizeInBytes)
+{
+   RTE_SystemUNIX::m_Instance->PseudoFreeMemory(SizeInBytes);
+   return;
+}
+
 /*===========================================================================*
  *  END OF CODE                                                              *
  *===========================================================================*/
