@@ -296,6 +296,11 @@ public:
         return m_tasCounter;
     }
 
+    virtual RTESync_SpinlockPool *GetSpinlockPool(void)
+	{
+		return (RTESync_SpinlockPool *)&m_pool;
+	}
+
 protected:
     SAPDB_Int8      m_id;
     RTE_TaskId      m_lastEntered;
@@ -1279,6 +1284,12 @@ RTESync_BaseSpinlockPool::RTESync_BaseSpinlockPool( SAPDB_UTF8 const *poolIdenti
 
 RTESync_BaseSpinlockPool::~RTESync_BaseSpinlockPool()
 {
+/*
+    for( SAPDB_Int4 i=0 ; i<m_numberOfElements ; i++)
+    {
+        m_pool[i].~RTESync_NamedSpinlock();
+    }
+*/
     m_allocator.Deallocate(m_pool);
 }
 
