@@ -79,6 +79,13 @@ public:
      */
     void FreeStatisticInfo(StatisticInfo *pInfoArray);
 
+    /*!
+        @brief return the number of registered items
+    */
+    SAPDB_UInt4 GetCount(void)
+    {
+        return m_Count;
+    }
 private:
     RTESync_SpinlockPoolRegister(SAPDB_Bool makeBackupCopy):RTE_ItemRegister<RTESync_BaseSpinlockPool>(makeBackupCopy) {}
 
