@@ -559,7 +559,7 @@ SAPDB_Bool RTESys_CmpxchgInt4( SAPDB_Int4 *memoryPosition,
 #if defined __INTEL_COMPILER
 /*LINUX && IA64*/	*pOldValue = _InterlockedCompareExchange_rel (memoryPosition, newValue, expectedValue);
 #elif defined __GNUC__
-/*LINUX && IA64*/	SAPDB_Int8 expectedValueAsLong = expectedValue;
+/*LINUX && IA64*/	SAPDB_UInt8 expectedValueAsLong = (SAPDB_UInt8)((SAPDB_UInt4)expectedValue);
 /*LINUX && IA64*/   __asm__ __volatile__ ("mov ar.ccv = %0 ;;" :: "rO"(expectedValueAsLong) );
 /*LINUX && IA64*/	__asm__ __volatile__ ("cmpxchg4.rel %0=%2,%3,ar.ccv"
 /*LINUX && IA64*/			: "=r"(*pOldValue),"=m"(*memoryPosition)
@@ -933,6 +933,120 @@ SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
 #endif /* BIT64 */
 }
 
+#elif defined (HP_IA64)
+
+#include <machine/sys/inline.h>
+
+/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgInt4( SAPDB_Int4 *memoryPosition,
+/*HP_IA64*/                               SAPDB_Int4 const expectedValue,
+/*HP_IA64*/                               SAPDB_Int4 const newValue,
+/*HP_IA64*/                               SAPDB_Int4 *pOldValue)
+/*HP_IA64*/{
+/*HP_IA64*/    _Asm_mov_to_ar
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
+/*HP_IA64*/        (SAPDB_UInt8)((SAPDB_UInt4)expectedValue),
+/*HP_IA64*/        FENCE
+/*HP_IA64*/    );
+/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_sz)_SZ_W,
+/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
+/*HP_IA64*/        (void *)memoryPosition,
+/*HP_IA64*/        (SAPDB_UInt8)newValue,
+/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
+/*HP_IA64*/    );
+/*HP_IA64*/    return (*pOldValue == expectedValue);
+/*HP_IA64*/}
+
+/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgUInt4( SAPDB_UInt4 *memoryPosition,
+/*HP_IA64*/                                SAPDB_UInt4 const expectedValue,
+/*HP_IA64*/                                SAPDB_UInt4 const newValue,
+/*HP_IA64*/                                SAPDB_UInt4 *pOldValue)
+/*HP_IA64*/{
+/*HP_IA64*/    _Asm_mov_to_ar
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
+/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
+/*HP_IA64*/        FENCE
+/*HP_IA64*/    );
+/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_sz)_SZ_W,
+/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
+/*HP_IA64*/        (void *)memoryPosition,
+/*HP_IA64*/        (SAPDB_UInt8)newValue,
+/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
+/*HP_IA64*/    );
+/*HP_IA64*/    return (*pOldValue == expectedValue);
+/*HP_IA64*/}
+
+/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgInt8( SAPDB_Int8 *memoryPosition,
+/*HP_IA64*/                               SAPDB_Int8 const expectedValue,
+/*HP_IA64*/                               SAPDB_Int8 const newValue,
+/*HP_IA64*/                               SAPDB_Int8 *pOldValue)
+/*HP_IA64*/{
+/*HP_IA64*/    _Asm_mov_to_ar
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
+/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
+/*HP_IA64*/        FENCE
+/*HP_IA64*/    );
+/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_sz)_SZ_D,
+/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
+/*HP_IA64*/        (void *)memoryPosition,
+/*HP_IA64*/        (SAPDB_UInt8)newValue,
+/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
+/*HP_IA64*/    );
+/*HP_IA64*/    return (*pOldValue == expectedValue);
+/*HP_IA64*/}
+
+/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgUInt8( SAPDB_UInt8 *memoryPosition,
+/*HP_IA64*/                                SAPDB_UInt8 const expectedValue,
+/*HP_IA64*/                                SAPDB_UInt8 const newValue,
+/*HP_IA64*/                                SAPDB_UInt8 *pOldValue)
+/*HP_IA64*/{
+/*HP_IA64*/    _Asm_mov_to_ar
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
+/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
+/*HP_IA64*/        FENCE
+/*HP_IA64*/    );
+/*HP_IA64*/    *pOldValue = _Asm_cmpxchg
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_sz)_SZ_D,
+/*HP_IA64*/        (_Asm_sem)_SEM_ACQ,
+/*HP_IA64*/        (void *)memoryPosition,
+/*HP_IA64*/        (SAPDB_UInt8)newValue,
+/*HP_IA64*/        (_Asm_ldhint)_LDHINT_NONE
+/*HP_IA64*/    );
+/*HP_IA64*/    return (*pOldValue == expectedValue);
+/*HP_IA64*/}
+
+/*HP_IA64*/SAPDB_Bool RTESys_CmpxchgPointer( void * *memoryPosition,
+/*HP_IA64*/                                  void * const expectedValue,
+/*HP_IA64*/                                  void * const newValue,
+/*HP_IA64*/                                  void * *pOldValue)
+/*HP_IA64*/{
+/*HP_IA64*/    _Asm_mov_to_ar
+/*HP_IA64*/    (
+/*HP_IA64*/        (_Asm_app_reg)_AREG_CCV,
+/*HP_IA64*/        (SAPDB_UInt8)expectedValue,
+/*HP_IA64*/        FENCE
+/*HP_IA64*/    );
+/*HP_IA64*/    *pOldValue = (void *)_Asm_cmpxchg
+/*HP_IA64*/        (
+/*HP_IA64*/            (_Asm_sz)_SZ_D,
+/*HP_IA64*/            (_Asm_sem)_SEM_ACQ,
+/*HP_IA64*/            (void *)memoryPosition,
+/*HP_IA64*/            (SAPDB_UInt8)newValue,
+/*HP_IA64*/            (_Asm_ldhint)_LDHINT_NONE
+/*HP_IA64*/        );
+/*HP_IA64*/    return (*pOldValue == expectedValue);
+/*HP_IA64*/}
+
 #endif
 
 #else
@@ -1110,9 +1224,7 @@ static void AtomicLockPoolInitialize()
         SAPDB_Int4 systemPageMask = (RTESys_SystemPageSize() - 1);
         SAPDB_Byte *lockPoolPtr;
         lockPoolPtr = (SAPDB_Byte *)malloc( systemPageMask + (RTESYS_ATOMIC_OPERATION_POOL_SIZE * lockSize) );
-        pLock = (RTE_Lock *)(
-                (SAPDB_Byte *)0 + ( ((lockPoolPtr - (SAPDB_Byte *)0) + systemPageMask)&(~systemPageMask) ) 
-                            );
+        pLock = (SAPDB_Byte *)0 + ( ((lockPoolPtr - (SAPDB_Byte *)0) + systemPageMask)&(~systemPageMask) );
     }
 #endif
     for ( iLock = 0; iLock < RTESYS_ATOMIC_OPERATION_POOL_SIZE; iLock++ )
