@@ -57,7 +57,7 @@
 #include "RunTime/RTE_CompilerFeatures.h"
 #include "SAPDBCommon/SAPDB_Types.h"
 
-#if defined(WIN32) || defined(AIX) || defined(OSF1) || (defined(LINUX) && (defined(I386) || defined(IA64) || defined(X86_64))) || defined(SUN)
+#if defined(WIN32) || defined(AIX) || defined(OSF1) || (defined(LINUX) && (defined(I386) || defined(IA64) || defined(X86_64))) || defined(SUN) || defined(HP_IA64)
 
 /* The coding does not need to simulate compare and exchange with spinlock */
 #define RTESYS_HAS_NATIVE_ATOMIC_OPERATION
