@@ -89,9 +89,9 @@ externC void RTESys_MemoryBarrier(void);
 /* WIN && LINUX */
 #elif defined( IA64 ) && defined( __INTEL_COMPILER )
 
-# define RTESys_MemoryBarrier()      __mf
-# define RTESys_ReadMemoryBarrier()  __mf
-# define RTESys_WriteMemoryBarrier() __mf
+# define RTESys_MemoryBarrier()      __mf()
+# define RTESys_ReadMemoryBarrier()  __mf()
+# define RTESys_WriteMemoryBarrier() __mf()
 
 #elif defined(LINUX) && defined(IA64)
 
