@@ -81,6 +81,9 @@
 
 #if defined(LINUX)
 #  include <sys/sysinfo.h>
+#  include <sys/types.h>
+#  include <sys/stat.h>
+#  include <fcntl.h>
 #endif /* LINUX */
 
 #if defined(SUN)
@@ -227,7 +230,14 @@ typedef struct myswaptable {
 
 #if defined(WIN32)
 
+#if defined(WIN32)
 static SYSTEM_INFO *getSystemInfo();
+static SAPDB_UInt4 getNumOfLogicalProcessors();
+#endif /* WIN32 */
+
+#if defined(WIN32) || defined(LINUX)
+static SAPDB_UInt4 getNumOfPhysicalProcessors();
+#endif
 
 #endif /* WIN32 */
 
@@ -244,7 +254,7 @@ externC SAPDB_UInt4 RTESys_NumberOfCPU()
 {
     SAPDB_UInt4 nProc = 0;
 #if defined(WIN32)
-    nProc = (SAPDB_UInt4)(getSystemInfo()->dwNumberOfProcessors);
+    nProc = getNumOfLogicalProcessors();
 #elif defined(_SC_NPROCESSORS_ONLN)
     /* AIX + SUN + DEC + LINUX */
     nProc = (SAPDB_UInt4)sysconf(_SC_NPROCESSORS_ONLN);
@@ -264,6 +274,17 @@ externC SAPDB_UInt4 RTESys_NumberOfCPU()
 
 /*-----------------*/
 
+externC SAPDB_UInt4 RTESys_NumberOfPhysicalCPUs()
+{
+#if defined(WIN32) || defined(LINUX)
+    return getNumOfPhysicalProcessors();
+#else
+    return RTESys_NumberOfCPU();
+#endif
+}
+
+/*-----------------*/
+
 externC SAPDB_UInt4 RTESys_SystemPageSize()
 {
   SAPDB_UInt4 pageSize;
@@ -1234,20 +1255,24 @@ externC SAPDB_Real8 RTESys_GetCPULoad(void)
     return result;
 #elif defined (AIX)
     static SAPDB_Bool initialized = false;
-    SAPDB_Int loadavg_seek,kmem;
-    SAPDB_Int4 result;
+    static SAPDB_Int loadavg_seek,kmem;
+    SAPDB_Long result = 0;
     if(!initialized)
     {
         nlist(KERNEL_EXE_NAME,namelist);
         loadavg_seek = namelist[0].n_value;
         kmem = open("/dev/kmem",0);
-        initialized = true;
+        if ( -1 != kmem )
+        {
+            initialized = true;
+        }
     }
+    if ( initialized )
+    {
+        lseek(kmem,loadavg_seek,0);
 
-    lseek(kmem,loadavg_seek,0);
-
-    read (kmem,(char *)&result,sizeof(result));
-
+        read (kmem,(char *)&result,sizeof(result));
+    }
     return (SAPDB_Real8)result / (SAPDB_Real8)65536;
 #elif defined (OSF1)
     struct tbl_loadavg load_data;
@@ -1362,10 +1387,22 @@ void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,
     {
         SAPDB_UInt nHz   = (SAPDB_UInt)sysconf(_SC_CLK_TCK);
         perfstat_cpu_total_t cpuPerfStat;
-        perfstat_cpu_total( NULL,&cpuPerfStat,sizeof(cpuPerfStat),1);
-        *secondsIdle    = (cpuPerfStat.idle)/nHz;
-        *secondsSystem  = (cpuPerfStat.sys)/nHz;
-        *secondsUser    = (cpuPerfStat.user)/nHz;
+        if ( 1 != perfstat_cpu_total( NULL,&cpuPerfStat,240/*sizeof(cpuPerfStat)*/,1))
+        // the size of the perfstat_cpu_total_t structure grows from AIX release to AIX release, 
+        // even within AIX 5.1-releases... As we cannot guarantee that the AIX we are running on is 
+        // as new as the one we were built on, the smallest size of a perfstat_memory_cpu_t structure 
+        // known is being used. It is the one from a very old AIX 5.1 and is 240 bytes.
+        {
+            *secondsIdle    = 0;
+            *secondsSystem  = 0;
+            *secondsUser    = 0;
+        }
+        else
+        {
+            *secondsIdle    = (cpuPerfStat.idle)/nHz;
+            *secondsSystem  = (cpuPerfStat.sys )/nHz;
+            *secondsUser    = (cpuPerfStat.user)/nHz;
+        }
     }
 #elif defined (HPUX)
     {
@@ -1385,6 +1422,7 @@ void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,
         static SAPDB_Int fd;
         SAPDB_UInt8 user=0,nice=0,system=0,idle=0;
         SAPDB_Char buf[80];
+        SAPDB_Char *pBegin=&buf[0];
 
         if(!initialized)
         {
@@ -1400,7 +1438,23 @@ void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,
         }
         if(read(fd,buf,sizeof(buf)-1) < 0)
             return;
-        sscanf(buf,"%*s%ld%ld%ld%ld",&user,&nice,&system,&idle);
+
+        /* the first line of /proc/stat is in the form "cpu  <user time> <nice time> <system time> <idle time> <....>"  */
+        /* it is parsed here */
+        /* first, skip until the first number is reached */
+        while(isalpha(*pBegin)||isblank(*pBegin))
+            pBegin++;
+        user = atoll(pBegin);
+
+        pBegin = strchr(pBegin,' ')+1;
+        nice = atoll(pBegin);
+
+        pBegin = strchr(pBegin,' ')+1;
+        system = atoll(pBegin);
+
+        pBegin = strchr(pBegin,' ')+1;
+        idle = atoll(pBegin);
+
         *secondsIdle    = (idle)/nHz;
         *secondsSystem  = (system)/nHz;
         *secondsUser    = ((user+nice))/nHz;
@@ -1464,6 +1518,168 @@ void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,
 
 #if defined(WIN32)
 
+typedef enum _SDB_LOGICAL_PROCESSOR_RELATIONSHIP {
+    SDB_RelationProcessorCore,
+    SDB_RelationNumaNode
+} SDB_LOGICAL_PROCESSOR_RELATIONSHIP;
+
+typedef struct _SDB_SYSTEM_LOGICAL_PROCESSOR_INFORMATION {
+    ULONG_PTR   ProcessorMask;
+    SDB_LOGICAL_PROCESSOR_RELATIONSHIP Relationship;
+    union {
+        struct {
+            BYTE  Flags;
+        } ProcessorCore;
+        struct {
+            DWORD NodeNumber;
+        } NumaNode;
+        ULONGLONG  Reserved[2];
+    };
+} SDB_SYSTEM_LOGICAL_PROCESSOR_INFORMATION, *SDB_PSYSTEM_LOGICAL_PROCESSOR_INFORMATION;
+
+SAPDB_UInt4 RTESys_GetPhysicalProcessorInfomation(  SAPDB_UInt4*       processorRelatedness,
+                                                    SAPDB_UInt4  const arraySize,
+                                                    SAPDB_Bool   const affinitMaskDependent )
+{
+    BOOL                                        ok; 
+    SDB_PSYSTEM_LOGICAL_PROCESSOR_INFORMATION   pBuffer                 = 0;
+    DWORD                                       retry                   = 5;
+    DWORD                                       returnLength            = 0;
+    SAPDB_UInt4                                 numOfPhysicalProcessors = 0;
+    SAPDB_UInt4                                 numOfLogicalProcessors;
+    SAPDB_UInt4                                 idx;
+    SAPDB_UInt4                                 processor;
+    HMODULE                                     hKernel32;
+    SAPDB_ULong                                 systemAffinityMask;
+    SAPDB_ULong                                 processAffinityMask;
+
+
+    numOfLogicalProcessors = getSystemInfo()->dwNumberOfProcessors;
+
+    //  processorRelatedness array to small?
+    if ( numOfLogicalProcessors > arraySize ) 
+        return 0;
+
+    if ( affinitMaskDependent )
+    {
+        // Get the process affinity
+        if ( !GetProcessAffinityMask( GetCurrentProcess(), &processAffinityMask, &systemAffinityMask ))
+            processAffinityMask = getSystemInfo()->dwActiveProcessorMask; // step through the active processor mask
+    }
+    else
+        processAffinityMask = getSystemInfo()->dwActiveProcessorMask; // step through the active processor mask
+
+    memset ( processorRelatedness, 0, sizeof(SAPDB_UInt4) * arraySize );
+
+    hKernel32 = LoadLibrary( "kernel32.dll" );
+
+    if ( 0 != hKernel32 )
+    {
+        typedef BOOL (__stdcall *tGLPI)( SDB_PSYSTEM_LOGICAL_PROCESSOR_INFORMATION Buffer, PDWORD ReturnLength ); 
+
+        tGLPI pGetLogicalProcessorInformation = (tGLPI)GetProcAddress( hKernel32, "GetLogicalProcessorInformation" );
+
+        if ( 0 != pGetLogicalProcessorInformation )
+        {
+            ok = pGetLogicalProcessorInformation( pBuffer, &returnLength );
+
+            while ( retry-- && !ok && GetLastError() == ERROR_INSUFFICIENT_BUFFER )
+            {
+                pBuffer = (SDB_PSYSTEM_LOGICAL_PROCESSOR_INFORMATION)alloca(returnLength);
+
+                memset ( pBuffer, 0, returnLength );
+                ok = pGetLogicalProcessorInformation( pBuffer, &returnLength );
+            }
+
+            if ( ok )
+            {
+                int        records = returnLength / sizeof(SDB_SYSTEM_LOGICAL_PROCESSOR_INFORMATION) - 1;
+                int        record;
+                SAPDB_Bool found;
+
+                // Step through the records of logical processor informations
+                for ( record = 0; record < records ; record++ )
+                {
+                    // Is it a processor core relationship information?
+                    if ( pBuffer[record].Relationship == SDB_RelationProcessorCore )
+                    {
+                        // Find all logical processors of this core
+                        for( found = false, idx = 0; idx < numOfLogicalProcessors; idx++)
+                        {
+                            // Processor relationship found and is it allowed to run on it?
+                            if (( pBuffer[record].ProcessorMask & ((SAPDB_UInt8)1) << idx ) &&
+                                ( processAffinityMask           & ((SAPDB_UInt8)1) << idx ))
+                            {
+                                found = true; // one more phys. processor 
+                                processorRelatedness[idx] = numOfPhysicalProcessors + 1;
+                            }
+                        }
+                        if ( found )
+                          numOfPhysicalProcessors++;
+                    }
+                }
+            }
+        }
+        FreeLibrary(hKernel32);
+    }
+    if ( 0 == numOfPhysicalProcessors ) 
+    {   // We could not determine any physical processor information. 
+        OSVERSIONINFOEX  VerInfo;
+
+        memset ( &VerInfo, 0, sizeof(VerInfo) );
+        VerInfo.dwOSVersionInfoSize = sizeof(VerInfo);
+        VerInfo.wProductType        = VER_NT_WORKSTATION;
+
+        GetVersionEx ((LPOSVERSIONINFO)&VerInfo );
+
+        if ( VerInfo.wProductType == VER_NT_WORKSTATION )
+        {
+            numOfPhysicalProcessors = 1;  // there is only one physical processor
+            processor = 0;
+        }
+        else
+        {
+            numOfPhysicalProcessors = 0;
+            processor = 1;
+        }
+
+        for( idx = 0; idx < numOfLogicalProcessors; idx++ )
+        {
+            numOfPhysicalProcessors += processor;
+
+            if ( processAffinityMask & ((SAPDB_UInt8)1) << idx ) 
+                processorRelatedness[idx] = numOfPhysicalProcessors;
+        }
+    }
+
+    return numOfPhysicalProcessors;
+}
+
+/*-----------------*/
+
+static SAPDB_UInt4 getNumOfPhysicalProcessors()
+{
+    static SAPDB_UInt4  numOfPhysicalProcessors = 0;
+
+    if ( 0 == numOfPhysicalProcessors )
+    {
+        SAPDB_UInt4  processorRelatedness[MAX_PROCESSORS];
+        numOfPhysicalProcessors = RTESys_GetPhysicalProcessorInfomation(  processorRelatedness, MAX_PROCESSORS, false );
+    }
+
+    return numOfPhysicalProcessors;
+}
+
+
+/*-----------------*/
+
+static SAPDB_UInt4 getNumOfLogicalProcessors()
+{
+    return (SAPDB_UInt4)getSystemInfo()->dwNumberOfProcessors;
+}
+
+/*-----------------*/
+
 static SYSTEM_INFO *getSystemInfo()
 {
     static SYSTEM_INFO   systemInfo;
@@ -1479,6 +1695,167 @@ static SYSTEM_INFO *getSystemInfo()
 
 #endif
 
+#if defined(LINUX)
+
+#define SIZEOFBUFFER 128
+
+static SAPDB_UInt4 RTESys_GetPhysicalProcessorInfomation( SAPDB_UInt4* processorRelatedness,
+                                                          SAPDB_UInt4  const arraySize )
+{
+    SAPDB_Int fdCpuInfo;
+    SAPDB_Char Buffer[SIZEOFBUFFER];
+    SAPDB_UInt4 NumberOfLogicalProcessors;
+	SAPDB_UInt4 NumberOfPhysicalProcessors;
+	SAPDB_Int Index;
+	SAPDB_Int HasLogicalProcessors;
+
+	NumberOfLogicalProcessors = ( SAPDB_UInt4 ) sysconf( _SC_NPROCESSORS_ONLN );
+	HasLogicalProcessors = 0;
+	
+    //  processorRelatedness array to small?
+    if ( NumberOfLogicalProcessors > arraySize )
+        return 0;
+
+    memset( processorRelatedness, 0, sizeof( SAPDB_UInt4 ) * arraySize );
+
+    fdCpuInfo = open( "/proc/cpuinfo", O_RDONLY );
+    if( fdCpuInfo >=0 )
+	{
+        memset( Buffer, 0, SIZEOFBUFFER );
+        for( ;; )
+		{
+            SAPDB_Int got;
+            SAPDB_Int want;
+            SAPDB_Int offset;
+            SAPDB_Char *ptr;
+            SAPDB_Char *next;
+            SAPDB_Char *key;
+            SAPDB_Char *value;
+
+            offset = strlen( Buffer );
+
+            /* skip oversized line */
+            if( offset >= SIZEOFBUFFER - 1 )
+                offset = 0;
+
+            want = SIZEOFBUFFER - offset - 1;
+            got = read( fdCpuInfo, Buffer + offset, want );
+            if( got < 0 )
+            {
+			    memset( processorRelatedness, 0, sizeof( SAPDB_UInt4 ) * arraySize );
+                break;
+            }
+
+            if( got == 0 )
+                break;
+
+            for( ;; )
+			{
+                key = 0;
+                value = 0;
+
+				next = strchr( Buffer, '\n' );
+                if( !next )
+                    break;
+
+                *next++ = '\0';
+
+                key = Buffer;
+                value = strchr( Buffer, ':' );
+                if( value )
+                {
+                    *value++ = '\0';
+
+                    while( *key && *key <= ' ' )
+                        key++;
+
+                    for( ;; )
+                    {
+                        ptr = key + strlen( key ) - 1;
+                        if( ptr <= key || *ptr > ' ' )
+                            break;
+
+                        *ptr = '\0';
+                    }
+
+                    while( *value && *value <= ' ' )
+                        value++;
+
+                    for( ;; )
+                    {
+                        ptr = value + strlen( value ) - 1;
+                        if( ptr <= value || *ptr > ' ' )
+                            break;
+
+                         *ptr = '\0';
+                    }
+                }
+
+                if( key && value )
+                {
+                    if( strcmp( key, "processor" ) == 0 )
+					{
+						Index = strtol( value, 0, 10 );
+					}
+					else if( strcmp( key, "physical id" ) == 0  && Index < NumberOfLogicalProcessors )
+					{
+						processorRelatedness[Index] = strtol( value, 0, 10 );
+						HasLogicalProcessors++;
+					}
+				}
+
+                memcpy( Buffer, next, strlen( next ) + 1 );
+            }
+
+        }
+
+        close( fdCpuInfo );
+	}
+
+	if( HasLogicalProcessors )
+	{
+		/* find any physical id */
+		NumberOfPhysicalProcessors = 1;
+		for( Index = 0; Index < NumberOfLogicalProcessors; Index++ )
+		{
+			SAPDB_Int SubIndex;
+			SAPDB_Int PhysicalId;
+			if( processorRelatedness[Index] )
+			{
+				/* remove all processors with current physical id */
+				PhysicalId = processorRelatedness[Index];
+				for( SubIndex = Index; SubIndex < NumberOfLogicalProcessors; SubIndex++ )
+				{
+					if( processorRelatedness[SubIndex] == PhysicalId )
+						processorRelatedness[SubIndex] = 0;
+				}
+
+				NumberOfPhysicalProcessors++;
+			}
+		}
+	}
+	else
+	{
+		NumberOfPhysicalProcessors = NumberOfLogicalProcessors;
+	}
+
+	return NumberOfPhysicalProcessors;
+}
+
+static SAPDB_UInt4 getNumOfPhysicalProcessors()
+{
+    static SAPDB_UInt4 numOfPhysicalProcessors = 0;
+
+    if ( 0 == numOfPhysicalProcessors )
+    {
+        SAPDB_UInt4 processorRelatedness[4096];
+        numOfPhysicalProcessors = RTESys_GetPhysicalProcessorInfomation( processorRelatedness, 4096 );
+    }
+
+    return numOfPhysicalProcessors;
+}
+
+#endif
 
 /*===========================================================================*
  *  END OF CODE                                                              *
