@@ -65,6 +65,16 @@
  */
 externC SAPDB_UInt4 RTESys_NumberOfCPU();
 
+/*!
+  @brief Return the number of physical CPUs on the machine
+
+  This call returns the number of physical CPUs available on the machine. This might differ to
+  the number of logical CPUs returned by RTESys_NumberOfCPU() e.g. on Intel Hyperthreading Plattforms.
+
+  @return Number of phsyical CPUs avaliable in the machine
+ */
+externC SAPDB_UInt4 RTESys_NumberOfPhysicalCPUs();
+
 /*
   Function: RTESys_SystemPageSize
   Description: Return the number of bytes in a memory page on the system
@@ -158,4 +168,37 @@ externC void RTESys_GetProcessTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *second
  */
 externC void RTESys_GetMachineTimes(SAPDB_UInt8 *secondsUser,SAPDB_UInt8 *secondsSystem,SAPDB_UInt8 *secondsIdle);
 
+#if defined(WIN32)
+/*! define */
+# define MAX_PROCESSORS  (sizeof(DWORD_PTR)*8)
+/*!
+   @brief Get physical processor information
+ 
+   The Function retrieves information about the relationship between logical 
+   processors in the system. If the function succeeds, the return value is 
+   nonzero and the processor relatedness array has been filled. The size of the 
+   array must be at least MAX_PROCESSORS. Each array element is representing a
+   logical processor which corresponds to the same position of the process 
+   affinity mask. Logical processors belonging to the same processor core
+   have the array element content. 
+   The functions return value is equal to the number of processor cores 
+   (pysical processors) configured into the system. If the parameter 
+   'affinitMaskDependent' is true, the return value represents the number of 
+   processor cores the process is allowed to run on. Additionally the array
+   values of the corresponding logical processors where the process is not
+   allowed to run on is set to zero.
+
+   @param processorRelatedness [out] array to fill
+   @param arraySize [in] array size
+   @param affinitMaskDependent [in] 
+   @return Number of physical processors of the system or the number of physical processor 
+                the process is allowed to run on.
+ */
+
+externC SAPDB_UInt4 RTESys_GetPhysicalProcessorInfomation(  SAPDB_UInt4*       processorRelatedness,
+                                                            SAPDB_UInt4  const arraySize,
+                                                            SAPDB_Bool   const affinitMaskDependent );
+
+
+#endif  /* WIN32 */
 #endif  /* RTESYS_SYSTEMINFO_H */
