@@ -377,7 +377,7 @@ static void ConsoleMain ( void )
 #if defined (_WIN32) 
     RTE_KGS::Instance().GetKGS()->Console.ThrdCtrlHeader.ulStartTime = kgs.ulCurrTime;
 #else
-	RTE_KGS::Instance().GetKGS()->console.start_time = time ((time_t *) 0);
+	RTE_KGS::Instance().GetKGS()->console.start_time = KGS->current_time;
 #endif
 
     for (;;)
