@@ -35,6 +35,8 @@
 
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_IAllocatorInfo.hpp"
 
+class SAPDBErr_MessageList;
+
 /*!
    @interface      SAPDBMem_IBlockAllocator
    @brief          Allocator interface for aligned blocks of memory of
@@ -60,8 +62,6 @@
      copy constructor and the assignment operator is inaccessible.
 
  */
-
-
 class SAPDBMem_IBlockAllocator : public SAPDBMem_IAllocatorInfo
 {
 public:
@@ -119,6 +119,29 @@ public:
 
    virtual void* Allocate(SAPDB_ULong BlockCount) = 0;
 
+  /*! 
+    Function: Allocate
+
+    Description: Allocates contiguous memory for 'count' blocks of memory.
+
+      An implementation grants that a pointer returned will be an
+      integral multiple of the system page size.
+
+      The memory is not initialised.  
+
+      If compiled with -DSAPDB_COMPILE_WITHOUT_EXCEPTION_HANDLING a (void *)0 is returned on failure.
+
+      If compiled without this switch an SAPDBMem_BadAllocException exception is thrown on failure.
+
+    Arguments: BlockCount [ in ] Number of blocks (NOT bytes!) to allocate.
+               messageList [out] filled if memory not available    
+    Return value: pointer to the block allocated
+   */
+  virtual void * Allocate(SAPDB_ULong BlockCount, SAPDBErr_MessageList &messageList)
+  {
+      return Allocate(BlockCount);
+  }
+
    /*!
       @brief          Frees the memory.
                       None of the objects in the memory block will be deinitialised
