@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -302,8 +303,14 @@ public:
      @see   SAPDBMem_IRawAllocator::Allocate
    */
 
-  virtual void* Allocate(SAPDB_ULong ByteCount, const void* Hint)
-  { return Allocate(ByteCount); }
+  virtual void* Allocate(SAPDB_ULong ByteCount, const void* Hint);
+
+  /*!
+     @brief allocates ByteCount bytes from allocator
+     @see   SAPDBMem_IRawAllocator::AllocateThrowNothing
+   */
+
+  virtual void* AllocateThrowsNothing(SAPDB_ULong ByteCount);
 
   /*!
      @brief checks allocator integrity
@@ -409,6 +416,13 @@ public:
   
   virtual int GetErrorCount() const;
 
+   /*!
+      @brief          Returns the number of failed allocation attemps
+                      The derived class is responsible to implement this feature (but must not do so...)
+      @return         integer
+    */
+  virtual SAPDB_ULong GetAllocFailedCount() const { return m_failedAllocCount; }
+
   /*!
      @brief          returns the minimal size of the first chunk allocated from the underlying allocator
      @return         size in Bytes
@@ -673,6 +687,7 @@ private:
   };
 
   INLINE static ChunkSize AlignedSize (ChunkSize req);                               //!< returns the aligned size of a given size
+  INLINE void*            AllocateImplementation(SAPDB_ULong ByteCount, bool CallBadAllocHandler); //!< implementation of a memory allocation
   INLINE void*            AllocateResult(CChunk* pChunk, int monitorCallStackLevel); //!< returns the result of an Allocate call
          bool             AnalyzeAllocator(void* p);                                 //!< checks the consistence of the allocator
   INLINE void             Assert(bool condtion);                                     //!< asserts a condition
@@ -743,6 +758,7 @@ private:
   bool                        m_doUnregister;            //!< true, if allocator has to be unregistered at destruction
   int                         m_monitorCallStackLevel;   //!< depth of back trace
   int                         m_errorCount;              //!< numbers of error detected
+  SAPDB_ULong                 m_failedAllocCount;        //!< number of failed allocation attempts
   CFreeChunkLists             m_freeLists;               //!< free lists of small chunks
   BadAllocFunc*               m_badAllocFunc;            //!< current bad alloc handler
   RTESync_Spinlock*           m_lock;                    //!< synchronisation object, may be NULL
