@@ -121,6 +121,12 @@
 
 /*--------End of registry path definition (WINDOWS only) --------------*/
 
+/*! the name of the kernel mini dump file */
+#  define SAPDB_KNL_MINI_DUMP             "KnlMini.dmp"
+
+/*! the name of the serv mini dump file */
+#  define SAPDB_SRV_MINI_DUMP             "SrvMini.dmp"
+
 #endif /* WIN32 */
 
 /*! the name of the key in the globals section for the independend data path key */
