@@ -52,7 +52,8 @@
 #include <stdio.h>
 #include <string.h>
 #include "SAPDBCommon/SAPDB_ToString.hpp"
-#include "RunTime/MemoryManagement/RTEMem_Allocator.hpp"
+#include "SAPDBCommon/MemoryManagement/SAPDBMem_IRawAllocator.hpp"
+#include "RunTime/RTE_IInterface.hpp"
 #include "hsp77.h" /* sp77sprintf */
 
 /*===========================================================================*
@@ -85,7 +86,7 @@ SAPDB_ToStringClass::~SAPDB_ToStringClass()
 {
     if ( 0 != m_Buf )
     {
-        RTEMem_Allocator::Instance().Deallocate(m_Buf);
+        RTE_IInterface::Instance().Allocator().Deallocate(m_Buf);
     }
 }
 
@@ -115,10 +116,13 @@ void SAPDB_ToStringClass::FillStringFormatBuffer( const char       *String ,
       StringLen = (int)strlen ( String ) ;
   }
 
-  if ( Precision == 0 && Width <= StringLen )
+  if ( Precision == 0 
+    && Width <= StringLen 
+    && StringLen <= MAX_CHARACTER_ALLOWED_IN_PRESENTATION )
   {
-    m_OutputString = String ;
-    m_Buf          = 0;
+      strcpy(&m_PresentationBuffer[0], String);
+      m_OutputString = &m_PresentationBuffer[0];
+      m_Buf          = 0;
   }
   else
   {
@@ -152,7 +156,7 @@ void SAPDB_ToStringClass::FillStringFormatBuffer( const char       *String ,
 
     if ( OutputLen > MAX_CHARACTER_ALLOWED_IN_PRESENTATION )
     {
-        m_Buf = (char *)RTEMem_Allocator::Instance().Allocate(OutputLen + 1);
+        m_Buf = (char *)RTE_IInterface::Instance().Allocator().Allocate(OutputLen + 1);
 
         if ( 0 != m_Buf )
         {
@@ -917,7 +921,7 @@ SAPDB_ToStringClass::SAPDB_ToStringClass( const void *Addr,
 
 SAPDB_Int4 const SAPDB_ToStringClass::Length() const
 {
-    return (SAPDB_Int4 const)strlen(const_cast<char *>(m_OutputString));
+    return (SAPDB_Int4)strlen(const_cast<char *>(m_OutputString));
 }
 /*===========================================================================*
  *  PUBLIC FUNCTIONS (CODE)                                                  *
