@@ -96,7 +96,9 @@
 @li _T_p pointer as hexadecimal number uppercase with prefix '0X'
 @li _T_d decimal number
 @li _T_h hexadecimal number using lowercase for a-f without prefix '0x' 
+@li _T_H hexadecimal number using uppercase for A-F without prefix '0x' 
 @li _T_x hexadecimal number using lowercase for a-f with prefix '0x' 
+@li _T_X hexadecimal number using uppercase for A-F with prefix '0x' 
 @li _T_o octal number with prefix '0'
 @li _T_e real value in scientific format, exponent 'e' lowercase
 @li _T_f real value in fixed format
@@ -116,7 +118,9 @@
 #define _T_b SAPDB_ToStringClass::boolalpha //!< bool as text
 #define _T_d SAPDB_ToStringClass::dec //!< decimal number
 #define _T_h SAPDB_ToStringClass::hex //!< hexadecimal number without base
+#define _T_H SAPDB_ToStringClass::hex,SAPDB_ToStringClass::uppercase //!< hexadecimal number without base
 #define _T_x SAPDB_ToStringClass::hex,SAPDB_ToStringClass::showbase  //!< hexadecimal number with base
+#define _T_X SAPDB_ToStringClass::hex,SAPDB_ToStringClass::uppercase,SAPDB_ToStringClass::showbase  //!< hexadecimal number with base
 #define _T_o SAPDB_ToStringClass::oct,SAPDB_ToStringClass::showbase  //!< octal number
 #define _T_e SAPDB_ToStringClass::scientific  //!< scientific notation
 #define _T_f SAPDB_ToStringClass::fixed  //!< fixed number
@@ -133,10 +137,10 @@
 class SAPDB_ToStringClass
 {
 private:
-    char m_FormatBuffer[MAX_CHARACTER_ALLOWED_IN_FORMAT+1]; //!< internal only used buffer for format string
-    char m_PresentationBuffer[MAX_CHARACTER_ALLOWED_IN_PRESENTATION+1]; //!< internal only used buffer for value representation
-    const char *m_OutputString ; //!< pointer to actually used output string
-          char *m_Buf          ; //!< pointer to actually used buffer
+    SAPDB_Char m_FormatBuffer[MAX_CHARACTER_ALLOWED_IN_FORMAT+1]; //!< internal only used buffer for format string
+    SAPDB_Char m_PresentationBuffer[MAX_CHARACTER_ALLOWED_IN_PRESENTATION+1]; //!< internal only used buffer for value representation
+    const SAPDB_Char *m_OutputString ; //!< pointer to actually used output string
+          SAPDB_Char *m_Buf          ; //!< pointer to actually used buffer
 
 public:
     //!< formatting flags (names almost identical with C++ standard stream buffer formatting flags)
@@ -168,8 +172,38 @@ public:
 
     @param String [in] the string
     */
-    explicit SAPDB_ToStringClass(const char *String)
-    { m_Buf = 0; m_OutputString = String ; } ;
+    explicit SAPDB_ToStringClass(const SAPDB_Char *String)
+    { m_Buf = 0; m_OutputString = String ; }
+
+    /*!
+    @brief ctor for simple string
+
+    No conversion needed
+
+    @param String [in] the string
+    */
+    explicit SAPDB_ToStringClass(SAPDB_Char *String)
+    { FillStringFormatBuffer( (const SAPDB_Char *)String, 0, 0, noformat ); }
+
+    /*!
+    @brief ctor for simple string
+
+    No conversion needed
+
+    @param String [in] the string
+    */
+    explicit SAPDB_ToStringClass(const SAPDB_UTF8 *String)
+    { m_Buf = 0; m_OutputString = (const SAPDB_Char *)String ; }
+
+    /*!
+    @brief ctor for simple string
+
+    No conversion needed
+
+    @param String [in] the string
+    */
+    explicit SAPDB_ToStringClass(SAPDB_UTF8 *String)
+    { FillStringFormatBuffer( (const SAPDB_Char *)String, 0, 0, noformat ); }
 
     /*!-------------------------------------------------------------------------
     @brief ctor for simple string with format flags
@@ -179,8 +213,41 @@ public:
     @param String [in] the string
     @param fmtflags [in] ignored
     */
-    SAPDB_ToStringClass(const char *String, const fmtflags )
-    { m_Buf = 0; m_OutputString = String ; } ;
+    SAPDB_ToStringClass(const SAPDB_Char *String, const fmtflags )
+    { m_Buf = 0; m_OutputString = String ; }
+
+    /*!-------------------------------------------------------------------------
+    @brief ctor for simple string with format flags
+
+    No conversion needed
+
+    @param String [in] the string
+    @param fmtflags [in] ignored
+    */
+    SAPDB_ToStringClass(SAPDB_Char *String, const fmtflags )
+    { FillStringFormatBuffer( (const SAPDB_Char *)String, 0, 0, noformat ); }
+
+    /*!-------------------------------------------------------------------------
+    @brief ctor for simple string with format flags
+
+    No conversion needed
+
+    @param String [in] the string
+    @param fmtflags [in] ignored
+    */
+    SAPDB_ToStringClass(const SAPDB_UTF8 *String, const fmtflags )
+    { m_Buf = 0; m_OutputString = (const SAPDB_Char *)String ; }
+
+    /*!-------------------------------------------------------------------------
+    @brief ctor for simple string with format flags
+
+    No conversion needed
+
+    @param String [in] the string
+    @param fmtflags [in] ignored
+    */
+    SAPDB_ToStringClass(SAPDB_UTF8 *String, const fmtflags )
+    { FillStringFormatBuffer( (const SAPDB_Char *)String, 0, 0, noformat ); }
 
     /*!-------------------------------------------------------------------------
     @brief ctor for simple string with format flags and width specification
@@ -193,7 +260,7 @@ public:
     @param Flag1 [in] first format flag
     @param Flag2 [in] second format flag
     */
-    SAPDB_ToStringClass( const char *String,
+    SAPDB_ToStringClass( const SAPDB_Char *String,
                          const SAPDB_UInt2 Width,
                          const fmtflags Flag1=noformat,
                          const fmtflags Flag2=noformat);
@@ -210,7 +277,7 @@ public:
     @param Flag1 [in] first format flag
     @param Flag2 [in] second format flag
     */
-    SAPDB_ToStringClass( const char *String,
+    SAPDB_ToStringClass( const SAPDB_Char *String,
                         const SAPDB_UInt2 Width,
                         const SAPDB_UInt2 Precision,
                         const fmtflags Flag1=noformat,
@@ -1027,16 +1094,16 @@ public:
     ~SAPDB_ToStringClass();
 
     /*!-------------------------------------------------------------------------
-    @brief cast operator (char *)
+    @brief cast operator (SAPDB_Char *)
     @return pointer to output string
     */
-    operator       char * () { return ( const_cast<char *>(m_OutputString) ) ; }
+    operator       SAPDB_Char * () { return ( const_cast<SAPDB_Char *>(m_OutputString) ) ; }
 
     /*!-------------------------------------------------------------------------
-    @brief cast operator (const char *)
+    @brief cast operator (const SAPDB_Char *)
     @return pointer to output string
     */
-    operator const char * () { return ( m_OutputString ) ; }
+    operator const SAPDB_Char * () { return ( m_OutputString ) ; }
 
     /*!-------------------------------------------------------------------------
     @brief return length of output string
@@ -1064,7 +1131,7 @@ private:
                                      const int         Flags,
                                      const bool        QuadWord=false );
 
-    void FillStringFormatBuffer( const char       *String,
+    void FillStringFormatBuffer( const SAPDB_Char       *String,
                                  const SAPDB_UInt2 Width,
                                  const SAPDB_UInt2 Precision,
                                  const int         Flags=noformat );
@@ -1079,20 +1146,20 @@ private:
   @brief Simple String
  */
 inline SAPDB_ToStringClass
-SAPDB_ToString( const char *String) { return SAPDB_ToStringClass(String); }
+SAPDB_ToString( const SAPDB_Char *String) { return SAPDB_ToStringClass(String); }
 
 /*!
   @brief Simple String with format flags
  */
 inline SAPDB_ToStringClass 
-SAPDB_ToString( const char *String,
+SAPDB_ToString( const SAPDB_Char *String,
                 const SAPDB_ToStringClass::fmtflags fmtflags) { return SAPDB_ToStringClass(String, fmtflags); }
 
 /*!
   @brief Simple String with width specification and format flags
  */
 inline SAPDB_ToStringClass 
-SAPDB_ToString( const char *String,
+SAPDB_ToString( const SAPDB_Char *String,
                 const SAPDB_UInt2 Width,
                 const SAPDB_ToStringClass::fmtflags Flag1=SAPDB_ToStringClass::noformat,
                 const SAPDB_ToStringClass::fmtflags Flag2=SAPDB_ToStringClass::noformat) { return SAPDB_ToStringClass(String, Width, Flag1, Flag2); }
@@ -1101,7 +1168,7 @@ SAPDB_ToString( const char *String,
   @brief Simple String with width and precision specification and format flags
  */
 inline SAPDB_ToStringClass
-SAPDB_ToString( const char *String,
+SAPDB_ToString( const SAPDB_Char *String,
                 const SAPDB_UInt2 Width,
                 const SAPDB_UInt2 Precision,
                 const SAPDB_ToStringClass::fmtflags Flag1=SAPDB_ToStringClass::noformat,
