@@ -6,7 +6,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 */
 
@@ -2801,4 +2802,63 @@ SAPDB_OStream & operator<< (SAPDB_OStream &os, const tgg00_StackOpType &value)
     return os;
 }
 
+// tgg00_StackOpFunc
+SAPDB_OStream & operator<< (SAPDB_OStream &os, const tgg00_StackOpFunc &value)
+{
+    switch ( value )
+    {
+        case op_f_none :
+            os << "LASTFUNCTION";
+            break;
+        case op_f_all_count :
+            os << "ALL COUNT";
+            break;
+        case op_f_avg :
+            os << "AVG";
+            break;
+        case op_f_check_null :
+            os << "CHECK NULL";
+            break;
+        case op_f_count :
+            os << "COUNT";
+            break;
+        case op_f_count_kb :
+            os << "COUNT KB";
+            break;
+        case op_f_dis_avg :
+            os << "DIS AVG";
+            break;
+        case op_f_dis_count :
+            os << "DIS COUNT";
+            break;
+        case op_f_dis_sum :
+            os << "DIS SUM";
+            break;
+        case op_f_max :
+            os << "MAX";
+            break;
+        case op_f_min :
+            os << "MIN";
+            break;
+        case op_f_sum :
+            os << "SUM";
+            break;
+        case op_f_stddev :
+            os << "STDDEV";
+            break;
+        case op_f_dis_stddev :
+            os << "DIS STDDEV";
+            break;
+        case op_f_variance :
+            os << "VARIANCE";
+            break;
+        case op_f_dis_variance :
+            os << "DIS VARIANCE";
+            break;
+        default :
+            os << "?";
+    }
+    return os;
+}
+
 
