@@ -19,7 +19,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 
 *****************************************************************************/
@@ -59,7 +60,9 @@ SQLManErr_Instance::SQLManErrorObject SQLManErr_Instance::errors [] =
     {e_missing_return,false,sqlm_internal,-28903,"DBFunction $1 must return a value","missing_return"},
     {e_too_many_catch_levels,false,sqlm_internal,-28902,"Too many nested try/catch statements","too_many_catch_levels"},
     {e_case_not_found,false,sqlm_internal,-28901,"No case match found","case_not_found"},
+    {e_recreate_index_failed,false,sqlm_internal,-28836,"Recreation of index for OmsKeyedContainer failed","index_recreation_failed"},
     {e_key_still_visible,false,sqlm_internal,-28835,"Key of new object is still visible within consistent version","key_still_visible"},
+    {e_consview_cancelled,false,sqlm_internal,-28833,"Consistent view has been cancelled","consistentview_cancelled"}, /* PTS 1134029 FF */
     {e_container_dropped,false,sqlm_internal,-28832,"Tried to access already dropped container","container_dropped"},
     {e_wrong_obj_count,false,sqlm_internal,-28831,"Wrong page count (internal error)","wrong_obj_count"},
     {e_inconsistent_drop_info,false,sqlm_internal,-28828,"Inconsistent information concerning 'is container dropped'","inconsistent_drop_info"},
