@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -40,6 +40,7 @@
 
 
 
+
 *****************************************************************************/
 
 #include "hak06.h"
@@ -95,6 +96,57 @@ SQLMan_Context* SQLMan_Context::GetContext()
 
 /*----------------------------------------------------------------*/
 
+SQLMan_SessionInfo& SQLMan_Context::GetSessionInfo()
+{
+    return CppMembers().m_sessionInfo;
+}
+
+/*----------------------------------------------------------------*/
+
+SQLMan_ContextSessionMembers& SQLMan_Context::CppMembers()
+{
+    return *REINTERPRET_CAST(SQLMan_ContextSessionMembers*, a_cpp_session_members);
+}
+
+const SQLMan_ContextSessionMembers& SQLMan_Context::CppMembersConst() const
+{
+    return *REINTERPRET_CAST(const SQLMan_ContextSessionMembers*, a_cpp_session_members);
+}
+
+bool SQLMan_Context::IsStatementActive(SAPDB_Int statementId) const
+{
+    return CppMembersConst().m_activeStatementDirectory.IsActive(statementId);
+}
+
+SAPDB_Int4 SQLMan_Context::RegisterCurrentStatement()
+{
+    if (CppMembers().m_activeStatementDirectory.RegisterStatement(a_command_count))
+    {
+      return a_command_count;
+    }
+    else
+    {
+        return -1;
+    }
+}
+
+void SQLMan_Context::UnregisterStatement(SAPDB_Int4 statementId)
+{
+    CppMembers().m_activeStatementDirectory.UnregisterStatement(statementId);
+}
+
+void SQLMan_Context::ReleaseDDLLock()
+{
+    CppMembers().ReleaseDDLLock();
+}
+
+void SQLMan_Context::RequireDDLLock()
+{
+    CppMembers().RequireDDLLock();
+}
+
+/*----------------------------------------------------------------*/
+
 DBProc_Debugger* SQLMan_Context::GetDBProcDebugger() const
 {
     return  REINTERPRET_CAST(SQLMan_ContextSessionMembers*, a_cpp_session_members)->m_dbprocDebugger;
