@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -34,12 +35,14 @@
 #include "vak001.h" 
 #include "SQLManager/SQLMan_Types.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_RawAllocator.hpp"
-#include "SQLManager/SQLMan_ContextSessionMembers.hpp"
+// #include "SQLManager/SQLMan_ContextSessionMembers.hpp"
 
+class SQLMan_ContextSessionMembers;
 class DBProc_Debugger;
 class SharedSQL_SQLCache;
 class Catalog_ISessionCache;
 class SQLMan_MessBlock;
+class SQLMan_SessionInfo;
 class SysView_PseudoLongHandler;
 
 /*!
@@ -69,6 +72,10 @@ public :
       brief returns the current sql command identification
     */
     inline SAPDB_Int4 GetCurrentCommandId() const;
+   /*!
+      brief returns the session info object
+    */
+    SQLMan_SessionInfo& GetSessionInfo();
    /*!
       @brief initialises the c++ members of the context 
     */
@@ -120,7 +127,7 @@ public :
       @brief tells whether a given statement is still active, i.e. has been started but not yet finished
       @param statementId identification of the inquired statement
     */
-    inline bool IsStatementActive(SAPDB_Int statementId) const;
+    bool IsStatementActive(SAPDB_Int statementId) const;
    /*!
       @brief returns a reference to the context mess block
     */
@@ -158,20 +165,20 @@ public :
       @brief  registers the current statement in the active statement directory
       @return the statement identification of the current statement, -1 if the statement couldn't be registered due to lack of memory.
     */
-    inline SAPDB_Int4 RegisterCurrentStatement();
+    SAPDB_Int4 RegisterCurrentStatement();
     /*!
        @brief releases the shared DDL lock hold by the current context.
      */
-    inline void ReleaseDDLLock();
+    void ReleaseDDLLock();
     /*!
        @brief requires a shared DDL lock for the current context. This lock is managed
               by the catalog and is requested whenever a task parses again due to -8 or -9.
      */
-    inline void RequireDDLLock();
+    void RequireDDLLock();
     /*!
       @brief unregisters the given statement from the active statement directory
     */
-    inline void UnregisterStatement(SAPDB_Int4 statementId);
+    void UnregisterStatement(SAPDB_Int4 statementId);
     /*!
       @brief resets the current error code (a_returncode) to 0;
     */
@@ -255,19 +262,19 @@ public :
     */
     inline static SQLMan_Context& AcvToContext(tak_all_command_glob& acv);
 private :
-    inline SQLMan_ContextSessionMembers& CppMembers();                  //!< returns the c++ members of the context
-    inline const SQLMan_ContextSessionMembers& CppMembersConst() const; //!< returns the c++ members of the context
+    SQLMan_ContextSessionMembers& CppMembers();                  //!< returns the c++ members of the context
+    const SQLMan_ContextSessionMembers& CppMembersConst() const; //!< returns the c++ members of the context
 };
 
-inline SQLMan_ContextSessionMembers& SQLMan_Context::CppMembers()
-{
-    return *REINTERPRET_CAST(SQLMan_ContextSessionMembers*, a_cpp_session_members);
-}
-
-inline const SQLMan_ContextSessionMembers& SQLMan_Context::CppMembersConst() const
-{
-    return *REINTERPRET_CAST(const SQLMan_ContextSessionMembers*, a_cpp_session_members);
-}
+//inline SQLMan_ContextSessionMembers& SQLMan_Context::CppMembers()
+//{
+//    return *REINTERPRET_CAST(SQLMan_ContextSessionMembers*, a_cpp_session_members);
+//}
+//
+//inline const SQLMan_ContextSessionMembers& SQLMan_Context::CppMembersConst() const
+//{
+//    return *REINTERPRET_CAST(const SQLMan_ContextSessionMembers*, a_cpp_session_members);
+//}
 
 inline tsp00_SwapKind_Param SQLMan_Context::ClientSwap() const
 {
@@ -289,10 +296,10 @@ inline SAPDBMem_RawAllocator& SQLMan_Context::GetAllocator() const
     return *REINTERPRET_CAST(SAPDBMem_RawAllocator*, a_transinf.tri_trans.trAllocator_gg00);
 }
 
-inline bool SQLMan_Context::IsStatementActive(SAPDB_Int statementId) const
-{
-    return CppMembersConst().m_activeStatementDirectory.IsActive(statementId);
-}
+//inline bool SQLMan_Context::IsStatementActive(SAPDB_Int statementId) const
+//{
+//    return CppMembersConst().m_activeStatementDirectory.IsActive(statementId);
+//}
 
 inline SQLMan_MessBlock& SQLMan_Context::GetMessBlock() 
 {
@@ -325,27 +332,27 @@ inline SQLMan_Context& SQLMan_Context::AcvToContext(tak_all_command_glob& acv)
     return *REINTERPRET_CAST(SQLMan_Context*, &acv);
 }
 
-inline SAPDB_Int4 SQLMan_Context::RegisterCurrentStatement()
-{
-    if (CppMembers().m_activeStatementDirectory.RegisterStatement(a_command_count))
-    {
-      return a_command_count;
-    }
-    else
-    {
-        return -1;
-    }
-}
+//inline SAPDB_Int4 SQLMan_Context::RegisterCurrentStatement()
+//{
+//    if (CppMembers().m_activeStatementDirectory.RegisterStatement(a_command_count))
+//    {
+//      return a_command_count;
+//    }
+//    else
+//    {
+//        return -1;
+//    }
+//}
 
-inline void SQLMan_Context::ReleaseDDLLock()
-{
-    CppMembers().ReleaseDDLLock();
-}
-
-inline void SQLMan_Context::RequireDDLLock()
-{
-    CppMembers().RequireDDLLock();
-}
+//inline void SQLMan_Context::ReleaseDDLLock()
+//{
+//    CppMembers().ReleaseDDLLock();
+//}
+//
+//inline void SQLMan_Context::RequireDDLLock()
+//{
+//    CppMembers().RequireDDLLock();
+//}
 
 inline void SQLMan_Context::ResetReturnCode()
 {
@@ -389,9 +396,9 @@ inline SQLMan_TransContext& SQLMan_Context::TransContext()
     return a_transinf.tri_trans;
 }
 
-inline void SQLMan_Context::UnregisterStatement(SAPDB_Int4 statementId)
-{
-    CppMembers().m_activeStatementDirectory.UnregisterStatement(statementId);
-}
+//inline void SQLMan_Context::UnregisterStatement(SAPDB_Int4 statementId)
+//{
+//    CppMembers().m_activeStatementDirectory.UnregisterStatement(statementId);
+//}
 
 #endif
