@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -33,25 +34,26 @@
  *  INCLUDES                                                                 *
  *===========================================================================*/
 
-#include "SQLManager/SharedSQL/SharedSQL_ICommandCache.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_CommandCacheStatistics.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_CommandCacheIterator.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_Types.hpp"
 
 #include "SAPDBCommon/SAPDB_Singleton.hpp"
 #include "SAPDBCommon/SAPDB_Types.hpp"
+#include "SAPDBCommon/Algorithms/SAPDBAlgo_FNVHash.hpp"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_Assertions.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_IRawAllocator.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_SynchronizedRawAllocator.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Usage.hpp"
+#include "SAPDB/Container/Container_Vector.hpp"
 
 #include "RunTime/Synchronisation/RTESync_RWRegion.hpp"
-//#include "RunTime/Synchronisation/RTESync_NamedSpinlock.hpp"
+#include "RunTime/System/RTESys_AtomicOperation.hpp"
 
 #include "ggg00.h"
 
 class SharedSQL_CachedCommand;
-class SharedSQL_IPrepareHandle;
+class SharedSQL_PrepareHandle;
 
 /*===========================================================================*
  *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
@@ -66,8 +68,9 @@ enum SharedSQL_TempFileState { NoFile, FileError, FileOk };
 /*!
     @class          SharedSQL_CommandCache
     @brief          Shared cache to store SharedSQL_CachedCommand
+    @copydoc        SAPDBMem_IRawAllocator
  */
-class SharedSQL_CommandCache : public SAPDB_Singleton, public SharedSQL_ICommandCache
+class SharedSQL_CommandCache : public SAPDB_Singleton, public SAPDBMem_IRawAllocator
 {
 private:
     /*!
@@ -83,82 +86,90 @@ public:
     /*!
         @brief  Returns a pointer to the singleton instance of the command cache (may be null)
         @param  Create [in] - If 'Create' is TRUE the instance will be created if it does not exsists
-        @return SharedSQL_ICommandCache*
+        @return SharedSQL_CommandCache*
     */
-    static SharedSQL_ICommandCache* Instance( SAPDB_Bool Create );
+    static SharedSQL_CommandCache* Instance( SAPDB_Bool Create );
 
     /*!
         @brief      Destructor
     */
     ~SharedSQL_CommandCache( void );
 
-    // Methods derived from SAPDBMem_IRawAllocator
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
+    // Begin - Methods derived from SAPDBMem_IRawAllocator
     virtual void* Allocate( SAPDB_ULong ByteCount );
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
     virtual void* Allocate( SAPDB_ULong ByteCount, const void* Hint );
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
     virtual void  Deallocate( void* p );
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
     virtual SAPDBMem_RawAllocator* GetBaseAllocator( void );
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
     virtual void GetBaseAllocatorCallStatistics( SAPDB_ULong &CountAlloc, SAPDB_ULong &CountDealloc ) const;
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
     virtual void GetCallStatistics( SAPDB_ULong &CountAlloc, SAPDB_ULong &CountDealloc ) const;
-    /*!
-        @copydoc        SAPDBMem_IRawAllocator
-    */
-    virtual int  GetErrorCount( void ) const;
+    // End - Methods derived from SAPDBMem_IRawAllocator
 
-    // Methods derived from SharedSQL_ICommandCache
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Free as much memory as possible by destroying unnecessary elements
     */
-    virtual void CleanUpAll( void );
+    void CleanUpAll( void );
+    
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Invalidate all commands within the cache
     */
-    virtual void InvalidateAll( void );
+    virtual SAPDB_ULong  GetAllocFailedCount( void ) const;
+    void Invalidate( bool NotifyApplication );
+
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Invalidate commands that belong to the given schema within the cache
     */
-	virtual SharedSQL_IPrepareHandle*	NewPrepareHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_SQLContext& Context, SharedSQL_SQLStmt& Stmt, SAPDB_Bool Internal );
+	void Invalidate( SharedSQL_Schema Schema, bool NotifyApplication );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Invalidate commands that belong to tables within the cache
     */
-    virtual void DestroyPrepareHandle( SharedSQL_IPrepareHandle* PH );
+    void Invalidate( SharedSQL_TableTree* Tables, bool NotifyApplication );
+
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Get an interface to a SharedSQL_PrepareHandle for some SharedSQL_CachedCommand
+        @param  Alloc    [in]
+        @param  Context  [in]
+        @param  Stmt     [in]
+        @param  Internal [in]
+        @return SharedSQL_PrepareHandle*
     */
-	virtual SAPDB_Bool  ReloadSQLStmt( tgg00_TransContext& TransContext, SharedSQL_ICachedCommand* Command );
+	SharedSQL_PrepareHandle*	NewPrepareHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_SQLContext& Context, SharedSQL_SQLStmt& Stmt, SAPDB_Bool Internal, SAPDB_Bool ParseAgain );
+
+	/*!
+        @brief  Destroy the Handle created with NewPrepareHandle
+        @param  PH [in]
+    */
+    void DestroyPrepareHandle( SharedSQL_PrepareHandle* PH );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  ReloadSQLStmt
+        @param  TransContext [in]
+        @param  Command [in]
+        @return ...
     */
-	virtual SAPDB_Bool	DeleteUnloadedSQLStmt( tgg00_TransContext& TransContext, SharedSQL_ICachedCommand* Command );
+	SAPDB_Bool  ReloadSQLStmt( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command );
+	SAPDB_Bool  ReloadSQLStmtIntoBuffer( void* Buffer, SAPDB_UInt8 RequestSize, tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  DeleteUnloadedSQLStmt
+        @param  TransContext [in]
+        @param  Command [in]
+        @return ...
     */
-    virtual void LRUListMoveCommandToTop( SharedSQL_ICachedCommand* Command );
+	SAPDB_Bool	DeleteUnloadedSQLStmt( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  LRUListMoveCommandToTop
+        @param  Command [in]
     */
-    virtual SharedSQL_ICachedCommand* GetHashTableEntry(SharedSQL_HashValue i);
+    void LRUListMoveCommandToTop( SharedSQL_CachedCommand* Cmd, bool force );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  GetHashTableEntry
+        @param  i [in]
+        @return ...
     */
-    virtual void GetCacheInfo( SharedSQL_CommandCacheInfo& S )
+    inline SharedSQL_CachedCommand* GetHashTableEntry(SharedSQL_HashValue i);
+    /*!
+        @brief  Get information about the CommandCache
+        @param  S [out]
+    */
+    inline void GetCacheInfo( SharedSQL_CommandCacheInfo& S )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_CommandCache::GetStatistics", SharedSQL_Trace, 5);
         S   = mCacheInfo;
@@ -172,63 +183,59 @@ public:
         S.UsableSize    = BytesControlled/1024 + (BytesControlled%1024 ? 1 : 0);
     };
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Get information about the CommandCache (reset version)
+        @param  S [out]
     */
-    virtual void GetCacheInfoReset( SharedSQL_CommandCacheInfo& S )
+    inline void GetCacheInfoReset( SharedSQL_CommandCacheInfo& S )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_CommandCache::GetStatisticsReset", SharedSQL_Trace, 5);
 
         S = mCacheInfoReset;
     };
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Reset statistics information of the cache
     */
-    virtual void ResetCacheInfo( void )
+    inline void ResetCacheInfo( void )
     {
         SAPDBTRACE_METHOD_DEBUG ("SharedSQL_CommandCache::ResetStatistics", SharedSQL_Trace, 5);
         mCacheInfo += mCacheInfo;
         mCacheInfoReset = SharedSQL_CommandCacheInfo();
     };
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Reset statistics information of the commands stored in the cache
     */
-    virtual void ResetCommandInfos( void );
+    void ResetCommandInfos( void );
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Calculate the slot to store the command in
+        @param  Hash [in]
+        @return SharedSQL_HashValue
     */
-    virtual SharedSQL_HashValue CalcSlot( const SharedSQL_HashValue Hash )
+    inline SharedSQL_HashValue CalcSlot( const SharedSQL_HashValue Hash )
     {
         return Hash%mNumberOfSlots;
     }
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  Begin
+        @return SharedSQL_CommandCacheIterator
     */
-    virtual SharedSQL_CommandCacheIterator Begin();
+    SharedSQL_CommandCacheIterator Begin();
     /*!
-        @copydoc        SharedSQL_ICommandCache
+        @brief  End
+        @return SharedSQL_CommandCacheIterator
     */
-    virtual SharedSQL_CommandCacheIterator End();
-    /*!
-        @copydoc        SharedSQL_ICommandCache
-    */
-    virtual void NonExclusiveLockSlot(SharedSQL_HashValue i);
-    /*!
-        @copydoc        SharedSQL_ICommandCache
-    */
-    virtual void LeaveLockSlot(SharedSQL_HashValue i);
+    SharedSQL_CommandCacheIterator End();
 
-    /*!
-        @copydoc        SharedSQL_ICommandCache
-    */
-    virtual void IncAccessCountExecute( void );
-    /*!
-        @copydoc        SharedSQL_ICommandCache
-    */
-    virtual void IncSuccessfulAccessCountExecute( void );
-    /*!
-        @copydoc        SharedSQL_ICommandCache
-    */
-    virtual void IncUnSuccessfulAccessCountExecute( void );
+	void EnterLockForStatisticsIterator( void );
+	void LeaveLockForStatisticsIterator( void );
+
+    /// ...
+    inline void IncCountLRUListMoveToTop( void );
+    /// ...
+    inline void IncAccessCountExecute( void );
+    /// ...
+    inline void IncSuccessfulAccessCountExecute( void );
+    /// ...
+    inline void IncUnSuccessfulAccessCountExecute( void );
 
     /// ...
     friend class SharedSQL_CommandCacheIterator;
@@ -255,7 +262,7 @@ private:
         @param  FlgUnload    [in] - The statement string may be unloaded to a temporary file if'FlgUnload' is TRUE
         @return TRUE is the Command still exists, FALSE if the command was deleted 
     */
-    inline SAPDB_Bool CleanUpCommand( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command, SAPDB_Bool FlgUnload );
+    SAPDB_Bool CleanUpCommand( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command, SAPDB_Bool FlgUnload, SAPDB_UInt4 LRUPos );
 
     /*!
         @brief  Unloads the statement strinf of the given command to a temorary file
@@ -263,21 +270,21 @@ private:
         @param  Command      [in]
         @return TRUE if succesfull
     */
-	inline SAPDB_Bool UnloadSQLStmt( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command );
+	SAPDB_Bool UnloadSQLStmt( tgg00_TransContext& TransContext, SharedSQL_CachedCommand* Command );
 
     /*!
         @brief  Creates the temporary file if it does not exist
         @param  TransContext [in] - The transaction context; necessary to handle the temporary file
         @return TRUE if succesfull
     */
-    inline SAPDB_Bool CreateTempFile( tgg00_TransContext& TransContext );
+    SAPDB_Bool CreateTempFile( tgg00_TransContext& TransContext );
     
     /*!
         @brief  Returns the ID for the temporary file
         @param  TransContext [in] - The transaction context; necessary to handle the temporary file
         @param  FileID       [out]
     */
-    inline void GetTempFileID( tgg00_TransContext& TransContext, tgg00_FileId& FileID );
+    void GetTempFileID( tgg00_TransContext& TransContext, tgg00_FileId& FileID );
 	
     /*!
         @brief  Returns the LKey for the data to be inserted, read or deleted
@@ -286,7 +293,7 @@ private:
         @param  Key    [out]
         @param  KeyLen [out]
     */
-    inline void GetLKey(SharedSQL_CommandID ID, int PartNo, tgg00_Lkey& Key, int& KeyLen);
+    void GetLKey(SharedSQL_CommandID ID, int PartNo, tgg00_Lkey& Key, int& KeyLen);
 	
     /*!
         @brief  WriteSQLStmtToTempFile
@@ -295,7 +302,7 @@ private:
         @param  Stmt         [in]
         @return TRUE if succesfull
     */
-    inline SAPDB_Bool WriteSQLStmtToTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
+    SAPDB_Bool WriteSQLStmtToTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
 	
     /*!
         @brief  ReadSQLStmtFromTempFile
@@ -304,7 +311,8 @@ private:
         @param  Stmt         [in]
         @return TRUE if succesfull
     */
-    inline SAPDB_Bool ReadSQLStmtFromTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
+    SAPDB_Bool ReadSQLStmtFromTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
+    SAPDB_Bool ReadSQLStmtFromTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, void* Buffer, SAPDB_UInt8 RequestSize );
 	
     /*!
         @brief  DeleteSQLStmtFromTempFile
@@ -313,58 +321,52 @@ private:
         @param  Stmt         [in]
         @return TRUE if succesfull
     */
-    inline SAPDB_Bool DeleteSQLStmtFromTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
-
-
-    /*!
-        @brief  Deletes the plan for a given command
-        @param  Command [in]
-        @return TRUE if succesfull
-    */
-    inline SharedSQL_Error DeletePlan( SharedSQL_ICachedCommand* Command );
+    SAPDB_Bool DeleteSQLStmtFromTempFile( tgg00_TransContext& TransContext, SharedSQL_CommandID ID, SharedSQL_SQLStmt* Stmt );
 
     /*!
         @brief  Attach the given command to hash table and lru list. Command and lru list must be locked before the method is called.
         @param  Command [in]
     */
-    inline void AttachCommand( SharedSQL_CachedCommand* Command );
+//    void AttachCommand( SharedSQL_CachedCommand* Command );
+    void AttachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
 
     /*!
         @brief  Detach the given command from hash table and lru list. Command and lru list must be locked before the method is called.
         @param  Command [in]
     */
-    inline void DetachCommand( SharedSQL_CachedCommand* Command );
+//    void DetachCommand( SharedSQL_CachedCommand* Command );
+    void DetachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
 
     /*!
         @brief  Attach the given command to the hash table. Command must be locked before the method is called.
         @param  Command [in]
         @param  Slot    [in]
     */
-    inline void HashTableAttachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
+    void HashTableAttachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
 
     /*!
         @brief  Detach the given command from the hash table. Command must be locked before the method is called.
         @param  Command [in]
         @param  Slot    [in]
     */
-    inline void HashTableDetachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
+    void HashTableDetachCommand( SharedSQL_CachedCommand* Command, SharedSQL_HashValue Slot );
 
     /*!
-        @brief  Attach the given command to the lru list. Lru list must be locked before the method is called.
+        @brief  Attach the given command to the lru list. LRU list must be locked before the method is called.
         @param  Command [in]
     */
-	inline void LRUListAttachCommand( SharedSQL_CachedCommand* Command );
+	void LRUListAttachCommand( SharedSQL_CachedCommand* Command );
 	
     /*!
-        @brief  Detach the given command from the lru list. Lru list must be locked before the method is called.
+        @brief  Detach the given command from the lru list. LRU list must be locked before the method is called.
         @param  Command [in]
     */
-	inline void LRUListDetachCommand( SharedSQL_CachedCommand* Command );
+	void LRUListDetachCommand( SharedSQL_CachedCommand* Command );
 
     // ...
     SAPDBMem_SynchronizedRawAllocator   mAllocator;
     /// Pointer to the singleton instance if the SharedSQL_CommandCache
-    static SharedSQL_ICommandCache*     mInstance; 
+    static SharedSQL_CommandCache*      mInstance; 
     /// Flag to indicate if errors occured during initializing the cache instance
     SAPDB_Bool                          mErrorInitialising;
     /// Status of the temporary file. May be NoFile, FileError or FileOk)
@@ -376,7 +378,7 @@ private:
     SharedSQL_HashValue					mNumberOfSlots;
     /// Pointer to the hash table
 	SharedSQL_CachedCommand**	        mHashTable;
-    //
+	//
     /// Spinlock pool used by ReaderWriter Regions for the hash table
     RTESync_BaseSpinlockPool            mSpinLockPoolForSlots;
     /// Spinlock pool used by ReaderWriter Regions for the cached commands
@@ -386,13 +388,11 @@ private:
     /// ...
     RTESync_IRWRegion**                 mpSlotLocks;        
     /// ...
-    RTESync_IRWRegion*                  mpLRULock;          
-    /// ...
+    RTESync_IRWRegion*                  mpLRULock;    
+	/// ...
     RTESync_IRWRegion*                  mpCleanUpLock;     
     /// ...
     RTESync_IRWRegion*                  mpCreateFileLock;     
-    /// ...
-    RTESync_IRWRegion*                  mpStatisticsLock;     
     //
     /// Pointer to the first command within the lru list
 	SharedSQL_CachedCommand*	        mFirstLRUCommand;
@@ -408,7 +408,57 @@ private:
     SharedSQL_CommandCacheInfo	        mCacheInfoReset;
     /// ID of the temporary table
     tgg00_Surrogate                     mCacheTableId;
+    ///
+    static SAPDB_Bool                   mCreateError;
     //
 };  // SharedSQL_CommandCache
 
 #endif  /* SHAREDSQL_COMMANDCACHE_HPP */
+
+//----------------------------------------------------------------------------
+
+inline SharedSQL_CommandID SharedSQL_CommandCache::NewCommandID( void )
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_CommandCache::NewCommandID", SharedSQL_Trace, 8);
+    return RTESys_AtomicModify((SAPDB_UInt8&)mActCommandID, (SAPDB_Int8)1);
+}
+
+inline SharedSQL_HashValue	SharedSQL_CommandCache::CalcHashValue( const SharedSQL_SQLContext& Context, const SharedSQL_SQLStmt& Stmt )
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_CommandCache::CalcHashValue", SharedSQL_Trace, 8);
+    SAPDBERR_ASSERT_ARGUMENT( Stmt.mStmt != 0 && Stmt.mStmtSize > 0 );
+
+    SharedSQL_HashValue Hash = FNV_32_INIT;
+    FNV32Hash((void*)Stmt.mStmt, Stmt.mStmtSize, Hash); 
+	if ( Stmt.mDescriptionSize > 0 )
+		FNV32Hash((void*)Stmt.mDescription, Stmt.mDescriptionSize, Hash); 
+    FNV32Hash((void*)&Context.UserID, sizeof(Context.UserID), Hash);
+    return Hash;
+}
+
+inline void SharedSQL_CommandCache::IncCountLRUListMoveToTop( void )              
+{ 
+    ++mCacheInfoReset.LRUListMoveToTopCount; 
+}
+
+inline void SharedSQL_CommandCache::IncAccessCountExecute( void )              
+{ 
+    ++mCacheInfoReset.AccessCountExecute; 
+}
+
+inline void SharedSQL_CommandCache::IncSuccessfulAccessCountExecute( void )    
+{ 
+    ++mCacheInfoReset.SuccessfulAccessCountExecute; 
+}
+
+inline void SharedSQL_CommandCache::IncUnSuccessfulAccessCountExecute( void )  
+{ 
+    ++mCacheInfoReset.UnSuccessfulAccessCountExecute; 
+}
+
+inline SharedSQL_CachedCommand* SharedSQL_CommandCache::GetHashTableEntry(SharedSQL_HashValue i)
+{
+    return mHashTable[i];
+}
+
+//----------------------------------------------------------------------------
