@@ -7,7 +7,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -34,6 +35,7 @@
 #include "SQLManager/SharedSQL/SharedSQL_CommandCache.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_CommandCacheStatistics.hpp"
 #include "SQLManager/SharedSQL/SharedSQL_CommandCacheIterator.hpp"
+#include "SAPDB/SQLManager/SharedSQL/SharedSQL_Messages.hpp"
 
 #include "SAPDBCommon/SAPDB_Types.hpp"
 #include "SAPDBCommon/ErrorsAndMessages/SAPDBErr_Assertions.hpp"
@@ -62,21 +64,21 @@ SharedSQL_SQLCache::~SharedSQL_SQLCache( void )
 {
 }
 
-SharedSQL_IPrepareHandle* SharedSQL_SQLCache::NewPrepareHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_SQLContext& Context, SharedSQL_SQLStmt& Stmt, SAPDB_Bool Internal )
+SharedSQL_PrepareHandle* SharedSQL_SQLCache::NewPrepareHandle( SAPDBMem_IRawAllocator& Alloc, SharedSQL_SQLContext& Context, SharedSQL_SQLStmt& Stmt, SAPDB_Bool Internal, SAPDB_Bool ParseAgain )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetPrepareHandle", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
-        return CommandCache->NewPrepareHandle(Alloc, Context, Stmt, Internal);
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
+        return CommandCache->NewPrepareHandle(Alloc, Context, Stmt, Internal, ParseAgain);
     else
         return 0;
 }
 
-void SharedSQL_SQLCache::DestroyPrepareHandle( SharedSQL_IPrepareHandle* PH )
+void SharedSQL_SQLCache::DestroyPrepareHandle( SharedSQL_PrepareHandle* PH )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::DestroyPrepareHandle", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
       	CommandCache->DestroyPrepareHandle(PH);
     else
     {
@@ -85,21 +87,21 @@ void SharedSQL_SQLCache::DestroyPrepareHandle( SharedSQL_IPrepareHandle* PH )
     }
 }
 
-SharedSQL_IExecuteHandle* SharedSQL_SQLCache::NewExecuteHandle( SAPDBMem_IRawAllocator& Alloc, const SharedSQL_ParseID& PID, bool CountExecuting, SAPDB_Bool& Valid, SAPDB_Bool& M9 )
+SharedSQL_ExecuteHandle* SharedSQL_SQLCache::NewExecuteHandle( SAPDBMem_IRawAllocator& Alloc, const SharedSQL_ParseID& PID, bool CountExecuting, SAPDB_Bool& Valid, SAPDB_Bool& M9 )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetExecuteHandle", SharedSQL_Trace, 8);
 
 	return mParseIDCache.NewExecuteHandle(Alloc, PID, CountExecuting, Valid, M9);
 }
 
-void SharedSQL_SQLCache::DestroyExecuteHandle( SharedSQL_IExecuteHandle* EH  )
+void SharedSQL_SQLCache::DestroyExecuteHandle( SharedSQL_ExecuteHandle* EH  )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::DestroyExecuteHandle", SharedSQL_Trace, 8);
 
 	mParseIDCache.DestroyExecuteHandle(EH);
 }
 
-SAPDB_Bool SharedSQL_SQLCache::PutParseID( const SharedSQL_IPrepareHandle* PH, const SharedSQL_ParseID& PID, const SharedSQL_ModuleName& ModuleName, const SAPDB_Bool M9 )
+SAPDB_Bool SharedSQL_SQLCache::PutParseID( const SharedSQL_PrepareHandle* PH, const SharedSQL_ParseID& PID, const SharedSQL_ModuleName& ModuleName, const SAPDB_Bool M9 )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::PutParseID", SharedSQL_Trace, 8);
 
@@ -144,7 +146,7 @@ void SharedSQL_SQLCache::GetCommandCacheInfo( SharedSQL_CommandCacheInfo& S )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetCommandCacheInfo", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->GetCacheInfo(S);
     else
         S = SharedSQL_CommandCacheInfo();
@@ -154,7 +156,7 @@ void SharedSQL_SQLCache::GetCommandCacheInfoReset( SharedSQL_CommandCacheInfo& S
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetCommandCacheInfoReset", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->GetCacheInfoReset(S);
     else
         S = SharedSQL_CommandCacheInfo();
@@ -164,7 +166,7 @@ void SharedSQL_SQLCache::ResetCommandCacheInfo( void )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::ResetCommandCacheInfo", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->ResetCacheInfo();
 }
 
@@ -172,7 +174,7 @@ void SharedSQL_SQLCache::ResetCommandInfos( void )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::ResetCommandCacheInfo", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->ResetCommandInfos();
 }
 
@@ -180,18 +182,44 @@ SharedSQL_CommandCacheIterator SharedSQL_SQLCache::GetCommandCacheIterator( void
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetCommandCacheIterator", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         return CommandCache->Begin();
     else
         return SharedSQL_CommandCacheIterator();
 }
 
+void SharedSQL_SQLCache::EnterLockForStatisticsIterator( void )
+{
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	{
+		SAPDB_UInt2& N = mParseIDCache.LocksForCommandCacheIterator();
+		if ( !N )
+		{
+			++N;
+			CommandCache->EnterLockForStatisticsIterator();
+		}
+	}
+}
+
+void SharedSQL_SQLCache::LeaveLockForStatisticsIterator( void )
+{
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+	{
+		SAPDB_UInt2& N = mParseIDCache.LocksForCommandCacheIterator();
+		--N;
+		if ( !N )
+		{
+			CommandCache->LeaveLockForStatisticsIterator();
+		}
+	}
+}
+
 SAPDBMem_RawAllocator* SharedSQL_SQLCache::GetCommandCacheBaseRawAllocator( void )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetCommandCacheBaseRawAllocator", SharedSQL_Trace, 8);
 
 #ifdef SHAREDSQL_PROTECT
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
         return CommandCache->GetBaseAllocator();
     else
         return 0;
@@ -204,7 +232,7 @@ void* SharedSQL_SQLCache::Allocate(SAPDB_ULong ByteCount)
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Allocate", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
         return CommandCache->Allocate(ByteCount);
     else
         return 0;
@@ -214,7 +242,7 @@ void* SharedSQL_SQLCache::Allocate(SAPDB_ULong ByteCount, const void* Hint)
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Allocate", SharedSQL_Trace, 8);
 
-	if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
+	if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_TRUE))
         return CommandCache->Allocate(ByteCount, Hint);
     else
         return 0;
@@ -224,7 +252,7 @@ void SharedSQL_SQLCache::Deallocate(void* p)
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Deallocate", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->Deallocate(p);
     else
     {
@@ -237,23 +265,39 @@ void SharedSQL_SQLCache::CleanUpAll( void )
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::CleanUpAll", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->CleanUpAll();
 }
 
-void SharedSQL_SQLCache::InvalidateAll( void )
+void SharedSQL_SQLCache::Invalidate( bool NotifyApplication )
 {
-    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::InvalidateAll", SharedSQL_Trace, 8);
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Invalidate", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
-        CommandCache->InvalidateAll();
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+        CommandCache->Invalidate(NotifyApplication);
+}
+
+void SharedSQL_SQLCache::Invalidate( SharedSQL_Schema Schema, bool NotifyApplication )
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Invalidate", SharedSQL_Trace, 8);
+
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+        CommandCache->Invalidate(Schema, NotifyApplication);
+}
+
+void SharedSQL_SQLCache::Invalidate( SharedSQL_TableTree* Tables, bool NotifyApplication )
+{
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::Invalidate", SharedSQL_Trace, 8);
+
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+        CommandCache->Invalidate(Tables, NotifyApplication);
 }
 
 void SharedSQL_SQLCache::GetBaseAllocatorCallStatistics( SAPDB_ULong &CountAlloc, SAPDB_ULong &CountDealloc ) const
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetBaseAllocatorCallStatistics", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->GetBaseAllocatorCallStatistics(CountAlloc, CountDealloc);
     else
         CountAlloc = CountDealloc = 0L;
@@ -263,18 +307,18 @@ void SharedSQL_SQLCache::GetCallStatistics( SAPDB_ULong &CountAlloc, SAPDB_ULong
 {
     SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetCallStatistics", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
         CommandCache->GetCallStatistics(CountAlloc, CountDealloc);
     else
         CountAlloc = CountDealloc = 0L;
 }
 
-int SharedSQL_SQLCache::GetErrorCount( void ) const
+SAPDB_ULong SharedSQL_SQLCache::GetAllocFailedCount( void ) const
 {
-    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetErrorCount", SharedSQL_Trace, 8);
+    SAPDBTRACE_METHOD_DEBUG ("SharedSQL_SQLCache::GetAllocFailedCount", SharedSQL_Trace, 8);
 
-    if (SharedSQL_ICommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
-        return CommandCache->GetErrorCount();
+    if (SharedSQL_CommandCache* CommandCache = SharedSQL_CommandCache::Instance(SAPDB_FALSE))
+        return CommandCache->GetAllocFailedCount();
     else
         return 0;
 }
