@@ -15,7 +15,7 @@
 
 \if EMIT_LICENCE
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 \endif
 */
 
@@ -48,6 +49,7 @@
 
 //#include "SAPDBCommon/SAPDB_MemCopyMove.hpp"
 #include "SAPDBCommon/SAPDB_Types.hpp"
+#include "SQLManager/SQLMan_Types.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_IRawAllocator.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Topic.hpp"
@@ -55,6 +57,8 @@
 #include "RunTime/Synchronisation/RTESync_NamedSpinlock.hpp"
 #include "RunTime/Synchronisation/RTESync_RWRegion.hpp"
 
+#include "Container/Container_AVLTree.hpp"
+
 #include "vak001.h"
 
 /// Topic to Trace SharedSQL
@@ -73,8 +77,6 @@ if (SharedSQL_Trace.TracesLevel (3)) {\
 
 /// User ID
 typedef tgg00_Surrogate             SharedSQL_UserID;
-/// Schema ID
-typedef tgg00_Surrogate             SharedSQL_Schema;
 /// SQL Mode
 typedef tsp00_SqlMode_Enum          SharedSQL_SQLMode;
 /// CodeType
@@ -92,8 +94,85 @@ typedef tsp00_Int2                  SharedSQL_NLSParam_DFLength;
 typedef SAPDB_UInt8                 SharedSQL_CommandID;
 /// Hashvalue 
 typedef SAPDB_UInt4                 SharedSQL_HashValue;
-/// ...
-typedef SAPDB_Int2                  SharedSQL_Error;
+
+/*---------------------------------------------------------------------------*/
+
+typedef tgg00_Surrogate SharedSQL_Schema;
+
+//class SharedSQL_Schema : public tgg00_Surrogate
+//{
+//public:
+//    //----------------------------------------------------------------------------
+//    /*!
+//       @brief       default constructor
+//    */
+//    SharedSQL_Schema( void ) { memset(this, 0x00, sizeof(*this)); };
+//
+//    ////----------------------------------------------------------------------------
+//    ///*!
+//    //   @brief       operator ==
+//    //   @param       S [in]
+//    //   @return      bool
+//    //*/
+//    //bool operator==( const SharedSQL_Schema& S ) const
+//    //{
+//    //    return ( *this==S );
+//    //}
+//    ///*!
+//    //   @brief       operator !=
+//    //   @param       S [in]
+//    //   @return      bool
+//    //*/
+//    //bool operator!=( const SharedSQL_Schema& S ) const
+//    //{
+//    //    return ( *this!=S );
+//    //}//
+//};  // SharedSQL_Schema
+
+/*---------------------------------------------------------------------------*/
+
+class SharedSQL_Table
+{
+public:
+    SharedSQL_Table( void ) // default constuctor necessary for Container_Vector<>
+        : mSchema()
+        , mTable()
+    {
+    }
+
+    SharedSQL_Table( SharedSQL_Schema S, SQLMan_Identifier T )
+        : mSchema(S)
+        , mTable(T)
+    {
+    }
+
+    bool operator==( const SharedSQL_Table& T ) const
+    {
+        if ( mTable==T.mTable )
+        {
+            if ( (mSchema==T.mSchema) || (mSchema==SharedSQL_Schema()) ||(T.mSchema==SharedSQL_Schema()) )
+                return true;
+        }
+        return false;
+    }
+
+    static int Compare (const SharedSQL_Table& Left, const SharedSQL_Table& Right)
+    {
+        if (Left.mSchema < Right.mSchema) return -1; 
+        if (Left.mSchema > Right.mSchema) return 1;
+        if (Left.mTable < Right.mTable) return -1;
+        if (Left.mTable > Right.mTable) return 1;
+        return 0;
+    }
+
+    // 
+    SharedSQL_Schema        mSchema;
+    SQLMan_Identifier       mTable;
+};  // SharedSQL_Table
+
+typedef Container_AVLNode<SharedSQL_Table,SharedSQL_Table> SharedSQL_TableNode;
+
+typedef Container_AVLTree<SharedSQL_TableNode,SharedSQL_Table,SharedSQL_Table> SharedSQL_TableTree;
 
 /*---------------------------------------------------------------------------*/
 
