@@ -292,13 +292,11 @@ void SysView_PascalTableObj::MoveToCol ( SysView_ITOVarType iType,
 
 void SysView_PascalTableObj::MoveInt8 ( SAPDB_Int8 &val )
 {
-#ifdef BIT64
-    a40move_counter (m_Context, m_Show, static_cast<long>(val), !C_IS_UNDEF, 0, !C_ZERO_AS_UNDEF);
-#else
-    a40move_counter (m_Context, m_Show, static_cast<double>(val), !C_IS_UNDEF, 0, !C_ZERO_AS_UNDEF);
-#endif
+    a40move_counter (m_Context, m_Show, (tsp00_8ByteCounter) val, !C_IS_UNDEF, 0, !C_ZERO_AS_UNDEF);
 }
 
+/*---------------------------------------------------------------------------*/
+
 void SysView_PascalTableObj::MoveUTF8Ptr ( SAPDB_UTF8 *val, SAPDB_Int length )
 {
     SAPDBTRACE_METHOD_DEBUG ("SysView_PascalTableObj::MoveToCol (UTF8 *)", SysView_Trace, 5);
