@@ -177,6 +177,7 @@ private :
         tgg00_DateTimeFormat_Enum m_dtFormat;
         SAPDB_Int2                m_dfLength;
         char                      m_dateFormat[50];
+        SAPDB_Int4                m_TempPageUsageSize;
     };
 
     typedef Container_List<SessionsRow> SessionRowList;
@@ -223,6 +224,16 @@ void SysView_ResultCollector::Append (
         int kbFactor = PAGE_MXSP00 / 1024;
         row.m_catalogCacheSize = sessionIt.GetCatalogCacheSize() * kbFactor;
 
+        row.m_TempPageUsageSize = sessionIt.GetTempPageUsage();
+        if ( row.m_TempPageUsageSize > 0 )
+        {
+            row.m_TempPageUsageSize *= kbFactor;
+        }
+        else
+        {
+            row.m_TempPageUsageSize = -1;
+        }
+
         row.m_parsFileSize     = sessionIt.GetParseFileSize();
         if ( row.m_parsFileSize > 0 )
         {
@@ -331,8 +342,16 @@ void SysView_ResultCollector::Flush()
             m_sessionView.AddColumn();
             m_sessionView.m_Table->MoveToCol (ITOVT_YESNO, &iter->m_vtrace, 0);
             m_sessionView.AddColumn(iter->m_catalogCacheSize);
-            // temp page count can't be determined reliably -> set null value
-            m_sessionView.AddColumn();
+            
+            if (iter->m_TempPageUsageSize >= 0)
+            {
+                m_sessionView.AddColumn(iter->m_TempPageUsageSize);
+            }
+            else
+            {
+                m_sessionView.AddColumn();
+            }
+
             if (iter->m_parsFileSize >= 0)
             {
                 m_sessionView.AddColumn(iter->m_parsFileSize);
