@@ -48,12 +48,20 @@
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_RawAllocator.hpp"
 #include "SAPDBCommon/MemoryManagement/SAPDBMem_NewDestroy.hpp"
 #include "SAPDBCommon/Tracing/SAPDBTrace_Usage.hpp"
+#include "SAPDBCommon/SAPDB_MemCopyMove.hpp"
 
 #include "RunTime/Configuration/RTEConf_ParameterAccessKernelInterface.hpp"
 
 #include "Table/Table_Messages.hpp"
 #include "Table/Table_Exceptions.hpp"
 
+#include "vak001.h"
+#include "hak07.h"
+
+// #############################################################################
+
+extern SAPDBDiag_CheckTopic HashedResultSet_Check;
+
 // #############################################################################
 
 struct tgg00_TransContext;
@@ -68,7 +76,7 @@ typedef SAPDB_UInt4 TempHashTable_HashValue;
 class Table_TempHashTableAggregate_IDataMerger
 {
 public:
-    virtual void MergeData( const SAPDB_Byte* Source, SAPDB_Byte* Destination, SAPDB_UInt2 Length, SAPDB_Bool Found ) = 0;
+    virtual void MergeData( const SAPDB_Byte* Source, SAPDB_Byte* Destination, SAPDB_UInt2 Length, SAPDB_Bool Found, SAPDB_Bool SourceIsPartialAggregate ) = 0;
 };
 
 // #############################################################################
@@ -126,11 +134,13 @@ public:
 		, mFirstInsert(true)
         , mValid(false)
 	{
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempSingleRecordAggregate::CompletelyConstructed", Table_Trace, 2);
 		mRecord = (SAPDB_Byte*) mSessionAllocator.Allocate(RecordLength);
 	}
 
 	virtual ~Table_FixSizeTempSingleRecordAggregate( void )
 	{
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempSingleRecordAggregate::CompletelyConstructed", Table_Trace, 2);
 		if ( mRecord )
 			destroy(mRecord, mSessionAllocator);
 	}
@@ -146,7 +156,7 @@ public:
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempSingleRecordAggregate::InsertOrReplace", Table_Trace, 5);
         SAPDBERR_ASSERT_STATE( Data );
 
-	    mMerger.MergeData(Data, mRecord, mRecordLength, !mFirstInsert);
+	    mMerger.MergeData(Data, mRecord, mRecordLength, !mFirstInsert, /*SourceIsPartialAggregate*/false);
         mFirstInsert = false;
 		mValid = false;	// for Next()
 		return true;
@@ -263,20 +273,25 @@ public:
         , mSortTable(0)
         , mSortTableEntryCnt(0)
         , mActSortTableEntry(0)
-        , mActEntryCnt(0)
+        , mAllocatedEntryCnt(0)
+        , mUsedEntryCnt(0)
+        , mFetchedRecord(0)
         , mFirstFree(0)
         , mValid(false)
         , mFirstInsert(true)
+        , mFlushed(false)
     {
-        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::Table_FixSizeTempHashTableAggregate", Table_Trace, 8);
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::Table_FixSizeTempHashTableAggregate", Table_Trace, 2);
+
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         RTEConf_Parameter::Integer ParamSize=0;
         SAPDBErr_MessageList       errLst;
 
         RTEConf_ParameterAccess::Instance()->GetInteger( UTF8( KERNELPARAM_HASHEDRESULTSET_CACHESIZE ), ParamSize, errLst );
-        if ( ParamSize == 0 )
+        if ( ParamSize < 32*1024 )  // (Minimum according to cserv.pcf)
         {
-            ParamSize = 128*1024; // default 128MByte
+            ParamSize = 64*1024;    // set to 64MByte 
         }
         SAPDB_UInt4 kBSizeMax = (SAPDB_UInt4) ParamSize;
 
@@ -286,7 +301,11 @@ public:
         SAPDBERR_ASSERT_STATE( FieldDescription.GetSize() >= KeyNoList.GetSize()  );
 
         SAPDB_UInt4  SizePerEntry    = 2*sizeof(void*) + sizeof(TEntry)+RecordLength;  // assume optimal hashing ...
-        mMaxEntryCnt                 = 1024L*kBSizeMax / SizePerEntry;
+        mMaxEntryCnt                 = (1024L*kBSizeMax-RecordLength) / SizePerEntry;
+#if defined  (SAPDB_SLOW)
+        // for test cases
+        mMaxEntryCnt                 = 43;
+#endif
         mMaxEntryCnt                 = (SAPDBAlgo_MAX_QUICKSORT_ELEMENTS < mMaxEntryCnt ? 
                                         SAPDBAlgo_MAX_QUICKSORT_ELEMENTS : mMaxEntryCnt );
 
@@ -307,9 +326,14 @@ public:
                                                 kBSizeMax*1024             // MaxCacheSize
                                             );
 
+
+
         if ( mAllocator)
         {
             mAllocator->DisableOpMessages();
+    
+            if ( !(mFetchedRecord = (SAPDB_Byte*)mAllocator->Allocate(RecordLength)) )
+                ErrorList = Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOHASHTABLE);
 
             if ( mHashTable = newarray(mHashTable, mNumberOfSlots, *mAllocator) )
             {
@@ -332,16 +356,24 @@ public:
 
     virtual ~Table_FixSizeTempHashTableAggregate( void )
     {
-        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::~Table_FixSizeTempHashTableAggregate", Table_Trace, 8);
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::~Table_FixSizeTempHashTableAggregate", Table_Trace, 2);
+
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         DestroyHashTableAndAllocator();
 
         for ( SAPDB_UInt4 i=0; i<mTempFileContainer.GetSize(); i++ )
         {
             if ( mTempFileContainer[i].mIter != 0 )
+            {
+                mTransContext.trError_gg00 = 0;
                 destroy(mTempFileContainer[i].mIter, mSessionAllocator);
+            }
             if ( mTempFileContainer[i].mFile != 0 )
+            {
+                mTransContext.trError_gg00 = 0;
                 destroy(mTempFileContainer[i].mFile, mSessionAllocator);
+            }
         }
     }
 
@@ -356,22 +388,23 @@ public:
     virtual SAPDB_Bool InsertOrReplace( SAPDB_Byte* Data, SAPDBErr_MessageList& ErrorList )
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::InsertOrReplace", Table_Trace, 5);
-        SAPDBERR_ASSERT_STATE( Data );
+        SAPDBERR_ASSERT_ARGUMENT( Data );
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         mFirstInsert = false;
         TempHashTable_HashValue Hash = CalcHashValueForKeys(Data);
         TempHashTable_HashValue Slot = CalcSlot(Hash);
 
-        SAPDBTRACE_WRITELN( Table_Trace, 3, "hash: " << Hash << " slot: " << Slot );
+        SAPDBTRACE_WRITELN( Table_Trace, 5, "hash: " << Hash << " slot: " << Slot );
 
         if ( TEntry* Act = mHashTable[Slot] )
         {
             do
             {
-                SAPDB_Byte* A = (SAPDB_Byte*)(Act+1);
+                SAPDB_Byte* A = (SAPDB_Byte*)&(Act[1]);
                 if ( IsEqual(Data, A) )
                 {
-                    mMerger.MergeData(Data, A, mRecordLength, true);
+                    mMerger.MergeData(Data, A, mRecordLength, true, /*SourceIsPartialAggregate*/false);
                     mValid = false;
                     return true;
                 }
@@ -383,8 +416,8 @@ public:
             NewEntry->mNext = mHashTable[Slot];
             mHashTable[Slot]= NewEntry;
 
-            SAPDB_Byte* N = (SAPDB_Byte*)(NewEntry+1);
-            mMerger.MergeData(Data, N, mRecordLength, false);
+            SAPDB_Byte* N = (SAPDB_Byte*)&(NewEntry[1]);
+            mMerger.MergeData(Data, N, mRecordLength, false, /*SourceIsPartialAggregate*/false);
             mValid = false;
             return true;
         }
@@ -396,7 +429,8 @@ public:
 
     virtual SAPDB_Bool First( SAPDBErr_MessageList& ErrorList )
     {
-        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::First", Table_Trace, 5);
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::First", Table_Trace, 2);
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         if ( !SortEntries(false, ErrorList) )
         {
@@ -407,23 +441,35 @@ public:
 
         SAPDB_UInt4 FileCnt = mTempFileContainer.GetSize();
 
+        SAPDBTRACE_WRITELN( Table_Trace, 2, "FileCnt: " << FileCnt );
+
         for ( SAPDB_UInt4 i=0; i<FileCnt; i++ )
         {
-            Data_TempFile::RecordIterator*& Iter = mTempFileContainer[i].mIter;
+            Data_TempFile::RecordIterator* Iter = mTempFileContainer[i].mIter;
             if ( !Iter )
             {
                 if ( !(Iter = new(mSessionAllocator) Data_TempFile::RecordIterator(mTempFileContainer[i].mFile->PageAccessManager())) )
                 {
-                    ErrorList = Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOITERATOR);
+                    mTransContext.trError_gg00 = 0;
                     return 0;
                 }
             }
             if(!mTempFileContainer[i].mFile->GetFirst(*Iter))
+            {
+                mTransContext.trError_gg00 = 0;
+                ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_FIRSTFAILED);
                 return 0;
+            }
             if ( Iter->IsValid() )
+            {
                 mTempFileContainer[i].mData = *(*(Iter));
+            }
             else
-                mTempFileContainer[i].mData = 0;
+            {
+                mTransContext.trError_gg00 = 0;
+                ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_FIRSTFAILED);
+                return 0;
+            }
         }
 
         if ( mFunnelMergeIterator = new(mSessionAllocator) SAPDBAlgo_FunnelMergeIteratorIdx<SAPDB_Byte*>(mSessionAllocator, *this, *this, ErrorList) )
@@ -432,7 +478,7 @@ public:
             {
                 mValid = true;
                 Collect();
-                return true;
+                return mValid;
             }
             else
             {
@@ -452,6 +498,7 @@ public:
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::Next", Table_Trace, 5);
         SAPDBERR_ASSERT_STATE( mValid );
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         Collect();
         return mValid;
@@ -460,8 +507,12 @@ public:
     virtual SAPDB_Byte* Get( void )
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::Get", Table_Trace, 5);
+        SAPDBERR_ASSERT_STATE( mValid );
 
-        return mFetchedRecord;
+        if ( mValid )
+            return mFetchedRecord;
+        else
+            return 0;
     }
 
     virtual SAPDB_Bool IsValid( void )
@@ -589,46 +640,50 @@ private:
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::DestroyHashTableAndAllocator", Table_Trace, 8);
 
+        if ( mSortTable )
+        {
+            destroyarray(mSortTable, mMaxEntryCnt, mSessionAllocator);
+        }
+		if ( mFunnelMergeIterator )
+		{
+			destroy(mFunnelMergeIterator, mSessionAllocator);
+		}
         if ( mAllocator )
         {
-            if ( mHashTable )
-            {
-	            for ( TempHashTable_HashValue i=0; i<mNumberOfSlots; i++ )
-                {
-		            if ( TEntry* Act = mHashTable[i] )
-		            {
-			            TEntry* Next;
-			            do 
-			            {
-				            Next = Act->mNext;
-                            destroy(Act, *mAllocator);          
-				            Act = Next;
-			            }while( Act );
-		            }
-                }
-    	        destroyarray(mHashTable, mNumberOfSlots, *mAllocator);    
-            }
-
-            if ( TEntry* Act = mFirstFree )
-            {
-                TEntry* Next;
-                do
-                {
-				    Next = Act->mNext;
-                    destroy(Act, *mAllocator);
-			        Act = Next;
-                }while ( Act );
-            }
-
-            if ( mSortTable )
-            {
-                destroyarray(mSortTable, mMaxEntryCnt, mSessionAllocator);
-            }
-
+            // we don't need to deallocate all that stuff as mAllocator itself will be deallocated !
             destroy(mAllocator, mSessionAllocator);
         }
     }
 
+    inline TEntry* TryAllocateNEntries( SAPDB_Int4 n )
+    {
+        if ( n > (SAPDB_Int4)(mMaxEntryCnt-mAllocatedEntryCnt) )
+            n = mMaxEntryCnt-mAllocatedEntryCnt;
+
+        if ( n>0 )
+        {
+            SAPDB_Int4 Size = sizeof(TEntry)+mRecordLength;
+			if ( Size % 8 != 0 )
+			{
+				Size  = (SAPDB_Int4)(Size/8);
+				Size += 1;
+				Size *= 8;
+			}
+            char* p = (char*)mAllocator->Allocate(n*Size);
+            if ( p )
+            {
+                mAllocatedEntryCnt += n;
+                for ( SAPDB_Int8 i=0; i<n; i++ )
+                {
+                    InsertToFreeList((TEntry*)p);
+                    p += Size;
+                }
+                return GetMemOfFirstFree();
+            }
+        }
+        return 0;
+    }
+
     TEntry* GetMemForEntry( SAPDBErr_MessageList& ErrorList )
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::GetMemForEntry", Table_Trace, 8);
@@ -641,25 +696,26 @@ private:
         }
         else
         {
-            if ( (mActEntryCnt < mMaxEntryCnt) && mAllocator )
+            if ( !mFlushed )
             {
-                SAPDB_UInt4 Size = sizeof(TEntry)+mRecordLength;
-                NewEntry = (TEntry*) mAllocator->Allocate(Size);
+                if ( !(NewEntry=TryAllocateNEntries(1000)) )
+                    if ( !(NewEntry=TryAllocateNEntries(100)) )
+                        if ( !(NewEntry=TryAllocateNEntries(10)) )
+                            NewEntry=TryAllocateNEntries(1);
             }
-            if ( NewEntry )
-            {
-                NewEntry->mNext = 0;
-                ++mActEntryCnt;
-            }
-            else
+            if ( !NewEntry )
             {
                 FlushToPage(ErrorList);
+                mFlushed = true;
+                mUsedEntryCnt = 0;
                 if ( mFirstFree )
                     NewEntry = GetMemOfFirstFree();
                 else
                     ErrorList  = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOFREEENTRY);
             }
         }
+        if ( NewEntry )
+            ++mUsedEntryCnt;
         return NewEntry;
     }
 
@@ -743,6 +799,24 @@ private:
                 ErrorList = Table_Exception(__CONTEXT__, TABLE_TEMPHASH_CANNOTSORT);
                 return false;
             }
+
+            if ( HashedResultSet_Check.ChecksLevel(5) )
+            {
+                for ( SAPDB_UInt4 k=1; k<mSortTableEntryCnt; k++ )
+                {
+                    SAPDBERR_ASSERT_STATE( IsPredecessor(mSortTable[k-1],  mSortTable[k]) );
+#if !defined (SAPDB_SLOW)
+                    if ( !IsPredecessor(mSortTable[k-1],  mSortTable[k]) )
+                    {
+                        a07_b_put_error( *(tak_all_command_glob*)(mTransContext.trAcvPtr_gg00), e_system_error, 1 );
+                        ErrorList = Table_Exception(__CONTEXT__, TABLE_TEMPHASH_CANNOTSORT);
+                        RTE_Message(ErrorList);
+                        return false;
+                    }
+#endif
+                }
+            }
+
             return true;
         }
         else
@@ -755,8 +829,9 @@ private:
 
     inline SAPDB_Bool FlushToPage( SAPDBErr_MessageList& ErrorList )
     {
-        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::FlushToPage", Table_Trace, 8);
+        SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::FlushToPage", Table_Trace, 2);
         SAPDBERR_ASSERT_STATE( mAllocator && mHashTable );
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         // Create new TempFile
         TempFileContainerEntry CE;
@@ -771,9 +846,41 @@ private:
                 if ( SortEntries(true, ErrorList) )
                 {
                     // Write data to temp file
+                    SAPDBTRACE_WRITELN( Table_Trace, 2, "Writing " << mSortTableEntryCnt << " records to Tempfile #" << mTempFileContainer.GetSize()-1 );
                     for ( SAPDB_UInt4 i=0; i<mSortTableEntryCnt; i++ )
+                    {
+                        SAPDBERR_ASSERT_STATE( mSortTable[i] );
+                        if ( i>0 )
+                        {
+                            SAPDBERR_ASSERT_STATE( IsPredecessor(mSortTable[i-1],  mSortTable[i]) );
+#if !defined (SAPDB_SLOW)
+                            if ( HashedResultSet_Check.ChecksLevel(3) )
+                            {
+                                if ( !IsPredecessor(mSortTable[i-1],  mSortTable[i]) )
+                                {
+                                    a07_b_put_error( *(tak_all_command_glob*)(mTransContext.trAcvPtr_gg00), e_system_error, 1 );
+                                    ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_CANNOTSORT);
+                                    RTE_Message(ErrorList);
+                                    return false;
+                                }
+                            }
+#endif
+                        }
                         if ( mSortTable[i] )
-                            CE.mFile->Append((const SAPDB_Byte *) mSortTable[i]);
+                        {
+                            if ( !CE.mFile->Append((const SAPDB_Byte *) mSortTable[i]) )
+                            {
+                                mTransContext.trError_gg00 = 0;
+                                ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOORDEREDFLUSH);
+                                return false;
+                            }
+                        }
+                        else
+                        {
+                            ErrorList = ErrorList + Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOORDEREDFLUSH);
+                            return false;
+                        }
+                    }
                     return true;
                 }
                 else
@@ -800,12 +907,14 @@ private:
     void Collect( void )
     {
         SAPDBTRACE_METHOD_DEBUG ("Table_FixSizeTempHashTableAggregate::Collect", Table_Trace, 8);
+        SAPDBERR_ASSERT_STATE( mTransContext.trError_gg00 == 0 );
 
         // Merge all Data that have the same key as the current entry 
         // and set the iterator to the first entry having a different key
         if ( mFunnelMergeIterator->IsValid() )
         {
-            mFetchedRecord = *(*mFunnelMergeIterator);
+            SAPDB_MemCopyNoCheck(mFetchedRecord, *(*mFunnelMergeIterator), mRecordLength);
+//            mFetchedRecord = *(*mFunnelMergeIterator);
 
             bool SameKey = true;
             do
@@ -815,8 +924,22 @@ private:
                 {
                     SAPDB_Byte* TempData = *(*mFunnelMergeIterator);
 
+                    SAPDBERR_ASSERT_STATE( !IsPredecessor(TempData, mFetchedRecord) );
+#if !defined (SAPDB_SLOW)
+                    if ( HashedResultSet_Check.ChecksLevel(3) )
+                    {
+                        if ( IsPredecessor(TempData, mFetchedRecord) )
+                        {
+                            a07_b_put_error( *(tak_all_command_glob*)(mTransContext.trAcvPtr_gg00), e_system_error, 1 );
+                            RTE_Message(Table_Exception(__CONTEXT__, TABLE_TEMPHASH_NOORDEREDFLUSH));
+                            mValid = false;
+//                            mFetchedRecord = 0;
+                            return;
+                        }
+                    }
+#endif
                     if ( IsEqual(TempData, mFetchedRecord) )
-                        mMerger.MergeData(TempData, mFetchedRecord, mRecordLength, true);
+                        mMerger.MergeData(TempData, mFetchedRecord, mRecordLength, true, /*SourceIsPartialAggregate*/true);
                     else
                         SameKey = false;
                 }
@@ -830,7 +953,7 @@ private:
         else
         {
             mValid = false;
-            mFetchedRecord = 0;
+ //           mFetchedRecord = 0;
         }
     };
 
@@ -851,7 +974,8 @@ private:
     SAPDB_UInt4                                     mActSortTableEntry;
 
     SAPDB_UInt4                                     mMaxEntryCnt;
-    SAPDB_UInt4                                     mActEntryCnt;
+    SAPDB_UInt4                                     mAllocatedEntryCnt;
+    SAPDB_UInt4                                     mUsedEntryCnt;
     TempHashTable_HashValue                         mNumberOfSlots;
     SAPDB_UInt2                                     mKeyCount;
 
@@ -860,10 +984,11 @@ private:
 
     Container_Vector<TempFileContainerEntry>        mTempFileContainer;
 
-    SAPDB_Bool                                      mValid;
     SAPDB_Byte*                                     mFetchedRecord;
     SAPDB_UInt2                                     mRecordLength;
+    SAPDB_Bool                                      mValid;
     bool                                            mFirstInsert;
+    bool                                            mFlushed;
 };
 
 // #############################################################################
