@@ -532,8 +532,14 @@ void WriteException( char const * const str,
 #ifdef WIN32
     DWORD Log_WriteException( LPEXCEPTION_POINTERS ec )
     {
+        eo670TraceContext traceContext;
+
         Log_Error("EXECPTION OCCURED:", 0);
-        eo670_CTraceContextStackOCB(ec->ContextRecord, WriteException, NULL);
+
+        traceContext.threadHandle   = GetCurrentThread();
+        traceContext.pThreadContext = ec->ContextRecord;
+        eo670_CTraceContextStackOCB(&traceContext, WriteException, NULL);
+
         return EXCEPTION_CONTINUE_SEARCH;
     }
 #else
