@@ -18,7 +18,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 
 
 
+
 ************************************************************************/
 
 #ifndef WDVCAPI_DEFINITION_H
@@ -430,6 +431,8 @@ WDV_Bool WDVCAPI_CreateWDV ( WDVCAPI_WDV       *wdv,
 
 WDV_Bool WDVCAPI_DestroyWDV( WDVCAPI_WDV  wdv  );
 
+WDV_Bool WDVCAPI_RollbackTransaction ( WDVCAPI_WDV  wdv );
+
 /*---------------------------------------------------------------------------*/
 
 WDV_Bool WDVCAPI_ClearErrorList( WDVCAPI_WDV  wdv );
@@ -647,7 +650,7 @@ WDV_Bool WDVCAPI_PutClose( WDVCAPI_WDV  wdv );
 
 WDV_Bool WDVCAPI_Delete( WDVCAPI_WDV            wdv,
                          WDVCAPI_URI            uri,
-                         WDVCAPI_LockIdString   lockIdString,
+                         WDVCAPI_LockId         lockIdString,
                          WDV_Bool               deleteIntoDeletedItems );
 
 /*---------------------------------------------------------------------------*/
