@@ -623,12 +623,14 @@ WDV_Bool WDVCAPI_LockAddIdToList( WDVCAPI_WDV           wdv,
 	}
 
     /* Is uri the deleted items folder? */
-    if(strncmp(lockUri, WDVCAPI_DELETED_ITEMS_FOLDER, WDVCAPI_DELETED_ITEMS_FOLDER_LEN) == 0) {
-        Error_AddErrorItem(wdv, WDVCAPI_ERR_TYPE_CAPI,
-                                WDVCAPI_ERR_CODE_NOT_ALLOWED_ON_DELETED_ITEMS_FOLDER,
-                                WDVCAPI_ERR_TEXT_NOT_ALLOWED_ON_DELETED_ITEMS_FOLDER);
+    if(lockUri != NULL) {
+        if(strncmp(lockUri, WDVCAPI_DELETED_ITEMS_FOLDER, WDVCAPI_DELETED_ITEMS_FOLDER_LEN) == 0) {
+            Error_AddErrorItem(wdv, WDVCAPI_ERR_TYPE_CAPI,
+                                    WDVCAPI_ERR_CODE_NOT_ALLOWED_ON_DELETED_ITEMS_FOLDER,
+                                    WDVCAPI_ERR_TEXT_NOT_ALLOWED_ON_DELETED_ITEMS_FOLDER);
 
-        return WDV_False;
+            return WDV_False;
+        }
     }
 
     /* Allocat new item */
