@@ -19,7 +19,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
 
 
 
+
 ************************************************************************/
 
 /***********************************************************************
@@ -460,6 +461,11 @@ WDV_Bool WDV_EndTransaction( WDVCAPI_WDV  wdv )
 
 /*===========================================================================*/
 
+WDV_Bool WDVCAPI_RollbackTransaction ( WDVCAPI_WDV  wdv )
+{
+    return WDV_StartTransaction(wdv);
+}
+
 WDV_Bool WDV_StartTransaction( WDVCAPI_WDV  wdv )
 {
 
