@@ -18,23 +18,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -171,7 +172,8 @@
 	/*------------------------------------------------------------------------
 		Function:	getDeletedItemsHeader
 	--------------------------------------------------------------------------*/
-	WDVH_Bool getDeletedItemsHeader(sapdbwa_HttpRequestP request,
+	WDVH_Bool getDeletedItemsHeader(sapdbwa_Handle wa,
+									sapdbwa_HttpRequestP request,
 									WDVH_Bool *delitems);
 
 	/*------------------------------------------------------------------------
@@ -302,6 +304,12 @@
 	--------------------------------------------------------------------------*/
 	WDVH_Bool WDVH_CheckPropertySet(WDVH_PChar tag);
 
+	/*------------------------------------------------------------------------
+		Function:	WDVH_CheckRequestURI
+		http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1135599
+	--------------------------------------------------------------------------*/
+	WDVH_Bool WDVH_CheckRequestURI(WDVH_PChar resourceURI);
+
 	/*------------------------------------------------------------------------
 		Function:	WDVH_CheckPropertyRemove
 		http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1123441
@@ -320,6 +328,12 @@
 	WDVH_Int4 AlphaNumeric (WDVH_Char ch);
 	WDVH_Int4 URLencode (const WDVH_Char * plain, WDVH_Char * encode, WDVH_Int4 maxlen);
 
+	WDVH_Bool checkAuthentication(sapdbwa_Handle		wa,
+								  sapdbwa_HttpRequestP	req,
+								  sapdbwa_HttpReplyP	rep,
+								  SAPDB_Char			*isRequired,
+								  SAPDB_Char			*user,
+								  SAPDB_Char			*password);
 
 
 #endif
