@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -142,13 +143,17 @@
 	--------------------------------------------------------------------------*/
 	sapdbwa_Bool closeConnection(sapdbwa_Handle wa, sapdbwa_DbConnectionP conn)
 	{
-		if (wa==NULL || conn==NULL)
+		WDVCAPI_WDV pCapiHandle;
+
+        if (wa==NULL || conn==NULL)
 			return WDVH_False;
 
 		/* close DB Connection */
 		#if defined(LOG_LEVEL_1) 
 			sapdbwa_WriteLogMsg(wa, "Try DB disconnect ...\n");
 		#endif
+        pCapiHandle = getWdvHandle(wa,conn);
+        WDVCAPI_RollbackTransaction(pCapiHandle);
 		sapdbwa_DbDisconnect(conn);
 		#if defined(LOG_LEVEL_1) 
 			sapdbwa_WriteLogMsg(wa, "DB disconnect successfull\n");
