@@ -16,23 +16,24 @@
   -------------------------------------------------------------------------
 
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -135,7 +136,8 @@
 	--------------------------------------------------------------------------*/
 	WDVH_Bool propfindBuildReply(sapdbwa_Handle		wa,
 						     sapdbwa_Int2 statuscode, 
-							sapdbwa_HttpReplyP reply, 
+								  sapdbwa_HttpRequestP		request,
+								  sapdbwa_HttpReplyP reply, 
 							WDVH_Char *host,
 							WDVH_Char *port,
 							WDVH_Char *uri,
@@ -309,12 +311,15 @@
 				/* set server prefix */
 				getWebDAVPrefix(wa,prefix);
 
-				length = strlen(prefix) + 1;
+				/* get server string for error messages */
+				buildServerString(request,&server);
+
+/*				length = strlen(prefix) + 1;
 				WDVHandler_Allocat(sizeof(SAPDB_Char)*length,(sapdbwa_UInt1**) &server,&allocatOK);
 				if (allocatOK) {
 					sp77sprintf(server,length,"%s",prefix);
 				}
-				/* build namespace list */
+*/				/* build namespace list */
 				if (WDVCAPI_PropfindGetFirstNameSpace(wdv,propfind,&propertyNamespaceShortcut,&propfindNamespace)) {
 					namespaceList = createStrBuffer(WDVH_MAX_STR_BUFFER_LEN);
 
@@ -407,6 +412,7 @@
 					/*		href */
 					WDVH_sendBodyChunkPropfind(reply,WDVH_HREF_OPEN,isMSWebFolder);
 					WDVH_sendBodyChunkPropfind(reply,server,isMSWebFolder);
+					WDVH_sendBodyChunkPropfind(reply,prefix,isMSWebFolder);
 					if (requestedResource) {
 						URLencode(uri,uri_enc,WDVH_MAX_URI_LEN);
 						WDVH_sendBodyChunkPropfind(reply,uri_enc,isMSWebFolder);
@@ -657,6 +663,7 @@
 
 				/* clean up */
 				destroyStrBuffer(namespaceList);
+
 			}
 		}
 
