@@ -291,6 +291,8 @@
 				if (allocatOK) {
 					sp77sprintf(server,length,"%s",/*host,port,*/prefix);
 				}
+				buildServerString(request,&server);
+
 				/* build namespace list */
 				if (WDVCAPI_ProppatchGetFirstProcessedNameSpace(wdv,proppatch,&propertyNamespaceShortcut,&propertyNamespace)) {
 					namespaceList = createStrBuffer(WDVH_MAX_STR_BUFFER_LEN);
@@ -298,53 +300,83 @@
 						if (!appendStrBuffer(namespaceList,WDVH_XMLNS)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,WDVH_XML_NS_PREFIX)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,propertyNamespaceShortcut)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,WDVH_XML_EQUAL_SIGN)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,WDVH_XML_QUOTE)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,propertyNamespace)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,WDVH_XML_QUOTE)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 						if (!appendStrBuffer(namespaceList,WDVH_XML_SPACE)) {
 							/* error handling */
 							sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 							return WDVH_True;
 						}
 
                         if (!WDVCAPI_ProppatchGetNextProcessedNameSpace(wdv,proppatch,&propertyNamespaceShortcut,&propertyNamespace)) {
 					        /* error handling */
 					        sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+							if (server) {
+								WDVHandler_Free((sapdbwa_UInt1*) server);
+							}
 					        return WDVH_True;
                         }
 					};
 				} else {
 					/* error handling */
 					sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+					if (server) {
+						WDVHandler_Free((sapdbwa_UInt1*) server);
+					}
 					return WDVH_True;
 				}
 
@@ -372,6 +404,9 @@
 					destroyStrBuffer(namespaceList);
 					/* error handling */
 					sendErrorReply(ERROR_500, reply, WEBDAV_PROPPATCH,"");
+					if (server) {
+						WDVHandler_Free((sapdbwa_UInt1*) server);
+					}
 					return WDVH_True;
 				}
 				while(propertyName) {
