@@ -224,15 +224,16 @@ HRESULT LVC_Dispatcher::dispGetClassObjectFromReg(
 /*---------------------------------------------------------------------------*/
 /* PTS 1121178 FF 19-Mar-2003 */
 HRESULT LVC_Dispatcher::dispGetClassObject(
-  char const* libname, 
-  GUID &CoClsId,
+  char const      *libname, 
+  const tsp00_C8  &packageId,
+  GUID            &CoClsId,
   const tsp00_C32 &MD5mark, 
-  tsp00_Addr &ifactory)
+  tsp00_Addr      &ifactory)
 {
   HRESULT         ret;
   LPCLASSFACTORY  lpIClassFactory;
 
-  ret = LVC_LoadComponentLibrary(libname, CoClsId, MD5mark, ifactory);
+  ret = LVC_LoadComponentLibrary(libname, packageId, CoClsId, MD5mark, ifactory);
   lpIClassFactory = (IClassFactory *) ifactory;
   if (!ret)
   {
