@@ -959,11 +959,16 @@ void LVC_InProcDispatcher::dispGetClassObjectWrapper(tsp_dcom_co_create_instance
 {
   parms->idispatch = 0;
   if ( parms->use_libname ) /* PTS 1121178 FF 19-Mar-2003 */
-    parms->ret = dispGetClassObject(parms->library_name, *reinterpret_cast<GUID*>(
-      &parms->coclsid[0]), parms->MD5_footprint, parms->ifactory);
+  {
+    parms->ret = dispGetClassObject(parms->library_name, parms->package_id,
+      *reinterpret_cast<GUID*>(&parms->coclsid[0]), 
+      parms->MD5_footprint, parms->ifactory);
+  }
   else
+  {
     parms->ret = dispGetClassObjectFromReg(*reinterpret_cast<GUID*>(
       &parms->coclsid[0]), parms->ifactory);
+  }
 }
 
 /*---------------------------------------------------------------------------*/
