@@ -41,6 +41,7 @@ class   SAPDBMem_IRawAllocator;
 class   OmsStackTraceCallbackInterface;
 class   DbpErrorCallbackInterface;
 class   LVC_LockRequest;
+class   RTE_IInterface;
 
 /*!
  * \brief LiveCache session-less kernel interface.
@@ -187,6 +188,15 @@ public :
    */
   virtual bool IsUnicodeInstance() = 0;
 
+  /*!
+   * \brief checks if the liveCache is a OneDB system
+   *
+   * Tells whether liveCache is a OneDB system.
+   *
+   * \return true, if parameter MCOD = 'YES', false otherwise
+   */
+  virtual bool IsOneDBSystem() = 0;
+
   /*!
    * \brief Allocate memory from OMS allocator.
    *
@@ -326,6 +336,15 @@ public :
    * \since PTS 1133630
    */
   virtual void SetErrorCallback(DbpErrorCallbackInterface *cb) = 0;
+
+  /*!
+   * \brief Get kernel runtime interface
+   *
+   * Returns a pointer to the liveCache kernel runtime interface
+   *
+   * \return pointer to the liveCache kernel runtime interface
+   */
+  virtual RTE_IInterface &GetKernelRunTimeInterface() = 0;
 };
 
 #endif
