@@ -1,6 +1,6 @@
 /*!
  * \file    LVC_LoadComponentLibrary.cpp
- * \author  IvanS, ThomasA, FerdiF
+ * \author  IvanS, FerdiF
  * \brief   Load a component library and calculate an MD5 footprint.
  */
 /*
@@ -28,6 +28,7 @@
 */
 
 #include "liveCache/LVC_LoadComponentLibrary.hpp"
+#include "liveCache/LVC_ILoadComponentLibraryCache.hpp"
 #include "liveCache/LVC_LoadLibrary.hpp"
 #include "geo00d.h"                          
 #include "gip00.h"                          
@@ -44,10 +45,14 @@ externC
 
 /*----------------------------------------------------------------------------*/
 
-HRESULT LVC_LoadComponentLibrary(char const* libName, 
-                                 HANDLE*     hInstance,
-                                 tsp00_C32  &MD5Footprint)
+HRESULT LVC_LoadComponentLibrary(char const     *libName, 
+                                 const tsp00_C8 &packageId,
+                                 HANDLE*         hInstance,
+                                 tsp00_C32      &MD5Footprint)
 {
+  // first check if library information has already been cached 
+  if (LVC_ILoadComponentLibraryCache::GetInstance().Find(packageId, hInstance, MD5Footprint))
+    return S_OK;
 
   /* 1) load library                                                        */
   /* truncate file-type ( .dll, .so, .sl, ... ),                            */
@@ -101,7 +106,10 @@ HRESULT LVC_LoadComponentLibrary(char const* libName,
     }  
   }
   if ( have_sum ) 
+  {
     memcpy(&MD5Footprint, sum, sizeof(MD5Footprint));
+    LVC_ILoadComponentLibraryCache::GetInstance().Insert(packageId, hInstance, MD5Footprint);
+  }
   else
   {
     memset(&MD5Footprint, '\00', sizeof(MD5Footprint));
@@ -113,6 +121,7 @@ HRESULT LVC_LoadComponentLibrary(char const* libName,
 /*----------------------------------------------------------------------------*/
 
 HRESULT LVC_LoadComponentLibrary(char const      *libName, 
+                                 const tsp00_C8  &packageId,
                                  const GUID      &CoClsId,
                                  const tsp00_C32 &MD5Footprint,
                                  tsp00_Addr      &ifactory)
@@ -120,7 +129,7 @@ HRESULT LVC_LoadComponentLibrary(char const      *libName,
   HRESULT hr;
   tsp00_C32   MD5Mark;
   HANDLE      hInstance;
-  hr = LVC_LoadComponentLibrary(libName, &hInstance, MD5Mark);
+  hr = LVC_LoadComponentLibrary(libName, packageId, &hInstance, MD5Mark);
   if (( S_OK == hr ) && memcmp(&MD5Footprint, &MD5Mark, sizeof(MD5Mark)) )
   {
       tsp00_Version kernelVersion;
