@@ -1,5 +1,5 @@
 /*!
- * \file    LVC_DispatcherParams.hpp
+ * \file    LVC_LoadComponentLibrary.hpp
  * \author  IvanS, ThomasA, FerdiF
  * \brief   Load a component library and calculate an MD5 footprint.
  */
@@ -40,14 +40,16 @@
 ** \param libName Library name, which may or may not contain a complete
 **        or partial path specification. The file type may be ommitted
 ** \param hInstance handle of loaded library
+** \param PackageId assigned by catalog. 
 ** \param MD5Footprint Out parameter containing the MD5 footprint if function 
 **        signals success
 ** \return S_OK if succeeded or ERROR_FILE_NOT_FOUND
 **/
 externCpp
-HRESULT LVC_LoadComponentLibrary(char const *libName, 
-                                 HANDLE     *hInstance,
-                                 tsp00_C32  &MD5Footprint); 
+HRESULT LVC_LoadComponentLibrary(char const     *libName, 
+                                 const tsp00_C8 &packageId,
+                                 HANDLE         *hInstance,
+                                 tsp00_C32      &MD5Footprint); 
 
 /// Loads a component library, calculates/compares MD5 footprint and gets component factory pointer.
 /*!
@@ -55,6 +57,7 @@ HRESULT LVC_LoadComponentLibrary(char const *libName,
 **
 ** \param libName Library name, which may or may not contain a complete
 **        or partial path specification. The file type may be ommitted
+** \param PackageId assigned by catalog. 
 ** \param CoClsId component class ID
 ** \param MD5Footprint Out parameter containing the MD5 footprint if function 
 **        signals success
@@ -62,6 +65,7 @@ HRESULT LVC_LoadComponentLibrary(char const *libName,
 **/
 externCpp
 HRESULT LVC_LoadComponentLibrary(char const      *libName, 
+                                 const tsp00_C8  &packageId,
                                  const GUID      &CoClsId,
                                  const tsp00_C32 &MD5Footprint,
                                  tsp00_Addr      &ifactory);
