@@ -22,7 +22,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@
 
 
 
+
 *****************************************************************************/
 
 
@@ -130,24 +131,36 @@ public :
    }
    virtual void* Allocate(SAPDB_ULong ByteCount)
    {
-      return m_lvcAllocator->OmsAllocate(ByteCount);
+       const bool cIsUsrRequest = true;
+       return m_lvcAllocator->AllocateImplementation(ByteCount, !cIsUsrRequest);
    }
    virtual void* Allocate(SAPDB_ULong ByteCount, const void* Hint)
    {
-       return m_lvcAllocator->OmsAllocate(ByteCount);
+       const bool cIsUsrRequest = true;
+       return m_lvcAllocator->AllocateImplementation(ByteCount, !cIsUsrRequest);
+   }
+   virtual void* AllocateThrowsNothing(SAPDB_ULong ByteCount)
+   {
+       const bool cIsUsrRequest = true;
+       const bool cThrowBadAlloc = true;
+       return m_lvcAllocator->AllocateImplementation(ByteCount, !cIsUsrRequest, !cThrowBadAlloc);
    }
-
    virtual void Deallocate(void* p)
    {
-       m_lvcAllocator->OmsDeallocate(p);
+       const bool cIsUsrRequest = true;
+       m_lvcAllocator->DeallocateImplementation(p, !cIsUsrRequest);
    }
    virtual void GetBaseAllocatorCallStatistics(SAPDB_ULong &CountAlloc, SAPDB_ULong &CountDealloc) const
    {
-       // just to fulfill interface
+        m_lvcAllocator->GetBaseAllocatorCallStatistics(CountAlloc, CountDealloc);
    }
    virtual void GetCallStatistics(SAPDB_ULong &CountAlloc, SAPDB_ULong &CountDealloc) const
    {
-       // just to fulfill interface
+       m_lvcAllocator->GetCallStatistics(CountAlloc, CountDealloc);
+   }
+   virtual const SAPDB_UTF8 *GetIdentifier() const
+   {
+       return m_lvcAllocator->GetIdentifier();
    }
    virtual int GetErrorCount() const 
    {
@@ -169,12 +182,11 @@ LVCMem_Allocator::LVCMem_Allocator()
 : m_Monitoring(false)
 , m_askForClient(false)
 , m_SubAllocatorCount(0)
-, m_omsAllocatorIdx(0)
-, m_firstAllocator( (const SAPDB_UTF8 *) "LVCMem_Allocator_1",
+, m_firstAllocator( (const SAPDB_UTF8 *) "LVCMem_Allocator_001",
       LVCMem_BlockAllocator::Instance(), 1024 * 1024, 0,
       SAPDBMem_SynchronizedRawAllocator::FREE_RAW_EXTENDS)
 {
-    m_SubAllocators[1] = &m_firstAllocator;
+    m_SubAllocators[0] = &m_firstAllocator;
 }
 
 /*-----------------------------------------------------*/
@@ -318,19 +330,18 @@ void LVCMem_Allocator::Create
   {
     subAllocatorCount = MAX_SUB_HEAPS;
   }
-  // allocator[0] is oms allocator
-  // allocator[1] already created via Instance call
+  // allocator[0] already created via Instance call
   for (int ix = 1; ix < subAllocatorCount; ++ix)
   {
     sp77sprintf (allocatorIdentifier, sizeof(allocatorIdentifier),
         "LVCMem_Allocator_%03d", ix + 1);
-    m_SubAllocators[ix+1] = new(this->GetSubAllocator(0)) SAPDBMem_SynchronizedRawAllocator(
+    m_SubAllocators[ix] = new(this->GetSubAllocator(0)) SAPDBMem_SynchronizedRawAllocator(
       (const SAPDB_UTF8 *) &allocatorIdentifier[0], 
       LVCMem_BlockAllocator::Instance(), 
       RawChunkSize * 1024,
       RawChunkSize * 1024,
       SAPDBMem_SynchronizedRawAllocator::FREE_RAW_EXTENDS);
-    if (!m_SubAllocators[ix+1])
+    if (!m_SubAllocators[ix])
     {
         char msg[100];
         sp77sprintf (msg, sizeof(msg), "Could not create %s", allocatorIdentifier);
@@ -340,22 +351,8 @@ void LVCMem_Allocator::Create
   }
   if (isLiveCache)
   {
-      // create oms allocator (index 0)
-      strcpy(allocatorIdentifier, "OMS_Allocator");
-      m_SubAllocators[0] = new (this->GetSubAllocator(0)) SAPDBMem_SynchronizedRawAllocator(
-          (const SAPDB_UTF8 *) &allocatorIdentifier[0], 
-          LVCMem_BlockAllocator::Instance(), 
-          RawChunkSize * 1024,
-          RawChunkSize * 1024,
-          SAPDBMem_SynchronizedRawAllocator::FREE_RAW_EXTENDS);
-      if (!m_SubAllocators[0])
-      {
-        theTracer.Exception("Could not create OMS_Allocator"); 
-      }
       SAPDBMEM_STATIC_RAW_ALLOCATE(Space, sizeof(LVCMem_OmsAllocatorWrapper));
       m_OmsInstance = new((void*) Space) LVCMem_OmsAllocatorWrapper(this);
-      this->GetSubAllocator(OMS_ALLOCATOR_IDX).SetTracer(&theTracer);
-      m_omsAllocatorIdx = OMS_ALLOCATOR_IDX;
       LVCMem_EmergencyAllocator::Instance();
   }
   else
@@ -408,19 +405,31 @@ SAPDBMem_IRawAllocator& LVCMem_Allocator::LVCOmsAllocatorInstance()
 
 void* LVCMem_Allocator::Allocate(SAPDB_ULong count)
 {
-  return AllocateImplementation(count);
+    const bool cIsUsrRequest = true;
+    return AllocateImplementation(count, cIsUsrRequest);
+
 }
 
 /*-----------------------------------------------------*/
 
 void* LVCMem_Allocator::Allocate(SAPDB_ULong count, const void * hint)
 {
-  return AllocateImplementation(count);
+   const bool cIsUsrRequest = true;
+   return AllocateImplementation(count, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
 
-void* LVCMem_Allocator::BadAllocHandling(int allocatorIdx, SAPDB_ULong count, bool badAllocRequired)
+void* LVCMem_Allocator::AllocateThrowsNothing(SAPDB_ULong count)
+{
+    const bool cIsUsrRequest = true;
+    const bool cThrowBadAlloc = true;
+    return AllocateImplementation(count, cIsUsrRequest, !cThrowBadAlloc);
+}
+
+/*-----------------------------------------------------*/
+
+void* LVCMem_Allocator::BadAllocHandling(int allocatorIdx, SAPDB_ULong count, bool badAllocRequired, bool throwBadAlloc)
 {
     void* p = (void*) 0;
     if (LVCMem_Wrapper::IsCurrentTaskInCppDBProc())
@@ -431,44 +440,29 @@ void* LVCMem_Allocator::BadAllocHandling(int allocatorIdx, SAPDB_ULong count, bo
             {
                 while (LVC_LibOmsInterface::Instance()->VersionUnloaded())
                 {
-                    if (OMS_ALLOCATOR_IDX == allocatorIdx)
+                    for (int slot = 0; slot < m_SubAllocatorCount; ++slot)
                     {
-                        p = this->GetSubAllocator(OMS_ALLOCATOR_IDX).Allocate(count);
+                        p = this->GetSubAllocator(slot).Allocate(count);
                         if ((void*) 0 != p)
                         {
                             return p;
                         }
                     }
-                    else
-                    {
-                        for (int slot = 0; slot < m_SubAllocatorCount; ++slot)
-                        {
-                            p = this->GetSubAllocator(slot).Allocate(count);
-                            if ((void*) 0 != p)
-                            {
-                                return p;
-                            }
-                        }
-                    }
                 }
             }
             catch (const DbpError& e)
             {
                 DbpErrorCallbackInterface *pCBInterface = DbpError::dbpGetCallback();  // PTS 1127871
                 if (pCBInterface){
-                  pCBInterface->dbpCaughtError(e);
+                    pCBInterface->dbpCaughtError(e);
                 }
 
                 Kernel_OpError (csp3_no_more_memory, csp3_n_memory) << "error " << e.dbpError() << " while unloading oms version";
             }
         }
-        if (OMS_ALLOCATOR_IDX == m_omsAllocatorIdx)
-        {
-            // running as liveCache, i.e. use emergency allocator
-            p = LVCMem_EmergencyAllocator::Instance().Allocate(count);
-        }
+        p = LVCMem_EmergencyAllocator::Instance().Allocate(count);
     }
-  if ((void*) 0 == p)
+  if (((void*) 0 == p) && throwBadAlloc)
   {
     // attach emergeny allocator for construction of bad_alloc instance
     LVCMem_ReserveEmergencyAllocator reservedScope;
@@ -483,7 +477,8 @@ void* LVCMem_Allocator::BadAllocHandling(int allocatorIdx, SAPDB_ULong count, bo
 
 void LVCMem_Allocator::Deallocate(void * p)
 {
-  this->DeallocateImplementation(p);
+    const bool cIsUsrRequest = true;
+    this->DeallocateImplementation(p, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
@@ -684,7 +679,8 @@ externC void LVCMem_SignalAnalysis()
 void *operator new (size_t Size) THROW_NEW_GEO573
 {
   LVCMem_Allocator& lvcAllocator = TheLiveCacheAllocatorWithBarrier;  // PTS 1130496
-  return lvcAllocator.AllocateImplementation(Size);
+  const bool cIsUsrRequest = true;
+  return lvcAllocator.AllocateImplementation(Size, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
@@ -693,7 +689,8 @@ void operator delete (void * pBuffer) THROW_DELETE_GEO573
 {
     LVCMem_Allocator& lvcAllocator = TheLiveCacheAllocatorWithBarrier;  // PTS 1130496
     lvcAllocator.IncrementDelete(pBuffer);
-    lvcAllocator.DeallocateImplementation(pBuffer);
+    const bool cIsUsrRequest = true;
+    lvcAllocator.DeallocateImplementation(pBuffer, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
@@ -701,7 +698,8 @@ void operator delete (void * pBuffer) THROW_DELETE_GEO573
 void *operator new[] (size_t Size) THROW_NEW_GEO573
 {
   LVCMem_Allocator& lvcAllocator = TheLiveCacheAllocatorWithBarrier;  // PTS 1130496
-  return lvcAllocator.AllocateImplementation(Size);
+  const bool cIsUsrRequest = true;
+  return lvcAllocator.AllocateImplementation(Size, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
@@ -710,7 +708,8 @@ void operator delete[]  (void * pBuffer) THROW_DELETE_GEO573
 {
     LVCMem_Allocator& lvcAllocator = TheLiveCacheAllocatorWithBarrier;  // PTS 1130496
     lvcAllocator.IncrementDelete(pBuffer);
-    lvcAllocator.DeallocateImplementation(pBuffer);
+    const bool cIsUsrRequest = true;
+    lvcAllocator.DeallocateImplementation(pBuffer, cIsUsrRequest);
 }
 
 /*-----------------------------------------------------*/
@@ -723,6 +722,7 @@ extern "C" void *__7__nw__FUl(size_t Size) {
 extern "C" void *__nw__XUl(size_t Size) { 
 #endif
   LVCMem_Allocator& lvcAllocator = TheLiveCacheAllocatorWithBarrier;  // PTS 1130496
-  return lvcAllocator.AllocateImplementation(Size);
+  const bool cIsUsrRequest = true;
+  return lvcAllocator.AllocateImplementation(Size, cIsUsrRequest);
 }
 #endif
\ No newline at end of file
