@@ -12,7 +12,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -148,6 +149,26 @@ public:
   virtual void* Allocate(SAPDB_ULong count, const void * hint);
 
   /*!
+      @brief          Allocates contiguous memory for &lt;ByteCount> bytes.
+              The memory is aligned as indicated by the 'GetAlignmentSize' 
+              method.
+              The memory is not initialised. 
+              This method assures, that no exception will be thrown.
+              The default implementation just call the Allocate method. Allocators, which may throw
+              an exception there, must overwrite this implementation !
+      @param          ByteCount [in] The size in bytes of the memory to be allocated. This 
+                      argument must be greater zero.
+      @return         void*
+                      A pointer to the allocated raw memory block of &lt;ByteCount> 
+                      bytes. If exception handling is disabled, a NULL pointer will
+                      be re turned in case of insufficient memory.
+      @exception      None
+
+    */
+
+  virtual void* AllocateThrowsNothing(SAPDB_ULong ByteCount);
+
+   /*!
      @brief    inline part of the implementaion of the Allocate method(s)
      @param    count [in] Number of Bytes to allocate
      @param    isUsrRequest [in] if true, method has been by operator new or
@@ -156,7 +177,7 @@ public:
      @return   Position where memory is allocated
    */
 
-  inline void* AllocateImplementation(SAPDB_ULong count);
+  inline void* AllocateImplementation(SAPDB_ULong count, bool isUsrRequest, bool ThrowBadAlloc = true); 
 
   ContentIterator Begin();
 
@@ -330,7 +351,7 @@ public:
        @return    none
      */
 
-    inline void DeallocateImplementation(void* p);
+    inline void DeallocateImplementation(void* p, bool isUsrRequest);
 
     /*!
        @brief     forces the alloctor to ask no longer for the client of a memory request
@@ -362,23 +383,23 @@ public:
    friend class LVCMem_Allocator::ContentIterator;
 private:
   enum { MAX_SUB_HEAPS = 128 };
-  enum { OMS_ALLOCATOR_IDX = -1 };
   // private allocator only used once during initialization
   LVCMem_Allocator();
 
   void* BadAllocHandling(
       int         allocatorIdx, 
       SAPDB_ULong count, 
-      bool        badAllocRequired); //!< handles out of memory, tries to free memory 
+      bool        badAllocRequired,
+      bool        throwBadAlloc); //!< handles out of memory, tries to free memory 
   static void CreateInstance();                 //!< creates the singleton instance
   void DeallocateInEmergencyAllocator(void* p); //!< deallocates a chunk in emergency allocator
   int  FirstAllocatorIndex() const
   {
-      return m_omsAllocatorIdx;
+      return 0;
   }
   inline SAPDBMem_SynchronizedRawAllocator& GetSubAllocator(int idx) const
   {
-      return *m_SubAllocators[1 + idx];
+      return *m_SubAllocators[idx];
   }
   
   /* data members */
@@ -386,12 +407,11 @@ private:
   static SAPDBMem_IRawAllocator*     m_OmsInstance;         //!< pointer to OMS allocator
   bool                               m_Monitoring;          //!< true, if monitoring is enabled
   bool                               m_askForClient;        //!< true, if acv can be used for subheap dispatching
-  int                                m_omsAllocatorIdx;     //!< index of oms allocator, (0 oltp, -1 livecache)
   SAPDB_ULong                        m_CountNew;            //!< counts calls of operator new
   SAPDB_ULong                        m_CountDelete;         //!< counts calls of oerator delete
   int                                m_SubAllocatorCount;   //!< number of sub allocators
   SAPDBMem_SynchronizedRawAllocator  m_firstAllocator;      //!< at least one allocator is present always
-  SAPDBMem_SynchronizedRawAllocator* m_SubAllocators[1 + MAX_SUB_HEAPS];
+  SAPDBMem_SynchronizedRawAllocator* m_SubAllocators[MAX_SUB_HEAPS];
 
   // Using a static reference would mean, that initialization function is called before main
   // This we have to prevent for the same reason we prevent static class instances
@@ -403,12 +423,12 @@ private:
 
 #include "liveCache/MemoryManagement/LVCMem_Wrapper.hpp"
 
-inline void* LVCMem_Allocator::AllocateImplementation(SAPDB_ULong count)
+inline void* LVCMem_Allocator::AllocateImplementation(SAPDB_ULong count,  bool isUsrRequest, bool ThrowBadAlloc)
 {
 #ifdef SAPDBMem_USE_SYSTEM_ALLOC
   void *p = malloc(count);
   if (!p) 
-    p = this->BadAllocHandling(0, count, false);
+    p = this->BadAllocHandling(0, count, false, ThrowBadAlloc);
   return p;
 #else
   const bool cBadAllocRequired = true;
@@ -422,7 +442,7 @@ inline void* LVCMem_Allocator::AllocateImplementation(SAPDB_ULong count)
   bool badAllocRequired = LVCMem_Wrapper::BadAllocRequired(pContext);
   if (badAllocRequired)
   {
-    this->BadAllocHandling(0, count, cBadAllocRequired);
+    this->BadAllocHandling(0, count, cBadAllocRequired, ThrowBadAlloc);
   }
 #endif
   p = this->GetSubAllocator(AllocatorId).Allocate(count);
@@ -444,18 +464,17 @@ inline void* LVCMem_Allocator::AllocateImplementation(SAPDB_ULong count)
   }
   if (0 == p)
   {
-    p = this->BadAllocHandling(AllocatorId, count, !cBadAllocRequired);
+    p = this->BadAllocHandling(AllocatorId, count, !cBadAllocRequired, ThrowBadAlloc);
   }
   SAPDB_ULong chunkSize = this->GetChunkSize(p);
-  const bool cIsUsrRequest = true;
-  LVCMem_Wrapper::MonitorAlloc (pContext, chunkSize, cIsUsrRequest);
+  LVCMem_Wrapper::MonitorAlloc (pContext, chunkSize, isUsrRequest);
   return p;
 #endif
 }
 
 /*--------------------------------------------------------------------------------*/
 
-inline void LVCMem_Allocator::DeallocateImplementation(void* p)
+inline void LVCMem_Allocator::DeallocateImplementation(void* p, bool isUsrRequest)
 {
 #ifdef SAPDBMem_USE_SYSTEM_ALLOC
     if (p) free(p);
@@ -466,8 +485,7 @@ inline void LVCMem_Allocator::DeallocateImplementation(void* p)
     }
     if (m_askForClient)
     {
-        const bool cIsUsrRequest = true;
-        LVCMem_Wrapper::MonitorDealloc (this->GetChunkSize(p), cIsUsrRequest);
+        LVCMem_Wrapper::MonitorDealloc (this->GetChunkSize(p), isUsrRequest);
     }
     SAPDBMem_SynchronizedRawAllocator::GetAllocator(p)->Deallocate(p);
 #endif
@@ -517,54 +535,19 @@ inline LVCMem_Allocator& LVCMem_Allocator::LVCAllocatorInstanceWithBarrier()  //
 
 inline void* LVCMem_Allocator::OmsAllocate(SAPDB_ULong count)
 {
-#ifdef SAPDBMem_USE_SYSTEM_ALLOC
-  void *p = malloc(count);
-  if (!p) 
-    p = this->BadAllocHandling(m_omsAllocatorIdx, count, false);
-  return p;
-#else
-  void* p;
-  const bool cBadAllocRequired = true;
-  void* pContext               = (m_askForClient) ? LVCMem_Wrapper::GetContext() : NULL;
-#if defined (OMSTST)
-    p               = (void*) 0;
-    bool badAllocRequired = LVCMem_Wrapper::BadAllocRequired(pContext);
-    if (badAllocRequired)
-    {
-        this->BadAllocHandling(m_omsAllocatorIdx, count, cBadAllocRequired);
-    }
-#endif
-    p = this->GetSubAllocator(m_omsAllocatorIdx).Allocate(count);
-    if (0 == p)
-    {
-        p = this->BadAllocHandling(m_omsAllocatorIdx, count, !cBadAllocRequired);
-    }
-    SAPDB_ULong chunkSize = this->GetChunkSize(p);
-    LVCMem_Wrapper::MonitorAlloc (pContext, chunkSize, false);
-    return p;
-#endif
+    const bool cIsUserRequest = true;
+    return AllocateImplementation (count, !cIsUserRequest);
 }
 
 /*--------------------------------------------------------------------------------*/
 
 inline void LVCMem_Allocator::OmsDeallocate(void * p)
 {
-#ifdef SAPDBMem_USE_SYSTEM_ALLOC
-    if (p) free(p);
-#else
-    if (0 == p)
-    {
-        return;
-    }
-    if (m_askForClient)
-    {
-        LVCMem_Wrapper::MonitorDealloc (this->GetChunkSize(p), false);
-    }
-    SAPDBMem_SynchronizedRawAllocator::GetAllocator(p)->Deallocate(p);
-#endif
+    const bool cIsUsrRequest = true;
+    DeallocateImplementation (p, !cIsUsrRequest);
 }
 
-/*--------------------------------------------------------------------------------*/
+/*-----------------------------------------------------------------*/
 
 inline void LVCMem_Allocator::SetMonitoring(bool enable)
 {
