@@ -162,6 +162,28 @@ public :
 
   virtual void* Allocate(SAPDB_ULong BlockCount);
 
+   /*!
+      @brief          Allocates contiguous memory for 'count' blocks of
+                      memory.
+                      An implementation grants that a pointer returned will be an
+                      integral multiple of the alignment size. 
+                      The memory is not initialised.
+      @param          BlockCount [in] The number of blocks to be allocated. This argument must be greater zero.
+      @param          messageList [out] filled if memory not available   
+      @return         void*
+                      A pointer to the allocated raw memory block of &lt;BlockCount> 
+                      blocks. If exception handling is disabled, a NULL pointer will
+                      be returned in case of insufficient memory.
+      @exception      From 'SAPDBMem_IBlockAllocator' derived classes may 
+                      throw a 'SAPDBMem_BadAllocException' if the allocation fails.
+
+    */
+
+   virtual void * Allocate(SAPDB_ULong BlockCount, SAPDBErr_MessageList &messageList)
+   {
+       return Allocate(BlockCount);
+   }
+
   /*!
      @brief    Frees the memory.
 
@@ -211,6 +233,8 @@ private :
   SAPDB_ULong                   m_defaultBlockCount;   //!< default block size
   SAPDB_ULong                   m_limit;               //!< upper heap limit
   SAPDB_ULong                   m_allocated;           //!< number of allocated blocks
+  SAPDB_ULong                   m_maxAllocated;        //!< maximal number of allocated blocks
+  SAPDB_ULong                   m_controlled;          //!< number of controlled blocks
   SAPDB_ULong                   m_CountAlloc;          //!< number of calls of Allocate
   SAPDB_ULong                   m_CountDealloc;        //!< number of calls of Deallocate
   SAPDB_ULong                   m_CountBaseAlloc;      //!< number of calls of Allocate to base allocator
