@@ -11,18 +11,18 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
- 
+    Copyright (c) 2000-2005 SAP AG
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 2
     of the License, or (at your option) any later version.
- 
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
- 
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -40,7 +40,7 @@
  *===========================================================================*/
 
 /*===========================================================================*
- *     MD5: '\xbe\x52\xed\x04\x45\x70\x6a\xf7\x78\x6d\x1c\x85\x64\x23\x6e\xeb'
+ *     MD5: '\x02\x4c\xae\xa2\xa0\x6e\x3a\x5c\x4a\xc2\xa0\x38\xdf\xf6\xfe\x35'
  *===========================================================================*/
 
 
@@ -54,6 +54,7 @@
 #include "vak001.h"
 #include "ggg07.h"
 #include "gak70.h"
+#include "gak71.h"
 
 
 /*===========================================================================*
@@ -87,7 +88,7 @@ externPascal void a70_strategy_search (
     tak_all_command_glob  VAR_VALUE_REF  acv,
     tak_dml_info          VAR_VALUE_REF  dmli,
     tgg00_FileId          VAR_VALUE_REF  rtree,
-    tak70_strat_rec       VAR_VALUE_REF  strat_rec);
+    tak71_strat_rec       VAR_VALUE_REF  strat_rec);
 
 /* Don't edit this file by hand, it is generated by ptocProto.py */
 
@@ -96,7 +97,7 @@ externPascal void a70strategy (
     tak_dml_info          VAR_VALUE_REF  dmli,
     tgg07_StrategyInfo    VAR_VALUE_REF  gg_strategy,
     tsp00_Int2            VAR_VALUE_REF  StratInfo_len,
-    tak70_page_eval_rec   VAR_VALUE_REF  eval_info,
+    tak71_page_eval_rec   VAR_VALUE_REF  eval_info,
     tak00_access_configuration                 config);
 
 /* Don't edit this file by hand, it is generated by ptocProto.py */
@@ -107,7 +108,7 @@ externPascal void a70L1_strat_search (
     tak70_strategy_record  VAR_VALUE_REF  access_info,
     tgg07_StrategyInfo    VAR_VALUE_REF  gg_strategy,
     tsp00_Int2            VAR_VALUE_REF  StratInfo_len,
-    tak70_page_eval_rec   VAR_VALUE_REF  eval_info,
+    tak71_page_eval_rec   VAR_VALUE_REF  eval_info,
     tak00_ord_fields      VAR_VALUE_REF  order_fields,
     tsp00_Int4            VAR_VALUE_REF  L1_pageIO,
     tsp00_Longreal        VAR_VALUE_REF  L1_stratvalue);
@@ -122,7 +123,7 @@ externPascal void a70L2L3_strat_search (
     tgg07_StrategyInfo    VAR_VALUE_REF  gg_strategy,
     tsp00_Int2            VAR_VALUE_REF  StratInfo_len,
     tsp00_Int4                           morestratpos,
-    tak70_page_eval_rec   VAR_VALUE_REF  eval_info,
+    tak71_page_eval_rec   VAR_VALUE_REF  eval_info,
     tak70_term            VAR_VALUE_REF  L1_terms,
     tak00_ord_fields      VAR_VALUE_REF  order_fields,
     tsp00_Int4                           L1_pageIO,
