@@ -326,6 +326,7 @@ public:
     tsp00_Int4      ociAllObjCntOnSubRoot_bd900; /*!< # of all objects */ /*PTS 1111390 AK 14/08/2001 */
     
 public:
+    friend SAPDB_OStream& operator<<(SAPDB_OStream& os, const cbd900_ObjChainInfo& chaininfo);
     void IncrementAllObjCnt();
     void DecrementAllObjCnt();
     tsp00_Int4 GetAllObjCnt() const;
@@ -408,7 +409,6 @@ public:
 #   endif
 
 public: 
-
   cbd900_ObjFileInfo ();        //!< ctor */
   /*!
         ctor
@@ -486,6 +486,9 @@ public:
         access one chain info by index
   */
   cbd900_ObjChainInfo & operator[] (tsp00_Int4 i) { return ofiChain_bd900[i]; };
+
+  friend SAPDB_OStream& operator<< (SAPDB_OStream& os, const cbd900_ObjFileInfo& fileinfo);
+
   /*!
         copy object file info 
         @param right [in] source
@@ -666,10 +669,11 @@ class  cbd900_ContObjFileInfo
 public: 
     tsp00_Int4          cfiNumContFiles_bd900;    /*!< number of continous files for container */
 
-private:
 #   ifdef BIT64
     tsp00_Int4          cfiFiller_bd900;		 /*!< filler because of alignment       */
 #   endif
+
+private:
 	/*!
 		vector of object file information of each continous container 
 	*/
@@ -683,13 +687,14 @@ private:
         check size of structure
         note that the dump routines in vxt08 rely on the size of this structure 
     */
-#  ifdef BIT64
+#   ifdef BIT64
     CHECK_MAPPABLE_CLASS_GIVEN_SIZE_SP00 (cbd900_ContObjFileInfo, 8 + MAX_NUM_CONT_OBJ_FILES_BD900 * sizeof(cbd900_ObjFileInfo))
-#  else
+#   else
     CHECK_MAPPABLE_CLASS_GIVEN_SIZE_SP00 (cbd900_ContObjFileInfo, 4 + MAX_NUM_CONT_OBJ_FILES_BD900 * sizeof(cbd900_ObjFileInfo))
-#  endif
+#   endif
     
 public:
+    friend SAPDB_OStream& operator<<(SAPDB_OStream& os, cbd900_ObjChainInfo& chaininfo);
   /*!
         copy continous object file info 
         @param right [in] source
@@ -730,6 +735,18 @@ public:
                            tgg00_FileId    &ContObjFileId);
 };
 
+inline SAPDB_OStream& operator<<(SAPDB_OStream& os, cbd900_ContObjFileInfo& continfo)
+{
+    os << NewLine << " #ContFiles:" << continfo.cfiNumContFiles_bd900;
+#   ifdef BIT64
+    os << " Filler:" << continfo.cfiFiller_bd900;
+#   endif
+    for ( int ix=1; ix <= MAX_NUM_CONT_OBJ_FILES_BD900; ix++ ) {
+        os << NewLine << " ***contfile:" << ix << "*** " << continfo[ix];
+    }
+    return os;
+};
+
 /*!
     continous object file directory
 */
@@ -917,6 +934,17 @@ tbd900_ObjFrame::bd900SetToReservedFrame (tsp00_Int4         ObjFrameLen,
 /*---------------------------------------------------------------------------*/
 /* METHODS of cbd900_ObjChainInfo                                            */
 /*---------------------------------------------------------------------------*/
+inline SAPDB_OStream& operator<<(SAPDB_OStream& os, const cbd900_ObjChainInfo& chaininfo)
+{
+    os << " SubRoot:" << chaininfo.ociSubRoot_bd900
+        << " #FreePage:" << chaininfo.ociFreePageCnt_bd900
+        << " #AllObjs:" << chaininfo.ociAllObjCnt_bd900
+        << " ActGC:" << chaininfo.ociCurrActivGC_bd900
+        << " Filler0:" << chaininfo.ociFiller0_bd900
+        << " Filler1:" << chaininfo.ociFiller1_bd900
+        << " #AllObjOnSubRoot:" << chaininfo.ociAllObjCntOnSubRoot_bd900;
+    return os;
+};
 
 inline  void
 cbd900_ObjChainInfo::bd900DumpChainInfo (tsp00_Int4          BufferSize,
@@ -968,7 +996,8 @@ cbd900_ObjChainInfo::ModifyAllObjCnt(tsp00_Int4 diff, bool bIncrement)
 inline void 
 cbd900_ObjChainInfo::IncrementAllObjCnt() 
 {
-    ModifyAllObjCnt(+1, true);
+    //ModifyAllObjCnt(+1, true);
+    ++ociAllObjCnt_bd900;
 };
 
 /*---------------------------------------------------------------------------*/
@@ -976,7 +1005,8 @@ cbd900_ObjChainInfo::IncrementAllObjCnt()
 inline void 
 cbd900_ObjChainInfo::DecrementAllObjCnt() 
 {
-    ModifyAllObjCnt(-1, true);
+    //ModifyAllObjCnt(-1, true);
+    --ociAllObjCnt_bd900;
 };
 
 /*---------------------------------------------------------------------------*/
@@ -984,7 +1014,7 @@ cbd900_ObjChainInfo::DecrementAllObjCnt()
 inline tsp00_Int4 
 cbd900_ObjChainInfo::GetAllObjCnt() const 
 { 
-    RTESys_ReadMemoryBarrier();
+    //RTESys_ReadMemoryBarrier();
     return ociAllObjCnt_bd900; 
 };
 
@@ -994,6 +1024,7 @@ inline void
 cbd900_ObjChainInfo::SetAllObjCnt(tsp00_Int4 num) 
 {
     ModifyAllObjCnt(num, false);
+    ociAllObjCnt_bd900 = num;
 };
 
 /*---------------------------------------------------------------------------*/
