@@ -10,7 +10,7 @@
 /*
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
     ========== licence end
 
 
+
 */
 #ifndef GBD930_H
 #define GBD930_H
@@ -77,6 +78,7 @@
 /* Timeinterval which is used to control starting GCs via Timeout process   */ 
 #define TIMEOUT_START_TIME_INTERVAL     30
 #define TIMEOUT_START_TIME_INTERVAL_RED  3
+#define TIMEOUT_UPD_MINTRANS_INTERVAL    3
 
 /*===========================================================================*
  *  MACROS                                                                   *
@@ -254,6 +256,7 @@ class  cbd930_GarbCollController : public GC_IGCController
   
 private://members
   SAPDB_UInt8                  gccLastTimeGCsStarted;
+  SAPDB_UInt8                  gccLastUpdMinTrans;                //
   tsp00_Int4                   gccNumGC_bd930;                    // # of all garbage collectors (GC) 
   tsp00_Int4                   gccNumGCUsed_bd930;                // # of used GCs  
   tsp00_Int4                   gccNumGCUsedToReleasePages_bd930;  // # of GCs used to remove empty pages or deleted files
@@ -369,6 +372,7 @@ cbd930_GarbCollController::bd930Init (cbd900_ObjFileDir     &ObjFileDir,
                                       cbd900_ContObjFileDir &ContObjFileDir)
 {
   gccLastTimeGCsStarted            = 0;
+  gccLastUpdMinTrans               = 0;
   gccNumGC_bd930                   = 0;
   gccNumGC_bd930                   = 0;
   gccNumGCUsed_bd930               = 0;                    
