@@ -57,57 +57,55 @@
  *  DEFINES                                                                  *
  *===========================================================================*/
 
-#ifdef NO_INLINES
-# define _INLINE
-#else
-# define _INLINE	inline
-#endif
 
 /*===========================================================================*
  *  FUNCTION PROTOTYPES                                                      *
  *===========================================================================*/
 
-externCpp void 
-bd402NextFromInvTree (cbd300_InvCurrent   &InvCurrent,
-                      bool                 bIncludeStartSecKey,
-                      tsp00_KeyPtr         pSecKey,
-                      tsp00_Int2          &SecKeyLen);
+externCpp void
+bd402NextFromInvTree (
+    cbd300_InvCurrent   &InvCurrent,
+    bool                 bIncludeStartSecKey,
+    tsp00_KeyPtr         pSecKey,
+    tsp00_Int2          &SecKeyLen);
 
 /*---------------------------------------------------------------------------*/
 
-externCpp void 
-bd402SearchIndexForQualifiedRecords (cbd300_InvCurrent        &InvCurrent,
-									 tgg00_FileId             &PrimFileId,
-									 tsp00_KeyPtr              pStartSecKey,
-									 tgg00_KeyLen             &StartSecKeyLen,
-									 tsp00_KeyPtr              pStopSecKey,
-									 tsp00_Int4                StopSecKeyLen,
-									 tsp00_KeyPtr              pStartPrimKey,
-									 tsp00_Int4                StartPrimKeyLen,
-									 tsp00_KeyPtr              pStopPrimKey,
-									 tsp00_Int4                StopPrimKeyLen,
-									 tsp00_KeyPtr              pFirstPrimKey,
-									 tsp00_Int2               &FirstPrimKeyLen,
-									 tsp00_Int4                RecBufSize,
-									 tsp00_MoveObjPtr          pRecBuf,
-									 tgg00_SelectFieldsParam  &SelectParam,
-									 tgg00_StackDesc          &StackDesc,
-									 tgg00_LockReqMode        &GrantedLock,
-									 bool                     &bPrimaryFileErr);
+externCpp void
+bd402SearchIndexForQualifiedRecords (
+    cbd300_InvCurrent&          InvCurrent,
+    tgg00_FileId&               PrimFileId,
+    tsp00_KeyPtr                pCurrSecKey,
+    tgg00_KeyLen&               currSecKeyLen,
+    const tsp00_KeyPtr          pStopSecKey,
+    const tsp00_Int4            stopSecKeyLen,
+    const tsp00_KeyPtr          pFrozenStartPrimKey,
+    const tsp00_Int4            frozenStartPrimKeyLen,
+    const tsp00_KeyPtr          pStopPrimKey,
+    const tsp00_Int4            stopPrimKeyLen,
+    tsp00_KeyPtr                pCurrPrimKey,
+    tgg00_KeyLen&               currPrimKeyLen,
+    const tsp00_Int4            RecBufSize,
+    tsp00_MoveObjPtr            pRecBuf,
+    tgg00_SelectFieldsParam&    SelectParam,
+    tgg00_StackDesc&            StackDesc,
+    tgg00_LockReqMode&          GrantedLock,
+    bool&                       bPrimaryFileErr);
 
 
 /*---------------------------------------------------------------------------*/
 
-externCpp void 
-bd402SearchResultFileForQualifiedRecords (cbd300_InvCurrent        &InvCurrent,
-										  tgg00_FileId             &PrimFileId,
-										  tsp00_KeyPtr              pStartKey,
-										  tgg00_KeyLen             &StartKeyLen,
-										  tsp00_Int4                RecBufSize,
-										  tsp00_MoveObjPtr          pRecBuf,
-										  tgg00_SelectFieldsParam  &SelectParam,
-										  tgg00_StackDesc          &StackDesc,
-										  tgg00_LockReqMode        &GrantedLock);
+externCpp void
+bd402SearchResultFileForQualifiedRecords (
+    cbd300_InvCurrent        &InvCurrent,
+    tgg00_FileId             &PrimFileId,
+    tsp00_KeyPtr              pStartKey,
+    tgg00_KeyLen             &StartKeyLen,
+    tsp00_Int4                RecBufSize,
+    tsp00_MoveObjPtr          pRecBuf,
+    tgg00_SelectFieldsParam  &SelectParam,
+    tgg00_StackDesc          &StackDesc,
+    tgg00_LockReqMode        &GrantedLock);
 
 /*---------------------------------------------------------------------------*/
 
