@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
  
 /*===========================================================================*
@@ -61,6 +62,7 @@
 #include "hbd30.h"
 #include "hbd22.h"    // OMS Key Management 
 #include "hbd90.h" 
+#include "hbd911.h" 
 #include "hbd92.h"
 #include "hbd95.h"
 #include "heo56.h"    // vreschedule_msec
@@ -349,8 +351,8 @@ bd04CreateKeyIterator (tgg00_TransContext &Trans,
             REINTERPRET_CAST( tsp00_BytePtr, &KeyTrace ), sizeof (KeyTrace) );
     }
 	
-	BD04_CHECK_FILE_SYSTEM   (Trans, ObjFileId, b04CreateKeyIter);
-  BD04_CHECK_OBJ_FILE_TYPE (Trans, ObjFileId, b04CreateKeyIter);
+    BD04_CHECK_FILE_SYSTEM   (Trans, ObjFileId, b04CreateKeyIter);
+    BD04_CHECK_OBJ_FILE_TYPE (Trans, ObjFileId, b04CreateKeyIter);
  	
     /* create correct file id */
 	const tgg00_ObjFileNo ObjFileNo  = ObjFileId.fileObjFileNo_gg00();
@@ -377,6 +379,11 @@ bd04CreateKeyIterator (tgg00_TransContext &Trans,
 	
 	if (TrError == e_ok)
 	{
+		// PTS 1134645
+		cbd911RecreateIndexLock lock(Trans);   
+ 		if (ObjFileInfo.bd900RecreateIndex()) 
+ 			lock.Lock( false /*not Exclusive*/ );
+ 
 		/* create the key Iterator on the heap */
 		SAPDBMem_IRawAllocator &RawAllocator = *(REINTERPRET_CAST(SAPDBMem_IRawAllocator*, Trans.trAllocator_gg00));
 
@@ -1117,12 +1124,19 @@ bd04NewObjKey (tgg00_TransContext  &Trans,
     tsp00_Int4       StartTime   = 0;
     tsp00_Int4       WaitingTime = Trans.trObjReqTimeout_gg00 * 1000; //msec
     bool             bTryAgain   = false;
- 
+    bool             bReCreateAddIndex = false;  // PTS 1134645
+
     BD04_CHECK_FILE_SYSTEM   (Trans, ObjFileId, b04newhash); 
     BD04_CHECK_OBJ_FILE_TYPE (Trans, ObjFileId, b04newhash); 
     BD04_CHECK_OID           (Trans, ObjFileId, b04newhash, OId);
     
     if (0 == WaitingTime) WaitingTime = MIN_RETRY_TIME;
+
+    // PTS 1134645
+ 	cbd900_ObjFileInfo    &ObjFileInfo = bd90ObjFileDir [ObjFileId.fileObjFileNo_gg00()];
+ 	cbd911RecreateIndexLock lock(Trans);   
+ 	if (ObjFileInfo.bd900RecreateIndex()) 
+ 		lock.Lock( false /*not Exclusive*/ );
  
     do
     {
@@ -1155,10 +1169,19 @@ bd04NewObjKey (tgg00_TransContext  &Trans,
 						Trans.trError_gg00 = e_cancelled;
                 }
             }
+            else if ((e_ok == Trans.trError_gg00) && !bTryAgain)
+                bReCreateAddIndex = true;
         }
     }
     while (bTryAgain);
     
+    // PTS 1134645
+    if ( (ObjFileInfo.bd900RecreateIndex()) && bReCreateAddIndex )
+    {
+        tgg92_KernelOid    DummyOId;
+        bd22InsertOIdReCreate (Trans, ObjFileId.fileObjFileNo_gg00(), KeyLen, pKey, ReUsedOId, DummyOId);
+    }
+ 
 	/* write vtrace entry                                    CRS 1109559 AK 07/03/2001 */
 	/* write vtrace entry in case an unexpected error occurs PTS 1112190 AK 18/10/2001 */
 	if (g01vtrace.vtrOmsNew_gg00 || ((Trans.trError_gg00 != e_ok) && (Trans.trError_gg00 != e_duplicate_hash_key)))
@@ -1772,7 +1795,8 @@ bd04_MapPhysicalOntoLogicalError (tgg00_TransContext &Trans)
             (e_too_old_oid           == TrError) ||
             /*(e_object_dirty          == TrError) ||  PTS 1119647 && PTS 1123209 */ 
             (e_container_dropped     == TrError) || /* PTS 1119647 */ 
-            (e_consview_cancelled    == TrError) || /* PTS 1120151 */ 
+            /*(e_consview_cancelled    == TrError) ||*/ /* PTS 1120151 */ /* PTS 1134029 */
+            (e_obj_history_not_found == TrError) || /* PTS 1134029 */
             (e_unknown_consist_vers  == TrError) || /* PTS 1120151 FF 2003-JAN-20 */ 
             (e_illegal_object_pos    == TrError))
         {
@@ -1787,15 +1811,17 @@ bd04_MapPhysicalOntoLogicalError (tgg00_TransContext &Trans)
                 {
                     Kernel_VTrace() << "b04_Map Error:" << TrError << " onto e_obj_history_not_found";
                 }
-                Trans.trError_gg00 = e_obj_history_not_found;
+                Trans.trError_gg00 = e_consview_cancelled;  /* PTS 1134029 */
             }
             else 
             {
+                if (e_obj_history_not_found != TrError) /* PTS 1134029 */
+                    Trans.trError_gg00 = e_object_not_found;
+
                 if (g01vtrace.vtrOmsUpd_gg00)
                 {
                     Kernel_VTrace() << "b04_Map Error:" << TrError << " onto e_object_not_found";
                 }
-                Trans.trError_gg00 = e_object_not_found;
             }
         }
         else
