@@ -781,6 +781,7 @@ b13new_node(
         {
             if( ! fileId.fileType_gg00().includes( ftsShared_egg00 )){
                 ++trans.trTempCount_gg00;
+                ++trans.trRteCommPtr_gg00->temp_page_cnt;
             }
         }
         else
@@ -2079,8 +2080,8 @@ bd13_BadDataPageHandling(
             trans.trError_gg00 = e_corrupted_datapage_from_io;
 
             Data_Exception errMsg( __CONTEXT__, DATA_ERR_CORRUPTED_PAGE,
-                                   SAPDB_ToString( pageNo, _T_d ), tfnText,
-                                   SAPDB_ToString( fileId.fileRoot_gg00(), _T_d ));
+                                   SAPDB_ToString( pageNo, _T_d ), 
+                                   SAPDB_ToString( fileId.fileRoot_gg00(), _T_d ), tfnText );
             RTE_Message( errMsg );
         }
         break;
@@ -2091,8 +2092,8 @@ bd13_BadDataPageHandling(
             trans.trError_gg00 = e_bad_datapage;
 
             Data_Exception errMsg( __CONTEXT__, DATA_ERR_BAD_PAGE,
-                                   SAPDB_ToString( pageNo, _T_d ), tfnText,
-                                   SAPDB_ToString( fileId.fileRoot_gg00(), _T_d ));
+                                   SAPDB_ToString( pageNo, _T_d ),
+                                   SAPDB_ToString( fileId.fileRoot_gg00(), _T_d ), tfnText );
             RTE_Message( errMsg );
         }
     }
@@ -2427,6 +2428,7 @@ bd13_FreeNode (
 
             if( ! fileId.fileType_gg00().includes( ftsShared_egg00 )){
                 --trans.trTempCount_gg00;
+                --trans.trRteCommPtr_gg00->temp_page_cnt;
             }
         }
         break;
