@@ -12,7 +12,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -46,11 +47,13 @@
 #include "hbd01.h"
 #include "hbd03.h"
 #include "hbd17.h" 
+#include "hbd911.h"
 #include "hbd92.h"
 #include "hgg01_1.h"
 #include "hgg01_3.h"
 #include "SAPDB/SAPDBCommon/SAPDB_RangeCode.hpp" // Kernel_move_and_fill
 #include "KernelCommon/Kernel_IAdminInfo.hpp"
+#include "RunTime/System/RTESys_MemoryBarrier.h" 
 #include "hgg10.h"
 
 #include "Trace/Trace_Entry.hpp"
@@ -100,6 +103,8 @@ extern cbd900_ObjFileDir  bd90ObjFileDir;
  *  LOCAL VARIABLES                                                          *
  *===========================================================================*/
 
+static const bool bExclusive = true;
+
 /*===========================================================================*
  *  LOCAL FUNCTIONS                                                          *
  *===========================================================================*/
@@ -135,25 +140,26 @@ bd22_GetOId (tgg00_TransContext   &Trans,
 	}
 };
 
-/*-----------------------------------------------------------------------------------*/
-inline static tsp00_Int4
-bd22_ObjKeyFileIndex (const	tsp00_Int4      KeyLen,
-					  void                 *pKey,
-					  const tsp00_Uint4     NumHashValues)
-{
-	/* this function hashes a key onto an integer value h with 0<= h <  NumHashValues */
-	
-	tsp00_Int4 sum = 0;
-	for (tsp00_Int4 i=0; i<KeyLen; ++i)
-		sum += *((char *) pKey + i);
-	
-	return (sum%NumHashValues);
-}
-
 /*===========================================================================*
  *  GLOBAL FUNCTIONS (CODE)                                                  *
  *===========================================================================*/
 
+externCpp tsp00_Int4
+bd22ObjKeyFileIndex (const	tsp00_Int4      KeyLen,
+                     void                 *pKey,
+                     const tsp00_Uint4     NumHashValues)
+{
+    /* this function hashes a key onto an integer value h with 0<= h <  NumHashValues */
+
+    tsp00_Int4 sum = 0;
+    for (tsp00_Int4 i=0; i<KeyLen; ++i)
+        sum += *((char *) pKey + i);
+
+    return (sum%NumHashValues);
+}
+
+/*-----------------------------------------------------------------------------------*/
+
 externCpp void 
 bd22CreateObjKeyFiles (tgg00_TransContext &Trans,
                        tgg00_ObjFileNo     ObjFileNo,
@@ -262,9 +268,14 @@ bd22GetOId (tgg00_TransContext  &Trans,
     ROUTINE_DBG_MEO00 ("bd22GetOid");
 	 
 	cbd900_ObjFileInfo    &ObjFileInfo    = bd90ObjFileDir [ObjFileNo];
+
+    cbd911RecreateIndexLock lock(Trans);   
+    if (ObjFileInfo.bd900RecreateIndex()) 
+        lock.Lock( !bExclusive );
+
 	const tsp00_Int4       NumObjKeyFiles = ObjFileInfo.GetKeyPartitionCount();
 	CHECK_NUM_KEY_FILES (NumObjKeyFiles); //PTS 1112190 18/10/2001
-	tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0:bd22_ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
+	tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0:bd22ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
 	cbd900_ObjKeyFileId  ObjKeyFileId (ObjFileInfo, ObjFileNo, ObjKeyFileIndex);
 	bd22_GetOId (Trans, ObjKeyFileId , KeyLen, pKey, Oid);		
 }
@@ -286,9 +297,14 @@ bd22InsertOId (tgg00_TransContext &Trans,
     if ( TrError != e_ok) return;
 
 	cbd900_ObjFileInfo    &ObjFileInfo = bd90ObjFileDir [ObjFileNo];
-	const tsp00_Int4       NumObjKeyFiles = ObjFileInfo.GetKeyPartitionCount();
+
+    cbd911RecreateIndexLock lock(Trans);   
+    if (ObjFileInfo.bd900RecreateIndex()) 
+        lock.Lock( !bExclusive );
+
+    const tsp00_Int4       NumObjKeyFiles = ObjFileInfo.GetKeyPartitionCount();
 	CHECK_NUM_KEY_FILES (NumObjKeyFiles); //PTS 1112190 18/10/2001
-	tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0 :bd22_ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
+	tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0 :bd22ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
     cbd900_ObjKeyFileId  ObjKeyFileId (ObjFileInfo, ObjFileNo, ObjKeyFileIndex);
 
     tsp00_Int4 FoundOIdLen;
@@ -302,6 +318,107 @@ bd22InsertOId (tgg00_TransContext &Trans,
 	case e_duplicate_key   : TrError = e_duplicate_hash_key; break;
     case e_inv_not_found   : TrError = e_hash_not_found;     break;
 	}
+         // PTS 1134645
+    if ( ObjFileInfo.bd900RecreateIndex() && ( e_ok == TrError ))
+    {
+        cbd900_ObjKeyFileId& ObjKeyFileId = bd911GetObjKeyFileId(ObjKeyFileIndex);
+        bd03OmsAddInv (Trans, ObjKeyFileId,
+            tsp00_BytePtr (pKey), KeyLen, tsp00_BytePtr(&OId), sizeof(OId),
+            sizeof(FoundOId), tsp00_BytePtr(&FoundOId), FoundOIdLen);
+        if (e_ok != TrError)
+        {			
+            Kernel_OpError( csp3_bd_msg, csp3_n_obj ) 
+                << "bd22InsertOId for RecreateIndex - error:" << TrError
+                << " FileNo:" << ObjFileNo
+                << " OId=" 
+                << OId.gg92GetPno() << "." 
+                << OId.gg92GetPos() << " (vers " 
+                << OId.gg92GetFrameVers() << " )";
+            bd911KeyToConsole(pKey, KeyLen);
+            RTESys_ReadMemoryBarrier();
+            if ( ObjFileInfo.bd900RecreateIndexError() == e_ok )
+                ObjFileInfo.bd900RecreateIndexError() = TrError;
+            RTESys_WriteMemoryBarrier();
+            TrError = e_ok;
+        }
+    }
+}
+ /*-----------------------------------------------------------------------------------*/
+ 
+externCpp void 
+bd22InsertOIdReCreate (tgg00_TransContext &Trans,
+                       tgg00_ObjFileNo     ObjFileNo,
+                       tsp00_Int4          KeyLen,
+                       void               *pKey,
+                       tgg92_KernelOid     OId,
+                       tgg92_KernelOid    &FoundOId)
+{
+    ROUTINE_DBG_MEO00 ("bd22InsertOIdReCreate");
+
+    tgg00_BasisError &TrError   = Trans.trError_gg00;
+
+    if ( TrError != e_ok) return;
+
+    cbd900_ObjFileInfo    &ObjFileInfo = bd90ObjFileDir [ObjFileNo];
+
+    const tsp00_Int4       NumObjKeyFiles = ObjFileInfo.GetKeyPartitionCount();
+    CHECK_NUM_KEY_FILES (NumObjKeyFiles); //PTS 1112190 18/10/2001
+    tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0 :bd22ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
+    cbd900_ObjKeyFileId& ObjKeyFileId = bd911GetObjKeyFileId(ObjKeyFileIndex);
+
+    tsp00_Int4 FoundOIdLen;
+    bd03OmsAddInv (Trans, ObjKeyFileId,
+        tsp00_BytePtr (pKey), KeyLen, tsp00_BytePtr(&OId), sizeof(OId),
+        sizeof(FoundOId), tsp00_BytePtr(&FoundOId), FoundOIdLen);
+
+    switch (TrError)
+    {
+    case e_ok:
+        break;
+    case e_duplicate_invkey:
+    case e_duplicate_key   : 
+        if ( OId.gg92IsEqIgnoreFrameVers(FoundOId))
+            TrError = e_ok; 
+        else
+        {
+            Kernel_OpError( csp3_bd_msg, csp3_n_obj ) 
+                << "bd22InsertOId for RecreateIndex - error:" << TrError
+                << " FileNo:" << ObjFileNo
+                << " OId=" 
+                << OId.gg92GetPno() << "." 
+                << OId.gg92GetPos() << " (vers " 
+                << OId.gg92GetFrameVers() << " )"
+                << " and OId=" 
+                << FoundOId.gg92GetPno() << "." 
+                << FoundOId.gg92GetPos() << " (vers " 
+                << FoundOId.gg92GetFrameVers() << " )"
+                << " have same key";
+            bd911KeyToConsole(pKey, KeyLen);
+            RTESys_ReadMemoryBarrier();
+            if ( ObjFileInfo.bd900RecreateIndexError() == e_ok )
+                ObjFileInfo.bd900RecreateIndexError() = TrError;
+            RTESys_WriteMemoryBarrier();
+            TrError = e_ok;
+        }
+        break;
+    default:
+        {
+            Kernel_OpError( csp3_bd_msg, csp3_n_obj ) 
+                << "bd22InsertOId for RecreateIndex - error:" << TrError
+                << " FileNo:" << ObjFileNo
+                << " OId=" 
+                << OId.gg92GetPno() << "." 
+                << OId.gg92GetPos() << " (vers " 
+                << OId.gg92GetFrameVers() << " )";
+            bd911KeyToConsole(pKey, KeyLen);
+            RTESys_ReadMemoryBarrier();
+            if ( ObjFileInfo.bd900RecreateIndexError() == e_ok )
+                ObjFileInfo.bd900RecreateIndexError() = TrError;
+            RTESys_WriteMemoryBarrier();
+            if ( ObjFileInfo.bd900RecreateIndex() ) 
+                TrError = e_ok;
+        }
+    }
 }
 
 /*-----------------------------------------------------------------------------------*/
@@ -321,7 +438,7 @@ bd22RemoveOid (tgg00_TransContext &Trans,
     cbd900_ObjFileInfo    &ObjFileInfo    = bd90ObjFileDir [ObjFileNo];
     const tsp00_Int4       NumObjKeyFiles = ObjFileInfo.GetKeyPartitionCount();
     CHECK_NUM_KEY_FILES (NumObjKeyFiles); //PTS 1112190 18/10/2001
-    tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0:bd22_ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
+    tsp00_Int4 ObjKeyFileIndex = (NumObjKeyFiles == 1 ? 0:bd22ObjKeyFileIndex (KeyLen, pKey, NumObjKeyFiles)); 
     cbd900_ObjKeyFileId  ObjKeyFileId (ObjFileInfo, ObjFileNo, ObjKeyFileIndex);
 
     tsp00_Int4 OidOfKeyLen;
@@ -369,6 +486,42 @@ bd22RemoveOid (tgg00_TransContext &Trans,
         Oid.gg92SetNil();          
         break;
 	}
+
+        // PTS 1134645
+    if ( ObjFileInfo.bd900RecreateIndex() && ( e_ok == TrError ))
+    {
+        cbd900_ObjKeyFileId& ObjKeyFileId = bd911GetObjKeyFileId(ObjKeyFileIndex);
+        bd03OmsDelInv (Trans, ObjKeyFileId,             
+            tsp00_BytePtr (pKey), KeyLen, tsp00_BytePtr(&Oid), sizeof(Oid),
+            sizeof(OidOfKey), tsp00_BytePtr(&OidOfKey), OidPrefixToCompareLen, OidOfKeyLen );
+        switch (TrError)
+        {
+        case e_ok                :  break;
+        case e_inv_list_not_found:
+        case e_key_not_found     :  
+            TrError = e_ok; 
+            break;
+        case e_inv_not_found     :  
+            TrError = e_ok;     
+            break;
+        default:
+            {
+                Kernel_OpError( csp3_bd_msg, csp3_n_obj ) 
+                    << "bd22RemoveOid for RecreateIndex - error:" << TrError
+                    << " FileNo:" << ObjFileNo
+                    << " Oid=" 
+                    << Oid.gg92GetPno() << "." 
+                    << Oid.gg92GetPos() << " (vers " 
+                    << Oid.gg92GetFrameVers() << " )";
+                bd911KeyToConsole(pKey, KeyLen);
+                RTESys_ReadMemoryBarrier();
+                if ( ObjFileInfo.bd900RecreateIndexError() == e_ok )
+                    ObjFileInfo.bd900RecreateIndexError() = TrError;
+                RTESys_WriteMemoryBarrier();
+                TrError = e_ok;
+            }
+        }
+    }
 }
 
 /*===========================================================================*
