@@ -64,6 +64,7 @@
 #include "hbd06.h"   // PASCAL: Error_text_handling
 
 #include "Trace/Trace_Entry.hpp"
+#include "KernelCommon/Kernel_Trace.hpp"
 #include "KernelCommon/Kernel_IAdminInfo.hpp"
 
 #if COMPILEMODE_MEO00 >= SLOW_MEO00
@@ -164,7 +165,7 @@ cbd300_InvCurrentBasis::bd300LockTree ()
 
 /*---------------------------------------------------------------------------*/
 
-void
+bool
 cbd300_InvCurrentBasis::bd300LockTreeExclusive()
 {
     ROUTINE_DBG_MEO00 ("bd300LockTreeExclusive");
@@ -176,6 +177,7 @@ cbd300_InvCurrentBasis::bd300LockTreeExclusive()
         bd13GetNode (*this, curr_tree_id.fileRoot_gg00(),
                      bd300_GetRootLockMode(), /* PTS 1108703 UH 2000-12-12 */
                      m_RequestKind, currRootNptrs_bd00);
+        return true;
     }
     else
     {
@@ -188,7 +190,9 @@ cbd300_InvCurrentBasis::bd300LockTreeExclusive()
             #endif
             m_RequestKind.becomes (nr_for_update); // for safety only
             bd300LockTree ();
+            return true;
         }
+        return false;
     }
 }
 
@@ -245,8 +249,6 @@ cbd300_InvCurrentBasis::bd300UnlockTree (bool bTreeIsRemoved) /* PTS 1106088 UH
                     if( e_ok != TrError )
                     {
                         b06write_filename_and_root( curr_tree_id );
-                        g01abort (csp3_bd_msg, csp3_n_btree, "bd300UnlockTree         ", 
-                            AuxNptrsRoot.np_ptr()->nd_id());
                     }
                 }
                 
@@ -260,7 +262,7 @@ cbd300_InvCurrentBasis::bd300UnlockTree (bool bTreeIsRemoved) /* PTS 1106088 UH
                     &&
                     (pRec->recKeyLen_gg00() != 0) )
                 {
-                    g01abort (csp3_bd_msg, csp3_n_btree, "Root: KeyLen != 0       ", pNode->nd_id());
+                    TrError = e_invalid_index_structure;
                 }
             }
             if ( ! bTreeIsRemoved ) /* PTS 1106088 UH 23-03-2000 */
@@ -400,17 +402,37 @@ cbd300_InvCurrent::bd300SetFileNotAccessible( bool bSetErrorToNotAccessible )
     {
         tbd_file_state_set AuxFileState;
         AuxFileState.clear();
+        const tgg00_BasisError    originalError = TrError;
         TrError = e_ok;
 
         b01bad_index_cnt = b01bad_index_cnt + 1;
 
         AuxFileState.addElement (f_not_accessible);
 
+
         if ( Kernel_IAdminInfo::Instance().KernelStateIsRestart() )
             b06file_opmsg (csp3_index_not_restored, this->curr_tree_id);
         else
+        {
             b06file_opmsg (csp3_bad_index, this->curr_tree_id);
 
+            if( e_ok != originalError ) // write reason for corruption into knldiag.err
+            {
+                char msgText[40]       = "Reason \"";
+                const int remainingLen = sizeof( msgText ) - strlen( msgText ) -1;
+
+                const char*   errCodeText    = Kernel_BasisErrorToResultString( originalError );
+                int           errCodeTextLen = strlen( errCodeText );
+
+                if( errCodeTextLen > remainingLen ){
+                    errCodeTextLen = remainingLen;
+                }
+                strncat( msgText, errCodeText, errCodeTextLen );
+                strncat( msgText, "\"", 1);
+                g01optextmsg (sp3p_knldiag, sp3m_error, csp3_bad_index, csp3_n_index, msgText );
+            }
+        }
+
         b17fadd_file_state (*(this->curr_trans), this->curr_tree_id, AuxFileState);
     }
     if( bSetErrorToNotAccessible )
