@@ -268,7 +268,9 @@ bd400AddToInvTree (cbd300_InvCurrent &InvCurrent,
                 LeafNode.bd600Release (! IS_CHANGED_BD600);
 
                 /* get exclusive tree lock if the record does not suit into current page */
-                InvCurrent.bd300LockTreeExclusive();
+                if ( InvCurrent.bd300LockTreeExclusive() )
+                    if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                        Tree.bd500_WriteTrace("bd400AddToInvTree: OverFlow1",28);
                 if (TrError != e_ok) return;
 
                 Tree.bd500FindNode (SecKey, SecKeyLen, LEAF_LEVEL_BD00);
@@ -320,7 +322,9 @@ bd400AddToInvTree (cbd300_InvCurrent &InvCurrent,
                     /* release current node */
                     LeafNode.bd600Release (! IS_CHANGED_BD600);
 
-                    InvCurrent.bd300LockTreeExclusive();
+                    if ( InvCurrent.bd300LockTreeExclusive() )
+                        if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                            Tree.bd500_WriteTrace("bd400AddToInvTree: OverFlow2",28);
                     if (TrError != e_ok) return;
 
                     Tree.bd500FindNode (SecKey, SecKeyLen, LEAF_LEVEL_BD00);
@@ -371,7 +375,9 @@ bd400AddToInvTree (cbd300_InvCurrent &InvCurrent,
 				// PTS 1120380 UH 2003-02-03 enter tree again for propagation
                 if ( ! LeafNode.bd600IsAccessable() )
                 {
-                    InvCurrent.bd300LockTreeExclusive();
+                    if ( InvCurrent.bd300LockTreeExclusive() )
+                        if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                            Tree.bd500_WriteTrace("bd400AddToInvTree: Propagation1",31);
                     if (TrError != e_ok) return; // PTS 1121867 UH 2003-05-02
                     Tree.bd500FindNode (SecKey, SecKeyLen, LEAF_LEVEL_BD00);
                     if (TrError != e_ok) return;
@@ -563,7 +569,9 @@ bd400DelFromInvTree (cbd300_InvCurrent &InvCurrent,
 				// PTS 1120380 UH 2003-02-03 enter tree again for propagation
                 if ( ! LeafNode.bd600IsAccessable() )
                 {
-                    InvCurrent.bd300LockTreeExclusive();
+                    if ( InvCurrent.bd300LockTreeExclusive() )
+                        if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                            Tree.bd500_WriteTrace("bd400DelFromInvTree: Propagation",32);
                     if (TrError != e_ok) return; // PTS 1121867 UH 2003-05-02
                     Tree.bd500FindNode (SecKey, SecKeyLen, LEAF_LEVEL_BD00);
                     if (TrError != e_ok) return;
@@ -1028,6 +1036,10 @@ bd400_AddPrimKeyToSubTree (cbd300_InvCurrent &InvCurrent,
     {
         if ( updateStatistics ) 	// PTS 1131150 UH revert increment of primkey count
         {
+            SubTreeLeaf.bd600Release(IS_CHANGED_BD600);
+            InvSubTreeCurrent.bd300UnlockTree(); // PTS 1137139 UH 2005-08-23 added to avoid deadlocks
+            if (e_ok != TrError) return;
+
             // reset the PrimKeyCount in the invBaseRecord
             tsp00_Int4       recindex;
             tbd_searchresult result;
@@ -2115,7 +2127,9 @@ bd400AddToOmsInvTree (cbd300_InvCurrent &InvCurrent,
         LeafNode.bd600Release (! IS_CHANGED_BD600);
 
         /* get exclusive tree lock if the record does not suit into current page */
-        InvCurrent.bd300LockTreeExclusive();
+        if ( InvCurrent.bd300LockTreeExclusive() )
+            if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                Tree.bd500_WriteTrace("bd400AddToOmsInvTree: Overflow",30);
         if (TrError != e_ok) return;
 
         Tree.bd500FindNode (pSecKey, SecKeyLen, LEAF_LEVEL_BD00);
