@@ -20,7 +20,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -1212,17 +1213,12 @@ bd401_CountKeys (tgg00_BasisError    &TrError,
     /* the number SecKeyCnt of Seckeys S with  StartKey <= S <= StopKey is             */
     /* determined. Moreover the number of the corresponding primary keys is calculated */                                                 
     /* PTS 1106934 16/06/2000 AK   (completely changed)                                */
+    // removed leaf count check
     
     tsp00_Int4        StartRecIndex;
     tsp00_Int4        StopRecIndex;
     tbd_searchresult  SearchResult;
     const bool        bStartKeyIsEqualtoStopKey       = ((pStartKey == pStopKey) && (StartKeyLen == StopKeyLen));
-#   if COMPILEMODE_MEO00 >= QUICK_MEO00
-    bool              bCalculatedPageCntMustBeCorrect = true;
-    tsp00_Int4        UpperMaxLeafCountError          = 0; 
-    tsp00_Int4        LowerMaxLeafCountError          = 0;
-    tsp00_Int4        LeafCount;
-#   endif
 
     /* initialize output varaiables */
     PageCnt    = 0;
@@ -1251,36 +1247,6 @@ bd401_CountKeys (tgg00_BasisError    &TrError,
             PrimKeyCnt    += Node.bd600PrimKeyCount (StartRecIndex, StopRecIndex); 
             if (StopRecIndex >= StartRecIndex)                                          // PTS 1106934 16/06/2000 AK 
                 PageCnt       += (Node.bd600LeafCount(StartRecIndex,StopRecIndex) + 1); 
-#           if COMPILEMODE_MEO00 >= QUICK_MEO00
-            /* due to the lazy propagation of the sub tree leaf count the */
-            /* calculated page count need not be correct except if there  */
-            /* are no sub trees which is displayed by a zero leafCount    */
-            /* PTS 1106934 16/06/2000 AK                                  */
-            bCalculatedPageCntMustBeCorrect &= (0==(Node.bd600LeafCount(StartRecIndex,StopRecIndex)));
-            if (StopRecIndex >= StartRecIndex)                
-            {
-                LeafCount = (Node.bd600LeafCount(StartRecIndex,StopRecIndex) + 1);
-                UpperMaxLeafCountError += MAX_EO00 (1, ((LeafCount * MAX_LEAFCOUNT_DIFF_GBD500)/(100-MAX_LEAFCOUNT_DIFF_GBD500)));
-                if (LeafCount > 1)
-                    LowerMaxLeafCountError += MAX_EO00 (1, ((LeafCount * MAX_LEAFCOUNT_DIFF_GBD500)/100));
-            }
-#           endif
-                    
-            if (NIL_PAGE_NO_GG00 == Node.bd600RightNeighbor() || (PageCnt > (2*CalculatedPageCnt)))  
-            {
-                g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                    "bd401CountKeys:CalPageCn", CalculatedPageCnt);
-                g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                    "bd401CountKeys: StartPno", StartLeafPno );
-#               if COMPILEMODE_MEO00 >= QUICK_MEO00
-                g01abort (csp3_eval, csp3_n_index, 
-                    "bd401CountKeys: StopPno ", StopLeafPno );
-#               else
-                g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                    "bd401CountKeys: StopPno ", StopLeafPno );
-                return;
-#               endif
-            }
             
             /* goto next leaf and set Startrecindex to first record */
             Node.bd600Move(Node.bd600RightNeighbor());
@@ -1298,29 +1264,6 @@ bd401_CountKeys (tgg00_BasisError    &TrError,
         PrimKeyCnt += Node.bd600PrimKeyCount (StartRecIndex, StopRecIndex); 
         if (StopRecIndex >= StartRecIndex)                                     // PTS 1106934 16/06/2000 AK 
             PageCnt += (Node.bd600LeafCount(StartRecIndex,StopRecIndex) + 1); 
-
-        /* compare the counted number of pages with the calculated number */
-#       if COMPILEMODE_MEO00 >= QUICK_MEO00 
-        if ((bCalculatedPageCntMustBeCorrect && (PageCnt != CalculatedPageCnt)) ||
-            (PageCnt > (CalculatedPageCnt+UpperMaxLeafCountError))              ||
-            (PageCnt < (CalculatedPageCnt-LowerMaxLeafCountError)))
-        {
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                "bd401CountKeys: PageNo  ", Node.bd600GetId());
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index,  //PTS 1106934 14/06/2000 AK 
-                "bd401CountKeys:Startleaf", StartLeafPno );
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index,  //PTS 1106934 14/06/2000 AK 
-                "bd401CountKeys:Stopleaf ", StopLeafPno );
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                "bd401CountKeys: PageCnt1", CalculatedPageCnt);
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                "bd401CountKeys: PageCnt2", PageCnt);
-            g01opmsg (sp3p_knldiag, sp3m_error, csp3_eval, csp3_n_index, 
-                "bd401CountKeys:+MaxError", UpperMaxLeafCountError);
-            g01abort (csp3_eval, csp3_n_index, 
-                "bd401CountKeys:-MaxError", LowerMaxLeafCountError);
-        }
-#       endif
     }
     
 #   if COMPILEMODE_MEO00 >= SLOW_MEO00 
