@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -230,7 +231,8 @@ bd405CreateIndex (
     tbd_current_tree       &PrimCurrent,       // [IN]
     tgg00_StackDesc        &StackDesc,         // [IN]
     tgg00_IndexMode         IndexMode,         // [IN]
-    tgg00_IndexCounter     &IndexCounter       // [OUT]
+    tgg00_IndexCounter     &IndexCounter,      // [OUT]
+    tsp00_Bool             &bErrorOnBaseTable  // [OUT]
 )
 {
     ROUTINE_DBG_MEO00 ("bd405CreateIndex");
@@ -250,7 +252,7 @@ bd405CreateIndex (
         cbd490_CreateIndexParallel  Coordinator (InvTree,
                 PrimCurrent, StackDesc, IndexCounter, IndexMode);
 
-        Coordinator.bd490BuildIndex ();
+        Coordinator.bd490BuildIndex( bErrorOnBaseTable );
 
         if ((e_sysbuffer_overflow == TrError) || (e_no_more_memory == TrError))
         {
@@ -271,7 +273,7 @@ bd405CreateIndex (
         cbd490_CreateIndexSequential Coordinator (InvCurrent,
                 PrimCurrent, StackDesc, IndexCounter, IndexMode);
 
-        Coordinator.bd490BuildIndex();
+        Coordinator.bd490BuildIndex( bErrorOnBaseTable );
     }
 }
 
@@ -294,7 +296,8 @@ bd405ParticipantCreateIndex (
     tgg00_IndexMode         IndexMode,         // [IN]
     tgg00_IndexCounter     &IndexCounter,      // [OUT]
     tsp00_PageNo           &TempInvRoot,       // [OUT]
-    tsp00_Bool             &bEntriesExist      // [OUT]
+    tsp00_Bool             &bEntriesExist,     // [OUT]
+    tsp00_Bool             &bErrorOnBaseTable  // [OUT]
 )
 {
     ROUTINE_DBG_MEO00 ("bd405ParticipantCreateIndex");
@@ -310,7 +313,8 @@ bd405ParticipantCreateIndex (
 
 
         Participant.bd491MemorySort (InvQueue, pStartPrimKey, pStopPrimKey, StartPrimKeyLen,
-                                     StopPrimKeyLen, NumLeavesToScan, AvgRecordsPerLeaf, bEntriesExist);
+                                     StopPrimKeyLen, NumLeavesToScan, AvgRecordsPerLeaf, 
+                                     bEntriesExist, bErrorOnBaseTable);
 
         /*
         if (e_ok == TrError) 
@@ -365,7 +369,7 @@ bd405ParticipantCreateIndex (
             cbd491_CreateIndexParticipant Participant (PrimCurrent, StackDesc, IndexCounter, false);
 
             Participant.bd491InsertionSort (InvTreeCurrent, IndexMode, pStartPrimKey, pStopPrimKey,
-                                            StartPrimKeyLen, StopPrimKeyLen, bEntriesExist);
+                                            StartPrimKeyLen, StopPrimKeyLen, bEntriesExist, bErrorOnBaseTable);
 
             if (bMemorySortFailed)
             {
@@ -420,7 +424,7 @@ bd405_CheckInvListForOneSecKey (
         PrimKeyIterator.bd460Deref (pPrimKey, PrimKeyLen);
         if (NULL == pPrimKey) return;
 
-        bd30SearchRecord (PrimCurrent, pPrimKey, PrimKeyLen,
+        bd30SearchRecord (PrimCurrent, pPrimKey, PrimKeyLen, ! LOCK_LEAF_EXCL_BD00,
                           pPrimNptr, PrimRecIndex, Neighbors, PrimKeySearchResult);
 
         if (NULL != pPrimNptr.np_ptr())
