@@ -13,7 +13,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -1223,7 +1224,8 @@ cbd491_CreateIndexParticipant::bd491InsertionSort(
     tsp00_BytePtr      pStopPrimKey,
     tsp00_Int4         StartPrimKeyLen,
     tsp00_Int4         StopPrimKeyLen,
-    tsp00_Bool        &bEntriesExist)
+    tsp00_Bool        &bEntriesExist,
+    tsp00_Bool        &bErrorOnBaseTable )
 {
     ROUTINE_DBG_MEO00 ("bd491InsertionSort");
 
@@ -1253,12 +1255,17 @@ cbd491_CreateIndexParticipant::bd491InsertionSort(
     {
         if (NULL == pPrimNptr.np_ptr())
         {
-            bd30SearchRecord (m_PrimCurrent, pStartPrimKey, StartPrimKeyLen,
+            bd30SearchRecord (m_PrimCurrent, pStartPrimKey, StartPrimKeyLen, ! LOCK_LEAF_EXCL_BD00,
                               pPrimNptr, PrimRecIndex, Neighbors, PrimKeySearchResult);
 
-            if (e_ok != m_TrError) break;
+            if (e_ok != m_TrError) 
+            {
+                bErrorOnBaseTable = true;
+                break;
+            }
 
-            if (nonefound == PrimKeySearchResult) break; // e_no_next_record;
+            if (nonefound == PrimKeySearchResult) 
+                break; // e_no_next_record;
         }
         else
         {
@@ -1266,7 +1273,11 @@ cbd491_CreateIndexParticipant::bd491InsertionSort(
 
             b31next_search( pPrimNptr, PrimRecIndex, m_PrimCurrent );
 
-            if (e_ok != m_TrError) break;
+            if (e_ok != m_TrError)
+            {
+                bErrorOnBaseTable = true;
+                break;
+            }
         }
 
         pRec = bd50GetRecPtr (m_PrimCurrent, pPrimNptr, PrimRecIndex);
@@ -1337,8 +1348,8 @@ cbd491_CreateIndexParticipant::bd491MemorySort(
     tsp00_Int4                StopPrimKeyLen,
     tsp00_Int4                NumLeavesToScan,
     tsp00_Int4                AvgRecordsPerLeaf,
-    tsp00_Bool               &bEntriesExist
-)
+    tsp00_Bool               &bEntriesExist,
+    tsp00_Bool               &bErrorOnBaseTable )
 {
     ROUTINE_DBG_MEO00 ("bd491MemorySort");
 
@@ -1358,7 +1369,9 @@ cbd491_CreateIndexParticipant::bd491MemorySort(
         return;
 
     bd491_ProcessPrimTreeRange (NodeList, InvRecDescList,
-                                pStartPrimKey, pStopPrimKey, StartPrimKeyLen, StopPrimKeyLen);
+                                pStartPrimKey, pStopPrimKey, 
+                                StartPrimKeyLen, StopPrimKeyLen,
+                                bErrorOnBaseTable);
 
     if( e_ok == m_TrError )
     {
@@ -1561,7 +1574,8 @@ cbd491_CreateIndexParticipant::bd491_ProcessPrimTreeRange(
     tsp00_BytePtr            pStartPrimKey,
     tsp00_BytePtr            pStopPrimKey,
     tsp00_Int4               StartPrimKeyLen,
-    tsp00_Int4               StopPrimKeyLen)
+    tsp00_Int4               StopPrimKeyLen,
+    tsp00_Bool              &bErrorOnBaseTable)
 {
     // Temp solution as long as no primtree class is available
 
@@ -1587,15 +1601,19 @@ cbd491_CreateIndexParticipant::bd491_ProcessPrimTreeRange(
 
     pPrimNptr.np_ptr()   = NULL;
     pPrimNptr.np_cbptr() = NULL;
-
+    
     do
     {
         if (NULL == pPrimNptr.np_ptr())
         {
-            bd30SearchRecord (m_PrimCurrent, pStartPrimKey, StartPrimKeyLen,
+            bd30SearchRecord (m_PrimCurrent, pStartPrimKey, StartPrimKeyLen, ! LOCK_LEAF_EXCL_BD00,
                               pPrimNptr, PrimRecIndex, Neighbors, PrimKeySearchResult);
 
-            if (e_ok != m_TrError) break;
+            if (e_ok != m_TrError)
+            {
+                bErrorOnBaseTable = true;
+                break;
+            }
 
             if (nonefound == PrimKeySearchResult) break; // e_no_next_record;
         }
@@ -1605,7 +1623,11 @@ cbd491_CreateIndexParticipant::bd491_ProcessPrimTreeRange(
 
             bd491_NextRecord( OldLeafPno, pIndexNptr, pPrimNptr, PrimRecIndex );
 
-            if (e_ok != m_TrError) break;
+            if (e_ok != m_TrError)
+            {
+                bErrorOnBaseTable = true;
+                break;
+            }
         }
         pRec = bd50GetRecPtr (m_PrimCurrent, pPrimNptr, PrimRecIndex);
 
