@@ -188,7 +188,7 @@ void cbd500_Tree::bd500_NextSubNode (tsp00_Int4       RecIndex,
         PathInfo.piId_bd500              = m_Node.m_pNode->nd_id();
         PathInfo.piSubNodeRecIndex_bd500 = RecIndex;
         PathInfo.piMaxRecIndex_bd500     = m_Node.bd600MaxRecIndex();
-        PathInfo.piLeafCount_bd500       = m_Node.bd600LeafCount();
+        PathInfo.piLeafCount_bd500       = m_Node.bd600LeafCount(RecIndex, RecIndex);
 
         --m_CurrLevel;
 
@@ -334,7 +334,7 @@ cbd500_Tree::bd500NextNode ()
         if ( e_ok != m_TrError ) return;
         m_PathInfo[m_CurrLevel].piSubNodeRecIndex_bd500 = FIRST_REC_INDEX_BD00;
         m_PathInfo[m_CurrLevel].piMaxRecIndex_bd500     = m_Node.bd600MaxRecIndex();
-        m_PathInfo[m_CurrLevel].piLeafCount_bd500       = m_Node.bd600LeafCount();
+        m_PathInfo[m_CurrLevel].piLeafCount_bd500       = m_Node.bd600LeafCount(FIRST_REC_INDEX_BD00,FIRST_REC_INDEX_BD00);
     }
     else
     {
@@ -433,8 +433,8 @@ cbd500_Tree::bd500PrevNode ()
             m_PathInfo[m_CurrLevel].piId_bd500              = m_PathInfo[m_CurrLevel].piLeftId_bd500;
             m_PathInfo[m_CurrLevel].piLeftId_bd500          = NIL_PAGE_NO_GG00;
             m_PathInfo[m_CurrLevel].piMaxRecIndex_bd500     = m_Node.bd600MaxRecIndex();
-            m_PathInfo[m_CurrLevel].piLeafCount_bd500       = m_Node.bd600LeafCount();
             m_PathInfo[m_CurrLevel].piSubNodeRecIndex_bd500 = m_Node.bd600MaxRecIndex();
+            m_PathInfo[m_CurrLevel].piLeafCount_bd500       = m_Node.bd600LeafCount(m_Node.bd600MaxRecIndex(),m_Node.bd600MaxRecIndex());
             --(m_PathInfo[m_CurrLevel+1].piSubNodeRecIndex_bd500); // update index above
             if ( TargetLevel == m_CurrLevel )
             {
