@@ -127,7 +127,9 @@ cbd500_Tree::bd520LeafCountPropagation (tsp00_KeyPtr  pKey,
     if ( NULL != pKey )
     {
         m_Node.bd600Release (nr_for_update == m_Node.m_RequestKind);
-        m_Node.m_Current.bd300LockTreeExclusive();
+        if ( m_Node.m_Current.bd300LockTreeExclusive() )
+            if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+                bd500_WriteTrace("bd520LeafCountPropagation",25);
         if (m_TrError != e_ok) return;
         bd500FindNode (pKey, KeyLen, LEAF_LEVEL_BD00);
         if (m_TrError != e_ok) return;
@@ -141,9 +143,6 @@ cbd500_Tree::bd520LeafCountPropagation (tsp00_KeyPtr  pKey,
         if ( ! bd500PropagationNeeded() ) return;
     }
 
-    if ( g01vtrace.vtrAll_gg00 && g01glob.treecheck )
-        bd500Print ("bd520LeafCountPropagation"); // PTS 1112713 UH 2001-12-07
-
     bd520_Propagate (! UPDATE_KEY, NewOrders);
     if ( NewOrders.iosOrderCount_bd501 > 0 )
     {
@@ -172,7 +171,9 @@ cbd500_Tree::bd520LeafUnderFlow (tsp00_KeyPtr pKey,
     m_Node.bd600Release (IS_CHANGED_BD600);
     if (e_ok != m_Node.m_TrError) return false;
 
-    m_Node.m_Current.bd300LockTreeExclusive ();
+    if ( m_Node.m_Current.bd300LockTreeExclusive() )
+        if ( g01vtrace.vtrAll_gg00 || g01vtrace.vtrBdIndex_gg00 )
+            bd500_WriteTrace("bd520LeafUnderFlow",18);
     if (e_ok != m_Node.m_TrError) return false;
 
     /* Because there were intermediately no locks on the tree.   */
