@@ -47,7 +47,7 @@
 #include "hbd13.h"
 #include "hbd20_2.h" // bd20IsPageRequested
 #include "hbd30.h"
-#include "hgg01_1.h" // g01abort, g01opmsg
+#include "hgg01_1.h" // g01opmsg
 #include "hgg01_3.h" // g01glob
 #include "SAPDB/SAPDBCommon/SAPDB_RangeCode.hpp" // Kernel_move_and_fill
 #include "hgg10.h"
@@ -137,8 +137,6 @@ cbd600_Node::bd600UpdRecordSpace (tsp00_Int4   RecSizeDelta,
         /* the new reclen must be aligned */
         m_TrError = e_illegal_entrylength;
         bd600Dump (bd600c1DataPageCorrupted_csp03, "UpdRecordSpace          ");
-        if (g01glob.treecheck)
-            g01abort (csp3_bd_msg, csp3_n_btree, "RecSizeDelta            ", RecSizeDelta);
         return;
     }
 
@@ -190,8 +188,6 @@ cbd600_Node::bd600UpdRecordSpace (tsp00_Int4   RecSizeDelta,
     {
         m_TrError = e_data_page_corrupted;
 		bd600Dump (bd600c1DataPageCorrupted_csp03, "Data page corrupted     ");
-        if ( g01glob.treecheck )
-            g01abort (csp3_bd_msg, csp3_n_btree, "RecSizeDelta            ", RecSizeDelta);
         return;
     }
 }
@@ -526,9 +522,6 @@ cbd600_Node::bd600CheckWithErrorHandling() const
                 "Action Code             ", m_Current.curr_action);
             
             b06write_filename_and_root( m_Current.curr_tree_id );
-            
-            g01abort (csp3_bd_msg, csp3_n_btree, "bd600CheckWithErrorHand ", 
-                m_pNode->nd_id());
         }
     }
 }
@@ -914,28 +907,38 @@ cbd600_Node::bd600CheckIndex() const
 		} // end of loops over records 
 
         /* check sum of leaf counts */
-        if ( e_ok == m_TrError && g01glob.treecheck && !m_pNode->nd_pmode().includes(pmTemp_egg00)){
+        if ( e_ok == m_TrError && g01glob.treecheck
+             &&
+             ! m_pNode->nd_pmode().includes(pmTemp_egg00) )
+        {
 			 bd600_CheckLeafCount();
         }
 	}	
-
-	if ( g01glob.treecheck && 
-        (e_ok != m_TrError) && (e_shutdown != m_TrError) && (e_sysbuffer_overflow != m_TrError) )
-    {
-		g01abort  (csp3_bd_msg, csp3_n_btree, "bd600CheckIndex         ", m_pNode->nd_id());
-    }
 }
 
 /*---------------------------------------------------------------------------*/
 
 tsp00_Int4  
 cbd600_Node::bd600LeafCount(const tsp00_Int4 StartRecIndex, 
-							const tsp00_Int4 StopRecIndex) const
+			                const tsp00_Int4 StopRecIndex) const
 {
 	/* this function returns the number off all leaves referenced by */
 	/* those records on the current node which have indices with     */
 	/* StartRecIndex <= index <= StopRecIndex.                       */
 
+    #if COMPILEMODE_MEO00 >= SLOW_MEO00 
+    t01p2int4 (bd_inv, "Node Id     ", m_pNode->nd_id(),
+                       "Node Type2  ", m_pNode->nd_pt2() );
+    t01p2int4 (bd_inv, "StrtRecIndex", StartRecIndex,
+                       "StopRecIndex", StopRecIndex );
+    #endif
+
+    const tsp00_Int4 MaxRecIndex = bd600MaxRecIndex();
+
+    if ( StartRecIndex < 0 || StartRecIndex > MaxRecIndex ||
+         StopRecIndex  < 0 || StopRecIndex  > MaxRecIndex )
+        return 0;
+
 	tsp00_Int4 SumNumLeaves = 0;
 	
 	if (LEAF_LEVEL_BD00 == m_pNode->nd_level())
@@ -979,16 +982,15 @@ cbd600_Node::bd600PrimKeyCount(const tsp00_Int4 StartRecIndex,
 	/* by those records on the current node which have indices with     */
 	/* StartRecIndex <= index <= StopRecIndex.                          */
 
-	tsp00_Int4 PrimKeyCount = 0;
-	
-#   if COMPILEMODE_MEO00 >= QUICK_MEO00 
-	if (LEAF_LEVEL_BD00 != m_pNode->nd_level())
-	{	
-		g01opmsg (sp3p_knldiag, sp3m_error,	csp3_bd_msg, 
+    if (LEAF_LEVEL_BD00 != m_pNode->nd_level())
+    {	
+        m_TrError = e_data_page_corrupted;
+        g01opmsg (sp3p_knldiag, sp3m_error,	csp3_bd_msg, 
             csp3_n_btree, "b600PKeyCnt:NoLeaf  Pno=", m_pNode->nd_id());
-		g01abort  (csp3_bd_msg, csp3_n_btree, "b600PKeyCnt:NoLeaf  Lvl=", m_pNode->nd_level());
-	}
-#   endif
+        return 0;
+    }
+	
+    tsp00_Int4 PrimKeyCount = 0;
 	
 	tgg00_RecPtr pRec;
 	
