@@ -108,6 +108,56 @@ bd900_NewDumpPage (tgg00_VfFileref      &HostFile,
 /* METHODS of cbd900_ObjFileInfo                                             */
 /*---------------------------------------------------------------------------*/
 
+SAPDB_OStream& operator<<(SAPDB_OStream& os, const cbd900_ObjFileInfo& fileinfo)
+{
+    int ix;
+    tsp00_Line line;
+    int        linelen = 0;
+    fileinfo.ofiTransNo.gg90AppendToLine (linelen, line);
+    line[linelen] = 0;
+
+#if defined(BIT64) 
+    struct {
+        SAPDB_UInt8 m_alloc;
+        SAPDB_UInt  m_Capacity;
+        SAPDB_UInt  m_Size;
+        SAPDB_UInt8 m_ArrayPtr;
+    } vector;
+#else
+    struct {
+        SAPDB_UInt  m_alloc;
+        SAPDB_UInt  m_Capacity;
+        SAPDB_UInt  m_Size;
+        SAPDB_UInt  m_ArrayPtr;
+    } vector;
+#endif
+
+    memcpy( &vector, &fileinfo.ofiKeyRoots_bd900, sizeof(vector));
+
+    os << "RecreateIndex:" << fileinfo.ofiRecreateIndex_bd900
+        << " #KeyPart:" << fileinfo.ofiNumKeyPartitions_bd900
+        << " bErrReCreIdx:" << fileinfo.ofiRecreateIndexError_bd900
+        << " #MaxChain:" << fileinfo.ofiMaxChain_bd900
+        << " #MaxObjPerPage:" << fileinfo.ofiMaxObjPerPageCnt_bd900
+        << " MaxObjBodySize:" << fileinfo.ofiMaxObjBodySize_bd900
+        << " keyroot-vector-alloc-addr:" << vector.m_alloc
+        << " keyroot-vector-capacity:" << vector.m_Capacity
+        << " keyroot-vector-size:" << vector.m_Size
+        << " keyroot-vector-arrayptr:" << vector.m_ArrayPtr;
+    for ( ix=0; ix < fileinfo.GetKeyPartitionCount(); ix++ )
+        os << " KeyRoot:" << ix << fileinfo.ofiKeyRoots_bd900[ix];
+
+    os << " Root:" << fileinfo.ofiRoot_bd900
+        << " IsVar:" << fileinfo.ofiFileIsForVarObj_bd900
+        << " RelFile:" << fileinfo.ofiRelFileIsReq_bd900
+        << " Filler1:" << fileinfo.ofiFiller1_bd900
+        << " DropFile:" << fileinfo.ofiDropFile_bd900
+        << " TransNo:"  << line
+        << " Filler2:" << fileinfo.ofiFiller2_bd900
+        << fileinfo.ofiChain_bd900[0];
+    return os;
+};
+
 externCpp void 
 cbd900_ObjFileInfo::bd900DumpFileInfo (               
 									   tgg00_VfFileref    &HostFile,
