@@ -20,7 +20,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -48,7 +49,7 @@
 #include "gbd900.h"
 #include "gbd910.h"
 #include "gbd930.h"
-
+#include "hkb67.h"
 #include "hgg06.h"
 
 #if defined(TESTCHAINING)
@@ -74,6 +75,8 @@ extern cbd930_GarbCollController  bd91GarbCollController;
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
  *===========================================================================*/
 
+static bool g_IsOnline = false;
+
 /*===========================================================================*
  *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
  *===========================================================================*/
@@ -297,7 +300,7 @@ cbd910_ObjNode::bd910InitObjPage (tsp00_Int4     ObjBodyLen,
 	pPage->nd_prev_free()            = NIL_PAGE_NO_GG00;  /* PTS 1115760 2002-05-15 FF */
 	pPage->nd_in_free_chain()        = false;
 	pPage->nd_space0()               = false;
-	pPage->nd_space1()               = 0;
+	pPage->nd_assigned_to_spec_trans() = 0;
     pPage->nd_num_chain_updater_mig()= 0;  // PTS 1113635 for migration only
 	pPage->nd_free_eot_obj_cnt()     = 0;
 	pPage->nd_free_obj_cnt()         = pPage->nd_max_obj_cnt();
@@ -353,6 +356,7 @@ cbd910_ObjNode::bd910InitObjPage (tsp00_Int4     ObjBodyLen,
 
 void  
 cbd910_ObjDataNode::bd910AssignToNewPageInDataChain (cbd910_SubRootNode  &NptrsSubRoot,
+                                                     bool                 bNoInsertToFreeList,
 													 tsp00_Bool           bPageMustNotBeCreated)
 {
 	ROUTINE_DBG_MEO00 ("bd910AssignToNewPageInDataChain");
@@ -424,10 +428,148 @@ cbd910_ObjDataNode::bd910AssignToNewPageInDataChain (cbd910_SubRootNode  &NptrsS
     /* update free chain, i.e put new page at the beginning */ 
 	/* of the chain of pages with free object frames        */
     /* PTS 1127493 FF 2004-FEB-02 */ 
-    if (!bPageMustNotBeCreated)           
+    if (!bPageMustNotBeCreated && !bNoInsertToFreeList) 
         NptrsSubRoot.bd910InsertPageIntoFreeChain (*this);   
 }
 
+/*---------------------------------------------------------------------------*/
+/* PTS 1115760 2002-05-15 FF                                                 */
+void  
+cbd910_SubRootNode::bd910InsertPageIntoFreeChain  (cbd910_ObjDataNode &NptrsPage)
+{
+    ROUTINE_DBG_MEO00 ("bd910InsertPageIntoFreeChain");
+    
+    /* check preconditions */
+    SAPDBERR_ASSERT_STATE (this->bd910PageIsAvailable());
+    SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageIsAvailable());
+    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_next_free() || 
+        (NptrsPage.np_ptr()->nd_id() == this->np_ptr()->nd_id()));
+    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_prev_free() || 0 == NptrsPage.np_ptr()->nd_prev_free());  
+    SAPDBERR_ASSERT_STATE (NIL_PAGE_NO_GG00 == NptrsPage.np_ptr()->nd_prev_free() || 0 == NptrsPage.np_ptr()->nd_prev_free());        
+    SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageMustBeInsertedIntoFreeChain());
+    
+    /* PTS 1135542 don't insert page assigned to one specific task for new object */
+    if (NptrsPage.np_ptr()->nd_assigned_to_spec_trans())
+    {
+        if (!g_IsOnline)
+        {
+            if (!Kernel_IAdminInfo::Instance().KernelStateIsOnline())
+                NptrsPage.np_ptr()->nd_assigned_to_spec_trans() = 0;
+            else 
+                g_IsOnline = true;
+        }
+        if (g_IsOnline)
+        {
+            bool isAssigendToSpecTrans = false;
+            tgg00_ObjPagePos   ObjPos;
+            const int ObjFrameLen        = NptrsPage.np_ptr()->nd_obj_frame_len();
+            const int AlignedObjFrameLen = BD92ALIGN_OBJ_FRAME(ObjFrameLen);
+
+            for ( ObjPos = NptrsPage.np_ptr()->nd_first_obj();
+                ((ObjPos + ObjFrameLen) <= BODY_END_BD00); ObjPos += AlignedObjFrameLen )
+            {
+                tbd900_ObjFrame* pObjFrame = NptrsPage.bd910ObjFramePtr (ObjPos);
+                if (kb67IsTransActive(pObjFrame->objHeader_bd900))
+                {
+                    isAssigendToSpecTrans = true;
+                    break;
+                }
+            }
+            if (isAssigendToSpecTrans)
+                return;
+            else
+                NptrsPage.np_ptr()->nd_assigned_to_spec_trans() = 0;
+        }
+    }
+
+    /* PTS 1127493 FF 2004-FEB-02 */
+    if (g01vtrace.vtrBdObject_gg00) 
+    {
+        Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
+            << " -->bd910InsertPageIntoFreeChain"
+            << " Page:" << NptrsPage.np_ptr()->nd_id()
+            << " NextPage:" << NptrsPage.np_ptr()->nd_next_free()
+            << " PrevPage:" << NptrsPage.np_ptr()->nd_prev_free()
+            << " Root:" << this->np_ptr()->nd_id()
+            << " FreeCnt:" << NptrsPage.np_ptr()->nd_free_obj_cnt()
+            << " MaxCnt:" << NptrsPage.np_ptr()->nd_max_obj_cnt()
+            << " InFreeChain:" << NptrsPage.np_ptr()->nd_in_free_chain();
+    }
+
+    /* PTS 1127493 FF 2004-FEB-02 */
+    if ( !NptrsPage.np_ptr()->nd_in_free_chain())
+    {
+        /* insert page into free page chain */
+        /* during chaining the subroot is never released. Therefore no other task may change  */
+        /* any page chain during this operation, because evry chaining is forced to allocated */
+        /* the corresponding subroot first !                                   FF 2004-FEB-02 */
+        if (NptrsPage.np_ptr()->nd_id() != this->np_ptr()->nd_id())
+        {
+            if (NIL_PAGE_NO_GG00 != this->np_ptr()->nd_next_free())
+            {
+                /* if (NptrsPage.np_ptr()->nd_free_obj_cnt() == 1)          PTS 1127493 FF 2004-FEB-02 */
+                /*     --NptrsPage.np_ptr()->nd_free_obj_cnt();             PTS 1127493 FF 2004-FEB-02 */
+                cbd910_ObjDataNode   NptrsPageNext (*m_ptrCurrent, nr_for_update);
+                NptrsPage.bd910GetAnotherObjPage (this->np_ptr()->nd_next_free(), 
+                    MAX_LOCK_REQUEST_SEQ_NO_BD900, NptrsPageNext);
+                SAPDBERR_ASSERT_STATE (NptrsPage.bd910PageIsAvailable());
+                NptrsPage.np_ptr()->nd_next_free()	    = this->np_ptr()->nd_next_free();
+                NptrsPageNext.np_ptr()->nd_prev_free()  = NptrsPage.np_ptr()->nd_id();
+                /* it can happend, that nd_free_obj_cnt has been changed by another server (rollforward delete) */
+                /* or by the garbage collector                                                   FF 2004-FEB-02 */
+                /* if (NptrsPage.np_ptr()->nd_free_obj_cnt() == 0)          PTS 1127493 FF 2004-FEB-02 */
+                /*     ++NptrsPage.np_ptr()->nd_free_obj_cnt();             PTS 1127493 FF 2004-FEB-02 */
+
+                /* PTS 1127493 FF 2004-FEB-02 */
+                if (g01vtrace.vtrBdObject_gg00) 
+                {
+                    Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
+                        << " NEXT Page:" << NptrsPageNext.np_ptr()->nd_id()
+                        << " NextPage:" << NptrsPageNext.np_ptr()->nd_next_free()
+                        << " PrevPage:" << NptrsPageNext.np_ptr()->nd_prev_free()
+                        << " FreeCnt:" << NptrsPageNext.np_ptr()->nd_free_obj_cnt()
+                        << " MaxCnt:" << NptrsPageNext.np_ptr()->nd_max_obj_cnt()
+                        << " InFreeChain:" << NptrsPageNext.np_ptr()->nd_in_free_chain();
+                }
+            }
+            this->np_ptr()->nd_next_free()		    = NptrsPage.np_ptr()->nd_id();
+            NptrsPage.np_ptr()->nd_prev_free()      = this->np_ptr()->nd_id();
+        }
+
+        NptrsPage.np_ptr()->nd_in_free_chain() = true;
+
+        /* increase free page counter on subroot page */ 
+        cbd900_SubRootPageInfo  SubRootPageInfo (*this);
+        ++SubRootPageInfo.bd900FreePageCnt();
+	    bd910_SetFreePageCntInChainInfo (m_ptrCurrent->curr_tree_id, this->np_ptr()->nd_chain_no(), SubRootPageInfo.bd900FreePageCnt());
+
+        /* perform some simple checks */
+#       if COMPILEMODE_MEO00 >= QUICK_MEO00 	
+        NptrsPage.bd910_CheckFreePageCnt (*this);
+#       endif
+
+        /* write a vtrace entry */		
+#       if COMPILEMODE_MEO00 >= SLOW_MEO00 
+        t01name (bi,"ins into free list");
+        t01int4 (bi,"ins page no=",NptrsPage.np_ptr()->nd_id()); 
+#       endif  
+    }
+
+    /* PTS 1127493 FF 2004-FEB-02 */
+    if (g01vtrace.vtrBdObject_gg00) 
+    {
+        Kernel_VTrace() << __FILE__ << ":" << __LINE__ 
+            << " <--bd910InsertPageIntoFreeChain"
+            << " Page:" << NptrsPage.np_ptr()->nd_id()
+            << " NextPage:" << NptrsPage.np_ptr()->nd_next_free()
+            << " PrevPage:" << NptrsPage.np_ptr()->nd_prev_free()
+            << " Root:" << this->np_ptr()->nd_id()
+            << " FreeCnt:" << NptrsPage.np_ptr()->nd_free_obj_cnt()
+            << " MaxCnt:" << NptrsPage.np_ptr()->nd_max_obj_cnt()
+            << " InFreeChain:" << NptrsPage.np_ptr()->nd_in_free_chain();
+    }
+};
+
 /*---------------------------------------------------------------------------*/
 
 externCpp bool 
@@ -522,6 +664,8 @@ cbd910_SubRootNode::bd910RemovePageFromChainOfAllPages(cbd910_ObjDataNode  &Nptr
                 << " Page:" << NptrsPage.np_ptr()->nd_id();
         }
 
+        /* release subroot beore freeing page PTS 1135421 */
+        this->bd910ReleasePage();
         /* release page */
         NptrsPage.bd910FreePage();
     }
