@@ -633,12 +633,15 @@ bd92_CheckConsistencyOfChain (tgg00_TransContext             &Trans,
         (SubRootPageInfo.bd900FreePageCnt()            != ChainStat.PageWithFreeLabelCnt)            ||
         (ChainStat.PageWithFreeLabelCnt                != ChainStat.PageInFreeChainCnt ))
     {
-        Kernel_OpError  opErrMsg( csp3_bd_msg, csp3_n_obj );
-        opErrMsg << "BD92_CheckConsistencyOfChain - odd freepage count:"
-            << ChainStat.FreePageCnt
-            << " SubRootPageInfo.cnt:" << SubRootPageInfo.bd900FreePageCnt();
-         if (e_ok == Trans.trError_gg00)
-            Trans.trError_gg00 = e_wrong_obj_count;
+        if (abs( ChainStat.FreePageCnt - SubRootPageInfo.bd900FreePageCnt()) > 1 )
+        {
+            Kernel_OpError  opErrMsg( csp3_bd_msg, csp3_n_obj );
+            opErrMsg << "BD92_CheckConsistencyOfChain - odd freepage count:"
+                << ChainStat.FreePageCnt
+                << " SubRootPageInfo.cnt:" << SubRootPageInfo.bd900FreePageCnt();
+            if (e_ok == Trans.trError_gg00)
+                Trans.trError_gg00 = e_wrong_obj_count;
+        }
     }
 }
 
@@ -1509,12 +1512,13 @@ bd92_VerifyObjPage (tbd_current_tree  &Current,
         
         /* check that the page has no next free page */
         /* if it is not a member of the free chain   */
-        if (pPage->nd_in_free_chain() != (pPage->nd_free_obj_cnt() > 0))
+        if (!pPage->nd_in_free_chain() && (pPage->nd_free_obj_cnt() > 1)
+            && !pPage->nd_assigned_to_spec_trans())
         {
             Kernel_OpError  opErrMsg( csp3_bd_msg, csp3_n_obj );
-            opErrMsg << "BD92VerObjPage - root:" << NptrsPage.np_ptr()->nd_root()
-                << " actual page:" << NptrsPage.np_ptr()->nd_id()
-                << " bad FreeCount";
+            opErrMsg << "BD92VerObjPage - root:" << pPage->nd_root()
+                << " actual page:" << pPage->nd_id()
+                << " bad FreeCount:" << pPage->nd_free_obj_cnt();
             if ( e_ok == TrError )
                 TrError = e_data_page_corrupted; // PTS 1121056
         }
@@ -1691,13 +1695,13 @@ bd92_VerifyObjRootPage (tbd_current_tree  &Current,
     
     /* check that the drop info on the root page ist consistent */
     /* with those in the objfiledir , PTS 1106900 14/06/2000 AK */
-    if (RootPageInfo.bd900FileIsDeleted() != pObjFileInfo->ofiRelFileIsReq_bd900)
+    if (RootPageInfo.bd900FileIsDeleted() != pObjFileInfo->ofiDropFile_bd900)       
     {
         {
             Kernel_OpError  opErrMsg( csp3_bd_msg, csp3_n_obj );
             opErrMsg << "BD92VerObjRootPage - root:" << pRoot->nd_id()
                 << " wrong DropInfo:" << RootPageInfo.bd900FileIsDeleted()
-                << " ObjFileInfo:" << pObjFileInfo->ofiRelFileIsReq_bd900;
+                << " ObjFileInfo:" << pObjFileInfo->ofiDropFile_bd900;
             if ( e_ok == TrError ) TrError = e_inconsistent_drop_info; 
         }
     }
