@@ -21,7 +21,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 
@@ -1053,7 +1054,7 @@ bd93_NewContObj (tbd_current_tree        &Current,                 // [inp]
 		if (NIL_PAGE_NO_GG00 != NptrsSubRoot.np_ptr()->nd_next_free())
 			NptrsBody.bd910AssignToPage (NptrsSubRoot.np_ptr()->nd_next_free());
 		else
-			NptrsBody.bd910AssignToNewPageInDataChain (NptrsSubRoot);
+			NptrsBody.bd910AssignToNewPageInDataChain (NptrsSubRoot, false /*insert into freelist*/);
 		if (e_ok != TrError) return;
 	}
 	
@@ -1083,21 +1084,25 @@ bd93_NewContObjFromThisPage (tbd_current_tree        &Current,
 	tgg00_BasisError      &TrError   = Current.curr_trans->trError_gg00;
     tbd_nodeptr           &pPage     = NptrsBody.np_ptr();
 	
-    /* check if the object frame is really free    PTS 1127804 FF 2004-FEB-17 */
-    if ( NIL_OBJ_PAGE_POS_GG92 == pPage->nd_first_free_obj())
+    /* (PTS 1134505) check if the position of the first free obj is valid   */
+    if ( !bd92ObjPosIsValid (pPage->nd_first_free_obj(), pPage->nd_first_obj(), pPage->nd_obj_frame_len()))
     {
         Kernel_OpError ( csp3_bd_msg, csp3_n_obj ) << __FILE__ << ":" << __LINE__
-            << " bd93_NewContObjFromThisPage:Objectframe freelist empty"
+            << " wrong position: " << pPage->nd_first_free_obj()
             << " page:" << pPage->nd_id()
             << " first free pos: " << pPage->nd_first_free_obj()
             << " page dumped into: d" 
             << pPage->nd_id() << ".obj"; 
-
         b06dump_bad_page (Current.curr_trans->trTaskId_gg00,'d', ".obj", pPage->nd_id(), 
             (void *) NptrsBody.np_ptr(), 1);
-        g01abort (csp3_bd_msg, csp3_n_obj, "bd90_NewObjFromThisPage:", pPage->nd_root());
+
+        if ( bd92ObjPosIsValid (pPage->nd_first_free_obj(), pPage->nd_first_obj(), pPage->nd_obj_frame_len()))
+            TrError = e_wrong_object_state;
+        else
+            TrError = e_illegal_object_pos;
+        return;
     }
-	
+ 	
 	/*  construct position of the object frame  header             */
 	pContObjFrame = (tbd900_ContObjFrame *)	((char*) pPage + pPage->nd_first_free_obj());
 	
@@ -1213,16 +1218,16 @@ bd93_ReleaseContObjFrame (tbd_current_tree       &Current,
 	const tsp00_Int4 ContObjFileNo  = Current.curr_tree_id.fileContObjFileNo_gg00();
 	const tsp00_Int2 &ChainNo       = pContObjPage->nd_chain_no();
     cbd900_ObjChainInfo  &ChainInfo = bd93ContObjFileDir[ObjFileNo][ContObjFileNo][ChainNo];
-	--ChainInfo.ociAllObjCnt_bd900;
+	ChainInfo.DecrementAllObjCnt();
 
 #   if COMPILEMODE_MEO00 >= SLOW_MEO00 
     // check if the number of objects is within reasonable limits  
-	if((0>ChainInfo.ociAllObjCnt_bd900) ||
-		(ChainInfo.ociAllObjCnt_bd900 >
+	if((0>ChainInfo.GetAllObjCnt()) ||
+		(ChainInfo.GetAllObjCnt() >
 		ChainInfo.ociAllPageCnt_bd900 * bd93ContObjFileDir[ObjFileNo][ContObjFileNo].GetObjPerPageCount()))
 	{
 		g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg, csp3_n_obj, 
-			"bd93RelCon:odd AllObjCnt",	ChainInfo.ociAllObjCnt_bd900 );
+			"bd93RelCon:odd AllObjCnt",	ChainInfo.GetAllObjCnt() );
 	}
 #   endif
 	
@@ -1233,6 +1238,7 @@ bd93_ReleaseContObjFrame (tbd_current_tree       &Current,
     /*--------------------------------------------------------------------*/
     if ( NptrsContObjPage.bd910IsEmptyPage())
     {
+        /* bd910RemovePageFromChainOfAllPages will release subroot PTS 1135421 */
         NptrsSubRoot.bd910RemovePageFromChainOfAllPages(NptrsContObjPage);         
     }
     else 
@@ -1246,7 +1252,7 @@ bd93_ReleaseContObjFrame (tbd_current_tree       &Current,
             /* ociAllObjCnt_bd900 is updated  dirty and need not be correct.Here it is tried  */
             /* to keep the trivial restriction that the number of all objects must be >=0     */
             cbd900_SubRootPageInfo  SubRootPageInfo (NptrsSubRoot);
-            SubRootPageInfo.bd900AllObjCnt() = SAPDB_MAX (ChainInfo.ociAllObjCnt_bd900, 0);
+            SubRootPageInfo.bd900AllObjCnt() = SAPDB_MAX (ChainInfo.GetAllObjCnt(), 0);
         }    
         
         /* release pointer to continuation page */
