@@ -489,7 +489,8 @@ cbd930_GarbageCollector::bd930_ReleaseUnusedPagesOfAllFiles()
     bool                   bAllContFilesAreEmptyAndDeleted;
 
     //#   if COMPILEMODE_MEO00 >= QUICK_MEO00      PTS 1113306  FF 10-JAN-2002
-    bool                   bSomethingDoneAtAll = false;
+    bool                   bSomethingDoneAtAll   = false;
+    bool                   bFileForDeletionExist = false;   // PTS 1136796
     //#   endif
 
     do
@@ -508,6 +509,10 @@ cbd930_GarbageCollector::bd930_ReleaseUnusedPagesOfAllFiles()
             FileNo = ObjFileIter.bd920Key();
             ObjFileIter()->bd900BuildFileId (FileNo, ObjFileId);
 
+            // PTS 1136793 
+			if ( ObjFileIter()->ofiRelFileIsReq_bd900 )  
+				bFileForDeletionExist = true; 
+
             bd930_ReleaseUnusedPagesOfOneFile (ObjFileId, *ObjFileIter(), bSomethingDoneDuringLastLoop, bPrimFileIsEmpty);
             if (gcoController_bd930.gccStopGC_bd930 || (e_ok != gcoTrans_bd930.trError_gg00))
                 return bSomethingDoneAtAll;   
@@ -516,6 +521,8 @@ cbd930_GarbageCollector::bd930_ReleaseUnusedPagesOfAllFiles()
             if (ObjFileIter() && (cbd900_ObjFileInfo::omsVariableFile == ObjFileIter()->GetFileType()) 
                 && ObjFileIter()->ofiRelFileIsReq_bd900)
             {
+				bFileForDeletionExist = true;   // PTS 1136793 
+
                 tgg00_FileId             ContObjFileId;
                 cbd900_ContObjFileInfo & ContObjFileInfo = gcoController_bd930.gccContObjFileDirPtr_bd930->operator[](FileNo);
                 bAllContFilesAreEmptyAndDeleted = true;
@@ -570,21 +577,21 @@ cbd930_GarbageCollector::bd930_ReleaseUnusedPagesOfAllFiles()
     /* check if anything was done in this function */
     if (! bSomethingDoneAtAll && !gcoController_bd930.gccStopGC_bd930 )
     {
-#       if defined(OBSOLET)
         /* +++ PTS 1113306 correct counter to avoid hot loops FF 10-JAN-2002 */
         if ( gcoController_bd930.gccNumGCUsedToReleasePages_bd930
-                <=gcoController_bd930.gccNumGCReqToReleasePages_bd930)
+            <=gcoController_bd930.gccNumGCReqToReleasePages_bd930)
         {
-            g01opmsg (sp3p_knldiag, sp3m_info, csp3_bd_msg, csp3_n_obj, "BD930RelPage: no wrk fnd", gcoIndex_bd930);
-            --gcoController_bd930.gccNumGCReqToReleasePages_bd930;
+            // PTS 1136793 
+            if (!bFileForDeletionExist && (0 < gcoController_bd930.gccNumGCReqToReleasePages_bd930))
+                --gcoController_bd930.gccNumGCReqToReleasePages_bd930;
+            //g01opmsg (sp3p_knldiag, sp3m_info, csp3_bd_msg, csp3_n_obj, "BD930RelPage: no wrk fnd", gcoIndex_bd930);
         }
-#       endif
         /* --- PTS 1113306 correct counter to avoid hot loops FF 10-JAN-2002 */
 #       if COMPILEMODE_MEO00 >= QUICK_MEO00 
         g01opmsg (sp3p_knldiag, sp3m_error, csp3_bd_msg, csp3_n_obj, "BD930RelPage: No Task   ", gcoIndex_bd930);
         /* check if the garbage controller is destroyed */
         gcoController_bd930.bd930_CheckGC();
-        g01abort (csp3_bd_msg, csp3_n_obj, "BD930RelPage: No Task   ", gcoIndex_bd930);
+//        g01abort (csp3_bd_msg, csp3_n_obj, "BD930RelPage: No Task   ", gcoIndex_bd930);
 #       endif
     }
     return bSomethingDoneAtAll;
@@ -882,7 +889,7 @@ cbd930_GarbageCollector::bd930_RemoveFile (tgg00_FileId &ObjFileId,
       ** release of all unused pages before, the counter may have been
       ** decremented twice (PTS 1113306)                                           
       */
-      if ( 0 < gcoController_bd930.gccNumGCReqToReleasePages_bd930 )  // PTS 1113306
+      if ( 1 < gcoController_bd930.gccNumGCReqToReleasePages_bd930 )  // PTS 1113306 & 1136793 
           gcoController_bd930.gccNumGCReqToReleasePages_bd930 --;
       
       /* check that this is the right item to delete and that the item is empty */
@@ -1181,17 +1188,17 @@ cbd930_GarbCollController::bd930_CheckGC ()
 
     /* check if the containers bd90ObjFileDir and bd93ContObjFileDir */
     /* the garbage collector is working on are consistent            */
-    bool bFileDirIsOk;
+    unsigned int bFileDirIsOk;
 
-    gccObjFileDirPtr_bd930->bd920Verify(bFileDirIsOk);
-    if (!bFileDirIsOk)
+    bFileDirIsOk = gccObjFileDirPtr_bd930->bd920Verify();
+    if ( bFileDirIsOk > 0 )
     {
         g01abort (csp3_b90_damaged_obj_chain, csp3_n_obj,
                   "BD930CGC: odd ObjFileDir", bFileDirIsOk);
     }
 
-    gccContObjFileDirPtr_bd930->bd920Verify(bFileDirIsOk);
-    if (!bFileDirIsOk)
+    bFileDirIsOk = gccContObjFileDirPtr_bd930->bd920Verify();
+    if ( bFileDirIsOk > 0 )
     {
         g01abort (csp3_b90_damaged_obj_chain, csp3_n_obj,
                   "BD930CGC:oddCoObjFileDir", bFileDirIsOk);
