@@ -18,23 +18,24 @@
 
   copyright:    (c) 2001-2004 SAP AG
 
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 
 *****************************************************************************/
 
@@ -665,7 +666,19 @@ bd95RollforwardObj_NewObj (tgg00_TransContext       &Trans,
         /* may collide with this page using bd910AssignToNewSpecifiedPage          */
         /* They MUST wait on this page until the first bd95RollforwardObj_NewObj   */
         /* has released it.                                                        */
-        NptrsSubRoot.bd910AssignToPage(bd90ObjFileDir[ObjFileNo].GetRootPage());
+        NptrsSubRoot.bd910AssignToPage(bd90ObjFileDir[ObjFileNo].GetRootPage(), false /*=dont wait for lock*/);
+        if (TrError == e_bd_page_collision)
+        {
+            /* PTS 1135361                                                        */
+            /* page MUST NOT be released because it isn't yet inilitialized       */
+            /* page lock MUST NOT be held when aquiring the root-page to avoid    */
+            /* deadlocks.                                                         */
+            /* Therefore release page as 'non used' page to converter and         */
+            /* reaccess it later                                                  */
+            TrError = e_ok;
+            NptrsPage.bd910FreePage(); 
+            NptrsSubRoot.bd910AssignToPage(bd90ObjFileDir[ObjFileNo].GetRootPage());
+        } 
         if (TrError != e_ok)
         {
             Kernel_OpError (csp3_bd_msg, csp3_n_obj)
@@ -677,7 +690,20 @@ bd95RollforwardObj_NewObj (tgg00_TransContext       &Trans,
                 << " FileNo:" << ObjFileNo;
             return;
         }
-    }
+        if (!NptrsPage.bd910PageIsAvailable())  /* PTS 1135361 */
+        {
+            NptrsPage.bd910AssignToNewSpecifiedPage (OId.gg92GetPno(), bPageGenerated);
+            if (TrError != e_ok )
+            {
+                Kernel_OpError(csp3_bd_msg, csp3_n_obj)
+                    << __FILE__ << ":" << __LINE__ 
+                    << " bd910AssignToNewSpecifiedPage:" << TrError
+                    << " PNo:"  << OId.gg92GetPno() 
+                    << " Root:" << bd90ObjFileDir[ObjFileNo].GetRootPage()
+                    << " FileNo:" << ObjFileNo;
+                return;
+            }
+        }   }
 
     /* if chaining is involved by this operation because of dechain from FreeList  */
     /* or because of synchronization with parallel running rollforward delete      */
@@ -685,7 +711,8 @@ bd95RollforwardObj_NewObj (tgg00_TransContext       &Trans,
         ((NptrsPage.np_ptr()->nd_free_obj_cnt() == 1) ||
             NptrsPage.bd910IsEmptyPage()))           /* PTS 1127493 FF 2004-FEB-02 */ 
     {
-        NptrsSubRoot.bd910AssignToSubroot(NptrsPage);
+        if( ! NptrsSubRoot.bd910PageIsAvailable())
+            NptrsSubRoot.bd910AssignToSubroot(NptrsPage); 
 
         /* PTS 1125141 03-NOV-2003                                                    */
         /* check if during access to subroot NptrsPage had been freed and couldn't be */
@@ -968,12 +995,13 @@ bd95RollforwardObj_NewObj (tgg00_TransContext       &Trans,
             ++ pPage->nd_occ_obj_cnt();
 
             /* update counter of used object frames in the chain info */
-            ++ ObjFileInfo[pPage->nd_chain_no()].ociAllObjCnt_bd900;
+            ObjFileInfo[pPage->nd_chain_no()].IncrementAllObjCnt();
 
             /* remove page from free page chain if there are no more free object frame on the page and           */
             /* update the empty page count on the root page if the page was empty before insering the new object */
             if ( NptrsPage.bd910IsEmptyPage())
             {
+                /* bd910RemovePageFromChainOfAllPages will release subroot PTS 1135421 */
                 NptrsSubRoot.bd910RemovePageFromChainOfAllPages(NptrsPage);  
             }
             else 
@@ -1028,8 +1056,9 @@ bd95RollforwardObj_NewObj (tgg00_TransContext       &Trans,
         tbd_nodeptr &pPage  = NptrsPage.np_ptr();
 
         /* integrate the new page into the object container */
+        const bool bNoInsertToFreeChain = false;
         const bool bPageMustNotBeCreated = true;
-        NptrsPage.bd910AssignToNewPageInDataChain (NptrsSubRoot, bPageMustNotBeCreated);
+        NptrsPage.bd910AssignToNewPageInDataChain (NptrsSubRoot, bNoInsertToFreeChain, bPageMustNotBeCreated);
         if (TrError != e_ok) return;
 
         /* get pointer to the wanted object frame */
@@ -1284,6 +1313,7 @@ bd95RemovePageFromObjFile (tgg00_TransContext       &Trans,
         /* if the page has to be an empty page by removing the objects        */ 
         /* and so it can be released                                          */
         /*--------------------------------------------------------------------*/
+        /* bd910RemovePageFromChainOfAllPages will release subroot PTS 1135421 */
         if (!NptrsSubRoot.bd910RemovePageFromChainOfAllPages(NptrsPage2))
         {        
             /* check if this error occured since the file was dropped */
