@@ -121,6 +121,7 @@ class cn50DBMUser;          //forward declaration to avoid inclusion of  vcn50.h
 class DBMSrvBHist_History;  //forward declaration to avoid inclusion of  DBMSrvBHist_History.hpp
 class DBMSrvBHist_EBIDList; //forward declaration to avoid inclusion of  DBMSrvBHist_EBIDList.hpp
 class DBMSrvHSS_Nodes;      //forward declaration to avoid include
+class DBMSrvKnlSrv_ConnectInfo; //forward declaration to avoid include
 class DBMSrvKnl_Session;    //forward declaration to avoid include
 
 class VControlDataT {
@@ -135,6 +136,7 @@ public:
       pUtilSession        = NULL;
       pSQLUserSession     = NULL;
       pServiceSession     = NULL;
+      pServiceSessionInfo = 0;
       pKernelSession      = NULL;
       pBackupSession      = NULL;
       pBackupStageSession = 0;
@@ -162,6 +164,7 @@ public:
     void                 * pUtilSession;
     void                 * pSQLUserSession;
     void                 * pServiceSession;
+    DBMSrvKnlSrv_ConnectInfo * pServiceSessionInfo;
     DBMSrvKnl_Session    * pKernelSession;
     void                 * pBackupSession;
     void                 * pBackupStageSession;
@@ -184,9 +187,10 @@ public:
       args      = NULL; 
     } // end CommandT
 
-    void setArgs(const char * pCommand) {
-      args = pCommand;
-      oArguments.setArguments((Tools_DynamicUTF8String::ConstPointer) pCommand);
+    void setArgs(const char * pCommand) 
+    {
+        args = pCommand;
+        oArguments.setArguments(pCommand);
     } // end setArgs
 
     int              nIndex;
