@@ -103,7 +103,8 @@ class tcn35b_DBMExternalBackupController: public tcn35a_DBBackupController
     void ReceiveReplyFromDBKernel(tin01_sql_session   & Session,
                                   int                 & SQLCode,
                                   tcn003_BackupResult & tResult,
-                                  boolean             & IsNoSQLError);
+                                  boolean             & IsNoSQLError,
+                                  bool                  verbose=true);
 
     int  GetStatusOfUtilityTask(tcn003_BackupResult &StatusInformation);
 
