@@ -388,30 +388,6 @@ tcn00_Error cn40DBMSetPath
         int           * replyLen,
         int             replyLenMax);
 
-/*!
-  -----------------------------------------------------------------------------
-  function:     cn40DBRegister
-  -----------------------------------------------------------------------------
-
-  description:  registers a database
-
-  arguments:    vcontrol    [INOUT]  - DBMServer session data
-                command     [IN]     - DBMServer command
-                replyData   [OUT]    - reply buffer
-                replyLen    [OUT]    - lenght of reply
-                replyLenMax [IN]     - max. length of reply buffer
-
-  return value: error code specified in gcn00c.h
- 
-  -----------------------------------------------------------------------------
- */
-tcn00_Error cn40DBRegister
-      ( VControlDataT * vcontrol,
-        CommandT      * command,
-        char          * replyData,
-        int           * replyLen,
-        int             replyLenMax);
-
 /*!
   -----------------------------------------------------------------------------
   function:     cn40DBCreate
