@@ -70,8 +70,8 @@ char *SdbinfoVersionMajor = "1";
 char *SdbinfoVersionMinor = "001";
 
 char *FullPrtFileName = NULL;     /*<IndepDataPath>/wrk/SDBINFO.PRT*/
-char *IndepDataPath = NULL;
-char *IndepProgPath = NULL;
+char IndepDataPath[1024];
+char IndepProgPath[1024];
 
 char *dll_filename_arr[20];       /*array for filenames: find_Files*/
 
@@ -568,17 +568,16 @@ int set_IndepPath(int path)
   char psBuffer[256];
   FILE *pipe;
 
-  char *lc_cmd_out = NULL;
+  char lc_cmd_out[40];
+
 
   /* command setting */
   switch(path)
   {
     case 1:
-      lc_cmd_out = (char *) malloc(33 *sizeof (char));
       strcpy (lc_cmd_out, "dbmcli dbm_getpath IndepDataPath");
       break;
     case 2:
-      lc_cmd_out = (char *) malloc(33 *sizeof (char));
       strcpy (lc_cmd_out, "dbmcli dbm_getpath IndepProgPath");
       break;
     default:
@@ -598,10 +597,11 @@ int set_IndepPath(int path)
     exit( 1 );
   }
  
-  #ifdef WIN32
+#ifdef WIN32
   /* Read pipe until end of file (termination of command) */
   while( !feof( pipe ) )
   {
+#endif
     if( fgets( psBuffer, 256, pipe ) != NULL )
     {
       /*std output*/
@@ -614,12 +614,10 @@ int set_IndepPath(int path)
           switch(path)
           {
             case 1:
-              IndepDataPath = (char *) malloc(strlen(psBuffer) *sizeof (char));
-              strcpy(IndepDataPath,psBuffer);
+               strcpy(IndepDataPath,psBuffer);
               break;
             case 2:
-              IndepProgPath = (char *) malloc(strlen(psBuffer) *sizeof (char));
-              strcpy(IndepProgPath,psBuffer);
+               strcpy(IndepProgPath,psBuffer);
               break;
             default:
               printf( "ERROR: undefined call of function set_IndepPath");
@@ -630,42 +628,9 @@ int set_IndepPath(int path)
         }
       }
     }
+#ifdef WIN32
   }
-  /* Close pipe and print return value */
-  /*printf( "\nProcess returned %d\n", _pclose( pipe ) );*/
-  #else
-  /* Read pipe until end of file (termination of command) */
-  if ((fgets( psBuffer, 256, pipe ) != NULL))
-  {
-    /*std output*/
-    if (strncmp(psBuffer,"OK",2)==0)
-    {
-      if (fgets( psBuffer, 256, pipe ) != NULL)
-      {
-        psBuffer[strlen(psBuffer)-1]='\0';
- 
-        switch(path)
-        {
-          case 1:
-            IndepDataPath = (char *) malloc(strlen(psBuffer) *sizeof (char));
-            strcpy(IndepDataPath,psBuffer);
-            break;
-          case 2:
-            IndepProgPath = (char *) malloc(strlen(psBuffer) *sizeof (char));
-            strcpy(IndepProgPath,psBuffer);
-            break;
-          default:
-            printf( "ERROR: undefined call of function set_IndepPath");
-            exit (-2);
-            break;
-        }
-        rc=0;
-      }
-    }
-  } 
-  /* Close pipe and print return value */
-  /*printf( "\nProcess returned %d\n", pclose( pipe ) );*/
-  #endif
+#endif
 
   return(rc);
 }
@@ -694,9 +659,8 @@ int get_Dll_info(char *dll_name)
 
   FILE *WriteHandle;
 
-  char *FullDllFileName = NULL;   /*<WinSystemPath>/dll_name*/
-  char *dll_name_str = NULL;      /*dll_name for stdout*/
-
+  char FullDllFileName[500];      /*<WinSystemPath>/dll_name*/
+  char dll_name_str[261];         /*dll_name for stdout*/
  
   TCHAR tchBuffer[BUFSIZE];       /*buffer for string*/
   DWORD dwResult;                 /*function return value + length of dll version info in byte*/
@@ -779,15 +743,10 @@ int get_Dll_info(char *dll_name)
   #######################
   */
 
-	/*set dll_name_str*/
-  dll_name_str = (char *) malloc(strlen(dll_name) *sizeof (char));
+  /*set dll_name_str*/
   strcpy(dll_name_str,dll_name);
  
-  /*set FullPrtFileName*/
-  FullDllFileName = (char *) malloc(strlen(FullWinSysPath)
-                    +strlen(slash)
-                    +strlen(dll_name) *sizeof (char));
-
+  /*set FullPrtFileName*/  
   strcpy(FullDllFileName,FullWinSysPath);
   strcat(FullDllFileName,slash);
   strcat(FullDllFileName,dll_name);
@@ -855,7 +814,7 @@ int get_Dll_info(char *dll_name)
       /* output signs (product name) ignoring peculiar to stdout and prt file */
       printf(" ");
 			fprintf(WriteHandle," ");
-      for (i=0; i<=length; i++)
+      for (i=0; i<length; i++)
       {
         if ((pcData[i] > 127) || (pcData[i]<0))
         { 
@@ -875,8 +834,8 @@ int get_Dll_info(char *dll_name)
           /*printf("  %i\n", (int) pcData[i]);*/
         }
       }
-      printf("runtime\n");       
-			fprintf(WriteHandle,"runtime\n");
+      printf(" runtime\n");       
+	  fprintf(WriteHandle," runtime\n");
  
 
       flag=0;
@@ -1003,7 +962,7 @@ size_t cnt_online;                    /*counter: processors online*/
 size_t cnt_configured;                /*counter: processors configured*/
 #endif
 
-  /* DDL Suffix */
+  /* Library Suffix */
 #ifdef WIN32
   #define SAPDB_DDL_SUFFIX cU(".dll")
 #elif defined (HPUX) && !defined (HP_IA64)
