@@ -1566,6 +1566,9 @@ static int cn12CServerCommand
                stricmp (data, CMD_EXIT   ) == 0 ||     
                stricmp (data, CMD_QUIT   ) == 0 ;
 
+    // exit client even we got an error on the exit commands
+    bool releaseOnError( bRelease && (stricmp(data, CMD_DROP)!=0) );
+
     if (options->bStaticCServer) {
       // static server
       commErr = ctrlservcommand (options->session, data, nCmdLen, *reply, (int *) &nReplyLen, nMaxReply) == CtrlCmdOk_csp09 
@@ -1577,6 +1580,7 @@ static int cn12CServerCommand
     } // end if
 
     if (commErr == DBMAPI_OK_CN14) {
+      bRelease = bRelease && (releaseOnError || (cn12CheckAnswer(*reply) == 0));
       if (!bQuiet || cn12CheckAnswer(*reply) != 0) {
         cn13fputs(options->outfile, *reply, IS_UNICODE(options), nReplyLen);
         cn12PrintProtocol(options, data, *reply, nReplyLen);
