@@ -22,7 +22,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 1998-2004 SAP AG
+    Copyright (c) 1998-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@
 
 
 
+
 */
 
 /* c-only module!!! */
@@ -65,6 +66,7 @@
 #include "gsp09.h"
 #include "hsp77.h"
 #include "heo01.h"
+#include "gip00.h"
 
 #include "hcn14.h"
 
@@ -2236,7 +2238,19 @@ tsp00_Int4 cn14GetTPUser (
 #endif
 /*    if (hTrace != NULL) fprintf(hTrace, "tmpfile is %s (%s %d)\n", szTmpFile, __FILE__, __LINE__); */
 
-    sprintf(szCommand, "tp pf=%s getlcconnectinfo %s lc-name=%s user-type=%s 1>%s 2>&1", profile, sysid, conn, pMode, szTmpFile);
+#ifdef _WIN32
+    if (getenv("SAPEXE") != NULL) {
+      sprintf(szCommand, "set PATH=%%SAPEXE%%;%%PATH%% && tp pf=%s getlcconnectinfo %s lc-name=%s user-type=%s 1>%s 2>&1", profile, sysid, conn, pMode, szTmpFile);
+    } else {
+      sprintf(szCommand, "tp pf=%s getlcconnectinfo %s lc-name=%s user-type=%s 1>%s 2>&1", profile, sysid, conn, pMode, szTmpFile);
+    } /* end if */
+#else
+    if (getenv("DIR_LIBRARY") != NULL) {
+      sprintf(szCommand, LDLIBPATH_IP00"=$DIR_LIBRARY:$"LDLIBPATH_IP00" ; tp pf=%s getlcconnectinfo %s lc-name=%s user-type=%s 1>%s 2>&1", profile, sysid, conn, pMode, szTmpFile);
+    } else {
+      sprintf(szCommand, "tp pf=%s getlcconnectinfo %s lc-name=%s user-type=%s 1>%s 2>&1", profile, sysid, conn, pMode, szTmpFile);
+    } /* end if */
+#endif
 
 /*    if (hTrace != NULL) fprintf(hTrace, "command is %s (%s %d)\n", szCommand, __FILE__, __LINE__); */
 
