@@ -1,20 +1,14 @@
-/*!*****************************************************************************
-  module:       vcn35.cpp
-  ------------------------------------------------------------------------------
-  responsible:  TiloH
-  special area: cn layer
-  description:  implementing connection between dbmsrv and abstract external
-                backup tool, declared in hcn35.h 
-  last change:  2000-11-24 14:37
-  version:      7.2.5
-  see also:     
-  ------------------------------------------------------------------------------
-                         Copyright (c) 1999-2004 SAP AG
-
+/*!
+    \file    vcn35.cpp
+    \author  TiloH
+    \ingroup cn layer
+    \brief   implementing connection between dbmsrv and abstract external
+             backup tool, declared in hcn35.h 
 
+\if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -31,9 +25,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
-
-
-*******************************************************************************/
+\endif
+*/
 
 // -----------------------------------------------------------------------------
 // includes
@@ -71,7 +64,9 @@ tcn35_BackupToolConnector::tcn35_BackupToolConnector(tcn35d_BackupInfo
     ToolTimeoutSuccess(300),
     ToolTimeoutSuccessIsDefaultFlag(1),
     ToolTimeoutFailure(60),
-    ToolTimeoutFailureIsDefaultFlag(1)
+    ToolTimeoutFailureIsDefaultFlag(1),
+    KernelTimeoutSuccess(300),
+    KernelTimeoutFailure(60)
 {
     int i;
 
@@ -138,11 +133,11 @@ tcn35_BackupToolConnector::tcn35_BackupToolConnector(tcn35d_BackupInfo
             tni34_ADataEntry::SetTemporaryDataEntryDirectory(TempDir);
     }
 
-    char *       TimeoutAsString=0;
+    char * TimeoutAsString=0;
 
     if(DetermineValueOfEnvironmentVariable("DBM_TTO_SUCCESS",
                                            TimeoutAsString,
-                                           "timeout for an external backup tool in a normal situation",
+                                           "timeout for the external backup tool in case of success",
                                            BackupInfo->DBName(),
                                            0,
                                            0)                                               &&
@@ -156,7 +151,7 @@ tcn35_BackupToolConnector::tcn35_BackupToolConnector(tcn35d_BackupInfo
 
     if(DetermineValueOfEnvironmentVariable("DBM_TTO_FAILURE",
                                            TimeoutAsString,
-                                           "timeout for an external backup tool in an error situation",
+                                           "timeout for the external backup tool in case of failure",
                                            BackupInfo->DBName(),
                                            0,
                                            0)                                                 &&
@@ -166,6 +161,36 @@ tcn35_BackupToolConnector::tcn35_BackupToolConnector(tcn35d_BackupInfo
             SetToolTimeoutFailure(i);
     }
 
+    cn36_StrDealloc(TimeoutAsString);
+
+    if(DetermineValueOfEnvironmentVariable("DBM_KTO_SUCCESS",
+                                           TimeoutAsString,
+                                           "timeout for database kernel in case of success",
+                                           BackupInfo->DBName(),
+                                           0,
+                                           0)                                               &&
+       0!=strlen(TimeoutAsString))
+    {
+        if(cn36_StrToInt(i, TimeoutAsString))
+            KernelTimeoutSuccess=i;
+    }
+
+    cn36_StrDealloc(TimeoutAsString);
+
+    if(DetermineValueOfEnvironmentVariable("DBM_KTO_FAILURE",
+                                           TimeoutAsString,
+                                           "timeout for database kernel in case of failure",
+                                           BackupInfo->DBName(),
+                                           0,
+                                           0)                                               &&
+       0!=strlen(TimeoutAsString))
+    {
+        if(cn36_StrToInt(i, TimeoutAsString))
+            KernelTimeoutFailure=i;
+    }
+
+    cn36_StrDealloc(TimeoutAsString);
+
     TheExternalBackupIDList=0;          //"avoid" deletion of TheExternalBackupIDList
 }
 
@@ -403,20 +428,25 @@ int tcn35_BackupToolConnector::StartTool()
     return rc;
 }
 
-int tcn35_BackupToolConnector::MaxWaitingTimeForToolInWaitingPhase(int DBActionWasSuccessful, int OnlyBackupToolIsRunning)
+int tcn35_BackupToolConnector::MaxWaitingTimeForToolInWaitingPhase(bool forTool, bool actionWasSuccessful)
 {
     int rc;
 
-    if(OnlyBackupToolIsRunning)
+    if(forTool)
     {
-        if(DBActionWasSuccessful)
+        if(actionWasSuccessful)
             rc=ToolTimeoutSuccess;
         else
             rc=ToolTimeoutFailure;
     }
     else
-        rc=60; //wait maximal 1 minute for the database
-    
+    {
+        if(actionWasSuccessful)
+            rc=KernelTimeoutSuccess;
+        else
+            rc=KernelTimeoutFailure;
+    }
+
     return rc;
 }
 
