@@ -9,7 +9,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -276,7 +277,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
         if(RequestSend==StatusOfRequest)
         {
             if(WaitForeverOnDB ||
-               MaxWaitingTimeOfCurrentWaitingPhase()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
+               MaxWaitingTimeForDB()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
             {
                 if(DBReplyAvailable(OutputMessagesForNonEvents)) // check db again
                     ReceiveReplyFromDB();
@@ -284,7 +285,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
                     ChangePhase=0;
             }
             else
-                elapsedTimeout=MaxWaitingTimeOfCurrentWaitingPhase();
+                elapsedTimeout=MaxWaitingTimeForDB();
         }
 
         if(ChangePhase)
@@ -318,7 +319,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
 
         if(Started==StatusOfTool || EndedPartially==StatusOfTool)  //was the tool running or partially running?
         {
-            if(MaxWaitingTimeOfCurrentWaitingPhase()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
+            if(MaxWaitingTimeForTool()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
             {
                 if(!BackupToolConnector->ToolIsRunning(ToolFinishedCompletely, OutputMessagesForNonEvents) && ToolFinishedCompletely)
                     StatusOfTool=Ended;
@@ -329,7 +330,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
             {
                 if(BackupToolConnector->ToolIsRunning(ToolFinishedCompletely, OutputMessagesForNonEvents) || !ToolFinishedCompletely)
                 {
-                    sprintf(MsgBuf_cn36, "Canceling tool after the timeout of %d seconds elapsed.\n", int(MaxWaitingTimeOfCurrentWaitingPhase()));
+                    sprintf(MsgBuf_cn36, "Canceling tool after the timeout of %d seconds elapsed.\n", int(MaxWaitingTimeForTool()));
                     LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::UsePrefixAndDateTime);
 
                     BackupToolConnector->CancelTool();
@@ -353,7 +354,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
 
         if(RequestSend==StatusOfRequest || CancelSendByDBMSrv==StatusOfRequest) // was the DB working on the request?
         {
-            if(MaxWaitingTimeOfCurrentWaitingPhase()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
+            if(MaxWaitingTimeForDB()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
             {
                 if(DBReplyAvailable(OutputMessagesForNonEvents))  // check db again
                     ReceiveReplyFromDB();
@@ -364,7 +365,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
 
         if(Started==StatusOfTool || EndedPartially==StatusOfTool)  //was the tool running or partialy running?
         {
-            if(MaxWaitingTimeOfCurrentWaitingPhase()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
+            if(MaxWaitingTimeForTool()>=cn36_SecondsBetween(StartOfCurrentWaitingPhase, cn36_GetCurrentTime()))
             {
                 if(!BackupToolConnector->ToolIsRunning(ToolFinishedCompletely, OutputMessagesForNonEvents) && ToolFinishedCompletely)
                     StatusOfTool=Ended;
@@ -374,7 +375,7 @@ int tcn35a_DBBackupController::BackupOperationIsRunning()
                 {
                     if(BackupToolConnector->ToolIsRunning(ToolFinishedCompletely, OutputMessagesForNonEvents) || !ToolFinishedCompletely)
                     {
-                        sprintf(MsgBuf_cn36, "Terminating tool after the timeout of %d seconds elapsed.\n", int(MaxWaitingTimeOfCurrentWaitingPhase()));
+                        sprintf(MsgBuf_cn36, "Terminating tool after the timeout of %d seconds elapsed.\n", int(MaxWaitingTimeForTool()));
                         LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::UsePrefixAndDateTime);
 
                         BackupToolConnector->TerminateTool();
@@ -618,9 +619,14 @@ int tcn35a_DBBackupController::RemovePipes()
     return rc;
 }
 
-int tcn35a_DBBackupController::MaxWaitingTimeOfCurrentWaitingPhase()
+int tcn35a_DBBackupController::MaxWaitingTimeForTool()
 {
-    return BackupToolConnector->MaxWaitingTimeForToolInWaitingPhase(DBActionWasSuccessful(), (WaitForBackupTool==CurrentWaitingPhase || WaitForKilled==CurrentWaitingPhase));
+    return BackupToolConnector->MaxWaitingTimeForToolInWaitingPhase(true, DBActionWasSuccessful()?true:false);
+}
+
+int tcn35a_DBBackupController::MaxWaitingTimeForDB()
+{
+    return BackupToolConnector->MaxWaitingTimeForToolInWaitingPhase(false, BackupToolConnector->ToolWasSuccessfulSoFar()?true:false);
 }
 
 void tcn35a_DBBackupController::ReceiveReplyFromDB()
