@@ -48,8 +48,9 @@
 
 #include <time.h>
 
-#include "SAPDB/DBM/Srv/DBMSrv_Reply.hpp"
-#include "SAPDB/DBM/Srv/HSS/DBMSrvHSS_Nodes.hpp"
+#include "DBM/Srv/DBMSrv_Reply.hpp"
+#include "DBM/Srv/HSS/DBMSrvHSS_Nodes.hpp"
+#include "DBM/Srv/KernelAccess/ServiceDB/DBMSrvKnlSrv_ConnectInfo.hpp"
 
 
 // -----------------------------------------------------------------------------
@@ -353,18 +354,30 @@ int  tcn35b_DBMExternalBackupController::DBIsReady()
         LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
 
         tcn003_BackupResult StatusInformation;
-        int ReplyFromDBKernel=DBReplyAvailable(),
+        int ReplyFromDBKernel=DBReplyAvailable(false),
             SleepTime=1;
 
         while(!ReplyFromDBKernel && !IsReady) // db-kernel should send reply in case of error or set szPagesLeft to a value
         {
-            Sleep(SleepTime++);
-
             if(GetStatusOfUtilityTask(StatusInformation))
+            {
                 if(StatusInformation.szPagesLeft[0]!='\0')
+                {
                     IsReady=1;
+                    sprintf(MsgBuf_cn36, "Database has finished preparation of the %s.\n", BackupInfo->getDataDirectionAsString());
+                }
+                else
+                {
+                    sprintf(MsgBuf_cn36, "Database is still preparing the %s.\n", BackupInfo->getDataDirectionAsString());
+                }
 
-            ReplyFromDBKernel=DBReplyAvailable();
+                LogWriter->Write(MsgBuf_cn36, tcn35d_DBBackupControllerLogWriter::UsePrefixAndDateTime);
+            }
+
+            ReplyFromDBKernel=DBReplyAvailable(false);
+
+            if(!ReplyFromDBKernel && !IsReady)
+                Sleep(SleepTime++);
         }
 
         if(ReplyFromDBKernel) // Reply available means, that db-kernel has finished the action
@@ -490,9 +503,10 @@ void tcn35b_DBMExternalBackupController::BackupRestoreIgnore()
 void tcn35b_DBMExternalBackupController::ReceiveReplyFromDBKernel(tin01_sql_session   & Session,
                                                                   int                 & SQLCode,
                                                                   tcn003_BackupResult & tResult,
-                                                                  boolean             & IsNoSQLError)
+                                                                  boolean             & IsNoSQLError,
+                                                                  bool                  verbose)
 {
-    const int RealParamCount=25;    //tFetchVars and sizeArray has at least 25 parts
+    const int RealParamCount=26;    //tFetchVars and sizeArray has at least 26 parts
                                     //Do not use BA_RESULT_PARAM_COUNT_CN003, because sizeArray maybe initialised with less parts.
                                     //This leads to a core.
 
@@ -522,8 +536,9 @@ void tcn35b_DBMExternalBackupController::ReceiveReplyFromDBKernel(tin01_sql_sess
                                                             sizeof (tResult.szDevicesUsed),
                                                             sizeof (tResult.szDatabaseID),
                                                             sizeof (tResult.szMaxUsedDataPage),
+                                                            sizeof (tResult.szConvPageCnt),
                                                             sizeof (tResult.szRedoTransRead),
-                                                            sizeof (tResult.szRedoTransDone)};  //<- 25-th element of sizeArray
+                                                            sizeof (tResult.szRedoTransDone)};  //<- 26-th element of sizeArray
 
     // init hostvar settings
     for(i=0;i<BA_RESULT_PARAM_COUNT_CN003;i++)
@@ -560,6 +575,7 @@ void tcn35b_DBMExternalBackupController::ReceiveReplyFromDBKernel(tin01_sql_sess
     tResult.szDevicesUsed[0] = '\0';
     tResult.szDatabaseID[0] = '\0';
     tResult.szMaxUsedDataPage[0]='\0';
+    tResult.szConvPageCnt[0]='\0';
     tResult.szRedoTransRead[0]='\0';
     tResult.szRedoTransDone[0]='\0';
 
@@ -587,179 +603,203 @@ void tcn35b_DBMExternalBackupController::ReceiveReplyFromDBKernel(tin01_sql_sess
                                  tResult.szDevicesUsed,
                                  tResult.szDatabaseID,
                                  tResult.szMaxUsedDataPage,
+                                 tResult.szConvPageCnt,
                                  tResult.szRedoTransRead,
                                  tResult.szRedoTransDone);
 
 
-    LogWriter->Write("Got the following reply from db-kernel:\n", tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
-
-    sprintf(MsgBuf_cn36, "SQL-Code              :%d\n", int(SQLCode));
-    LogWriter->Write(MsgBuf_cn36);
-
-    if('\0'!=tResult.szDate[0])
+    if(verbose)
     {
-        sprintf(MsgBuf_cn36, "Date                  :%s\n", tResult.szDate);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        LogWriter->Write("Got the following reply from db-kernel:\n", tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
 
-    if('\0'!=tResult.szTime[0])
-    {
-        sprintf(MsgBuf_cn36, "Time                  :%s\n", tResult.szTime);
+        sprintf(MsgBuf_cn36, "SQL-Code              :%d\n", int(SQLCode));
         LogWriter->Write(MsgBuf_cn36);
-    }
 
-    if('\0'!=tResult.szDatabase[0])
-    {
-        sprintf(MsgBuf_cn36, "Database              :%s\n", tResult.szDatabase);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDate[0])
+        {
+            sprintf(MsgBuf_cn36, "Date                  :%s\n", tResult.szDate);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szServer[0])
-    {
-        sprintf(MsgBuf_cn36, "Server                :%s\n", tResult.szServer);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szTime[0])
+        {
+            sprintf(MsgBuf_cn36, "Time                  :%s\n", tResult.szTime);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szKernelVersion[0])
-    {
-        sprintf(MsgBuf_cn36, "KernelVersion         :%s\n", tResult.szKernelVersion);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDatabase[0])
+        {
+            sprintf(MsgBuf_cn36, "Database              :%s\n", tResult.szDatabase);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szPagesTransfered[0])
-    {
-        sprintf(MsgBuf_cn36, "PagesTransfered       :%s\n", tResult.szPagesTransfered);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szServer[0])
+        {
+            sprintf(MsgBuf_cn36, "Server                :%s\n", tResult.szServer);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szPagesLeft[0])
-    {
-        sprintf(MsgBuf_cn36, "PagesLeft             :%s\n", tResult.szPagesLeft);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szKernelVersion[0])
+        {
+            sprintf(MsgBuf_cn36, "KernelVersion         :%s\n", tResult.szKernelVersion);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szVolumes[0])
-    {
-        sprintf(MsgBuf_cn36, "Volumes               :%s\n", tResult.szVolumes);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szPagesTransfered[0])
+        {
+            sprintf(MsgBuf_cn36, "PagesTransfered       :%s\n", tResult.szPagesTransfered);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szMediaName[0])
-    {
-        sprintf(MsgBuf_cn36, "MediaName             :%s\n", tResult.szMediaName);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szPagesLeft[0])
+        {
+            sprintf(MsgBuf_cn36, "PagesLeft             :%s\n", tResult.szPagesLeft);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szLocation[0])
-    {
-        sprintf(MsgBuf_cn36, "Location              :%s\n", tResult.szLocation);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szVolumes[0])
+        {
+            sprintf(MsgBuf_cn36, "Volumes               :%s\n", tResult.szVolumes);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szErrortext[0])
-    {
-        sprintf(MsgBuf_cn36, "Errortext             :%s\n", tResult.szErrortext);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szMediaName[0])
+        {
+            sprintf(MsgBuf_cn36, "MediaName             :%s\n", tResult.szMediaName);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szLabel[0])
-    {
-        sprintf(MsgBuf_cn36, "Label                 :%s\n", tResult.szLabel);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szLocation[0])
+        {
+            sprintf(MsgBuf_cn36, "Location              :%s\n", tResult.szLocation);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szIsConsistent[0])
-    {
-        sprintf(MsgBuf_cn36, "IsConsistent          :%s\n", tResult.szIsConsistent);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szErrortext[0])
+        {
+            sprintf(MsgBuf_cn36, "Errortext             :%s\n", tResult.szErrortext);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szFirstLogPageNo[0])
-    {
-        sprintf(MsgBuf_cn36, "FirstLogPageNo        :%s\n", tResult.szFirstLogPageNo);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szLabel[0])
+        {
+            sprintf(MsgBuf_cn36, "Label                 :%s\n", tResult.szLabel);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szLastLogPageNo[0])
-    {
-        sprintf(MsgBuf_cn36, "LastLogPageNo         :%s\n", tResult.szLastLogPageNo);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szIsConsistent[0])
+        {
+            sprintf(MsgBuf_cn36, "IsConsistent          :%s\n", tResult.szIsConsistent);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDBStamp1Date[0])
-    {
-        sprintf(MsgBuf_cn36, "DBStamp1Date          :%s\n", tResult.szDBStamp1Date);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szFirstLogPageNo[0])
+        {
+            sprintf(MsgBuf_cn36, "FirstLogPageNo        :%s\n", tResult.szFirstLogPageNo);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDBStamp1Time[0])
-    {
-        sprintf(MsgBuf_cn36, "DBStamp1Time          :%s\n", tResult.szDBStamp1Time);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szLastLogPageNo[0])
+        {
+            sprintf(MsgBuf_cn36, "LastLogPageNo         :%s\n", tResult.szLastLogPageNo);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDBStamp2Date[0])
-    {
-        sprintf(MsgBuf_cn36, "DBStamp2Date          :%s\n", tResult.szDBStamp2Date);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDBStamp1Date[0])
+        {
+            sprintf(MsgBuf_cn36, "DBStamp1Date          :%s\n", tResult.szDBStamp1Date);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDBStamp2Time[0])
-    {
-        sprintf(MsgBuf_cn36, "DBStamp2Date          :%s\n", tResult.szDBStamp2Time);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDBStamp1Time[0])
+        {
+            sprintf(MsgBuf_cn36, "DBStamp1Time          :%s\n", tResult.szDBStamp1Time);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szBDPageCount[0])
-    {
-        sprintf(MsgBuf_cn36, "BDPageCount           :%s\n", tResult.szBDPageCount);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDBStamp2Date[0])
+        {
+            sprintf(MsgBuf_cn36, "DBStamp2Date          :%s\n", tResult.szDBStamp2Date);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDevicesUsed[0])
-    {
-        sprintf(MsgBuf_cn36, "DevicesUsed           :%s\n", tResult.szDevicesUsed);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDBStamp2Time[0])
+        {
+            sprintf(MsgBuf_cn36, "DBStamp2Date          :%s\n", tResult.szDBStamp2Time);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szDatabaseID[0])
-    {
-        sprintf(MsgBuf_cn36, "DatabaseID            :%s\n", tResult.szDatabaseID);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szBDPageCount[0])
+        {
+            sprintf(MsgBuf_cn36, "BDPageCount           :%s\n", tResult.szBDPageCount);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szMaxUsedDataPage[0])
-    {
-        sprintf(MsgBuf_cn36, "Max Used Data Page    :%s\n", tResult.szMaxUsedDataPage);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDevicesUsed[0])
+        {
+            sprintf(MsgBuf_cn36, "DevicesUsed           :%s\n", tResult.szDevicesUsed);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szRedoTransRead[0])
-    {
-        sprintf(MsgBuf_cn36, "Redo Transactions Read:%s\n", tResult.szRedoTransRead);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szDatabaseID[0])
+        {
+            sprintf(MsgBuf_cn36, "DatabaseID            :%s\n", tResult.szDatabaseID);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    if('\0'!=tResult.szRedoTransDone[0])
-    {
-        sprintf(MsgBuf_cn36, "Redo Transactions Done:%s\n", tResult.szRedoTransDone);
-        LogWriter->Write(MsgBuf_cn36);
-    }
+        if('\0'!=tResult.szMaxUsedDataPage[0])
+        {
+            sprintf(MsgBuf_cn36, "Max Used Data Page    :%s\n", tResult.szMaxUsedDataPage);
+            LogWriter->Write(MsgBuf_cn36);
+        }
 
-    LogWriter->Write(tcn35d_DBBackupControllerLogWriter::SubALevelFromPrefixAndEndParagraph);
+        if('\0'!=tResult.szConvPageCnt[0])
+        {
+            sprintf(MsgBuf_cn36, "Converter Page Count  :%s\n", tResult.szConvPageCnt);
+            LogWriter->Write(MsgBuf_cn36);
+        }
+
+        if('\0'!=tResult.szRedoTransRead[0])
+        {
+            sprintf(MsgBuf_cn36, "Redo Transactions Read:%s\n", tResult.szRedoTransRead);
+            LogWriter->Write(MsgBuf_cn36);
+        }
+
+        if('\0'!=tResult.szRedoTransDone[0])
+        {
+            sprintf(MsgBuf_cn36, "Redo Transactions Done:%s\n", tResult.szRedoTransDone);
+            LogWriter->Write(MsgBuf_cn36);
+        }
+
+        LogWriter->Write(tcn35d_DBBackupControllerLogWriter::SubALevelFromPrefixAndEndParagraph);
+    }
 }
 
-int tcn35b_DBMExternalBackupController::GetStatusOfUtilityTask(tcn003_BackupResult &StatusInformation)
+int tcn35b_DBMExternalBackupController::GetStatusOfUtilityTask(tcn003_BackupResult & StatusInformation)
 {
     tin01_sql_session NormalSQLSession;
     tcn00_Error       rcDBM=OK_CN00;
     int               SQLCode=0;
     int               GotReplyFromKernel=0;
+    tcn003_BackupSession  * pBackupSession=(tcn003_BackupSession *) cn00DBMServerData::vcontrol()->pBackupSession;
 
     // connect temporary
-    tsp00_DbNamec   szDBName;
-    szDBName.rawAssign(BackupInfo->DBName());
-    rcDBM=cn80ConnectSQL(szDBName, &NormalSQLSession);
+    if(0!=pBackupSession &&
+       pBackupSession->bCheckOnly &&
+       0!=cn00DBMServerData::vcontrol()->pServiceSession)
+    {
+        rcDBM=cn80ConnectSQL(
+                    cn00DBMServerData::vcontrol()->pServiceSessionInfo->getDBName(),
+                    cn00DBMServerData::vcontrol()->pServiceSessionInfo->getUserName(),
+                    cn00DBMServerData::vcontrol()->pServiceSessionInfo->getUserPassword(),
+                    &NormalSQLSession);
+    }
+    else
+    {
+        tsp00_DbNamec szDBName;
+        szDBName.rawAssign(BackupInfo->DBName());
+        rcDBM=cn80ConnectSQL(szDBName, &NormalSQLSession);
+    }
 
     // ask for state
     if(OK_CN00==rcDBM)
@@ -790,7 +830,7 @@ int tcn35b_DBMExternalBackupController::GetStatusOfUtilityTask(tcn003_BackupResu
             if(0==SQLCode)
             {
                 boolean IsNoSQLError;
-                ReceiveReplyFromDBKernel(NormalSQLSession, SQLCode, StatusInformation, IsNoSQLError);
+                ReceiveReplyFromDBKernel(NormalSQLSession, SQLCode, StatusInformation, IsNoSQLError, false);
 
                 if(0==SQLCode)                // ignore IsNoSQLError
                     GotReplyFromKernel=1;
@@ -1095,22 +1135,30 @@ void tcn35b_DBMExternalBackupController::WriteHistoryFile()
                     int    NumberOfExternalBackupIDsFound=0;
                     char * lineForHSSCommand=0; //!< used to hold the backup_history_append command for HSS systems
                     bool   isHSS=DBMSrvHSS_Nodes::isHSS();
+                    bool   toolWasSuccessful=BackupToolConnector->ToolWasSuccessful(DBBackupSize)?true:false;
+                    int    toolError=toolWasSuccessful?0:int(GiveLastError());
 
                     AllIsOK=1;
 
                     sprintf(MsgBuf_cn36, "Using '%s' as external backup history.\n", BackupInfo->PathOfExternalBackupHistory());
                     LogWriter->Write(MsgBuf_cn36);
 
-                    if(BackupToolConnector->ToolWasSuccessful(DBBackupSize))
+                    if(toolWasSuccessful)
                     {
                         if(!BackupToolConnector->CollectExternalBackupIDs(ExternalBackupID, NumberOfExternalBackupIDsFound) ||
                            NumberOfExternalBackupIDsFound!=BackupInfo->NumberOfPipes())
                         {
-                            ErrorHandler->Report(tcn35e_DBMBackupError(tcn35e_DBMBackupError::CaseCouldNotGetExternalBackupIDs));    // rc allready 0
-                            AllIsOK=0;
+                            tcn35e_DBMBackupError error(tcn35e_DBMBackupError::CaseCouldNotGetExternalBackupIDs);
+                            ErrorHandler->Report(error);
+
+                            //we had no previous error (toolWasSuccessful==true), so prepare to report this new error in dbm.ebf
+                            toolError=GiveLastError();
+                            cn36_StrAllocCpy(ToolErrorText, error.GiveErrorMsgBuffer());
+                            toolWasSuccessful=false;
                         }
                     }
-                    else
+
+                    if(!toolWasSuccessful)
                     {
                         for(int i=0; AllIsOK && i<BackupInfo->NumberOfPipes(); i++)
                         {
@@ -1164,8 +1212,8 @@ void tcn35b_DBMExternalBackupController::WriteHistoryFile()
                                             DataTypeToListSaveTypeMap[DataType],
                                             DBStartDateTime,
                                             tcn35_BackupToolConnectorEnum(BackupInfo->MediaName()).MagicString(),
-                                            BackupToolConnector->ToolWasSuccessful(DBBackupSize)?0:int(GiveLastError()),
-                                            BackupToolConnector->ToolWasSuccessful(DBBackupSize)?"":(0==ToolErrorText?"":ToolErrorText),
+                                            toolError,
+                                            toolWasSuccessful?"":(0==ToolErrorText?"":ToolErrorText),
                                             BackupInfo->MediaName(),
                                             long(BackupInfo->CountInPages(i)),
                                             int(BackupInfo->PagesPerBlock()),
@@ -1485,6 +1533,9 @@ void tcn35b_DBMExternalBackupController::PrintBackupAnswer(/*char *ReplyData, in
         sprintf(pCurrPos, "%-20s%s%s%s",BA_RESULT_MUSEDATAPG_CN003, VALUE_SEPSTRING_CN00, TheDBResult.szMaxUsedDataPage, LINE_SEPSTRING_CN00);
         pCurrPos = ReplyData + strlen(ReplyData);
 
+        sprintf(pCurrPos, "%-20s%s%s%s",BA_RESULT_CONVPGCNT_CN003, VALUE_SEPSTRING_CN00, TheDBResult.szConvPageCnt, LINE_SEPSTRING_CN00);
+        pCurrPos = ReplyData + strlen(ReplyData);
+
         //szRedoTransRead and szRedoTransDone should not be displayed for backup/restore commands
 
         LogWriter->Write("Constructed the following reply:\n", tcn35d_DBBackupControllerLogWriter::AddALevelToPrefix);
@@ -1564,6 +1615,9 @@ void tcn35b_DBMExternalBackupController::PrintBackupAnswer(/*char *ReplyData, in
         sprintf(MsgBuf_cn36, "%-20s%s%s%s",BA_RESULT_MUSEDATAPG_CN003, VALUE_SEPSTRING_CN00, TheDBResult.szMaxUsedDataPage, LINE_SEPSTRING_CN00);
         LogWriter->Write(MsgBuf_cn36);
 
+        sprintf(MsgBuf_cn36, "%-20s%s%s%s",BA_RESULT_CONVPGCNT_CN003, VALUE_SEPSTRING_CN00, TheDBResult.szConvPageCnt, LINE_SEPSTRING_CN00);
+        LogWriter->Write(MsgBuf_cn36);
+
         LogWriter->Write(tcn35d_DBBackupControllerLogWriter::SubALevelFromPrefixAndEndParagraph);
     }
 }
