@@ -200,7 +200,7 @@ bool StageFileInfo::determineBackupLabel(
     replyData[0]='\0';
     replyLen=0;
 
-    return m_Label.readLabelFrom(NameOfStageFile, m_BlockSize, replyData, &replyLen, replyLenMax);
+    return m_Label.readLabelFrom(NameOfStageFile, m_BlockSize, DBMSrvBMedia_DeviceType::File, replyData, &replyLen, replyLenMax);
 }
 
 int StageFileInfo::SetInternalBackupID(const char * Key, const char * Label)
@@ -797,7 +797,7 @@ int tcn35c_DBMStageBackupController::Prepare()
                             int  replyLength=0;
                             int  maxReplyLength=1024;
 
-                            if(m_Label.readLabelFrom(CurrentStageFile->GiveInfo()->GiveNameOfStageFile(), m_BytesPerBlockOnStage, reply, &replyLength, maxReplyLength))   //determine label of file
+                            if(m_Label.readLabelFrom(CurrentStageFile->GiveInfo()->GiveNameOfStageFile(), m_BytesPerBlockOnStage, DBMSrvBMedia_DeviceType::File, reply, &replyLength, maxReplyLength))   //determine label of file
                             {
                                 if(!m_Label.equals(CurrentStageFile->GiveInfo()->getBackupLabel()))
                                 {
@@ -956,6 +956,23 @@ int tcn35c_DBMStageBackupController::Prepare()
                             }
                         }
                     }
+                    else
+                    {
+                        char * DateTime=FileListElem->GiveInfo()->getStartDateTimeAsString();
+                        char * DateTimeModified=FileListElem->GiveInfo()->getLastModificationDateTimeAsString();
+
+                        sprintf(
+                            MsgBuf_cn36,
+                            "Stage file '%s' created at '%s' and lastly modified at '%s' will not be processed, as it can not be found in the backup history.\n",
+                            FileListElem->GiveInfo()->GiveNameOfStageFile(),
+                            0==DateTime?"":DateTime,
+                            0==DateTimeModified?"":DateTimeModified);
+
+                        LogWriter->Write(MsgBuf_cn36);
+
+                        cn36_StrDealloc(DateTime);
+                        cn36_StrDealloc(DateTimeModified);
+                    }
                 }
 
                 LogWriter->Write(tcn35d_DBBackupControllerLogWriter::EndParagraph);
