@@ -1024,12 +1024,12 @@ tcn35d_DBBackupError::DBBackupErrorDescription tcn35e_DBMBackupError::DBMBackupE
 
     {CaseCouldNotGetInternalBackupIDs,
      None,
-     "Could not get external backup ID's from the backup tool.\n",
+     "Could not get internal backup ID assigned by the database kernel.",
      0},
 
     {CaseCouldNotGetExternalBackupIDs,
      None,
-     "Could not get external backup ID's from the backup tool.\n",
+     "Could not get external backup ID's from the backup tool.",
      0},
 
     {CaseCouldNotWriteToToolHistFile,
