@@ -671,6 +671,19 @@ int  cn36_StrConsistsOfDigits(const char *String)
     return rc;
 }
 
+const char * cn36_FirstNonDigitOf(const char * string, size_t stringLength)
+{
+    size_t i=0;
+
+    while(i<stringLength && '\0'!=(*string) && isdigit(*string))
+    {
+        ++i;
+        ++string;
+    }
+
+    return string;
+}
+
 char * cn36_TerminatingZeroOf(char * s)
 {
     return s+strlen(s);
