@@ -297,15 +297,11 @@ static int cn38_ReadParameterFile(const char *           ParameterFileName,
                         const char * EndOfNewStagingName=0;
                         const char * NewStagingSize;
                         const char * EndOfNewStageSize;
-                        const char * UnitOfNewSize;
-                        const char * EndOfUnitOfNewSize;
 
                         cn36_GetStringBetweenDoubleQuotesOrWhiteSpaces(NewStagingName, EndOfNewStagingName);    // stage names can be enclosed in double qoutes
 
                         NewStagingSize=cn36_FirstNonWhiteSpaceOf(cn36_FirstWhiteSpaceOf(EndOfNewStagingName));
                         EndOfNewStageSize=cn36_FirstWhiteSpaceOf(NewStagingSize);
-                        UnitOfNewSize=cn36_FirstNonWhiteSpaceOf(EndOfNewStageSize);
-                        EndOfUnitOfNewSize=cn36_FirstWhiteSpaceOf(UnitOfNewSize);
 
                         if('\0'==NewStagingName[0] || '\0'==NewStagingSize[0])
                         {
@@ -314,9 +310,26 @@ static int cn38_ReadParameterFile(const char *           ParameterFileName,
                         }
                         else
                         {
+                            const char * UnitOfNewSize;
+                            const char * EndOfUnitOfNewSize;
+
                             teo00_Uint8 ISize;
                             teo00_Uint8 UnitFactor=1;
 
+                            if(cn36_StrNConsistsOfDigits(
+                                   NewStagingSize,
+                                   EndOfNewStageSize-NewStagingSize))
+                            {
+                                UnitOfNewSize=cn36_FirstNonWhiteSpaceOf(EndOfNewStageSize);
+                            }
+                            else
+                            {
+                                UnitOfNewSize=cn36_FirstNonDigitOf(NewStagingSize, EndOfNewStageSize-NewStagingSize);
+                                EndOfNewStageSize=UnitOfNewSize;
+                            }
+
+                            EndOfUnitOfNewSize=cn36_FirstWhiteSpaceOf(UnitOfNewSize);
+
                             if(!cn36_StrNToUInt8(ISize,
                                                  NewStagingSize,
                                                  EndOfNewStageSize-NewStagingSize) ||   //could not transform String to Integer
@@ -337,14 +350,22 @@ static int cn38_ReadParameterFile(const char *           ParameterFileName,
                                         else
                                             if(0==cn36_StrStrNUprCmp("GB", UnitOfNewSize, EndOfUnitOfNewSize-UnitOfNewSize))
                                                 UnitFactor=1024*1024*1024;
+                                            else
+                                            {
+                                                rc=0;
+                                                TheBackint2ErrorHandler_cn385->Report(tcn385_Backint2Error(tcn385_Backint2Error::SyntaxErrorSize));
+                                            }
 
-                                    if(MAX_UINT8_CN36/UnitFactor<ISize) // test for (MAX_UINT8_CN36<ISize*UnitFactor) without risking an overflow by multiplication
+                                    if(rc)
                                     {
-                                        rc=0;
-                                        TheBackint2ErrorHandler_cn385->Report(tcn385_Backint2Error(tcn385_Backint2Error::SyntaxErrorSize));
+                                        if(MAX_UINT8_CN36/UnitFactor<ISize) // test for (MAX_UINT8_CN36<ISize*UnitFactor) without risking an overflow by multiplication
+                                        {
+                                            rc=0;
+                                            TheBackint2ErrorHandler_cn385->Report(tcn385_Backint2Error(tcn385_Backint2Error::SyntaxErrorSize));
+                                        }
+                                        else
+                                            ISize*=UnitFactor;
                                     }
-                                    else
-                                        ISize*=UnitFactor;
                                 }
 
                                 if(rc)
@@ -370,7 +391,7 @@ static int cn38_ReadParameterFile(const char *           ParameterFileName,
                                             TheBackint2ErrorHandler_cn385->Report(tcn385_Backint2Error(tcn385_Backint2Error::InternalError));
                                         }
                                         else
-                                            Output.Write("Using staging area ", CopyOfNewStagingName, " of size ", ISizeAsString, ".");
+                                            Output.Write("Using staging area ", CopyOfNewStagingName, " with a size of ", ISizeAsString, " bytes.");
                                     }
                                 }
                             }
