@@ -16,7 +16,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@
 
 
 
+
 */
 
 /*
@@ -206,25 +207,17 @@ tcn00_Error cn41UserLogon
                            .setUserName ( szUser );
 
     nFuncReturn = vcontrol->pCurrentUser->reload();
+
     if (nFuncReturn == ERR_USRREAD_CN00) {
-      // try to restore
-      cn42RestoreFile(vcontrol->dbname, FGET_USER_CN42);
+      if (cn50DBMUser::isEmpty(vcontrol->dbname)) {
+        if (cn50DBMUser::tryRestoreIfEmpty(vcontrol->dbname)) {
+          nFuncReturn = vcontrol->pCurrentUser->reload();
+        } // end if
+      } // end if
     } // end if
-
-    nFuncReturn = vcontrol->pCurrentUser->reload();
+  
     if (nFuncReturn == ERR_USRREAD_CN00) {
-      // check if upc is empty 
-      tsp00_Int4              nLength = 0;
-      tsp00_Uint4             nToken = FIRST_TOKEN_EO28;
-      tcn00_UserNamec         szUserName;
-      teo200_EventList        EventList;
-
-      {
-        teo28_ProfileContainer  Profile(vcontrol->dbname, &EventList);
-        Profile.eo28_ScanProfiles(nToken, nLength, NULL, szUserName, &EventList);
-      }
-    
-      if(!EventList && nToken == NO_TOKEN_EO28) {
+      if (cn50DBMUser::isEmpty(vcontrol->dbname)) {
         // Yes, upc is empty -> create user
         nFuncReturn = OK_CN00;
 
@@ -245,10 +238,7 @@ tcn00_Error cn41UserLogon
                                   .setGUIRights    ( DBMMaskAll_CN50, DBMUserDefaultGUI_CN50 );
 
           nFuncReturn = vcontrol->pCurrentUser->save(true);
-          if (nFuncReturn == OK_CN00) {
-            // make a copy from the upc
-            cn42BackupFile(vcontrol->dbname, FGET_USER_CN42);
-          } else {
+          if (nFuncReturn != OK_CN00) {
             nFuncReturn = (nFuncReturn != ERR_USRFRM_CN00) ? ERR_USRFAIL_CN00 : nFuncReturn;
           } // end if
         } // end if 
@@ -648,8 +638,6 @@ tcn00_Error cn41UserCreate
   } // end if
   
   if (nFuncReturn == OK_CN00) {
-    // make a copy from the upc
-    cn42BackupFile(vcontrol->dbname, FGET_USER_CN42);
     cn90AnswerOK(replyData, replyLen, NULL);
   } else {
     cn90AnswerIError(replyData, replyLen, nFuncReturn);
@@ -828,8 +816,6 @@ tcn00_Error cn41UserPut
   } // end if
 
   if (nFuncReturn == OK_CN00) {
-    // make a copy from the upc
-    cn42BackupFile(vcontrol->dbname, FGET_USER_CN42);
     cn90AnswerOK(replyData, replyLen, NULL);
   } else {
     cn90AnswerIError(replyData, replyLen, nFuncReturn);
