@@ -1054,7 +1054,39 @@ tcn00_UserNamec cn50DBMUser :: getUser
      } // end switch
    } // end if
 
-   return aUser;
+    // fallback to paramfile (if exists)
+    if ((aUser.length() == 0) && (nProperty == FIRSTDBM_CN50)) {
+        tcn002_XpValueString     szNameXP;
+        tcn00_UserNamec          szName;
+        if (cn20XParamGetValue( szDBName, PAN_CONTROLID, szNameXP) == OK_CN00) {
+            szName.rawAssign(szNameXP);
+            cn50DBMUser oUser(szDBName, szName);
+            if (!oUser.lastEvent()) {
+                oUser.setColdUser(true, false);
+                oUser.save();
+                aUser = oUser.getUserName();
+            } else {
+                tcn002_XpValueString     szPwXP;
+                tcn00_UserNamec          szPw;
+                if (cn20XParamGetValue( szDBName, PAN_CONTROLPW, szPwXP) == OK_CN00) {
+                    szPw.rawAssign(szPwXP);
+                    cn50DBMUser newUser;
+                    newUser.clear();
+                    newUser.setDBName    ( szDBName    )
+                        .setUserName     ( szName      )
+                        .setMasterPwd    ( szPw        )
+                        .setServerRights ( DBMMaskAll_CN50, DBMUserDefault_CN50 )
+                        .setGUIRights    ( DBMMaskAll_CN50, DBMUserDefaultGUI_CN50 )
+                        .setColdUser     (true, false);
+
+                    newUser.save(true);
+                    aUser = newUser.getUserName();
+                } // end if
+            } // end if
+        } // end if
+    } // end if 
+
+    return aUser;
 } // end cn50DBMUser :: getUser 
 /*
   -----------------------------------------------------------------------------
