@@ -63,6 +63,8 @@
 #include "hcn80.h"
 #include "hcn90.h"
 
+#include "DBM/Srv/KernelAccess/ServiceDB/DBMSrvKnlSrv_ConnectInfo.hpp"
+
 /* ------------------------------------------------------------------
  * SPECIFICATION PRIVATE TYPES/MACROS
  * ------------------------------------------------------------------
@@ -186,6 +188,12 @@ static void cn80_FreeSession(
       case SESSION_SERVICE:
         pSession =  (tin01_sql_session *) vcontrol->pServiceSession;
         vcontrol->pServiceSession = NULL;
+
+        if(0!=vcontrol->pServiceSessionInfo)
+        {
+            delete vcontrol->pServiceSessionInfo;
+            vcontrol->pServiceSessionInfo=0;
+        }
         break;
     } /* end switch */
   } /* end if */
@@ -786,7 +794,10 @@ tcn00_Error cn80ServiceConnect (
     if (nFuncReturn == OK_CN00) {
       /* allocate new memory for sql session */
       cn00MyMalloc (sizeof (tin01_sql_session), &pSession, &bMallocOK);
-      if ((pSession == NULL) || (!bMallocOK)) {
+
+      vcontrol->pServiceSessionInfo=new DBMSrvKnlSrv_ConnectInfo(szDBName, szUserName, szPassword);
+
+      if ((pSession == NULL) || (!bMallocOK) || 0==vcontrol->pServiceSessionInfo) {
         nFuncReturn = cn90AnswerIError(replyData, replyLen, ERR_MEM_CN00);
       } else {
         cn80_SetSession(vcontrol, pSession, SESSION_SERVICE);
@@ -1427,6 +1438,27 @@ tcn00_Error cn80ConnectSQL
                        SESSION_SQLUSER);
 
 } // end cn80ConnectSQL
+/*
+  -----------------------------------------------------------------------------
+ */
+tcn00_Error cn80ConnectSQL(
+                const char        * dbName,
+                const char        * userName,
+                const char        * userPassword,
+                tin01_sql_session * sqlSession)
+{
+    char reply[PARAMETER_MAXLEN_CN90]="";
+    int  replyLen;
+
+    return cn80_Connect(
+                reply, 
+                &replyLen, 
+                sqlSession,
+                dbName,
+                userName, 
+                userPassword, 
+                SESSION_SQLUSER);
+}
 
 /*
   -----------------------------------------------------------------------------
