@@ -60,7 +60,9 @@
 #include "heo01.h"
 #include "hcn90.h"
 
-#include "SAPDB/RunTime/RTE_GetDBRootOfDB.h"
+#include "RunTime/RTE_GetDBRootOfDB.h"
+#include "RunTime/RTE_ActiveDatabase.hpp"
+#include "RunTime/RTE_DBRegister.hpp"
 
 #include "geo00_2.h"
 
@@ -1212,32 +1214,14 @@ tcn00_DBState cn90DBState
         ( const tsp00_DbNamec  & szDbName,
                 tsp00_C256c    & szErrText)
 {
-  FUNCTION_DBG_MCN00_1("cn90DBState");
+  SAPDBErr_MessageList oMsg;
+  tcn00_DBState        DBState = STATE_UNKNOWN_CN00;
+  RTE_ActiveDatabase * pActiveDatabase = (RTE_DBRegister::Instance()).GetActiveDatabase( szDbName.asCharp(), oMsg);
 
-  tcn00_DBState     DBState = STATE_UNKNOWN_CN00;
-  tsp9_rte_xerror   xError;
-  tsp00_Uint4       kernelDbState;
-
-  /* set global variables for sqlxknlopenmonitor */
-  tsp00_Pathc     szDBRoot;
-  sqlxinit (szDbName, cn90DBRoot(szDbName, szDBRoot));
-
-  kernelDbState = sqlxdbstate( szDbName, &xError );
-
-  if ( xError.xe_result != csp9_xrte_ok ) {
-    kernelDbState = sqlxdbstate( szDbName, &xError );
-  } // end if
-  
-  if ( xError.xe_result != csp9_xrte_ok ) {
-      DBState = STATE_ERROR_CN00;
-      szErrText.rawAssign(xError.xe_text);
-      {
-      teo200_EventList aEvent1(FUNCTION_NAME_MCN00_1, 1, TERR_CN00_1, "DBM", "%d, %s ", (int) xError.xe_result, szErrText.asCharp());
-      teo200_EventList aEvent(aEvent1, FUNCTION_NAME_MCN00_1, ERR_STATE_CN00_1);
-      tin100_GlobalLog::writeEntry (aEvent);
-      }
-  } else {
-      switch( kernelDbState ) {
+  if (pActiveDatabase != NULL) {
+    const RTE_Database::DBStatusInfo * pStatus = pActiveDatabase->GetDBStatus(oMsg);
+    if (pStatus != NULL) {
+      switch (pStatus->statusId) {
         case SERVER_OFFLINE_EO00:
             DBState = STATE_OFFLINE_CN00;
             break;
@@ -1278,18 +1262,16 @@ tcn00_DBState cn90DBState
             DBState = STATE_UNDEFINED_CN00;
             break;
         default:
-            {
-            teo200_EventList aEvent1(FUNCTION_NAME_MCN00_1, 1, TERR_CN00_1, "DBM", "unexpected dbstate %d", (int) kernelDbState);
-            teo200_EventList aEvent(aEvent1, FUNCTION_NAME_MCN00_1, ERR_STATE_CN00_1);
-            tin100_GlobalLog::writeEntry (aEvent);
-            }
             DBState = STATE_UNKNOWN_CN00;
             break;
       } // end switch
+    } else {
+      DBState = STATE_ERROR_CN00;
+    } // end if
+  } else {
+    DBState = STATE_ERROR_CN00;
   } // end if
 
-  sqlxfinish();
-
   return DBState;
 } /* end cn90DBState */
 
@@ -1301,24 +1283,20 @@ tcn00_DBState cn90DBState
 tsp9_pgm_kind cn90DBSpeed
       ( const tsp00_DbNamec szDbName )
 {
-  tsp9_pgm_kind nDBSpeed = csp9_any_pgm;
-  tsp9_rte_xerror     xError;
-  void              * hEnum;
-  tsp9_rte_dbinfo     dbInfo;
+  SAPDBErr_MessageList oMsg;
+  tsp9_pgm_kind        nDBSpeed = csp9_any_pgm;
+  RTE_ActiveDatabase * pActiveDatabase = (RTE_DBRegister::Instance()).GetActiveDatabase( szDbName.asCharp(), oMsg);
 
-  sqlxopen_db_enum (&hEnum, true, &xError);
+  if (pActiveDatabase != NULL) {
+    const RTE_SpeedInfo & oSpeed = pActiveDatabase->GetActiveSpeed();
 
-  if (xError.xe_result == csp9_xrte_ok) {
-    while (xError.xe_result == csp9_xrte_ok) {
-      sqlxnext_db (hEnum, &dbInfo, &xError);
-      if (xError.xe_result == csp9_xrte_ok) {
-        if ((_tcsicmp(dbInfo.dbname, szDbName) == 0) && dbInfo.state == csp9_state_running ) {
-          nDBSpeed = dbInfo.pgmKind;
-        } // end if
-      } // end if
-    } // end while
-
-    sqlxclose_db_enum (hEnum);
+    if (oSpeed == speedFast) {
+      nDBSpeed = csp9_fast_pgm;
+    } else if (oSpeed == speedSlow) {
+      nDBSpeed = csp9_slow_pgm;
+    } else if (oSpeed == speedTest) {
+      nDBSpeed = csp9_test_pgm;
+    } // end if
   } // end if
 
   return nDBSpeed;
