@@ -72,19 +72,6 @@ public:
         sqlInitSession (pIKernelSink);
 	}
 
-  /* +++ PTS 1119957 change char* to DbpTypeUnicode* +++ */
-  long  DropUser (DbpTypeUnicode*);
-  long  RenameUser (DbpTypeUnicode*,DbpTypeUnicode*);
-
-  long  DropTable (DbpTypeUnicode*,DbpTypeUnicode*);
-  long  RenameTable (DbpTypeUnicode*,DbpTypeUnicode*,DbpTypeUnicode*);
- 
-  /* PTS 1111215 */
-  long  DropColumn (DbpTypeUnicode*,DbpTypeUnicode*,DbpTypeUnicode*);
-  long  RenameColumn (DbpTypeUnicode*,DbpTypeUnicode*,DbpTypeUnicode*,DbpTypeUnicode*);
-  
-  /* --- PTS 1119957 change char* to DbpTypeUnicode* --- */
-
 #define COM_INTERFACE IDbpInstall
 #define COM_INTERFACE_IID IID_IDbpInstall
 #include "livecachedbproc.h" /* no check */
@@ -115,6 +102,7 @@ public:
   STDMETHOD(FORCE_AND_WAIT_FOR_CHECKPOINT)();
   STDMETHOD(Register)();
   STDMETHOD(DROP_SCHEMAS)();
+  STDMETHOD(OMS_CLEANUP_AFTER_INIT)();
 };
 
 #endif  /* HCO20_H */
