@@ -1,5 +1,5 @@
 /*!
-  @file           Copy of gen50.h
+  @file           gen50.h
   @author         JoergM
   @special area   Kernel LZU UNIX
   @brief          Kernel interne Strukturen
@@ -48,20 +48,23 @@
 #include "heo07.h"
 #include "vsp002.h"
 #include "RunTime/RTE_Types.h"
+#include "RunTime/System/RTESys_AtomicOperation.h"
 
 /*===========================================================================*
  *  DEFINES                                                                  *
  *===========================================================================*/
 
 #define NO_DISTRIBUTION
+/* Define this to reenabled old IOC queue using spinlocks instead of cmpxchg PTS 1138110 */
+/* #define OLD_SPINLOCK_IOC_QUEUE */
 
 /*
    --- Kernel threads stack sizes 
    These sizes are used as input for sqlbeginthread() calls
  */
 #if defined (HP_IA64) || (defined(LINUX) && defined(IA64))
-#define UKT_BASE_STACK_SIZE             ( 512 * 1024)
-#define UKT_TEMP_STACK_SIZE             ( 512 * 1024)
+#define UKT_BASE_STACK_SIZE             ( 768 * 1024)
+#define UKT_TEMP_STACK_SIZE             ( 768 * 1024)
 #define KT_WORKER_STACK_SIZE            ( 512 * 1024)
 #define KT_TIMER_STACK_SIZE             ( 512 * 1024)
 #define KT_CLOCK_STACK_SIZE             ( 512 * 1024)
@@ -343,6 +346,7 @@ struct XXX_QUEUE_HEAD
  */
 struct IOC_QUEUE_HEAD
 {
+#if defined(OLD_SPINLOCK_IOC_QUEUE) || !defined(RTESYS_HAS_NATIVE_ATOMIC_OPERATION)
     struct IOC_QUEUE          *first;
     struct IOC_QUEUE          *last;
    ALONE_IN_CACHE(dum_before) 
@@ -352,6 +356,9 @@ struct IOC_QUEUE_HEAD
      * first is first free element
      * last is last used element
      */
+#else
+      struct DOUBLY_LINKED       *last;
+#endif
 };
 
 
@@ -543,12 +550,14 @@ struct TASK_TYPE
     SAPDB_Bool                              connectable;
     SAPDB_Int4                              state_reason ;
     SAPDB_Int4                              stack_size ;
+    struct DOUBLE_Q_HEAD                    dlq_connreq ;
+
+
     /*
      *  time for task's timeout if still in VRECEIVE
      */
     time_t                                  task_timeout ;
     time_t                                  CmdWaitTime  ;
-    time_t                                  wait_time ;
 
     SAPDB_Int4                              signal_count ;
     SAPDB_Int4                              vsignal_ok ;
@@ -594,6 +603,8 @@ struct TASK_TYPE
     SAPDB_Bool                      fTaskIsWaitingForExclusiveAccess; /* ... to a RWRegion */
     struct TASK_TYPE               *nextTaskInWaitQueue ;
     void                           *RWRegion;
+    SAPDB_Char                      NameOfSpinlockYieldingFor[20]; /* - pointer to spinlock task is currently yielding for or 0 */
+    SAPDB_Bool                      m_AlreadyYielding; 
     /* no filler */
 }; /* TASK_TYPE */
 
@@ -833,6 +844,9 @@ typedef struct ten50_UKT_Control
 
     struct RTE_CoroutineContext *       removeTaskContext; /* used only if coroutines enabled */
 
+    /* used to enforce spinlocks to use giveup timeslice while in dispatcher */
+    SAPDB_Bool                          m_IsWaitingForNextScheduledTask; 
+
 } ten50_UKT_Control; /* ten50_UKT_Control */
 
 externC ten50_UKT_Control *en88GetThisUkt();
@@ -1037,7 +1051,7 @@ struct KERNEL_GLOBAL_SECTION
     SAPDB_Int4                      restart_timeout ;
 
     time_t                          start_time ;
-
+    volatile time_t                 current_time ; /* set by watchdog every second */
     /*
      * MWa Spinlock
      */
@@ -1103,6 +1117,7 @@ struct KERNEL_GLOBAL_SECTION
   SAPDB_Bool                          fBusyWaitingForbidden;
   SAPDB_Int4                          taskResponsibleForOffline; /* id of task responsible for offline state */
   SAPDB_Int4                          gotCrashSignal;
+  SAPDB_UInt8                         symbolResolutionLockCount; /* counts the locks of symbol resolution code */
 };
 /* KERNEL_GLOBAL_SECTION */
 
