@@ -139,6 +139,7 @@
 #define IERR_VREC_ILL_LENGTH         11008,IERR_TYPE,"COMMUNIC","illegal length, act:%d, max:%d (T%d)"
 #define IERR_VREPLY_WRONG_PACK_ADDR  11009,IERR_TYPE,"COMMUNIC","wrong packet addr 0x%p, expected 0x%p (T%d)"
 #define IERR_VREPLY_ILL_PACK_LEN     11009,IERR_TYPE,"COMMUNIC","ill packet len %d, max %d (T%d)"
+#define ERR_ILLEGAL_REQUEST          11009,IERR_TYPE,"TASKING ","Illegal '%s' request type: %d"
 
 /* ============================ ven54c ================================ */
 
@@ -463,6 +464,10 @@
 #define ERR_ABORT_CALLED             11200,ERR_TYPE,"dbcrash ","Emergency Shutdown"
 #define ERR_ABORT_CALLED_FROM        11200,ERR_TYPE,"dbcrash ","Emergency Shutdown from T%d"
 
+#define ERR_RESUME_IOTHREAD          11201,ERR_TYPE,"TASKING ","Could not resume IO thread: '%s', rc = %d"
+#define ERR_SUSPEND_IOTHREAD         11202,ERR_TYPE,"TASKING ","Could not resume IO thread: '%s', rc = %d"
+#define ERR_CREATING_IOTHREAD        11203,ERR_TYPE,"TASKING ","Could not create thread: '%s', rc = %d"
+
 /* ============================ ven58c ================================ */
 
 #define ERR_INCORRECT_TR_DEVSIZE     11201,ERR_TYPE,"vdiagini","size incorrect of kernel trace file %s"
