@@ -93,4 +93,12 @@ externC int   e54_asyn_vasynio_result ( struct DOUBLY_LINKED  * request,
 
 externC void  en54FindPipeCheckAlgorithm(char *dbname);
 
+/*!
+  @brief create semaphores and threads of IO worker threads
+  The parameter PREALLOCATE_IOWORKER controls, if only DEV0 thread is started or all other possible DEVi threads too.
+  In case of a fatal resource allocation problem, the routine writes diagnostics into knldiag
+  @return 0 if start succeeded, else kernel should terminate...
+ */
+externC int   en54CreateIOWorkerThreads();
+
 #endif  /* GEN54_H */
