@@ -60,7 +60,8 @@ externC int e75_has_com ( struct TASK_TYPE *tcb );
 
 externC int e75_is_connected ( struct TASK_TYPE *tcb );
 
-externC int e75_connect_request ( struct DOUBLY_LINKED  *lquu );
+externC int e75_connect_request ( struct TASK_TYPE  * tcb, 
+                                  connection_info   * cip );
 
 externC void e75_release_request ( struct DOUBLY_LINKED *lquu );
 
