@@ -9,7 +9,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2003-2004 SAP AG
+    Copyright (c) 2003-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 \endif
 ---------------------------------------------------------------------*/
 
@@ -163,17 +164,18 @@ static            tsp00_Bool fNI_Installed        = FALSE;
 
 /*------------------------------*/
 
-static  int            sql03_connect (char           *servernode,
-                                      tsp00_DbNamec         serverdb,
-                                      int                 service,
-                                      int                 packet_cnt,
-                                      tsp00_Int4           *reference,
-                                      tsp00_Int4           *sql_packet_size,
+static  int            sql03_connect (char              *servernode,
+                                      tsp00_DbNamec     serverdb,
+                                      int               service,
+                                      int               packet_cnt,
+                                      tsp00_Int4        *reference,
+                                      tsp00_Int4        *max_reply_packet_size,
+                                      tsp00_Int4        *sql_packet_size,
                                       void              **sql_packet_list,
-                                      char               *dbroot,
-                                      char               *serverpgm,
-                                      connection_VMT     *vmt,
-                                      tsp00_ErrTextc      pErrText );
+                                      char              *dbroot,
+                                      char              *serverpgm,
+                                      connection_VMT    *vmt,
+                                      tsp00_ErrTextc     pErrText );
 
 static  int            sql03_release ( tsp00_Int4         reference,
                                        tsp00_ErrTextc   errtext );
@@ -246,6 +248,7 @@ externC tsp01_CommErr_Enum  SqlPingConnect ( char*                  szServerNode
   tsp01_CommErr_Enum        commError;
   int                       packetSize;
   void*                     packetList;
+  tsp00_Int4                max_reply_packet_size;
 
   DBGIN;
 
@@ -264,6 +267,7 @@ externC tsp01_CommErr_Enum  SqlPingConnect ( char*                  szServerNode
                                                   (int) srvPing_esp01,
                                                   1,
                                                   reference,
+                                                  &max_reply_packet_size,
                                                   &packetSize,
                                                   &packetList,
                                                   NULL,
@@ -433,6 +437,7 @@ SqlAConnect ( char                  *szServerNode,      /* '\0' terminated node
   #undef  MF__
   #define MF__ MOD__"SqlAConnect"
     tsp01_CommErr_Enum        commError;
+    tsp00_Int4                max_reply_packet_size;
 
     DBGIN;
 
@@ -444,6 +449,7 @@ SqlAConnect ( char                  *szServerNode,      /* '\0' terminated node
                 (int) service,
                 (int) packet_cnt,
                 reference,
+                &max_reply_packet_size,
                 sql_packet_size,
                 sql_packet_list,
                 NULL, NULL, NULL, szErrText);
@@ -452,6 +458,41 @@ SqlAConnect ( char                  *szServerNode,      /* '\0' terminated node
     return (commError);
 }
 
+externC tsp01_CommErr_Enum
+SqlDBConnect ( char                  *szServerNode,      /* '\0' terminated node or saprouterstring */
+               tsp00_DbNamec          szServerDB,        /* '\0' terminated dbname                  */
+               tsp01_Service_Enum     service,
+               tsp00_Int4             packet_cnt,
+               tsp00_Int4             *reference,
+               tsp00_Int4             *max_reply_packet_size,
+               tsp00_Int4             *sql_packet_size,
+               void                   **sql_packet_list,  /* tsp00_Array<tsp1_packet_ptr, ...> */
+               tsp00_ErrTextc         szErrText )        /* '\0' terminated error string   */
+{
+  #undef  MF__
+  #define MF__ MOD__"SqlDBConnect"
+    tsp01_CommErr_Enum        commError;
+
+    DBGIN;
+
+    DBG3 (( MF__, "pszServerNode '%s'", szServerNode ));
+    DBG3 (( MF__, "pszServerDB   '%s'", szServerDB ));
+
+    commError = (tsp01_CommErr_Enum) sql03_connect ( szServerNode,
+                szServerDB,
+                (int) service,
+                (int) packet_cnt,
+                reference,
+                max_reply_packet_size,
+                sql_packet_size,
+                sql_packet_list,
+                NULL, NULL, NULL, szErrText);
+
+    DBGOUT
+    return (commError);
+}
+
+
 /*
  * ===========================================================================
  */
@@ -475,6 +516,7 @@ void sqlaconnect ( tsp00_TaskId           pid,
     tsp00_NodeIdc     szServerNode;
     tsp00_DbNamec     szServerDB;
     tsp00_ErrTextc    pErrText;
+    tsp00_Int4        max_reply_packet_size;
 
     eo46PtoC ( szServerNode, servernode,  sizeof(tsp00_NodeId) );
     eo46PtoC ( szServerDB,   serverdb,    sizeof(tsp00_DbName) );
@@ -487,6 +529,7 @@ void sqlaconnect ( tsp00_TaskId           pid,
                   (int) service,
                   (int) packet_cnt,
                   reference,
+                  &max_reply_packet_size,
                   sql_packet_size,
                   sql_packet_list,
                   NULL,
@@ -649,6 +692,7 @@ void    sql03_xconnect (
     tsp1_comm_error     *returncode)
 {
     tsp00_ErrTextc    pErrText;
+    tsp00_Int4        max_reply_packet_size;
 
     DBG3 (( MF__,"node '%.10s' db '%.8s' srv %d \n",
             servernode , serverdb , (int) srvControl_esp01 ));
@@ -658,6 +702,7 @@ void    sql03_xconnect (
                   srvControl_esp01,
                   1,
                   reference,
+                  &max_reply_packet_size,
                   sql_packet_size,
                   sql_packet_list,
                   dbroot,
@@ -846,6 +891,7 @@ static  int     sql03_connect (char            * servernode,
                                int               service,
                                int               packet_cnt,
                                tsp00_Int4        * reference,
+							   tsp00_Int4        * max_reply_packet_size,
                                tsp00_Int4        * sql_packet_size,
                                void           ** sql_packet_list,
                                char            * dbroot,
@@ -1051,7 +1097,8 @@ static  int     sql03_connect (char            * servernode,
             sql_packet_list [idx] = cip->ci_packetData [idx];
         }
         cip->ci_max_request_size = cip->ci_max_data_size - cip->ci_min_reply_size;
-        *sql_packet_size = cip->ci_max_request_size;
+        *sql_packet_size       = cip->ci_max_request_size;
+        *max_reply_packet_size = cip->ci_max_data_size;
         *reference = ref;
         DBG1 (( MF__,"pack1 0x%08lx pack2 0x%08lx siz %d \n",
                 (long) sql_packet_list[0] , (long) sql_packet_list[1],
