@@ -40,6 +40,8 @@
 #include "geo007_2.h"
 #include "geo57.h"
 #include "hen40.h"
+#include "RunTime/System/RTESys_Time.h"
+#include "SAPDBCommon/SAPDB_string.h"
 
 /* ***** externC vars ****************************************************** */
 
@@ -52,12 +54,18 @@
 #define         NUM_START_PARAMS 200
 #define         NUM_NEW_PARAMS    50
 
+/*! opening a parameter fail may file when another process is currently accessing the file */
+/*! If this case is detected, just sleep for a given interval and try again */
+#define NUMBER_OF_ATTEMPTS_ON_OPEN_ 600
+/*! the sleep interval between open attempts in 100 milliseconds  */
+#define WAIT_INTERVAL_ON_OPEN_      5
+
 /* ***** macro definitions ************************************************ */
 
 #define SEEK_BEG_OF_FILE(_fd, _ret, _errtext) \
           if ( xp_data [ _fd ] . params ) xp_data [ _fd ] . act_param = 0 ; \
           else \
-           if ( fseek ( xp_data [ _fd ] . xp_stream , 0 , SEEK_SET ) < 0 ) \
+           if ( lseek ( xp_data [ _fd ] . xp_stream , 0 , SEEK_SET ) < 0 ) \
              { *_ret = XP_NOT_OK ; \
 		ERRTEXT ( _errtext , CANNOT_FIND_START_POINT ) ; \
 		return ; \
@@ -92,7 +100,7 @@ static char PARAMETER_ALREADY_IN_USE[] = "Parameter already in use" ;
 typedef struct  xp_data_struc
   { 
     tsp00_C132 xp_file ;
-    FILE *xp_stream ;
+    int   xp_stream ;
     char *params ;
     ULONG ulOpenMode ; /* PTS 1104765 */
     LONG act_param ;
@@ -103,7 +111,7 @@ typedef struct  xp_data_struc
     tsp00_Bool file_is_new ; 
   } XP_DATA_STRUC ;
 
-static XP_DATA_STRUC  xp_data [ MAX_OPEN_PARAMS ] ; 
+static XP_DATA_STRUC  xp_data [ MAX_OPEN_PARAMS ] = { 0 }; 
 /* ***** externC functions ************************************************* */
 
 externC	void			sql11c_get_xparam_buffer ();
@@ -156,7 +164,7 @@ void    sql11c_CloseXParam  (   tsp00_Int4    lXParamFd,
                                 tsp00_ErrText acErrorText,
                                 tsp00_Bool     *ok        )
 {
-    memset (( char* ) acErrorText, ' ', sizeof ( tsp00_ErrText ));
+    SAPDB_memset (( char* ) acErrorText, ' ', sizeof ( tsp00_ErrText ));
 
 	*ok = sql11c_close_xparam_file ( lXParamFd , fFlush ) == 0 ;
 }
@@ -186,9 +194,9 @@ static int     sql11c_GetFreeXparamSlot ()
 {
   int xp_fd ;
   for ( xp_fd = 0; xp_fd < MAX_OPEN_PARAMS &&
-                   xp_data[xp_fd].xp_stream != NULL ; xp_fd++ ) ; 
+                   xp_data[xp_fd].xp_stream > 0; xp_fd++ ) ; 
 
- if ( xp_data [ xp_fd ]. xp_stream != NULL ) 
+ if ( xp_data [ xp_fd ]. xp_stream > 0 ) 
    { MSGD (( -11113, ERR_TYPE, "XPARAM  ", "too many open paramfiles" ));
      xp_fd = -1 ;
    }
@@ -209,6 +217,9 @@ tsp00_Int4        OpenMode )
 	tsp00_Int4        xp_fd ;
         struct stat     stat_buf ;
 
+    SAPDB_UInt attempts;
+    SAPDB_Bool dummyFlag = false;
+
 	DBGIN;
 
 	/* ***** look for xparam file ***** */
@@ -262,8 +273,20 @@ tsp00_Int4        OpenMode )
     	        return ( - 1 ) ;
               }
 
-	  xp_data[xp_fd].xp_stream = fopen ( xp_file , "r+" ) ;
-	  if ( xp_data[xp_fd].xp_stream == ( FILE* )NULL )
+      for(attempts=0;attempts < NUMBER_OF_ATTEMPTS_ON_OPEN_;attempts++)   
+      {
+        xp_data[xp_fd].xp_stream = open ( xp_file , O_RDWR ) ;
+        /* If (and only if!) the file is open by another process, wait a little while and try again. */
+        if( EACCES == errno )
+        {
+            RTESys_Timeout(&dummyFlag, WAIT_INTERVAL_ON_OPEN_+1);
+        }
+        else
+        {
+            break;
+        }
+      }
+	  if ( xp_data[xp_fd].xp_stream < 0 )
 	    {
 	      MSGD (( -11113, ERR_TYPE, "XPARAM  ", "open error (creat) %s\n", sqlerrs() ))
 	      return ( - 1 ) ;
@@ -299,7 +322,7 @@ tsp00_Bool                 flush_buffer )
         MSGD (( -11114, ERR_TYPE, "XPARAM  ", "flush_buffer = true no longer supported for sql11c_close_xparam_file()")) ;
 		/* ***** close XPARAN file ***** */
                 
-  	  (void) fclose ( xp_data [ xp_fd ]. xp_stream ) ;
+  	  (void) close ( xp_data [ xp_fd ]. xp_stream ) ;
       if ( xp_data [ xp_fd ] . last_param <= 1 &&
            xp_data [ xp_fd ] . file_is_new ) 
         (void) unlink ( (char *)xp_data [ xp_fd ] . xp_file ) ;
@@ -309,7 +332,7 @@ tsp00_Bool                 flush_buffer )
       if ( xp_data [ xp_fd ] . RefXparams != ( char *) NULL ) 
         FREE_MEM_EO57 ( xp_data [ xp_fd ] . RefXparams ) ; 
 
-      memset ( & xp_data [ xp_fd ], 0, sizeof ( XP_DATA_STRUC ) ) ;
+      SAPDB_memset ( & xp_data [ xp_fd ], 0, sizeof ( XP_DATA_STRUC ) ) ;
 	  return ( 0 ) ;
 	}
 	else
@@ -331,19 +354,20 @@ tsp00_ErrText       errtext ,
 tsp00_Uint1        * xp_ret )
 
 {
-  *bytes_read = fread ( buf , sizeof(char) , 
-                        bytes_to_read , xp_data[ xparam_fd ]. xp_stream ) ;
+  *bytes_read = read ( xp_data[ xparam_fd ]. xp_stream
+                     , buf
+                     , bytes_to_read ) ;
 
   if ( *bytes_read < 0 )
-    { * xp_ret = XP_NOT_OK ;
+  {   * xp_ret = XP_NOT_OK ;
       ERRTEXT ( errtext , READING_ERROR )
       MSGD (( ERR_READ_ERROR )) ;
-    }
-  else
-  if ( *bytes_read < bytes_to_read )
-    { * xp_ret = XP_EOF ;
-	ERRTEXT ( errtext , EOF_REACHED )
-    }
+  }
+  else if ( *bytes_read < bytes_to_read )
+  {
+      * xp_ret = XP_EOF ;
+	  ERRTEXT ( errtext , EOF_REACHED )
+  }
   else
     * xp_ret = XP_OK ;
 
@@ -361,20 +385,20 @@ tsp00_Int4        *bytes_written ,
 tsp00_ErrText     errtext ,
 tsp00_Uint1        * xp_ret )
 {
-  *bytes_written = fwrite ( buf, sizeof(char), bytes_to_write, 
-                            xp_data[ xparam_fd ]. xp_stream ) ;
+  *bytes_written = write ( xp_data[ xparam_fd ]. xp_stream , buf, bytes_to_write );
 
   if ( *bytes_written != bytes_to_write )
-    { * xp_ret = XP_NOT_OK ;
+  {
+      * xp_ret = XP_NOT_OK ;
       ERRTEXT ( errtext , WRITING_ERROR )
       MSGD (( ERR_WRITE_ERROR )) ;
-    }
+  }
   else
-    {
+  {
       xp_data[xparam_fd].act_param = bytes_to_write / XP_PAGE_SIZE ;
       xp_data[xparam_fd].last_param += xp_data[xparam_fd].act_param;
       * xp_ret = XP_OK ;
-    }
+  }
 
   return  ;
 }
