@@ -75,12 +75,9 @@ externC	void	e52_init_time ( )
     /*
      *  Get start_time in seconds
      */
-    startTime = time((time_t *)0);
-
-    /* Synchronize to beginn of next second */
-    for ( KGS->start_time = startTime = time((time_t *)0); KGS->start_time == startTime; )
+    for ( KGS->current_time = KGS->start_time = startTime = time((time_t *)0); KGS->start_time == startTime; )
     {
-        KGS->start_time = time((time_t *)0);
+        KGS->current_time = KGS->start_time = time((time_t *)0);
     }
     /* Initialize microsecond timer now. This allows a smaller jitter for calculating actual real time */
     RTESys_InitMicroSecTimer();
