@@ -44,6 +44,7 @@
 #include "RunTime/System/RTESys_MicroTime.h"
 #include "geo002.h"
 #include "gen45.h"
+#include "gen73.h"
 
 /* imported functions */
 
@@ -58,6 +59,9 @@ extern  void              sql46_dump_packet (rte_header * header );
 #endif
 
 static void               HandlePing( tsp00_TaskId          pid );
+static void               ReleaseConnection ( struct TASK_TYPE        *tcb,
+                                              tsp01_CommErr            commState, 
+                                              int                      waitflag );
 
 
 extern  tsp00_DbNamec                   en81_dbname; 
@@ -73,7 +77,7 @@ externC	tsp00_Int4	vcmd_wait_time ( tsp00_TaskId		pid )
   struct TASK_TYPE *tcb = KGS -> pFirstTaskCtrl + ( pid - 1 ) ;
 
   time_t WaitTime = tcb->state == TSK_VRECEIVE ? 
-                    time ( ( time_t *)0 ) - tcb->CmdWaitTime : 0 ;
+                    KGS->current_time - tcb->CmdWaitTime : 0 ;
   return ( (tsp00_Int4 )WaitTime ) ;
 }
 
@@ -90,33 +94,51 @@ tsp00_Bool		*webuser ,
 tsp01_CommErr	*returncode )
 {
 ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
-    struct TASK_TYPE   *tcb = this_ukt->curr_task;
-    connection_info	   *cip ;
+    struct TASK_TYPE        *tcb = this_ukt->curr_task;
+    connection_info	        *cip ;
+    struct DOUBLY_LINKED	*lquu;
 
     DBGIN_T( tcb->index );
 
     tcb->state = TSK_CONNECTWAIT ;
     cip = tcb->connection;
 	DBG1(( MF__,"state %d\n", cip->ci_state ));
- 
-    if ( cip->ci_state != CON_ESTABLISHED )
+
+    lquu = e73_dl_dequ ( &tcb->dlq_connreq );
+
+    /* connect request already received? */
+    if ( lquu == NULL )
     {
 		tcb->task_timeout = MAXTIMEVALUE ;
-		MSGD (( INFO_VCON_WAITING, tcb->index ));
-
-        /* - alter task activ counters */
-        en71AlterTaskCnt( this_ukt->curr_task, SUB_ACTIVE_COUNTER );
-
-		DBG1 (( MF__,"goto_disp  T%d \n", tcb->index ));
+        DBG1 (( MF__,"goto_disp  T%d \n", tcb->index ));
         GOTO_DISP (&this_ukt);
-		DBG1 (( MF__,"from disp  T%d \n", tcb->index ));
+        DBG1 (( MF__,"from disp  T%d \n", tcb->index ));
 
-        /* - alter task activ counters */
-        en71AlterTaskCnt( this_ukt->curr_task, ADD_ACTIVE_COUNTER );
+        if ( this_ukt->curr_quu->req_type != REQ_CONNECT )
+        {
+            MSGALL (( ERR_ILLEGAL_REQUEST, "connect", this_ukt->curr_quu->req_type ));
+            vabort ( WRITE_CORE );
+        }
+
+        lquu = this_ukt->curr_quu;
     }
 
+    /* free the queue element which woke us */
+    e73_dl_enqu ( & KGS->freelist , lquu );
+
     RTESys_ReadMemoryBarrier();
 
+    if ( !cip->ci_alter_server_sem )
+    {   /* set move lock... */
+        en71LongTermMoveLock( tcb, CLIENT_NOT_TASK_MOVE_ENABLED, true );
+    }
+
+    /* Set move lock, because the task should not move to another UKT 
+    until we have received a command from client */ 
+    en71LongTermMoveLock( tcb, WAITING_FOR_NEW_COMMAND, true );
+
+    e75_connect_request ( tcb, cip );
+
     *webuser = (cip->ci_service == 4);
     *max_data_len = cip->ci_max_data_size ;
     *returncode = ( cip->ci_state == CON_ESTABLISHED ? commErrOk_esp01 : commErrNotOk_esp01 );
@@ -129,7 +151,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
 
             /* --- release connection */
             *returncode = commErrNotOk_esp01;
-            vrelease ( pid );
+            ReleaseConnection ( tcb, commErrOk_esp01, TRUE );
         }
         else
         {
@@ -147,6 +169,13 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
             }
         }
     }
+    else
+    {
+        /* remove long term move lock */
+        en71LongTermMoveLock( tcb, CLIENT_NOT_TASK_MOVE_ENABLED, false );
+        en71LongTermMoveLock( tcb, WAITING_FOR_NEW_COMMAND, false );
+    }
+
     DBG1 (( MF__,"leaving state %d datasize %d\n",
 			 cip->ci_state , *max_data_len ));
 
@@ -175,17 +204,13 @@ tsp01_CommErr         *returncode )
 externC	void	vrelease ( tsp00_TaskId	pid )
 {
     struct TASK_TYPE   *tcb = KGS -> pFirstTaskCtrl + ( pid - 1 ) ;
-    int				rc ;
     connection_info		*cip ;
 
     DBGIN_T(tcb->index);
 
     cip = tcb->connection;
 
-    rc = ( cip->ci_state == CON_REPLIED 
-			? commErrOk_esp01 : commErrReleased_esp01 );
-
-    e75_release_connection ( rc , TRUE ); /* wait */
+    ReleaseConnection( tcb, (cip->ci_state == CON_REPLIED ? commErrOk_esp01 : commErrReleased_esp01), TRUE ); /* wait */
 
     DBGOUT_T( tcb->index );
 }
@@ -215,7 +240,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     connection_info		*cip ;
 
     DBG1 (( MF__,"T%d timeout %d \n", tcb->index , timeout ));
-    tcb->wait_time = tcb->CmdWaitTime = time ((time_t *)0);
+    tcb->CmdWaitTime = KGS->current_time;
     tcb->state = TSK_VRECEIVE ;
     cip = tcb->connection;
 
@@ -237,7 +262,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     if ( state == CON_ABORTED )
     {
 		MSGD (( WRN_VRECV_APPLICATION_DEAD, tcb->index ));
-        e75_release_connection ( commErrCrash_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrCrash_esp01 , FALSE ); /* no wait */
         tcb->state = TSK_RUNNING ;
         return ;
     }
@@ -261,7 +286,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
 
     if ( timeout > 0 )
 	{
-		tcb->task_timeout = timeout + time(0);
+		tcb->task_timeout = timeout + KGS->current_time;
 	}
     else
     {
@@ -283,17 +308,12 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
      *  The dispatcher thinks a request has arrived
      *************************************************
      */
-
     RTESys_ReadMemoryBarrier();
 
-    tcb->wait_time = 0 ;
-
-    en71TempMoveLock ( tcb, 1, false );  /* remove temporary move lock */
-
     if ( ( KGS -> state == SERVER_SHUTDOWN ) && ( tcb->type != TT_EV ) )
     {
         DBG1 (( MF__,"database shutdown, T%d", tcb->index ));
-        e75_release_connection ( commErrShutdown_esp01 , TRUE ); /* wait */
+        ReleaseConnection( tcb, commErrShutdown_esp01 , TRUE ); /* wait */
         *returncode      = commErrShutdown_esp01 ;
         tcb->state = TSK_RUNNING ;
         return ;
@@ -302,7 +322,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     if ( cip->ci_state == CON_TIMEDOUT )
     {
         DBG1 (( MF__,"connection timeout, T%d" , tcb->index ));
-        e75_release_connection ( commErrTimeout_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrTimeout_esp01 , FALSE ); /* no wait */
         *returncode      = commErrTimeout_esp01 ;
         tcb->state = TSK_RUNNING ;
         return ;
@@ -311,7 +331,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     if ( cip->ci_state == CON_ABORTED )
     {
 		MSGD (( WRN_VRECV_APPLICATION_DEAD, tcb->index ));
-        e75_release_connection ( commErrCrash_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrCrash_esp01 , FALSE ); /* no wait */
         tcb->state = TSK_RUNNING ;
         return ;
     }
@@ -320,7 +340,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     if ( ! comseg )
     {
 		MSGD (( INFO_CONN_BROKEN_NO_COMSEG, tcb->index )) ;
-        e75_release_connection ( commErrCrash_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrCrash_esp01 , FALSE ); /* no wait */
         tcb->state = TSK_RUNNING ;
         return ;
     }
@@ -331,7 +351,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     {
 		MSGD (( INFO_CONN_BROKEN_BY_APPL_ST, *returncode , 
 			tcb->index ));
-        e75_release_connection ( commErrCrash_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrCrash_esp01 , FALSE ); /* no wait */
         tcb->state = TSK_RUNNING ;
         return ;
     }
@@ -341,7 +361,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     {
         MSGD (( IERR_VREC_WRONG_PACKET_REQ, idx , 
 			tcb->index ));
-        e75_release_connection ( commErrNotOk_esp01 , TRUE ); /* wait */
+        ReleaseConnection( tcb, commErrNotOk_esp01 , TRUE ); /* wait */
         tcb->state = TSK_RUNNING ;
 		*returncode = commErrNotOk_esp01 ;
         return ;
@@ -354,7 +374,7 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
     {
         MSGD (( IERR_VREC_ILL_LENGTH ,
 	         length , cip->ci_max_request_size, tcb->index ));
-        e75_release_connection ( commErrNotOk_esp01 , TRUE ); /* wait */
+        ReleaseConnection( tcb, commErrNotOk_esp01 , TRUE ); /* wait */
         tcb->state = TSK_RUNNING ;
 		*returncode = commErrNotOk_esp01 ;
         return ;
@@ -422,6 +442,8 @@ ten50_UKT_Control *this_ukt = THIS_UKT_CTRL;
         tcb->TaskStateStat.vreceiveORvreplyLeaveTime  = 0;
     }
 
+
+
     tcb->state = TSK_RUNNING ;
 }
 
@@ -473,7 +495,7 @@ tsp01_CommErr		*returncode )
     if ( state == CON_ABORTED )
     {
 		DBG1 (( MF__,"application dead for T%d \n", tcb->index ));
-        e75_release_connection ( commErrCrash_esp01 , FALSE ); /* no wait */
+        ReleaseConnection( tcb, commErrCrash_esp01 , FALSE ); /* no wait */
         tcb->state = TSK_RUNNING ;
         return ;
     }
@@ -545,7 +567,7 @@ tsp01_CommErr		*returncode )
 #endif
 
     comseg->cs_server_semid = tcb->ukt->semid;  /* we are waiting on this UKT sem */
-    en71TempMoveLock ( tcb, 1, true );          /* so that, we should not move to other UKTs */
+    en71LongTermMoveLock( tcb, WAITING_FOR_NEW_COMMAND, true );
 
     comseg->cs_server_flag = 1 ;
 
@@ -713,4 +735,17 @@ static void HandlePing( tsp00_TaskId          pid )
     while( commState == commErrOk_esp01  );
 }
 
+/*
+ * =====================================================================
+ */
 
+static void ReleaseConnection ( struct TASK_TYPE        *tcb,
+                                tsp01_CommErr            commState, 
+                                int                      waitflag )
+{
+    e75_release_connection ( commState, waitflag );
+
+    /* remove long term move lock */
+    en71LongTermMoveLock( tcb, CLIENT_NOT_TASK_MOVE_ENABLED, false );
+    en71LongTermMoveLock( tcb, WAITING_FOR_NEW_COMMAND, false );
+}
