@@ -41,21 +41,10 @@
 
 #include "gen71.h"
 #include "gen83.h"
+#include "RunTime/System/RTESys_MicroTime.h" /* for vreschedule_msec */
 
 extern  int                             e60_dbgdbglvl ;
 
-#if ! ( defined(_IBMR2) || defined(OSF1) || defined(NMP) )	/* already declared in include file */
-#   if defined(HP9) || defined(MI_ULT)
-    extern  clock_t                         times ();
-#   else
-    extern  long                            times ();
-#   endif
-#endif  /* _IBMR2 */
-
-#if ! ( defined(MI_ULT) || defined(OSF1) || defined(HPUX) || defined(NMP) )	/* already declared in include file */
-extern  time_t                              time ();
-#endif
-
 /* local functions */
 
 static  void    en56_remvresume (void *pDummy,
@@ -192,7 +181,6 @@ void    vsuspend ( tsp00_TaskId pid ,
         ten50_UKT_Control * this_ukt;
 
         this_ukt = pTaskCtrl->ukt;
-        pTaskCtrl->wait_time = time ((time_t *)0) ;
 
 		pTaskCtrl->state = TSK_VSUSPEND_EO00;
 #ifdef MAX_SUSPEND_REASONS 
@@ -235,7 +223,6 @@ void    vsuspend ( tsp00_TaskId pid ,
 	}
 
 	pTaskCtrl->lWaitForRoot = pTaskCtrl->lWaitForTask = undef_ceo00  ;
-	pTaskCtrl->wait_time = 0 ;
 
 	DBG1(( MF__,"T%d suspendend T%d cnt %d",
 			pTaskCtrl->index , (int) pid , 
@@ -395,7 +382,6 @@ void    vwait ( tsp00_TaskId pid,
 
   if ( tcb->vsignal_ok == 0 )
   {
-      tcb->wait_time = time ((time_t *)0) ;
       DBG1 (( MF__,"before goto_disp T%d \n", tcb->index ));
       GOTO_DISP (&this_ukt);
       if ( tcb->TimeCollectionEnabled )
@@ -438,7 +424,6 @@ void    vwait ( tsp00_TaskId pid,
   tcb->vsignal_ok = 0 ;
   tcb->lWaitForTask = undef_ceo00  ;
   tcb->state = TSK_RUNNING_EO00 ;
-  tcb->wait_time = 0 ;
   this_ukt->ActTasksVwait-- ;
 
   DBGOUT_T(pid);
@@ -556,7 +541,7 @@ void    vsleep ( tsp00_TaskId  pid,
     lquu = &tcb->qa ;
     lquu->req_type = REQ_VSLEEP_EO00;
     lquu->taskid   = tcb;
-    time_now       = time ( (time_t *)0 );
+    time_now       = KGS->current_time;
     lquu->args.timer_auftrag.time_to_wake = time_now + limit ;
     en83TimerJob ( lquu );
   
@@ -570,12 +555,21 @@ void    vsleep ( tsp00_TaskId  pid,
 
     if ( this_ukt->curr_quu != lquu )
     {
-        MSGALL (( ERR_VSLEEP_WRONG_EVENT, this_ukt->curr_task->index ));
+        MSGALL (( ERR_AWOKE_FROM_WRONG_EVENT, "vsleep", this_ukt->curr_task->index, this_ukt->curr_quu, lquu ));
+        MSGALL (( ERR_VSLEEP_WRONG_REQ_ARGS,
+            this_ukt->curr_task->index,
+            this_ukt->curr_quu->taskid  ? this_ukt->curr_quu->taskid->index : 0,
+            this_ukt->curr_quu->req_type, REQ_VSLEEP_EO00 ));
+
         vabort ( WRITE_CORE );
     }
     if ( this_ukt->curr_quu->req_type != REQ_VSLEEP_EO00 )
     {
-        MSGALL (( ERR_VSLEEP_WRONG_REQ, pid, this_ukt->curr_quu->req_type));
+        MSGALL (( ERR_VSLEEP_WRONG_REQ ));
+        MSGALL (( ERR_VSLEEP_WRONG_REQ_ARGS,
+            this_ukt->curr_task->index,
+            this_ukt->curr_quu->taskid  ? this_ukt->curr_quu->taskid->index : 0,
+            this_ukt->curr_quu->req_type, REQ_VSLEEP_EO00 ));
         vabort ( WRITE_CORE );
     }
   }
@@ -607,14 +601,14 @@ void  vreschedule_msec     ( tsp00_TaskId      pid,
 
   if ( *StartMsec == 0 )
   {
-    *StartMsec = ( (time ( (time_t *)0 ) - KGS->start_time) * 1000);
+    *StartMsec = (SAPDB_Int4)(RTESys_MicroSecTimer() / 1000);
   }
 
   e71_YieldTaskEnquRex ( this_ukt, this_ukt->curr_task->prio_flag );
 
   GOTO_DISP (&this_ukt);
 
-  time_now_in_msec       = ( (time ( (time_t *)0 ) - KGS->start_time) * 1000);
+  time_now_in_msec = (SAPDB_Int4)(RTESys_MicroSecTimer() / 1000);
 
   if ( time_now_in_msec - *StartMsec >= *RemainMsec || 
        time_now_in_msec < *StartMsec )
