@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -779,9 +780,6 @@ int                             length )
 static  void    en60_InitDiag ( const char *msg, int length )
 {
     long                                pos ;
-    int                                 lgt ;
-    int                                 off ;
-
 
     if ( e60_op3_minpos == INIT_DIAG )
     {
@@ -1090,70 +1088,174 @@ static	int     en60_OpenOp3Msg ( RTE_XPARAM_REC *XParam )
 
 static void en60_CheckForUtilProtHeader( char *filename )
 {
-  FILE *stream = fopen ( (const char *)filename, "rt" ) ;
+  int fd = open ( filename, O_RDONLY );
   long headerLength = strlen(en60_UTILPROT_HEADER);
 
-  if ( stream != NULL ) 
+  if ( fd >= 0 ) 
   {
-	  char line[MESSAGE_LINE_MXEN60];
-      memset(line, 0, sizeof(line));
+	  char * line = alloca ( headerLength );
 
-	  if ( fread ( line, headerLength, 1, stream ) == 1
+	  if ( read ( fd, line, headerLength ) == headerLength
 		&& memcmp( line, en60_UTILPROT_HEADER, headerLength ) == 0 )
 	  {
-	      fclose ( stream ) ;
+	      close ( fd );
 		  return;
 	  }
 
-      fclose ( stream ) ;
+      close ( fd ) ;
 
 	  {
 		  char * oldFilename = alloca ( strlen(filename) + strlen(".old") + 1 );
 		  strcpy(oldFilename, filename);
 		  strcat(oldFilename, ".old");
-		  rename( filename, oldFilename);
+		  rename(filename, oldFilename);
 	  }
   }
 }
 
+/*
+ * ===========================================================================
+ */
+static int getNextFileLine(int fd, off_t *pLinePos, char *bufferStart, long bufferSize, long *pBytesCached, long *lengthFound)
+{
+    int  iBytes;
+    long bytesIn;
+
+    if ( 0 == *lengthFound )
+    {
+        *pLinePos = 0;
+    }
+    else
+    {
+        *pLinePos += *lengthFound;
+    }
+
+    if ( *pBytesCached > 0 )
+    {
+        memmove( bufferStart
+                     , bufferStart + *lengthFound
+                     , *pBytesCached);
+        memset(bufferStart + *pBytesCached
+             , 0
+             , bufferSize - *pBytesCached);
+        for ( iBytes = 0
+            ; iBytes < *pBytesCached
+            ; ++iBytes )
+        {
+            if ( bufferStart[iBytes] == '\n' )
+            {
+                bufferStart[iBytes] = 0;
+                *lengthFound = (iBytes+1);
+                *pBytesCached -= *lengthFound;
+                return 1;
+            }
+        }
+    }
+
+    do {
+        bytesIn = read( fd
+                      , bufferStart + *pBytesCached
+                      , bufferSize - *pBytesCached );
+
+        if ( bytesIn == 0 ) /* end of file condition */
+        {
+            bufferStart[*pBytesCached ] = 0;
+            *lengthFound = *pBytesCached;
+            *pBytesCached = 0;
+            return (*lengthFound > 0 ? 1 : 0); /* check for end of file... */
+        }
+
+        if ( bytesIn > 0 )
+        {
+            *pBytesCached += bytesIn;
+            for ( iBytes = *pBytesCached - bytesIn; iBytes < *pBytesCached; ++iBytes )
+            {
+                if ( bufferStart[iBytes] == '\n' )
+                {
+                    bufferStart[iBytes] = 0;
+                    *lengthFound = (iBytes+1);
+                    *pBytesCached -= *lengthFound;
+                    return 1;
+                }
+            }
+
+            if ( bufferSize == *pBytesCached ) /* slowly skip until end of line... */
+            {
+                char searchEndOfLine;
+
+                bufferStart[bufferSize] = 0;
+                *lengthFound = bufferSize;
+                do {
+                    switch( read( fd
+                          , &searchEndOfLine
+                          , 1 ) )
+                    {
+                        case 0:
+                            *pBytesCached = 0;
+                            break;
+                        case 1:
+                            ++*lengthFound;
+                            if ( '\n' == searchEndOfLine )
+                            {
+                                *pBytesCached = 0;
+                            }
+                            break;
+                        default:
+                            if ( errno != EINTR )
+                            {
+                                return 0;
+                            }
+                            break;
+                    }
+                } while ( *pBytesCached > 0 );
+
+                return 1;
+            }
+        }
+    } while ( bytesIn > 0 || EINTR == errno );  /* force ignore of interrupted read call... */
+
+    return 0;
+}
+
 /*
  * ===========================================================================
  */
 static void en60_FindUtilBeginPos( char *filename, 
                                    long *act_pos  ) 
 {
-  FILE *stream = fopen ( (const char *)filename, "rt" ) ;
+  int fd = open ( filename, O_RDONLY );
   long headerLength = strlen(en60_UTILPROT_HEADER) ;
 
   *act_pos = headerLength ;
 
-  if ( stream != NULL ) 
+  if ( fd >= 0 ) 
   {
-	  long cur_pos ;
-	  int end = FALSE ;
+      off_t cur_pos = 0;
+	  int   reachedEndOfFile = 0 ;
+      long   bytesCached = 0;
+      long   lengthFound = 0;
       char line[MESSAGE_LINE_MXEN60] ;
       memset(line, 0, sizeof(line));
 
 	  do
       {
-          cur_pos = (long)ftell (stream);    /* PTS 1110178 */
-          if ( fgets ( line, sizeof ( line ) - 1, stream ) != NULL )
+          if ( getNextFileLine(fd, &cur_pos, &line[0], sizeof ( line ) - 1, &bytesCached, &lengthFound) )
           {
               if ( memcmp ( line, e60_ENDMARK , sizeof(e60_ENDMARK)-1 ) == 0 )
               { 
                   LOCALDBG (( "en60_FindUtilBeginPos: end found at pos %ld\n", cur_pos ));
-				  *act_pos = cur_pos;
-                  end = TRUE ;
+				  *act_pos = (long)cur_pos;
+                  reachedEndOfFile = 1 ;
               }
           }
           else
 		  {
               LOCALDBG (( "en60_FindUtilBeginPos: no ENDMARK. Begin after header\n" ));
-              end = TRUE ;
+              reachedEndOfFile = 1 ;
 		  }
-      } while ( !end ) ;
+      } while ( !reachedEndOfFile ) ;
  
-      fclose ( stream ) ;
+      close ( fd ) ;
   }
 }
 
@@ -1260,6 +1362,40 @@ static	int     en60_OpenErrmsg ( int tryToWriteStartingMessage )
     return ( 0 );
 }
 
+/*
+ * ===========================================================================
+ */
+void RTE_WriteDatabaseStopTime()
+{
+    char MsgTxt[MESSAGE_LINE_MXEN60] ;
+    RTESys_Timestamp         timeBuffer;
+    RTESys_Timestamp         timeBufferGMT;
+    tsp00_Versionc           currentVersion;
+	SAPDB_Char	speed[RTE_MAXSPEEDLEN + 1];	
+
+	memset (speed, 0, RTE_MAXSPEEDLEN + 1);
+	strcpy (speed, RTE_GetSpeed ());
+	if (!strcmp (speed, RTE_FAST) )
+	{
+		strcpy (speed, " ");
+	}
+	else
+	{
+		strcat (speed, " ");
+	}
+
+	sp100_GetVersionString( speed, 
+	    					s100buildnumber,
+		    				&currentVersion[0]);
+
+    /*  Create Starting Message */
+    (void) sp77sprintf ( MsgTxt , sizeof(MsgTxt), "%s %5.5s %3.3s %5.5s %8.8s ___ Stopping GMT %s %s \n",
+                                RTESys_FillProtocolTimeStamp(timeBuffer), "", "", "", "", 
+                                RTESys_FillProtocolGMTTimeStamp(timeBufferGMT), &currentVersion[0] );
+
+    write(e60_operrfd, MsgTxt, strlen(MsgTxt));
+}
+
 /*
  * ===========================================================================
  */
@@ -1486,70 +1622,64 @@ static	void    en60_UpdateDiagPosition( char *filename, long *min_pos, long *act
 {
   long last_pos;
   char line[MESSAGE_LINE_MXEN60] ;
-  FILE *stream;
+  int fd;
 
   last_pos = 0;
-/* PTS 1103512 always append at end of file... */
-/*
-  *act_pos = 0;
- */
   *min_pos = 0;
+  *act_pos = 0;
 
-  stream = fopen ( (const char *)filename, "rt" ) ;
-  if ( stream != NULL ) 
+  fd = open ( filename, O_RDONLY );
+  if ( fd >= 0 ) 
   {
-	  tsp00_Bool end = FALSE ;
+      off_t  cur_pos = 0;
+	  int    reachedEndOfFile = 0 ;
+      long   bytesCached = 0;
+      long   lengthFound = 0;
+
       do
       {
-          if ( fgets ( line, sizeof ( line ) -1, stream ) != NULL )
+          if ( getNextFileLine( fd, &cur_pos, &line[0], sizeof ( line ) -1, &bytesCached, &lengthFound) )
           {
+              /* found "--- current write position --- " */
+              if ( memcmp( line, e60_ENDMARK, strlen(e60_ENDMARK)-1 ) == 0 )
+              {
+                  last_pos = (long)(cur_pos);
+                  break;
+              }
+
               if ( memcmp( line, e60_FILLINE, strlen(e60_FILLINE)-1 ) == 0 )
               {
                   if ( last_pos == 0 )
                   {
-    	    	      last_pos = ftell( stream );
+                      /* Prepare for the case, that no "--- current write position --- " was ever written... */
+                      last_pos = (long)cur_pos;
                   }
               }
-              else if ( memcmp ( line, e60_ENDSTARTUP , strlen(e60_ENDSTARTUP)-1 ) == 0 )   /* PTS 1110178 */
+              else if ( memcmp ( line, e60_ENDSTARTUP , strlen(e60_ENDSTARTUP)-1 ) == 0 )
               {
-				  *min_pos = ftell( stream );
-                  LOCALDBG (( "en60_UpdateDiagPosition: min found at pos %ld\n", 
-							*min_pos));
+                  /* Save position of end of startup part, to prevent cyclic rewrite... */
+				  *min_pos = (long)(cur_pos + lengthFound);
+                  LOCALDBG (( "en60_UpdateDiagPosition: min found at pos %ld\n", *min_pos));
               }
-
-/* PTS 1103512 always append at end of file... */
-/*
-              else if ( memcmp ( line, e60_ENDMARK , strlen(e60_ENDMARK)-1 ) == 0 )
-              {
-				  *act_pos = ftell( stream ) - sizeof(e60_ENDMARK)+1;
-                  LOCALDBG (( "en60_UpdateDiagPosition: end found at pos %ld\n", 
-							*act_pos));
-                  end = TRUE ;
-              }
- */
           }
           else
 		  {
               LOCALDBG (( "en60_UpdateDiagPosition: no ENDMARK. Begin at %ld\n", last_pos ));
-/* PTS 1103512 always append at end of file... */
-/*
-			  if ( *act_pos == 0 )
-              {
-                  *act_pos = last_pos;
-              }
- */
-              end = TRUE ;
+              reachedEndOfFile = 1 ;
               if ( last_pos == 0 )
               {
-                  last_pos = ftell( stream );
+                  last_pos = (long)(cur_pos + lengthFound);
               }
 		  }
-      } while ( !end ) ;
+      } while ( !reachedEndOfFile ) ;
  
-/* PTS 1103512 always append at end of file... */
+      if ( *min_pos == 0 )
+      {
+          *min_pos = last_pos;
+      }
       *act_pos = last_pos;
 
-      fclose ( stream ) ;
+      close ( fd ) ;
   }
 }
 
@@ -1674,11 +1804,9 @@ externC void en60_ReopenKnldiagFile(RTE_XPARAM_REC *XparamParameters)
 {
     int				rc ;
 
-    en60_DiagMutex = 0;
-
     LOCALDBG (( "en60_ReopenKnldiagFile: called \n" ))
 
-    en60_DiagMutex = 0;
+    en60_DiagMutex = 0; /* Reopened knldiag output in watchdog thread is no longer serialized... */
 
     rc  = en60_ReopenDiag  ( XparamParameters);
     rc |= en60_OpenErrmsg ( DO_NOT_TRY_TO_WRITE_STARTING_MESSAGE );
