@@ -1,5 +1,5 @@
 /*!
-  @file           Copy of ven70.c
+  @file           ven70.c
   @author         JoergM
   @brief          SAPDB Kernel: Initialization of shared memory
   
@@ -1198,7 +1198,7 @@ int                 count )
   for ( stcb = & pcb->pFirstTaskCtrl, prev_tcb = NULL, idx = 0, j = 0;
 	    * stcb; 
         prev_tcb = *stcb, stcb = & (*stcb)->next_task ) ;
-
+  
   DBG1 (( MF__,"end of task is T%d\n", tcb->index ));
   DBG1 (( MF__,"try to insert %d Tasks\n", count ));
   for ( idx = 0 ; idx < count ; idx++ , tcb++ , stcb = & (*stcb)->next_task ) 
@@ -1213,6 +1213,8 @@ int                 count )
     case TT_US:
     case TT_UT:
     case TT_EV:
+      /*  mark as inactive */
+      tcb->state       = TSK_INACTIVE;
       tcb->connectable = true;
       break;
     default:
@@ -1220,17 +1222,19 @@ int                 count )
       break;
     }
 
+    tcb->moveLock.val = 0;  /* reset lock */
+
+    tcb->moveLock.type.longTerm = TASK_IS_INACTIVE; /* Set move lock. Will be removed
+                                                        by the first 'vreceive' */
     if ( tcb->type != TT_US )
-        tcb->moveLock.type.longTerm = NEVER_MOVE_TASK;
+        tcb->moveLock.type.longTerm |= NEVER_MOVE_TASK;
     else
         pcb->tasksAllowedToMoveTo = SAPDB_TRUE;
 
-    if ( tcb->connectable )
-        tcb->moveLock.type.temporary = 1; /* Set temporary move lock. Will be removed
-                                          by the first 'vreceive' */
-
     en71AlterTaskCnt( tcb, ADD_TOTAL_COUNTER );
 
+    e73_dl_init ( &tcb->dlq_connreq, "DLQConnect" );
+
     tcb->prev_task = prev_tcb;  /* prev. pointer */
     *stcb          = tcb;       /* next pointer  */
 
