@@ -49,6 +49,7 @@
 #include "RunTime/System/RTESys_MicroTime.h"
 #include "hsp77.h"
 #include "RunTime/System/RTESys_MemoryBarrier.h"
+#include "RunTime/System/RTESys_AtomicOperation.h"
 
 /*
  *  DEFINES
@@ -228,6 +229,8 @@ sp77sprintf(eBuffer, sizeof(eBuffer), "ENTER en71Dispatcher UKT%d curr_task T%d"
 MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 #endif
 
+    this_ukt->m_IsWaitingForNextScheduledTask = true; /* enforce spinlocks to use giveup timeslice while in dispatcher */
+
     en71_HandleUKTStatisticReset(this_ukt);
 
     /* PTS 1110829 */
@@ -240,6 +243,24 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
         en71_HandleTaskStatisticReset(this_ukt, pTaskCtrl);
 
         pTaskCtrl->pCurrStackPointer = (SAPDB_UInt4 *)&rc;
+#ifdef DEBUG_RTE
+        if ( ((SAPDB_Byte *)pTaskCtrl->pCurrStackPointer) < pTaskCtrl->StackChunkStart
+          || ((SAPDB_Byte *)pTaskCtrl->pCurrStackPointer) > pTaskCtrl->StackChunkEnd )
+        {
+            char sBuffer[256];
+            tsp00_TaskId taskId;
+            vgetpid(&taskId); 
+            sp77sprintf(sBuffer, sizeof(sBuffer),
+                            "Stack chunk UKT %d task T%d mismatch %p not [%p,%p] (T%d)", 
+                            this_ukt->index, pTaskCtrl->index,
+                            pTaskCtrl->pCurrStackPointer, pTaskCtrl->StackChunkStart,
+                            pTaskCtrl->StackChunkEnd, taskId );
+            MSGD(( INFO_TEST_WILDCARD, sBuffer ));
+            while ( ((SAPDB_Byte *)pTaskCtrl->pCurrStackPointer) < pTaskCtrl->StackChunkStart
+                 || ((SAPDB_Byte *)pTaskCtrl->pCurrStackPointer) > pTaskCtrl->StackChunkEnd )
+              sleep(0);
+        }
+#endif
         /* PTS 1110953 */
         if ( pTaskCtrl->maxStackPointer < (SAPDB_UInt4 *)&rc )
         {
@@ -467,6 +488,7 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
         /******************************************************************/
         /* search IOC queue, add elemets to RUN_QUEU                      */
         /******************************************************************/
+#if defined(OLD_SPINLOCK_IOC_QUEUE) || !defined(RTESYS_HAS_NATIVE_ATOMIC_OPERATION)
 #ifdef  DEBUG_RTE
         DBG1 (( MF__,"searching in IOC-Queue \n" ));
 
@@ -489,217 +511,247 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
         CLEARLOCK ( this_ukt->ioc_queue.exclusive );
 #endif /*DEBUG_RTE*/
 
-        for (;;)
+        while ( 0 != ( this_ukt->curr_quu = this_ukt->ioc_queue.last->request ) )
         {
-            this_ukt->curr_quu = this_ukt->ioc_queue.last->request;
-            DBG1 (( MF__,"ioc_queue.last->request = 0x%lx\n",
-                        this_ukt->ioc_queue.last->request ));
-            if ( this_ukt->curr_quu == NULL )
-               break;
+            RTESys_ReadMemoryBarrier();
+
             /* dequeue the request */
             this_ukt->ioc_queue.last->request = 0 ;
             this_ukt->ioc_queue.last = this_ukt->ioc_queue.last->next ;
+            this_ukt->curr_task      = this_ukt->curr_quu->taskid ;
 
-            this_ukt->curr_task = this_ukt->curr_quu->taskid ;
+#else
+        {
+            struct  DOUBLY_LINKED * lastIocElement;
 
-            RTESys_ReadMemoryBarrier();
-
-            if ( this_ukt->curr_task) 
-            { /* since REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00 and REQ_MOVE_TASK_EO00 no task might be specified */
-                this_ukt->curr_task->is_in_queue = TASK_IS_IN_NON_QUEUE ;
-                IGNORE_REQUEST_AT_SYSTEM_END() ;
-
-                /* The load balancing has moved the task to another UKT during
-                   'ioc' enqueue operation. Now we forward this request.. */
-                if( this_ukt != this_ukt->curr_task->ukt )
-                {
-                    en71_iocEnquAndWake ( this_ukt->curr_task->ukt, this_ukt->curr_task, 
-                                          this_ukt->curr_quu );
-                    this_ukt->curr_task = NULL;
-                    continue;
-                }
-            }
-
-            /*
-             *  INSERT_MOVING_TASK requests
-             */
-            if (this_ukt->curr_quu->req_type == REQ_INSERT_MOVING_TASK_E000)
+            while ( 0 != (lastIocElement = this_ukt->ioc_queue.last) )
             {
-                struct  TASK_TYPE * tmp_tcb;
+                struct  DOUBLY_LINKED * firstIocElement;
 
-                MSGD(( INFO_TASK_MOVE_REQUEST_REC, this_ukt->curr_task->index ));
+                while ( !RTESys_CmpxchgPointer( (void **)&this_ukt->ioc_queue.last,
+                                                lastIocElement,
+                                                0,
+                                                (void **)&lastIocElement ) );
+                
+                RTESys_ReadMemoryBarrier();
 
-                /* integrate task into UKTs task chain! */
-                tmp_tcb = this_ukt->pFirstTaskCtrl;
-
-                if ( tmp_tcb ) tmp_tcb->prev_task   = this_ukt->curr_task;
-
-                this_ukt->pFirstTaskCtrl       = this_ukt->curr_task;
-                this_ukt->curr_task->next_task = tmp_tcb;
-                this_ukt->curr_task->prev_task = NULL;
-
-                if (this_ukt->curr_task->prio_flag)  this_ukt->SelfDispatch++;
-
-                en71AlterTaskCnt( this_ukt->curr_task, ADD_ALL_COUNTER );
-
-                this_ukt->curr_quu->req_type     = this_ukt->curr_quu->req_type_org;
-                this_ukt->curr_quu->req_type_org = 0;
-            }
-
-            /*
-             *  NEW_MOVE_TASK_MEAS_INTERVAL requests
-             */
-            if (this_ukt->curr_quu->req_type == REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00)
-            {   
-                tsp00_Int4                           idx;
-                struct REQ_PARMS_MOVE_TASK_MESS_INT* reqArg;
-                SAPDB_UInt8                          runnableMicroSeconds;
-                struct TASK_TYPE*                    pTaskCtrl;
-                SAPDB_UInt8                          timeNow = RTESys_MicroSecTimer();
-                tsp00_Int4                           runQueueLen = this_ukt->RunQueueLen;
-
-                for ( idx = 0; idx < runQueueLen; idx++ )
+                firstIocElement = lastIocElement;
+                while ( firstIocElement->backward )
                 {
-                    pTaskCtrl = this_ukt->RunQueue[idx].Task;
-
-                    if ( pTaskCtrl->moveLock.type.longTerm != 0 ) 
-                        continue;
-
-                    runnableMicroSeconds = timeNow - pTaskCtrl->TaskStateStat.runqueueEnqueueTime;
-
-                    /* accumulate the tasks time waititng in the run queue to be scheduled */
-                    pTaskCtrl->runnableMicroSeconds[this_ukt->currTimeVar] += runnableMicroSeconds;
-
-                    /* Has the tasks a new runnable time maximum? */
-                    if ( pTaskCtrl->maxRunnableMicroSeconds[this_ukt->currTimeVar] < runnableMicroSeconds )
-                        pTaskCtrl->maxRunnableMicroSeconds[this_ukt->currTimeVar] = runnableMicroSeconds;
-
-                    /* set the UKTs runnable time values */
-                    this_ukt->runnableMicroSeconds[this_ukt->currTimeVar] += runnableMicroSeconds;
-
-                    if ( this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar] < runnableMicroSeconds )
-                        this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar] = runnableMicroSeconds;
+                    firstIocElement->backward->forward = firstIocElement;
+                    firstIocElement = firstIocElement->backward;
                 }
 
-                reqArg = &this_ukt->curr_quu->args.mtmi_parms;
-                /* skip old requests */
-                if ( reqArg->taskMoveIntervalStartTime == KGS->taskMoveIntervalStartTimes[KGS->currTimeVar])
+                while ( firstIocElement )
                 {
-                    this_ukt->currTimeVar                                     = reqArg->timeVar;
-                    this_ukt->taskMoveIntervalStartTime                       = reqArg->taskMoveIntervalStartTime;
-                    this_ukt->UKTSleepTimeMicroSeconds[this_ukt->currTimeVar] = 0;
-                    this_ukt->runnableMicroSeconds[this_ukt->currTimeVar]     = 0;
-                    this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar]  = 0;
-                    this_ukt->moveTaskToUKT                                   = NULL; /* drop old move task requests */
-                }
-                /* free the queue element which woke us */
-                e73_dl_enqu ( &KGS->freelist, this_ukt->curr_quu );
-                this_ukt->curr_task = 0 ;
-                continue ;
-            }
+                    this_ukt->curr_quu = firstIocElement;
+                    firstIocElement = firstIocElement->forward;
+            
+                    this_ukt->curr_task      = this_ukt->curr_quu->taskid ;
+#endif
 
-            /*
-             *  MOVE_TASK requests
-             */
-            if (this_ukt->curr_quu->req_type == REQ_MOVE_TASK_EO00)
-            {   
-                struct REQ_PARMS_MOVE_TASK *reqArg;
+                    if ( this_ukt->curr_task) 
+                    { /* since REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00 and REQ_MOVE_TASK_EO00 no task might be specified */
+                        this_ukt->curr_task->is_in_queue = TASK_IS_IN_NON_QUEUE ;
+                        IGNORE_REQUEST_AT_SYSTEM_END() ;
 
-                reqArg = &this_ukt->curr_quu->args.mt_parms;
-                /*  skip old requests */
-                if ( reqArg->taskMoveIntervalStartTime == KGS->taskMoveIntervalStartTimes[KGS->currTimeVar])
-                {
-                    this_ukt->stopWaitForBestFitTaskAt = reqArg->stopWaitForBestFitTaskAt;
-                    this_ukt->moveTaskToUKT            = reqArg->moveTaskToUKT;
-                }
-                /* free the queue element which woke us */
-                e73_dl_enqu ( &KGS->freelist, this_ukt->curr_quu );
-                this_ukt->curr_task = 0 ;
-                continue ;
-            }
+                        /* The load balancing has moved the task to another UKT during
+                           'ioc' enqueue operation. Now we forward this request.. */
+                        if( this_ukt != this_ukt->curr_task->ukt )
+                        {
+                            en71_iocEnquAndWake ( this_ukt->curr_task->ukt, this_ukt->curr_task, 
+                                                  this_ukt->curr_quu );
+                            this_ukt->curr_task = 0;
+                            continue;
+                        }
+                    }
 
+                    /*
+                     *  INSERT_MOVING_TASK requests
+                     */
+                    if (this_ukt->curr_quu->req_type == REQ_INSERT_MOVING_TASK_E000)
+                    {
+                        struct  TASK_TYPE * tmp_tcb;
 
-            /*
-             *  CONNECT requests
-             */
-            if ( (this_ukt->curr_quu->req_type == REQ_CONNECT) ||
-             (this_ukt->curr_quu->req_type == REQ_BIG_CONNECT) )
-            {
-                DBG1 (( MF__,"a CONNECT request for T%d \n", 
-                    this_ukt->curr_task->index ));
-                rc = e75_connect_request ( this_ukt->curr_quu );
-                if ( rc == 0 )
-                {
-                    ENQU_RUNQUEUE(this_ukt->curr_task, NULL, 
-                        this_ukt->curr_quu, BASE_PRIO_COM )  ;
-                }
-                this_ukt->curr_task = 0 ;
-                continue ;
-            }
+                        MSGD(( INFO_TASK_MOVE_REQUEST_REC, this_ukt->curr_task->index ));
 
-            /*
-             *  RELEASE requests
-             */
-            if ( this_ukt->curr_quu->req_type == REQ_RELEASE )
-            {
-                e75_release_request ( this_ukt->curr_quu );
-                this_ukt->curr_task = 0 ;
-                continue ;
-            }
+                        /* integrate task into UKTs task chain! */
+                        tmp_tcb = this_ukt->pFirstTaskCtrl;
+
+                        if ( tmp_tcb ) tmp_tcb->prev_task   = this_ukt->curr_task;
+
+                        this_ukt->pFirstTaskCtrl       = this_ukt->curr_task;
+                        this_ukt->curr_task->next_task = tmp_tcb;
+                        this_ukt->curr_task->prev_task = NULL;
+
+                        if (this_ukt->curr_task->prio_flag)  this_ukt->SelfDispatch++;
+
+                        en71AlterTaskCnt( this_ukt->curr_task, ADD_ALL_COUNTER );
+
+                        this_ukt->curr_quu->req_type     = this_ukt->curr_quu->req_type_org;
+                        this_ukt->curr_quu->req_type_org = 0;
+                    }
+
+                    /*
+                     *  NEW_MOVE_TASK_MEAS_INTERVAL requests
+                     */
+                    if (this_ukt->curr_quu->req_type == REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00)
+                    {   
+                        tsp00_Int4                           idx;
+                        struct REQ_PARMS_MOVE_TASK_MESS_INT* reqArg;
+                        SAPDB_UInt8                          runnableMicroSeconds;
+                        struct TASK_TYPE*                    pTaskCtrl;
+                        SAPDB_UInt8                          timeNow = RTESys_MicroSecTimer();
+                        tsp00_Int4                           runQueueLen = this_ukt->RunQueueLen;
+
+                        for ( idx = 0; idx < runQueueLen; idx++ )
+                        {
+                            pTaskCtrl = this_ukt->RunQueue[idx].Task;
+
+                            if ( pTaskCtrl->moveLock.type.longTerm != 0 ) 
+                                continue;
+
+                            runnableMicroSeconds = timeNow - pTaskCtrl->TaskStateStat.runqueueEnqueueTime;
+
+                            /* accumulate the tasks time waititng in the run queue to be scheduled */
+                            pTaskCtrl->runnableMicroSeconds[this_ukt->currTimeVar] += runnableMicroSeconds;
+
+                            /* Has the tasks a new runnable time maximum? */
+                            if ( pTaskCtrl->maxRunnableMicroSeconds[this_ukt->currTimeVar] < runnableMicroSeconds )
+                                pTaskCtrl->maxRunnableMicroSeconds[this_ukt->currTimeVar] = runnableMicroSeconds;
+
+                            /* set the UKTs runnable time values */
+                            this_ukt->runnableMicroSeconds[this_ukt->currTimeVar] += runnableMicroSeconds;
+
+                            if ( this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar] < runnableMicroSeconds )
+                                this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar] = runnableMicroSeconds;
+                        }
+
+                        reqArg = &this_ukt->curr_quu->args.mtmi_parms;
+                        /* skip old requests */
+                        if ( reqArg->taskMoveIntervalStartTime == KGS->taskMoveIntervalStartTimes[KGS->currTimeVar])
+                        {
+                            this_ukt->currTimeVar                                     = reqArg->timeVar;
+                            this_ukt->taskMoveIntervalStartTime                       = reqArg->taskMoveIntervalStartTime;
+                            this_ukt->UKTSleepTimeMicroSeconds[this_ukt->currTimeVar] = 0;
+                            this_ukt->runnableMicroSeconds[this_ukt->currTimeVar]     = 0;
+                            this_ukt->maxRunnableMicroSeconds[this_ukt->currTimeVar]  = 0;
+                            this_ukt->moveTaskToUKT                                   = NULL; /* drop old move task requests */
+                        }
+                        /* free the queue element which woke us */
+                        e73_dl_enqu ( &KGS->freelist, this_ukt->curr_quu );
+                        this_ukt->curr_task = 0 ;
+                        continue ;
+                    }
+
+                    /*
+                     *  MOVE_TASK requests
+                     */
+                    if (this_ukt->curr_quu->req_type == REQ_MOVE_TASK_EO00)
+                    {   
+                        struct REQ_PARMS_MOVE_TASK *reqArg;
+
+                        reqArg = &this_ukt->curr_quu->args.mt_parms;
+                        /*  skip old requests */
+                        if ( reqArg->taskMoveIntervalStartTime == KGS->taskMoveIntervalStartTimes[KGS->currTimeVar])
+                        {
+                            this_ukt->stopWaitForBestFitTaskAt = reqArg->stopWaitForBestFitTaskAt;
+                            this_ukt->moveTaskToUKT            = reqArg->moveTaskToUKT;
+                        }
+                        /* free the queue element which woke us */
+                        e73_dl_enqu ( &KGS->freelist, this_ukt->curr_quu );
+                        this_ukt->curr_task = 0 ;
+                        continue ;
+                    }
+
+                    /*
+                     *  CONNECT requests
+                     */
+                    if (this_ukt->curr_quu->req_type == REQ_CONNECT)
+                    {
+                        if ( this_ukt->curr_task->state == TSK_CONNECTWAIT )
+                        {
+                            ENQU_RUNQUEUE(this_ukt->curr_task, NULL, 
+                                          this_ukt->curr_quu, BASE_PRIO_COM )  ;
+                        }
+                        else
+                        {
+                            /* - don't enqueue into the run-queue if the task
+                                 is not waiting for a connection */
+                            e73_dl_enqu ( &this_ukt->curr_task->dlq_connreq, this_ukt->curr_quu );
+                        }
+
+                        this_ukt->curr_task = 0 ;
+                        continue ;
+                    }
+
+                    /*
+                     *  RELEASE requests
+                     */
+                    if ( this_ukt->curr_quu->req_type == REQ_RELEASE )
+                    {
+                        e75_release_request ( this_ukt->curr_quu );
+                        this_ukt->curr_task = 0 ;
+                        continue ;
+                    }
 
 #ifdef DEBUG_RTE
-            if ( this_ukt->curr_quu->req_type == REQ_VBLOCKIO )
-            {
-                DBG1 (( MF__,"REQ_VBLOCKIO, this_ukt 0x%x, quu->ukt 0x%x \n",
-                            this_ukt , this_ukt->curr_task->ukt ));
-            }
+                    if ( this_ukt->curr_quu->req_type == REQ_VBLOCKIO )
+                    {
+                        DBG1 (( MF__,"REQ_VBLOCKIO, this_ukt 0x%x, quu->ukt 0x%x \n",
+                                    this_ukt , this_ukt->curr_task->ukt ));
+                    }
 #endif /* DEBUG_RTE */
 
-            if ( this_ukt->curr_quu->req_type == REQ_ASYNIO )
-            {
-                DBG1 (( MF__,"REQ_ASYNIO, this_ukt 0x%x, quu->ukt 0x%x \n",
-                            this_ukt , this_ukt->curr_task->ukt ));
-                this_ukt->curr_quu->args.vai_parms.finished = TRUE ;
-                /* task searches for finished io req. on call of 'vasynwait' */
-                if ( this_ukt->curr_task->state != TSK_ASYNWAIT_READ &&
-                     this_ukt->curr_task->state != TSK_ASYNWAIT_WRITE ) continue ;
-            }
+                    if ( this_ukt->curr_quu->req_type == REQ_ASYNIO )
+                    {
+                        DBG1 (( MF__,"REQ_ASYNIO, this_ukt 0x%x, quu->ukt 0x%x \n",
+                                    this_ukt , this_ukt->curr_task->ukt ));
+                        this_ukt->curr_quu->args.vai_parms.finished = TRUE ;
+                        /* task searches for finished io req. on call of 'vasynwait' */
+                        if ( this_ukt->curr_task->state != TSK_ASYNWAIT_READ &&
+                             this_ukt->curr_task->state != TSK_ASYNWAIT_WRITE ) continue ;
+                    }
 
-            /*
-			 *  RESUME Tracewriter
-			 */
-			if ( this_ukt->curr_quu->req_type == REQ_RESUME_TW_EO00 )
-			{
-   				DBG1 (( MF__,"REQ_RESUME_TW, this_ukt 0x%x, quu->ukt 0x%x \n",
-					    this_ukt , this_ukt->curr_task->ukt ));
+                    /*
+			         *  RESUME Tracewriter
+			         */
+			        if ( this_ukt->curr_quu->req_type == REQ_RESUME_TW_EO00 )
+			        {
+   				        DBG1 (( MF__,"REQ_RESUME_TW, this_ukt 0x%x, quu->ukt 0x%x \n",
+					            this_ukt , this_ukt->curr_task->ukt ));
 
-                RELEASE_FREELIST_ELEM (this_ukt->curr_quu);
+                        RELEASE_FREELIST_ELEM (this_ukt->curr_quu);
 
-                /* --- tracewriter suspended and not already triggered? */
-                if ( KGS->tw->state == TSK_VSUSPEND && Trace_Flush (KGS->tw->index))
-                {
-       				DBG1 (( MF__,"REQ_RESUME_TW, this_ukt 0x%x, quu->ukt 0x%x \n",
-						    this_ukt , this_ukt->curr_task->ukt ));
+                        /* --- tracewriter suspended and not already triggered? */
+                        if ( KGS->tw->state == TSK_VSUSPEND && Trace_Flush (KGS->tw->index))
+                        {
+       				        DBG1 (( MF__,"REQ_RESUME_TW, this_ukt 0x%x, quu->ukt 0x%x \n",
+						            this_ukt , this_ukt->curr_task->ukt ));
 
-                    /* --- resume tracewriter by 'REQ_VRESUME' and 'qa' */
-                    this_ukt->curr_quu              = &KGS->tw->qa;
-                    this_ukt->curr_quu->req_type    = REQ_VRESUME;
-                    KGS->tw->resume_count = 0; /* This is done instead of increment the counter by one as */
-                                               /* vresume would do */
-                    ++KGS->tw->totalResumerCount;
-                }
-                else
-                {
-                    this_ukt->curr_task = 0;
-                    continue ;
+                            /* --- resume tracewriter by 'REQ_VRESUME' and 'qa' */
+                            this_ukt->curr_quu              = &KGS->tw->qa;
+                            this_ukt->curr_quu->req_type    = REQ_VRESUME;
+                            KGS->tw->resume_count = 0; /* This is done instead of increment the counter by one as */
+                                                       /* vresume would do */
+                            ++KGS->tw->totalResumerCount;
+                        }
+                        else
+                        {
+                            this_ukt->curr_task = 0;
+                            continue ;
+                        }
+                    }
+
+			        DBG1 (( MF__,"IOC task    T%d  request %d \n", 
+					        this_ukt->curr_task->index ,  
+					        this_ukt->curr_quu->req_type ));
+                    ENQU_RUNQUEUE(this_ukt->curr_task, NULL, 
+                            this_ukt->curr_quu,  BASE_PRIO_IOC) ;
+#if !defined(OLD_SPINLOCK_IOC_QUEUE) && defined(RTESYS_HAS_NATIVE_ATOMIC_OPERATION)
                 }
             }
-
-			DBG1 (( MF__,"IOC task    T%d  request %d \n", 
-					this_ukt->curr_task->index ,  
-					this_ukt->curr_quu->req_type ));
-            ENQU_RUNQUEUE(this_ukt->curr_task, NULL, 
-                    this_ukt->curr_quu,  BASE_PRIO_IOC) ;
+#endif
         }
         /* IOC queue */
 
@@ -744,7 +796,7 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 
                     if (( tempTaskCtrl->moveLock.val == 0 ) && ( tempTaskCtrl != lastRunningTaskCtrl ))
                     {
-                        if ( this_ukt->stopWaitForBestFitTaskAt > time ( (time_t*)0 ) )
+                        if ( this_ukt->stopWaitForBestFitTaskAt > KGS->current_time )
                         { /* we are searching for the UKTs task with maximum runnable time */
                             if ( taskMaxRunnableMicroSeconds == this_ukt->maxRunnableMicroSeconds[prevTimeVar] )
                             {
@@ -808,7 +860,16 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
                 if ( tempTaskCtrl->prio_flag ) 
                     this_ukt->SelfDispatch++;
 
-                if ( highestPrioTask->ulDynPrio < tempTaskCtrl->ulDynPrio )
+                if ( highestPrioTask == tempTaskCtrl ) /* More than one queue element for the same task found? */
+                {
+                    if ( REQ_RESCHEDULE_EO00 == runQueue[idx].Req->req_type ) /* Yield request? */
+                    {   /* We have use the yield element first because the task 
+                           is waiting for the yield request first. */
+                        highestPrioTask = tempTaskCtrl;
+                        runIndex        = idx;
+                    }
+                }
+                else if ( highestPrioTask->ulDynPrio < tempTaskCtrl->ulDynPrio )
                 { 
                     highestPrioTask = tempTaskCtrl;
                     runIndex        = idx;
@@ -860,6 +921,7 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
                     en71_shutdownKill (this_ukt);
                 }
 
+                this_ukt->m_IsWaitingForNextScheduledTask = false; /* allow spinlocks to yield again */
                 return ;
             }
         }
@@ -870,7 +932,7 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
             loop_count = DISPATCHER_LOOPS ;
 
             this_ukt->ukp_timeout = new_timeout ;
-            DBG1 (( MF__,"SLEEP, timeout %d seconds \n", (int) (new_timeout - time(0)) ));
+            DBG1 (( MF__,"SLEEP, timeout %d seconds \n", (int) (new_timeout - KGS->current_time) ));
 
 WAIT_AGAIN :
 
@@ -1022,6 +1084,8 @@ static  void    en71_findcom ( ten50_UKT_Control *this_ukt,
                 REMOVE_TASK_FROM_COM_QUEU ( stcb , tcb );
                 DBG1 (( MF__,"COM task  T%d \n", tcb->index ));
                 if ( this_ukt->last_com_task == tcb ) this_ukt->last_com_task = NULL ;
+
+                en71LongTermMoveLock( tcb, WAITING_FOR_NEW_COMMAND, false );
                 ENQU_RUNQUEUE_NO_REQUEST(tcb, BASE_PRIO_COM) ;
             }
             else
@@ -1648,7 +1712,7 @@ time_t en71LoadBalancing()
 
       if (en71TaskMoveCheck( &srcUKT, &dstUKT ))
       {
-        en71SendMoveRequest ( srcUKT, dstUKT, XPARAM(uLoadBalancingCheck) / 2 + time((time_t*)0) );
+        en71SendMoveRequest ( srcUKT, dstUKT, XPARAM(uLoadBalancingCheck) / 2 + KGS->current_time );
 
         sleepTime = XPARAM(uLoadBalancingCheck);
       }
@@ -1679,7 +1743,7 @@ void en71TempMoveLock( struct TASK_TYPE   *tcb,
 
         tcb->moveLock.type.temporary += cnt;
     }
-    else
+    else if ( tcb->moveLock.type.temporary != 0 )
     {
 #if defined (CHECK_MOVELOCK_UNDERRUN)
         if (tcb->moveLock.type.temporary < cnt )
@@ -1710,7 +1774,7 @@ void en71LongTermMoveLock( struct TASK_TYPE   *tcb,
 
         tcb->moveLock.type.longTerm |= lockType;
     }
-    else
+    else if (( tcb->moveLock.type.longTerm & lockType ) != 0 )
     {
         tcb->moveLock.type.longTerm &= ~lockType;
 
@@ -1801,7 +1865,7 @@ static void en71SendMoveMeassIntRequest()
   }
 
   KGS->currTimeVar                                  = NEXT_TIME_VAR(KGS->currTimeVar);
-  KGS->taskMoveIntervalStartTimes[KGS->currTimeVar] = time ( (time_t*)0 );
+  KGS->taskMoveIntervalStartTimes[KGS->currTimeVar] = KGS->current_time;
   KGS->taskMoveMeasIntervals++;
 
   for ( tmpUKT =  KGS->first_kp; tmpUKT <= KGS->last_kp; tmpUKT++ )
@@ -1879,7 +1943,7 @@ static void en71MoveTask ( struct TASK_TYPE*       tcb,
 
   timeVar = PREV_TIME_VAR(ukt->currTimeVar);
 
-  KGS->lastTaskMoves.entries[entry].moveTime                    = time ( (time_t*)0 );
+  KGS->lastTaskMoves.entries[entry].moveTime                    = KGS->current_time;
   KGS->lastTaskMoves.entries[entry].task                        = tcb;
   KGS->lastTaskMoves.entries[entry].taskMaxRunnableMicroSeconds = tcb->maxRunnableMicroSeconds[timeVar];
   KGS->lastTaskMoves.entries[entry].srcUKT                      = ukt;
@@ -2066,7 +2130,7 @@ static void en71_HandleUKTStatisticReset( ten50_UKT_Control *this_ukt )
         /* If we would have a console pipe, the internal MicroSecTimer */
         /* could be used, but if we use shared memory to collect information */
         /* the MicroSecondTimer cannot be used, since it is process local. To */
-        /* provide propper adjustment time() is used, which is identical for all processes */
+        /* provide propper adjustment KGS->current_time is used, which is identical for all processes */
         struct timeval  tv ;
 
         (void) gettimeofday ( &tv , (void *)0 );
