@@ -194,6 +194,10 @@ void en75FinalReleaseConnections( int kernelExitCode )
             /* We do not inform the task about release state here !!!
                It will get informed by removing semaphore later on */
             sql41_detach_shm ( &addr );
+#ifdef SDB_WITH_PROFILER
+            /* If profiling is used, the semaphore is not removed, so we inform client now */
+            (void)semop ( cip->ci_peer_semid , &semsnd , 1 );
+#endif /* SDB_WITH_PROFILER */
         }
     }
 }
@@ -360,7 +364,7 @@ void e75_release_connection ( int reason ,
 
 		if ( wait_for_client )
 		{
-			tcb->task_timeout = LOCL_PKT_TMO + time( (time_t *)0 ) + MAXSLEEPTIME ;
+			tcb->task_timeout = LOCL_PKT_TMO + KGS->current_time + MAXSLEEPTIME ;
 			/*
 			 *  insert task into COM queue, where it waits for a packet
 			 */
@@ -408,9 +412,6 @@ void e75_release_connection ( int reason ,
             KGS->connectedUserTasks -= this_ukt->curr_task->type == TT_US ? 1 : 0;
         }
         CLEARLOCK ( tcb->ukt->exclusive );
-
-        /* remove long term move lock */
-        en71LongTermMoveLock( tcb, CLIENT_NOT_TASK_MOVE_ENABLED, false );
     }
 
     tcb->state = tskstate ;
@@ -467,26 +468,28 @@ int    e75_has_com ( struct TASK_TYPE *tcb )
     /* dont use actual time (to expensive to get... 
       KGS->curr_time may be not up to date, but it
       is good enough for checking task timeout */
-	clock_time = time((time_t *)0);
-
-    /*
-     *  Check for timeout.
-     *  IST 1994-09-07: hanging shutdown:
-     *  using <= istead of < for disabled command timeout.
-     */
-    if ( (tcb->task_timeout <= clock_time) 
-      && (tcb->type != TT_UT) )
+    if ( MAXTIMEVALUE != tcb->task_timeout
+      && tcb->type != TT_UT )
     {
-		/*
-		 * timeout found
-		 */
-		DBG1 (( MF__,"timeout T%d since %d seconds", 
-            tcb->index , (long) (clock_time - tcb->task_timeout) ));
-		tcb->connection->ci_state = CON_TIMEDOUT ;
-		DBGOUT;
-		return true;
-    }
+        clock_time = KGS->current_time;
 
+        /*
+         *  Check for timeout.
+         *  IST 1994-09-07: hanging shutdown:
+         *  using <= istead of < for disabled command timeout.
+         */
+        if ( tcb->task_timeout <= clock_time )
+        {
+		    /*
+		     * timeout found
+		     */
+		    DBG1 (( MF__,"timeout T%d since %d seconds", 
+                tcb->index , (long) (clock_time - tcb->task_timeout) ));
+		    tcb->connection->ci_state = CON_TIMEDOUT ;
+		    DBGOUT;
+		    return true;
+        }
+    }
 
     DBG1 (( MF__,"no packet" ));
 	DBGOUT;
@@ -518,32 +521,24 @@ int     e75_is_connected ( struct TASK_TYPE	*tcb )
  * ===========================================================================
  */
 
-int e75_connect_request ( struct DOUBLY_LINKED	*lquu )
+int e75_connect_request ( struct TASK_TYPE  * tcb,
+                          connection_info   * cip )
 {
 #undef  MF__
 #define MF__ MOD__"e75_connect_request"
-    struct TASK_TYPE  * tcb;
     ten50_UKT_Control * this_ukt = THIS_UKT_CTRL;
-    int				rc ;
-    int				stack_avail = TRUE ;
+    int				    rc ;
+    int				    stack_avail = TRUE ;
     tsp1_comm_error		result ;
     comseg_header		*comseg ;
-    connection_info		*cip ;
     char			logbuf [ 256 ];
 
 	DBGIN;
 
-    PID_TCB(lquu->args.conn_auftrag.task_index, tcb);
-
     DBG1 (( MF__,"connecting T%d", tcb->index ));
 
-    /*
-     *  free the queue element which woke us
-     */
-    e73_dl_enqu ( & KGS->freelist , lquu );
-
     result = SP1CE_OK ;
-    cip = tcb->connection ;
+
     DBG1 (( MF__,"T%d my_ref %d peer_ref %d",
 	    tcb->index,
 	    cip->ci_my_ref , cip->ci_peer_ref ));
@@ -581,12 +576,6 @@ int e75_connect_request ( struct DOUBLY_LINKED	*lquu )
 		return ( -1 );
     }
 
-    if ( !cip->ci_alter_server_sem )
-    {
-        /* set long term move lock... */
-        en71LongTermMoveLock( tcb, CLIENT_NOT_TASK_MOVE_ENABLED, true );
-    }
-
     KGS->connectedUserTasks += this_ukt->curr_task->type == TT_US ? 1 : 0;
 
     comseg = cip->ci_comseg ;
