@@ -61,9 +61,6 @@ extern  void        e72_wake ();
 extern  int         e73_ioc_enqu();
 extern  void        e84_test_application ();
 extern  void        vabort ( tsp00_Bool write_core );
-#if ! ( defined(MI_ULT) || defined(OSF1) || defined(HPUX) )	/* already declared in include file */
-extern  time_t      time ( time_t * );
-#endif
 
 /* local functions */
 
@@ -115,7 +112,7 @@ externC void * en83TimerThread ( void *arg )
 
     this_ukt = (ten50_UKT_Control *) & KGS->timer ;
 
-    this_ukt->start_time = time ( (time_t *) 0 );
+    this_ukt->start_time = KGS->current_time;
     nextApplicationTestTime = this_ukt->start_time + MAXSLEEPTIME;
 
     DBG1 (( MF__,"start_time %ld \n", (long)this_ukt->start_time ));
@@ -128,7 +125,7 @@ externC void * en83TimerThread ( void *arg )
     while (en84_neverStop)
 	{
 		KGS->timer.state = KT_RUNNING ;
-		time_now = time ( (time_t*)0 );
+		time_now = KGS->current_time;
 
     /* PTS 1107963 do no longer react on SERVER_STOP/KILL ... */
 		/*==================================
@@ -255,7 +252,6 @@ externC void * en83TimerThread ( void *arg )
             if (KGS-> ti->state == TSK_VSLEEP
 			 && KGS-> al->state == TSK_VSUSPEND
 			 && KGS-> tw->state == TSK_VSUSPEND
-			 && KGS-> ut->state == TSK_CONNECTWAIT
 			 && en83_tasks_started ( KGS-> first_datawriter ) 
 			 && en83_tasks_started ( KGS-> first_server )
 			   )
