@@ -127,7 +127,7 @@ ten50_KT_Control         *this_kt;
     MSGD (( INFO_PROCESS_STARTED, "REQUESTOR" ));
 
     this_kt = & KGS-> requestor ;
-    this_kt->start_time = time ( (time_t*)0 );
+    this_kt->start_time = KGS->current_time;
 
     DBG1 (( MF__,"REQUESTOR: thread %ld \n", (long)this_kt->tid ));
 
@@ -368,6 +368,8 @@ rte_header		*header )
 			break ;
 		}
 
+		tcb->rte_comm.to_cancel = 0 ; /* reset cancellation flag */
+
 		/*
 		 *  Log the connect request.
 		 */
@@ -542,7 +544,8 @@ struct TASK_TYPE **pTcb )
 		 */
 	    e84_test_application ( KGS-> ut );
 
-		if ( KGS-> ut->state == TSK_CONNECTWAIT )
+		if  (( KGS-> ut->state == TSK_CONNECTWAIT ) ||
+             ( KGS-> ut->state == TSK_INACTIVE ))
 		{
 			DBG1 (( MF__,"utility is waiting for connect \n" ));
 			if ( ! KGS-> ut->connection->ci_connect_time )
@@ -550,7 +553,7 @@ struct TASK_TYPE **pTcb )
 				DBG1 (( MF__,"connecting UTILITY \n" ));
 				tcb = KGS-> ut ;
 				WAIT_UNTIL_ALONE ( tcb->ukt->exclusive );
-				tcb->connection->ci_connect_time = time( (time_t*)0 );
+				tcb->connection->ci_connect_time = KGS->current_time;
 				CLEARLOCK( tcb->ukt->exclusive );
 				*pTcb = tcb;
 				DBG1 (( MF__,"returning SP1CE_OK \n" ));
@@ -648,12 +651,12 @@ struct TASK_TYPE **pTcb )
 		DBG1 (( MF__,"found T%d \n", tcb->index ));
 
 		WAIT_UNTIL_ALONE ( tcb->ukt->exclusive );
-		tcb->connection->ci_connect_time = time( (time_t*)0 );
+		tcb->connection->ci_connect_time = KGS->current_time;
 		tsk_cip = tcb->connection ;
 		tsk_cip->ci_service = cip->ci_service ;
 		CLEARLOCK ( tcb->ukt->exclusive );
 
-		*pTcb = tcb ;
+        *pTcb = tcb ;
 		DBG1 (( MF__,"returning SP1CE_OK \n" ));
 		return ( SP1CE_OK );
     }
@@ -1023,6 +1026,18 @@ struct TASK_TYPE *tcb )
     struct DOUBLY_LINKED	*lquu ;
 
     DBGIN;
+
+    /*  start task if inactive! */
+    if ((( tcb->type == TT_US ||
+           tcb->type == TT_EV )||
+         ( tcb->type == TT_UT ))  &&
+         ( tcb->state == TSK_INACTIVE ))
+    {
+        lquu = e73_dl_dequ ( & KGS-> freelist );
+        lquu->req_type = REQ_INITOK;
+        en71_iocEnquAndWake ( tcb->ukt, tcb, lquu );
+    }
+
     /*
      *  After an accepted connect: send request to proper UKP
      *  This procedure is called from the REQUESTOR process, and
@@ -1080,12 +1095,10 @@ struct TASK_TYPE                *tcb )
      *  connection establishment, the task hangs in an intermediate state.
      *  If this lasts too long, free the task.
      */
-    if (    ((task_state == TSK_CONNECTWAIT)
-	      || (task_state == TSK_INACTIVE) )
-	 && (    tcb->connection->ci_state == CON_CONNECTING )
-       )
+    if ( ((task_state == TSK_CONNECTWAIT) || (task_state == TSK_INACTIVE) )
+	     && (    tcb->connection->ci_state == CON_CONNECTING ))
 	{
-		time_t time_now = time( (time_t*)0 );
+		time_t time_now = KGS->current_time;
 
         if ( (time_now - connect_time) > (2 * SOCK_CON_TMO) )
 		{
@@ -1111,11 +1124,14 @@ struct TASK_TYPE                *tcb )
     /*
      *  Test applications of locally connected tasks only.
      */
-    if (    (tcb->connection->ci_state != CON_TIMEDOUT)
+    if ( (  (tcb->connection->ci_state != CON_TIMEDOUT)
          && (tcb->connection->ci_state != CON_ABORTED)
          && (tcb->connection->ci_state != CON_CONNECTING)
          && (tcb->connection->ci_state != CON_UNUSED)
-	 && (tcb->connection->ci_peer_semid > 0) )
+         && (tcb->connection->ci_peer_semid > 0) )
+      || (  (tcb->connection->ci_state == CON_UNUSED)
+         && (tcb->state == TSK_VRELEASE)
+         && tcb->connection->ci_connect_time ) )
     {
 		pid = tcb->connection->ci_peer_pid ;
 		DBG1 (( MF__,"test pid %ld \n", (long) pid ));
