@@ -51,7 +51,7 @@
 #include "gen73.h"  /* en73_dl_enqu() */
 #include "gen74.h"  /* e74_init_big_comseg() */
 #include "gen81.h"
-#ifdef DEBUG_RTE
+#if defined(DEBUG_RTE) || defined(DEBUGCOROUTINE)
 #include "SAPDBCommon/SAPDB_sprintf.h" /*nocheck*/
 #endif
 
@@ -262,7 +262,7 @@ extern "C" void *en88ExecuteCoroutineUKT(ten50_UKT_Control *this_ukt)
 {
     // starting task of UKT has to complete initialization of UKT structure
     this_ukt->state      = KT_RUNNING;
-    this_ukt->start_time = time ( (time_t *) 0 );
+    this_ukt->start_time = KGS->current_time;
  
     // Initialize communication segment of this UKT
     e74_init_big_comseg (this_ukt);
@@ -280,14 +280,27 @@ extern "C" void *en88ExecuteCoroutineUKT(ten50_UKT_Control *this_ukt)
         en71Dispatcher (this_ukt);
     }
 
-//    do {
-        RTE_ContextSwitch( *(this_ukt->removeTaskContext),
+#ifdef DEBUG_RTE
+    {
+            char eBuffer[256];
+            SAPDB_sprintf(eBuffer, sizeof(eBuffer), "Initial Task T%d(UKT%d)"
+                , this_ukt->curr_task->index, this_ukt->index );
+            MSGD(( INFO_TEST_WILDCARD, eBuffer ));
+    }
+#endif
+#ifdef ALPHA
+      e71_FirstChangeStack ( & this_ukt->curr_task->taskContext->context.ownC , & this_ukt->removeTaskContext->context.ownC );
+#else
+      //    do {
+       RTE_ContextSwitch( *(this_ukt->removeTaskContext),
                            *(this_ukt->curr_task->taskContext) );
         // finalize....
 //        this_ukt->curr_task = (struct TASK_TYPE*) 0 ;
 //        en71Dispatcher (this_ukt);
 //    } while ( this_ukt->curr_task );
-    return (void *)0;
+#endif
+
+       return (void *)0;
 }
 
 //---------------------------------------------------------------
@@ -335,6 +348,7 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
 #undef MF__
 #define MF__ MOD__ "en88RunCoroutineUKT"
     ten50_UKT_Control *this_ukt = (ten50_UKT_Control *)arg;
+    struct TASK_TYPE *pTask;
 
     MSGD(( INFO_UNIX_UKT_STARTED , this_ukt->index )) ;
 
@@ -344,24 +358,31 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
         vabort(WRITE_CORE);
     }
 
-    RTE_ContextPrepare( *(this_ukt->removeTaskContext), 0, 0, 0);
-
-    SAPDB_Int4 totalAlignedStackSize;
-    struct TASK_TYPE *pTask;
-    for ( totalAlignedStackSize = 0, pTask = this_ukt->pFirstTaskCtrl; 
+#ifdef DEBUG_RTE
+    for ( pTask = this_ukt->pFirstTaskCtrl; 
           pTask;
           pTask = pTask->next_task )
     {
-#ifdef DEBUGCOROUTINE
-        printf("UKT%d T%d\n", this_ukt->index, pTask->index);
-        fflush(stdout);
-#endif
-        totalAlignedStackSize += RTE_ISystem::Instance().RoundUpToSystemPageSize(pTask->stack_size);
+          char eBuffer[256];
+          SAPDB_sprintf(eBuffer, sizeof(eBuffer), "UKT%d T%d [%p-%p] 0x%x"
+              , this_ukt->index, pTask->index, pTask->StackChunkStart, pTask->StackChunkEnd, pTask->stack_size);
+          MSGD(( INFO_TEST_WILDCARD, eBuffer ));
     }
+#endif
+
+    RTE_ContextPrepare( *(this_ukt->removeTaskContext), 0, 0, 0);
 
     /* as long as it need tasks on stack of pthread this will be true... */
     if ( XPARAM(fUseStackOnStack) )
     {
+        SAPDB_Int4 totalAlignedStackSize;
+        for ( totalAlignedStackSize = 0, pTask = this_ukt->pFirstTaskCtrl; 
+              pTask;
+              pTask = pTask->next_task )
+        {
+            totalAlignedStackSize += RTE_ISystem::Instance().RoundUpToSystemPageSize(pTask->stack_size);
+        }
+
         SAPDB_Byte *UKTtaskStack = (SAPDB_Byte *)alloca(totalAlignedStackSize+RTE_ISystem::Instance().GetSystemPageSize());
 
         SAPDB_Byte *stackStartAddress = (SAPDB_Byte *)0 +
@@ -373,7 +394,7 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
             alignedStackSize = RTE_ISystem::Instance().RoundUpToSystemPageSize(pTask->stack_size);
             pTask->StackChunkStart = stackStartAddress;
             pTask->StackChunkEnd   = stackStartAddress + alignedStackSize;
-            pTask->stack_size      = pTask->stack_size;
+            pTask->stack_size      = alignedStackSize;
 
             pTask->GuardPageBegin  = 0;
             pTask->GuardPageEnd    = 0;
@@ -406,8 +427,9 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
         for ( pTask = this_ukt->pFirstTaskCtrl; pTask; pTask = pTask->next_task )
         {
 #ifdef DEBUGCOROUTINE
-            printf("Preparing 0x%p for Task T%d\n", pTask->taskContext, pTask->index);
-            fflush(stdout);
+            char eBuffer[256];
+            SAPDB_sprintf(eBuffer, sizeof(eBuffer), "UKT%d: Preparing 0x%p for Task T%d", this_ukt->index, pTask->taskContext, pTask->index);
+            MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 #endif
             RTE_ContextPrepare( *(pTask->taskContext),
                                 pTask->StackChunkStart,
@@ -422,8 +444,9 @@ extern "C" void *en88RunCoroutineUKT(void *arg)
         for ( pTask = this_ukt->pFirstTaskCtrl; pTask; pTask = pTask->next_task )
         {
 #ifdef DEBUGCOROUTINE
-            printf("Preparing 0x%p for Task T%d\n", pTask->taskContext, pTask->index);
-            fflush(stdout);
+            char eBuffer[256];
+            SAPDB_sprintf(eBuffer, sizeof(eBuffer), "UKT%d: Preparing 0x%p for Task T%d", this_ukt->index, pTask->taskContext, pTask->index);
+            MSGD(( INFO_TEST_WILDCARD, eBuffer ));
 #endif
             RTE_ContextPrepare( *(pTask->taskContext),
                                 pTask->StackChunkStart,
@@ -475,12 +498,74 @@ extern "C" void en88TaskContextSwitch( struct TASK_TYPE * pOldTask,
 {
    if ( XPARAM(fUseCoroutines) )
    {
+       char someLocal;
+
+#ifdef DEBUG_RTE
+       {
+       if ( ((SAPDB_Byte *)&someLocal) < pOldTask->StackChunkStart
+          || ((SAPDB_Byte *)&someLocal) > pOldTask->StackChunkEnd )
+        {
+            char sBuffer[256];
+            tsp00_TaskId taskId;
+            vgetpid(taskId); 
+            SAPDB_sprintf(sBuffer, sizeof(sBuffer),
+                            "Before switch task T%d(UKT%d)->T%d(UKT%d) mismatch %p not [%p,%p] (T%d)", 
+                            pOldTask->index, pOldTask->ukt->index, 
+                            pNewTask->index, pNewTask->ukt->index, 
+                            &someLocal, pOldTask->StackChunkStart,
+                            pOldTask->StackChunkEnd, taskId );
+            MSGD(( INFO_TEST_WILDCARD, sBuffer ));
+            abort();
+        }
+       }
+#endif
+#ifdef DEBUG_RTE
+       {
+            char eBuffer[256];
+            SAPDB_sprintf(eBuffer, sizeof(eBuffer), "Switch Task T%d(UKT%d) -> T%d(UKT%d)"
+                , pOldTask->index, pOldTask->ukt->index
+                , pNewTask->index, pNewTask->ukt->index);
+            MSGD(( INFO_TEST_WILDCARD, eBuffer ));
+       }
+#endif
+
        if ( !RTE_ContextSwitch( *(pOldTask->taskContext),
                                 *(pNewTask->taskContext) ) )
        {
            MSGD(( 11900, ERR_TYPE, "TASKING ", "switching to next task failed" ));
            vabort(true);
        }
+#ifdef DEBUG_RTE
+       {
+            char sBuffer[256];
+            tsp00_TaskId taskId;
+            vgetpid(taskId);
+            SAPDB_sprintf(sBuffer, sizeof(sBuffer),
+                            "-> T%d(UKT%d) %p [%p,%p] (T%d)", 
+                            pOldTask->index, pOldTask->ukt->index, 
+                            &someLocal, pOldTask->StackChunkStart,
+                            pOldTask->StackChunkEnd, taskId );
+            MSGD(( INFO_TEST_WILDCARD, sBuffer ));
+            if ( taskId != pOldTask->index )
+            {
+                abort();
+            }
+            if ( ((SAPDB_Byte *)&someLocal) < pOldTask->StackChunkStart
+               || ((SAPDB_Byte *)&someLocal) > pOldTask->StackChunkEnd )
+            {
+                char sBuffer[256];
+                tsp00_TaskId taskId;
+                vgetpid(taskId); 
+                SAPDB_sprintf(sBuffer, sizeof(sBuffer),
+                                "After switch UKT %d task T%d mismatch %p not [%p,%p] (T%d)", 
+                                pOldTask->ukt->index, pOldTask->index,
+                                &someLocal, pOldTask->StackChunkStart,
+                                pOldTask->StackChunkEnd, taskId );
+                MSGD(( INFO_TEST_WILDCARD, sBuffer ));
+                abort();
+            }
+       }
+#endif
    }
    else
    {
@@ -521,7 +606,7 @@ static void en88_InitializePthreadTaskUKT( struct  TASK_TYPE * firstTask )
     ten50_UKT_Control *this_ukt = firstTask->ukt;
 
     this_ukt->state = KT_RUNNING;
-    this_ukt->start_time = time ( (time_t *) 0 );
+    this_ukt->start_time = KGS->current_time;
 
     MSGD(( INFO_UNIX_UKT_STARTED , this_ukt->index )) ;
 
@@ -548,8 +633,8 @@ static void en88_InitializePthreadTaskUKT( struct  TASK_TYPE * firstTask )
     else
     {
         DBG1 (( MF__,"entering dispatcher to find first task" ));
-        this_ukt->curr_task = (struct TASK_TYPE*) 0 ;
-        en71Dispatcher (this_ukt);
+        this_ukt->curr_task = (struct TASK_TYPE*) firstTask;
+        GOTO_DISP (&this_ukt);
     }
 }
 
@@ -567,6 +652,24 @@ extern "C" void en88_CallCoroutineKernelTaskMain ()
     en88_CallKernelTaskMain(RTE_ITaskStackControl::Instance().GetTaskControl());
 }
 
+#ifdef DEBUG_RTE
+void whereIsTaskStack(struct  TASK_TYPE * tcb, ten50_UKT_Control *this_ukt)
+{
+char eBuffer[256];
+SAPDB_sprintf(eBuffer, sizeof(eBuffer), "en88_CallKernelTaskMain ---> Task%d(%s) UKT%d (curr T%d) Stack %p [%p-%p] curr_quu 0x%p first_free 0x%p last_free 0x%p",
+    tcb->index,
+    "_",
+    this_ukt->index,
+    this_ukt->curr_task->index,
+    &this_ukt,
+    tcb->StackChunkStart, tcb->StackChunkEnd,
+    this_ukt->curr_quu,
+    KGS->first_free,
+    KGS->last_free);
+MSGD(( INFO_TEST_WILDCARD, eBuffer ));
+}
+#endif
+
 /*---------------------------------------------------------------------------
   Function: en88_CallKernelTaskMain
   Description: All UKT C++ main function
@@ -580,21 +683,13 @@ static void en88_CallKernelTaskMain ( struct  TASK_TYPE * tcb )
 {
 #undef MF__
 #define MF__ MOD__"en88_CallKernelTaskMain"
+#ifndef OSF1
     try {
+#endif /* !OSF1 */
         ten50_UKT_Control *this_ukt = tcb->ukt;
-#ifdef DEBUG_RTE 
-char eBuffer[256];
-SAPDB_sprintf(eBuffer, sizeof(eBuffer),"---> Task%d(%s) UKT%d (curr T%d) curr_quu 0x%p first_free 0x%p last_free 0x%p",
-    tcb->index,
-    e38_type_name(this_ukt->curr_task->type),
-    this_ukt->index,
-    this_ukt->curr_task->index,
-    this_ukt->curr_quu,
-    KGS->first_free,
-    KGS->last_free);
-MSGD(( INFO_TEST_WILDCARD, eBuffer ));
+#ifdef DEBUG_RTE
+        whereIsTaskStack(tcb, this_ukt);
 #endif
-
         if ( this_ukt->curr_quu )
         {
             DBG1((MF__, "T%d found curr_quu entry", this_ukt->curr_task->index ));
@@ -637,11 +732,13 @@ MSGD(( INFO_TEST_WILDCARD, eBuffer ));
             en51Finish();
 
         }
+#ifndef OSF1
     }
     catch(SAPDBErr_MessageList &lastMsg)
     {
         RTE_Crash(lastMsg);
     }
+#endif /* !OSF1 */
 
 }
 
