@@ -215,6 +215,8 @@
 #define PAN_UTILITY_PROTSIZE          (SAPDB_Char *)KERNELPARAM_UTILITY_PROTSIZE
 #define PAN_VALLOC_MEM_POOL           (SAPDB_Char *)KERNELPARAM_VALLOC_MEM_POOL
 #define PAN_XPARAM_CHANGED            (SAPDB_Char *)KERNELPARAM___PARAM_CHANGED___
+#define PAN_SYMBOL_RESOLUTION         (SAPDB_Char *)KERNELPARAM_SYMBOL_RESOLUTION
+#define PAN_PREALLOCATE_IOWORKER      (SAPDB_Char *)KERNELPARAM_PREALLOCATE_IOWORKER
 /***************************************************************/
 #if defined(_WIN32)
 /***************************************************************/
@@ -428,6 +430,8 @@ typedef struct  rte_xparam_record
   tsp00_Bool                  fLogMirrored;
   tsp00_Bool                  fSetVolumeLock;
   tsp00_Bool                  fForbidLoadBalancing;
+  tsp00_Bool                  allowSymbolResolution;
+  tsp00_Bool                  preallocateIOWorker;
 } RTE_XPARAM_REC;
 
 /*===========================================================================*
