@@ -6,23 +6,24 @@
   @see            
 
 \if EMIT_LICENCE
-  ========== licence begin  GPL
-  Copyright (c) 2001-2004 SAP AG
+    ========== licence begin  GPL
+    Copyright (c) 2001-2005 SAP AG
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation; either version 2
+    of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    ========== licence end
 
-  You should have received a copy of the GNU General Public License
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  ========== licence end
 \endif
 */
 
@@ -79,14 +80,14 @@ static SUSPEND_STATE_REASON SuspendReasonText[MAX_SUSPEND_REASONS] =
     {  "ObjNodeExcl   " , "bd13GetNode                             " } ,
     {  "ObjNodeShare  " , "bd13GetNode                             " } ,
     {  "SVP-End  (028)" , "bd13WriteExclusiveLockedRoot            " } ,
-    {  "Vsuspend (029)" , "                                        " } ,
-    {  "Vsuspend (030)" , "                                        " } ,
-    {  "Vsuspend (031)" , "                                        " } ,
-    {  "Vsuspend (032)" , "                                        " } ,
-    {  "Vsuspend (033)" , "                                        " } ,
-    {  "Vsuspend (034)" , "                                        " } ,
-    {  "Vsuspend (035)" , "                                        " } ,
-    {  "Vsuspend (036)" , "                                        " } ,
+    {  "UndoRootExcl  " , "bd13GetNode                             " } ,
+    {  "UndoRootShare " , "bd13GetNode                             " } ,
+    {  "UndoNodeExcl  " , "bd13GetNode                             " } ,
+    {  "UndoNodeShare " , "bd13GetNode                             " } ,
+    {  "HistRootExcl  " , "bd13GetNode                             " } ,
+    {  "HistRootShare " , "bd13GetNode                             " } ,
+    {  "HistNodeExcl  " , "bd13GetNode                             " } ,
+    {  "HistNodeShare " , "bd13GetNode                             " } ,
     {  "Vsuspend (037)" , "                                        " } ,
     {  "Vsuspend (038)" , "                                        " } ,
     {  "Vsuspend (039)" , "                                        " } ,
@@ -247,7 +248,7 @@ static SUSPEND_STATE_REASON SuspendReasonText[MAX_SUSPEND_REASONS] =
     {  "Vsuspend (194)" , "                                        " } ,
     {  "Vsuspend (195)" , "                                        " } ,
     {  "Vsuspend (196)" , "                                        " } ,
-    {  "db-full  (197)" , "Conv_HandleDBFull                       " } ,
+    {  "DB FULL  (197)" , "Conv_HandleDBFull                       " } ,
     {  "Vsuspend (198)" , "                                        " } ,
     {  "Vsuspend (199)" , "                                        " } ,
     {  "Vsuspend (200)" , "                                        " } ,
