@@ -154,6 +154,20 @@ typedef struct eo670AddressInfo_
 } eo670AddressInfo;
 
 
+#ifdef WIN32
+
+typedef struct eo670TraceContext_
+{
+    HANDLE      threadHandle;     /*!< handle to the thread for which the stack trace has to be generated  */
+    CONTEXT*    pThreadContext;   /*!< contains processor-specific register data snapshot of the thread */
+} eo670TraceContext, * eo670TraceContextPtr;
+
+#else /* UNIX */
+
+typedef void*   eo670TraceContextPtr;
+
+#endif
+
 
 /*!
    @brief          Pointer type of callback functions used to write on stack back trace 
@@ -332,11 +346,11 @@ externC void eo670_FreeAddressInfo(eo670AddressInfo* pAddrInfo);
   The given context is retrieved as third argument of a sigaction handler on UNIX and as
   exception context on NT.
   If 0 the current context is retrieved.
-   @param          pBTraceContext [in] a CONTEXT on NT or a struct sigcontext * on UNIX
+   @param          pBTraceContext [in] a struct sigcontext * on UNIX
 
  */
 
-externC void eo670_CTraceContextStack   ( void*                 pBTraceContext );
+externC void eo670_CTraceContextStack   ( eo670TraceContextPtr    pBTraceContext );
 /*!
   @brief          Create a stack backtrace using given context into the user given stack back trace output channel
 
@@ -354,11 +368,11 @@ externC void eo670_CTraceContextStack   ( void*                 pBTraceContext )
   exception context on NT.
   If 0 the current context is retrieved.
 
-  @param          pBTraceContext [in] a CONTEXT on NT or a struct sigcontext * on UNIX
+  @param          pBTraceContext [in] a struct sigcontext * on UNIX
   @param pOutput [in] output callback
   @param pOutContext [in] output callback context
  */
-externC void eo670_CTraceContextStackOCB( void*                 pBTraceContext,
+externC void eo670_CTraceContextStackOCB( eo670TraceContextPtr  pBTraceContext,
                                           OutputCallBackFuncPtr pOutput,    /* with ouput callback func.*/
                                           void * const          pOutContext); 
 
@@ -366,11 +380,38 @@ externC void eo670_CTraceContextStackOCB( void*                 pBTraceContext,
 /*!
   @brief          Write a minidump (equivalent to UNIX core dump)
 
+  @param threadId[in] thread id throwing the exception
+  @param pExcPtrs[in] pointer to the exception context          
+  @param pszFile [in] dump file name
   @param WriteFullMemoryDump [in] write a full memory dump
   @param IfDumpFileExists [in] write dump only if dump file exists
  */
-externC bool eo670_WriteDump ( bool WriteFullMemoryDump,
-                               bool IfDumpFileExists );
+externC bool eo670_WriteMiniDump ( DWORD                      threadId,
+                                   LPEXCEPTION_POINTERS       pExcPtrs,
+                                   char const * const         pszFile,
+                                   bool                       WriteFullMemoryDump,
+                                   bool                       IfDumpFileExists,
+                                   PSECURITY_ATTRIBUTES       pSA );
+/*!
+  @brief          Write a minidump (equivalent to UNIX core dump)
+
+  @param threadId[in] thread id throwing the exception
+  @param pExcPtrs[in] pointer to the exception context          
+  @param pszFile [in] dump file name
+  @param WriteFullMemoryDump [in] write a full memory dump
+  @param IfDumpFileExists [in] write dump only if dump file exists
+  @param pOutput [in] output callback
+  @param pOutContext [in] output callback context
+ */
+externC bool eo670_WriteMiniDumpOCB ( DWORD                      threadId,
+                                      LPEXCEPTION_POINTERS       pExcPtrs,
+                                      char const * const         pszFile,
+                                      bool                       WriteFullMemoryDump,
+                                      bool                       IfDumpFileExists,
+                                      OutputCallBackFuncPtr      pOutput,    /* with ouput callback func.*/
+                                      void * const               pOutContext,
+                                      PSECURITY_ATTRIBUTES       pSA );
+
 #endif
 
 /*!
