@@ -339,7 +339,7 @@ static void eo02AixQueryError(const char *DLFunction, tsp00_Pathc fullName, char
     {
         int iMsg;
         char **cmdArgv = 0;
-        SAPDB_Int4 bufferSize = 8192;;
+        SAPDB_Int4 bufferSize = 8192;
 
         /* try again until either buffer exceeds mem available or loadquery is satisfied...*/
         do
@@ -351,11 +351,12 @@ static void eo02AixQueryError(const char *DLFunction, tsp00_Pathc fullName, char
                 cmdArgv[1] = &fullName[0];
                 iMsg = loadquery( L_GETMESSAGES
                                 , &cmdArgv[2]
-                                , sizeof(cmdArgv) - ( 2 * sizeof(char *) ) );
+                                , bufferSize - ( 2 * sizeof(char *) ) );
                 if ( (-1 == iMsg) && (ENOMEM == errno) )
                 {
                     free(cmdArgv);
                     bufferSize *= 2;
+                    errno = ENOMEM;
                 }
             }
             else
