@@ -70,9 +70,9 @@
 #include "geo001.h"
 #include "geo007_1.h" /* For error messages */
 #include "geo007_2.h" /* For error messages */
-#if defined(_WIN32) && defined(KERNEL_LZU)
-#include "geo50_0.h" /* nocheck */ /* sql57k_pmalloc, sql57k_pfree, vabort */
-#endif /*_WIN32 && KERNEL_LZU*/
+#if defined(KERNEL_LZU)
+#include "geo50_0.h" /* nocheck */ /* sql57k_pmalloc, sql57k_pfree, vabort + KGS->current_time for UNIX */
+#endif /* KERNEL_LZU*/
 
 #if defined(KERNEL_LZU) && !defined(WIN32)
 #    include "RunTime/RTE_Coroutine.h" /*nocheck*/
@@ -107,6 +107,7 @@
 # undef HAVE_PTHREAD_SCOPE_PROCESS
 # undef TIMEOUT_SYSTEM_RC
     /* PTS 1105217 */
+# undef USE_GETTID_FOR_THREAD_ID
 # undef USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID
 # undef USE_GETSEQUENCE_NP_FOR_THREAD_ID
 # undef USE_CLONE_PID_FOR_THREAD_ID
@@ -158,8 +159,15 @@
 #    define USE_CLONE_PID_FOR_THREAD_ID 1
 #    define YIELD_CALL sched_yield()
 #  else
+/*!
+  The manual page for gettid() shows an alternative to using syscall() but
+  unfortunatly this does not work on linuxia64! Using syscall(__NR_gettid)
+  instead works fine on all Linux plattforms tested 
+  (linux,linuxx86_64,linuxpppc,linuxia64,linuxs390x)
+ */
+#    define USE_GETTID_FOR_THREAD_ID
+#       include <sys/syscall.h>
 #    define YIELD_CALL pthread_yield()
-#    define USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID
 #    define HAVE_PTHREAD_SCOPE_PROCESS
 #  endif /* HAS_NPTL */
 
@@ -444,6 +452,11 @@ void sqlinit_multithreading( teo07_Thread *thread,
 # endif
 
     pThreadObj->thread    = pthread_self();
+
+# ifdef USE_GETTID_FOR_THREAD_ID
+  pThreadObj->thread_id = (teo07_ThreadId)syscall(__NR_gettid);
+# endif
+
 # ifdef USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID
     pThreadObj->thread_id = eo07_GetSequenceNumber();
 # endif /* USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID */
@@ -1033,6 +1046,11 @@ teo07_ThreadId sqlgetthreadid()
 #endif /* _WIN32 */
 
 #ifdef PTHREADS
+
+# ifdef USE_GETTID_FOR_THREAD_ID
+    return (teo07_ThreadId)syscall(__NR_gettid);
+# endif
+
 # ifdef USE_CLONE_PID_FOR_THREAD_ID
     return (teo07_ThreadId)getpid();
 # else
@@ -1866,6 +1884,13 @@ void sqltimedwaitsem (teo07_ThreadSemaphore sem,
 {
 #undef MF__
 #define MF__ MOD__"sqltimedwaitsem"
+
+    if ( seconds < 0 )
+    {
+        seconds = 0;
+    }
+
+    {
 #ifdef _WIN32
 
     DWORD result = WaitForSingleObject (sem, seconds*1000);
@@ -1890,20 +1915,28 @@ void sqltimedwaitsem (teo07_ThreadSemaphore sem,
 
 #ifdef PTHREADS
     struct timespec timeout;
+#if defined(KERNEL_LZU)
+    timeout.tv_sec = KGS->current_time + seconds;
+#else
     timeout.tv_sec = time (NULL) + seconds;
+#endif
     timeout.tv_nsec = 0;
 
     pthread_mutex_lock (&semObj->mutex);
-    while ( semObj->token < 1 ) 
+    if ( seconds > 0 )
     {
-      ++semObj->waiter;
-      rc = pthread_cond_timedwait (&semObj->condition, &semObj->mutex, &timeout);
-      --semObj->waiter;
-      if (rc == TIMEOUT_SYSTEM_RC) 
-      {
-        break;
-      }
+        while ( semObj->token < 1 ) 
+        {
+          ++semObj->waiter;
+          rc = pthread_cond_timedwait (&semObj->condition, &semObj->mutex, &timeout);
+          --semObj->waiter;
+          if (rc == TIMEOUT_SYSTEM_RC) 
+          {
+            break;
+          }
+        }
     }
+
     if ( semObj->token >= 1 ) 
     {
       --semObj->token;
@@ -1917,6 +1950,7 @@ void sqltimedwaitsem (teo07_ThreadSemaphore sem,
 #endif /* PTHREADS */
 
 #endif /* UNIX */
+    }
 } /* sqltimedwaitsem */
 
 /*---------------------------------------------------------------------------*/
@@ -2173,6 +2207,8 @@ static void eo07_CreateThread( tsp00_Int4 StackSize,
 
 #ifdef USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID
   pThreadObj->thread_id = eo07_GetSequenceNumber();
+#else
+  pThreadObj->thread_id = 0;
 #endif /* USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID */
 
   rc = pthread_create(&pThreadObj->thread, &attr, eo07_PthreadEntry, (void *)pThreadObj);
@@ -2207,19 +2243,16 @@ static void eo07_CreateThread( tsp00_Int4 StackSize,
   else
   {
 # ifdef USE_GETSEQUENCE_NP_FOR_THREAD_ID
-    /* done twice: here and in PthreadEntry to make sure scheduler want make a problem */
-    /* Callable only after thread exists... */
-    pThreadObj->thread_id = (teo07_ThreadId)pthread_getsequence_np(pThreadObj->thread);
+      /* done twice: here and in PthreadEntry to make sure scheduler will not make a problem */
+      /* Callable only after thread exists... */
+      pThreadObj->thread_id = (teo07_ThreadId)pthread_getsequence_np(pThreadObj->thread);
+# elif !defined(USE_EO07_GET_SEQUENCE_NUMBER_FOR_THREAD_ID)
+      volatile teo07_ThreadObj *pTheThreadObj = pThreadObj;
+      while ( pTheThreadObj->thread_id == 0 )
+      {
+          YIELD_CALL;
+      }
 # endif
-
-# ifdef USE_CLONE_PID_FOR_THREAD_ID
-  /* PTS 1105217 */
-    volatile teo07_ThreadObj *pTheThreadObj = pThreadObj;
-    while ( pTheThreadObj->thread_id == 0 )
-    {
-      YIELD_CALL;
-    }
-#endif
   }
 #endif /* PTHREADS */
 
@@ -2329,6 +2362,10 @@ static void *eo07_PthreadEntry( void *arg )
         return (void *)rc;
     }
 
+# ifdef USE_GETTID_FOR_THREAD_ID
+    pThreadObj->thread_id = (teo07_ThreadId)syscall(__NR_gettid);
+# endif
+
 # ifdef USE_GETSEQUENCE_NP_FOR_THREAD_ID
       /* Callable only after thread exists... */
     pThreadObj->thread_id = (teo07_ThreadId)pthread_getsequence_np(pThreadObj->thread);
