@@ -16,7 +16,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -34,6 +34,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -47,6 +48,9 @@
 #include "geo001.h"
 #include "geo200.h"
 #include "geo007_1.h"
+#define  ERR_CANT_GET_FILE_OWNER  N(152), ERR_TYPE,_T("MEMORY  "),_T("Could not get file '%s' owner, rc = %d")
+#define  ERR_CANT_GET_FILE_GROUP  N(152), ERR_TYPE,_T("MEMORY  "),_T("Could not get file '%s' group, rc = %d")
+#define  ERR_CANT_SET_FILE_GROUP  N(152), ERR_TYPE,_T("MEMORY  "),_T("Could not set file '%s' group '%s', rc = %d")
 #include "geo28.h"
 #include "geo60.h"
 #include "geo570.h"
@@ -665,7 +669,7 @@ bool t_Container::NewDirectoryPage( teo200_EventList *   pEventList )
   }
   
   // --- initialize the new page!
-  memset ( &pDirPages[m_pHeader->NumOfDirPages], 0, sizeof(t_Page) );      
+  memset ( &pDirPages[m_pHeader->NumOfDirPages], 0, sizeof(t_Page) );
   pDirPages[m_pHeader->NumOfDirPages].Dir.PageType   = DirPage_e;
   pDirPages[m_pHeader->NumOfDirPages].Dir.CurrPageNo = NewDirPageNo;
   
@@ -1539,7 +1543,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = GetLastError();
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_GET_FILE_OWNER, m_FileName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
@@ -1557,7 +1561,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = errno;
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_GET_FILE_GROUP, m_FileName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
@@ -1575,7 +1579,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = errno;
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_SET_FILE_GROUP, m_FileName.asCharp(), GroupName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
@@ -1773,7 +1777,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = errno;
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_GET_FILE_OWNER, m_FileName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
@@ -1791,7 +1795,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = errno;
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_GET_FILE_GROUP, m_FileName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
@@ -1809,7 +1813,7 @@ t_FileContainer::t_FileContainer( tsp00_DbNamec const     ServerDB,
    {
      teo001_SystemRc  rc = errno;
 
-     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_OPEN_FILE, m_FileName.asCharp() );
+     teo200_EventList EvtLst( rc, FUNCTION_NAME_MEO60, ERR_CANT_SET_FILE_GROUP, m_FileName.asCharp(), GroupName.asCharp(), rc );
      COPY_OR_THROW_EVENTLIST_EO200( pEventList, EvtLst );
      return false;
    }
