@@ -8,7 +8,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -74,7 +75,7 @@
 #endif
 
 #if defined SAPwithUNICODE
-#if defined (LINUX) && defined (X86_64)
+#if defined (LINUX) && (defined (X86_64) || (defined (IA64) && SLES_VER >= 9))
 #include "sap/700/saptype.h"	/* nocheck */
 #include "sap/700/saptypeb.h"	/* nocheck */
 #include "sap/700/saptypec.h"	/* nocheck */
