@@ -218,6 +218,7 @@ char *eo92GetTaskStateName ( tsp00_Int lState,
     case TSK_VCOPYVOLUME_EO00: return XCONS_TSK_STATE_VCOPYVOLUME;
     case TSK_ENTERRWREGION_EO00:return ( XCONS_TSK_STATE_VENTERRWREGION );
     case TSK_LEAVERWREGION_EO00:return ( XCONS_TSK_STATE_VLEAVERWREGION );
+    case TSK_YIELDING_EO00:return ( XCONS_TSK_STATE_YIELDING );
 
     default: break;
   }
@@ -575,6 +576,7 @@ if ( *param_id == 'h' && *param_val == 'h' )
     e92_print_param ( XParam, PAN_PRIO_BASE_REX ) ;
     e92_print_param ( XParam, PAN_PRIO_BASE_COM ) ;
     e92_print_param ( XParam, PAN_PRIO_FACTOR   ) ;
+    e92_print_param ( XParam, PAN_SYMBOL_RESOLUTION   ) ;
   }
 else if ( ! strcmp( param_id , PAN_PRIO_BASE_U2U  ) )
   set_ok = set_int_param ( TYPE_INT4, &XParam->lPrioBaseU2U, param_val, 0, 10000 ) ; 
@@ -629,6 +631,8 @@ else if ( ! strcmp( param_id , PAN_MP_RGN_LOOP ) )
   if ( XParam->ulMaxCPU > 1 )
     set_ok = set_int_param ( TYPE_INT4, &XParam->ulRegionCollisionLoop, 
                                         param_val, 1, 100000 ) ; 
+else if ( ! strcmp( param_id , PAN_SYMBOL_RESOLUTION ) )
+    set_ok = set_bool_param ( &XParam->allowSymbolResolution, param_val ) ; 
 else
   { set_ok = FALSE ;
     pri ( "putparam for parameter '%s' not allowed!\n", param_id ) ;
@@ -742,6 +746,8 @@ PRINT_ONE_PARAM ( PAN_MAX_BACKUP_TASKS , &XParam->ulMaxBackupTasks , TYPE_INT4 )
 
 PRINT_ONE_PARAM ( PAN_MAXGARBAGE_COLLECTOR , &XParam->ulMaxGarbageCollector , TYPE_INT4 );
 
+PRINT_ONE_PARAM ( PAN_SYMBOL_RESOLUTION , &XParam->allowSymbolResolution , TYPE_BOOL );
+
 /******************************/
 #if _WIN32 || OS2 
 /******************************/
