@@ -49,6 +49,7 @@
 
 #ifdef WIN32
 #include "gos003.h" /* nocheck */
+#include <time.h>
 #else
 #include "gen45.h" /* nocheck */
 #include "gen003.h" /* nocheck */
@@ -56,8 +57,7 @@
 #include "RunTime/MemoryManagement/RTEMem_AllocatorRegister.hpp"
 #include "RunTime/Synchronisation/RTESync_NamedSpinlock.hpp"
 #include "RunTime/RTE_ConsoleStandardOutput.h"
-
-#include <time.h>
+#include "RunTime/Diagnose/RTEDiag_SymbolResolutionLock.h"
 
 /*===========================================================================*
  *  DEFINES                                                                  *
@@ -1042,12 +1042,16 @@ static void eo922FillTaskInfo( TASK_CTRL      pTaskCtrl,
   if ( TASK_STATE(pTaskCtrl) != TSK_VRECEIVE_EO00 || RteTaskInfo->TimeOut == undef_ceo00 )
     RteTaskInfo->TimeOut = undef_ceo00 ;
   else
-  { 
-    tsp00_Int4 ActTime = (tsp00_Int4 )time ( (time_t *)0 ) ;
-    if ( RteTaskInfo->TimeOut < ActTime ) 
+  {
+#if defined(WIN32)
+    tsp00_Uint4 ActTime = (tsp00_Uint4)time((time_t *)0);
+#else
+    tsp00_Uint4 ActTime = (tsp00_Uint4)KGS->current_time;
+#endif
+    if ( ((tsp00_Uint4)(RteTaskInfo->TimeOut)) < ActTime ) 
       RteTaskInfo->TimeOut = 0 ;
     else 
-      RteTaskInfo->TimeOut -= ActTime ;
+      RteTaskInfo->TimeOut = ((tsp00_Uint4)(RteTaskInfo->TimeOut) - ActTime);
   }
 
   RteTaskInfo->WaitingForRoot= pTaskCtrl->lWaitForRoot ;
@@ -1069,6 +1073,9 @@ static void eo922FillTaskInfo( TASK_CTRL      pTaskCtrl,
   if ( (TaskState == TSK_VBEGEXCL_EO00 || TaskState == TSK_VENDEXCL_EO00) &&
        (RteTaskInfo->HoldingRegion > 0 && RteTaskInfo->HoldingRegion < (tsp00_Longint )XPARAM(ulNoOfRegions) ))
     RteTaskInfo->ExtendedTaskState.c2p(SEMA_NAME(RteTaskInfo->HoldingRegion-1));
+  else
+  if ( TaskState == TSK_YIELDING_EO00 )
+    RteTaskInfo->ExtendedTaskState.c2p(&pTaskCtrl->NameOfSpinlockYieldingFor[0]);
   else
     RteTaskInfo->ExtendedTaskState.c2p("");
 
@@ -1379,6 +1386,8 @@ externC void vGetRteInfoTotalCnt ( tsp92_RteTotalCntInfo *RteTotalCntInfo )
     BegSearchRegion = ActRegion+1 ;
   }
 
+  RteTotalCntInfo->SymbolResolutionCnt = (tsp00_8ByteCounter)RTEDiag_SymbolResolutionLockCalls();
+
   return ;
 }
 
