@@ -47,6 +47,8 @@
 #include "SQLManager/SQLMan_Context.hpp"
 #include "SAPDB/SAPDBCommon/SAPDB_RangeCode.hpp"
 #include "hgg10.h"
+#include "SAPDBCommon/SAPDB_sprintf.h"
+#include "SAPDBCommon/SAPDB_string.h"
 
 /* --------------------------------------------------------------------------- */
 static inline void CopyNodeIdToNodename(tsp00_NodeId & nodeId, tsp00_NodeIdc & nodeName)
@@ -253,7 +255,7 @@ externPascal void gg999GetRestartVersion (
                            1 * RESNUM_MXSP00             +
                            1 * sizeof (tsp00_NodeId)+1   +   // PTS 1111229 E.Z.
                            1 * RESNUM_MXSP00             +   // PTS 1114658 UH 2002-03-06
-                           7+1;
+                           11+1;
 
     if ( mblock.mb_data_len() > mblock.mb_data_size() )
     {
@@ -325,18 +327,23 @@ externPascal void gg999GetRestartVersion (
     s41pluns (buffer, currentBufferPos + 1, 10, 0, converterVersion, dummyNumError);
 	currentBufferPos += RESNUM_MXSP00;
     // ***** 11 **** OLDEST COMPATIBLE VERSION *****
-    Kernel_Version oldestCompatibleVersion = Kernel_Migration::GetOldestCompatibleVersion();
+    const SAPDB_UInt2 maxStringLength = 11;
+    Kernel_Version    oldestCompatibleVersion = Kernel_Migration::GetOldestCompatibleVersion();
+    SAPDB_UInt2       maj,min,corr,build,addBlanks=0;
+    SAPDB_Char        versionString [maxStringLength+1];
+    maj    = oldestCompatibleVersion.MajorVersion();
+    min    = oldestCompatibleVersion.MinorVersion();
+    corr   = oldestCompatibleVersion.CorrectionLevel();
+    build  = oldestCompatibleVersion.BuildNo();
+    SAPDB_sprintf( versionString, sizeof(versionString), "%d.%d.%02d.%02d", maj, min, corr, build); 
+    SAPDB_memcpy ( &(buffer[currentBufferPos]), versionString, maxStringLength);
+    if ( maj < 10 ) addBlanks++;
+    if ( min < 10 ) addBlanks++;
+    SAPDB_memset ( &(buffer[currentBufferPos+maxStringLength-addBlanks]), ' ', maxStringLength-(maxStringLength-addBlanks));
     buffer[currentBufferPos-1] = csp_ascii_blank;
-    buffer[currentBufferPos+0] = oldestCompatibleVersion.MajorVersion() + 48;
-    buffer[currentBufferPos+1] = '.';
-    buffer[currentBufferPos+2] = oldestCompatibleVersion.MinorVersion() + 48;
-    buffer[currentBufferPos+3] = '.';
-    buffer[currentBufferPos+4] = oldestCompatibleVersion.CorrectionLevel() + 48;
-    buffer[currentBufferPos+5] = '.';
-    buffer[currentBufferPos+6] = oldestCompatibleVersion.BuildNo() + 48;
-	currentBufferPos += (1 + 7);
+    currentBufferPos += maxStringLength;
     // ***** **** *****
-    mblock.mb_data_len() = currentBufferPos - 1;
+    mblock.mb_data_len() = currentBufferPos;
     mblock.mb_type().becomes(m_return_result);
 }
 /* --------------------------------------------------------------------------- */
