@@ -12,7 +12,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
 
+
 *****************************************************************************/
 
 /*===========================================================================*
@@ -68,6 +69,8 @@
 #include "Logging/Log_History.hpp"
 
 #include "hkb560.h" // kb560ConvertWriteRedoEntryResultToBasisError
+#include "gkb05.h"
+#include "hkb52.h"
 
 /*===========================================================================*
  *  DEFINES                                                                  *
@@ -362,14 +365,17 @@ kb67GetObjConsistent(tgg00_TransContext &Trans,
     if (e_ok != Trans.trError_gg00) return;  
 
     kb50ObjConsistentCheck (Trans, ObjTransInfo.otrUpdTransId_gg00, bConsistent, bCancelled);
-    if (g01vtrace.vtrKbLock_gg00 && 
-        (e_ok == Trans.trError_gg00) && bCancelled) /* PTS 1120151 FF 2003-JAN-29 */
+    if ((e_ok == Trans.trError_gg00) && bCancelled) /* PTS 1120151 FF 2003-JAN-29 */
     {
-        Kernel_VTrace     vTrace;
-        vTrace << "cancelled ConsistView:";
-        for (int i=0; i < sizeof(Trans.trConsistView_gg00); i++)
-            vTrace << ToStr((SAPDB_UInt1)Trans.trConsistView_gg00[i], _T_h);
-        vTrace << " found";
+        if (g01vtrace.vtrKbLock_gg00 && 
+            (e_ok == Trans.trError_gg00) && bCancelled) /* PTS 1120151 FF 2003-JAN-29 */
+        {
+            Kernel_VTrace     vTrace;
+            vTrace << "cancelled ConsistView:";
+            for (int i=0; i < sizeof(Trans.trConsistView_gg00); i++)
+                vTrace << ToStr((SAPDB_UInt1)Trans.trConsistView_gg00[i], _T_h);
+            vTrace << " found";
+        }
         Trans.trError_gg00 = e_consview_cancelled;
     }
     if (e_ok != Trans.trError_gg00) return;  
@@ -418,7 +424,47 @@ kb67GetObjConsistent(tgg00_TransContext &Trans,
     }
 }
 
-
+/*---------------------------------------------------------------------------*/
+/* PTS 1135542 FF used within vdb910.cpp to check if page should be inserted */
+/*                to freepage-chain                                          */
+externCpp bool
+kb67IsTransActive(tgg92_ObjHeader &ObjHeader)
+{
+    bool bRC;
+    tkb05_TransEntryPtr ThisTrans;
+    switch (ObjHeader.ohdState_gg92)
+    {
+    case obsFree_egg00:
+        bRC = false;
+        break;
+    case obsReserved_egg00:
+    case obsKeyReserved_egg00:
+        bRC = true;
+        break;
+    case obsFreeAfterEot_egg00:
+    case obsOccupied_egg00:
+        {
+            if (ObjHeader.ohdTransInfo_gg92.otrLockTransId_gg00.gg90IsNil())
+                bRC = false;
+            else if (ObjHeader.ohdTransInfo_gg92.otrLockTransId_gg00.gg90IsDummy() ||
+                ObjHeader.ohdTransInfo_gg92.otrLockTransId_gg00.gg90IsZero())
+                bRC = true;  /* isn't really exact, because lock may not be active */
+            else
+            {
+                k52acc_trans_entry( ObjHeader.ohdTransInfo_gg92.otrLockTransIndex_gg00, ThisTrans );
+                if (( ObjHeader.ohdTransInfo_gg92.otrLockTransId_gg00 == ThisTrans->teWriteTransId_kb05 ) &&
+                    ( m_delete != ThisTrans->teState_kb05 ))
+                    bRC = true;
+                else
+                    bRC = false;
+            }
+        }
+        break;
+    default:
+        bRC = false;
+    }
+    return bRC;
+}
 
 /*---------------------------------------------------------------------------*/
 
@@ -450,25 +496,28 @@ kb67LockObj (tgg00_TransContext  &Trans,
     if (e_ok != Trans.trError_gg00) return;
     
     kb50LockObj (Trans, ObjFile.fileObjFileNo_gg00(), Oid, ObjTransInfo); // PTS 1105492 JA 2000-03-15
-    
     if (e_ok != Trans.trError_gg00) return;
     
-    if ( ! WantedObjVers.gg91IsDummyRef() ) 
+    /* PTS 1135716 */
+    if ( obsFreeAfterEot_egg00 == ObjState )
     {
-        if (WantedObjVers != ObjTransInfo.otrBeforeRef_gg00 && obsFreeAfterEot_egg00 != ObjState)
-        {
-            kb50UnlockObj (Trans.trTaskId_gg00, Trans.trWriteTransId_gg00, Trans.trIndex_gg00,
-                Oid, ObjTransInfo);
-            
-            Trans.trError_gg00 = e_object_dirty;
+        kb50UnlockObj (Trans.trTaskId_gg00, Trans.trWriteTransId_gg00, Trans.trIndex_gg00,
+            Oid, ObjTransInfo);
+        Trans.trError_gg00 = e_object_not_found;
+        return;
+    }
 
-            if (g01vtrace.vtrKbLock_gg00)
-            {
-                kb50XxxObjTrace (Trans, "  kb67LckObj",
-                    Oid, ObjTransInfo.otrUpdTransId_gg00, ObjTransInfo.otrBeforeRef_gg00, ObjState);
-            }
-            return;
+    if ( ! WantedObjVers.gg91IsDummyRef() && (WantedObjVers != ObjTransInfo.otrBeforeRef_gg00))
+    {
+        kb50UnlockObj (Trans.trTaskId_gg00, Trans.trWriteTransId_gg00, Trans.trIndex_gg00,
+            Oid, ObjTransInfo);
+        Trans.trError_gg00 = e_object_dirty;
+        if (g01vtrace.vtrKbLock_gg00)
+        {
+            kb50XxxObjTrace (Trans, "  kb67LckObj",
+                Oid, ObjTransInfo.otrUpdTransId_gg00, ObjTransInfo.otrBeforeRef_gg00, ObjState);
         }
+        return;
     }
     
 #   if COMPILEMODE_MEO00 >= SLOW_MEO00
@@ -758,14 +807,16 @@ kb67GetBeforeImage (tgg00_TransContext &Trans,
             kb50ObjConsistentCheck (Trans, PrevUpdTrans, bConsistent, bCancelled);
             //                      without NextPageRef:  PTS 1105492 JA 2000-03-15 
             
-            if (g01vtrace.vtrKbLock_gg00 &&                 // PTS 1122466
-               (bCancelled && e_ok == Trans.trError_gg00))  /* PTS 1120151 FF 2003-JAN-29 */
+            if (bCancelled && e_ok == Trans.trError_gg00)  
             {
-                Kernel_VTrace     vTrace;
-                vTrace << "cancelled ConsistView:";
-                for (int i=0; i < sizeof(Trans.trConsistView_gg00); i++)
-                    vTrace << ToStr((SAPDB_UInt1)Trans.trConsistView_gg00[i], _T_h);
-                vTrace << " found";
+                if (g01vtrace.vtrKbLock_gg00)
+                {
+                    Kernel_VTrace     vTrace;
+                    vTrace << "cancelled ConsistView:";
+                    for (int i=0; i < sizeof(Trans.trConsistView_gg00); i++)
+                        vTrace << ToStr((SAPDB_UInt1)Trans.trConsistView_gg00[i], _T_h);
+                    vTrace << " found";
+                }
                 Trans.trError_gg00 = e_consview_cancelled;
                 return;
             }
