@@ -457,24 +457,21 @@ STDMETHODIMP Clvcbench::CLEAN_UP()
 {
     TRACE_METHOD(CLEAN_UP)
  
-    try
-    {
+    try {
         OmsSchemaHandle schemaHandle = omsGetSchemaHandle(lvcBenchSchema);
         omsDropSchema(schemaHandle);
         this->DropTableOrdkey();
-        this->WaitForGarbageCollector();
-        
+        this->WaitForGarbageCollector();  
     }
     catch (DbpError&)
-    {
-    }
-    try
-    {
+    {}
+    
+    try {
         globSchemaHandle = omsCreateSchema(lvcBenchSchema);
     }
     CATCH_ALL
         
-        return S_OK;
+    return S_OK;
 }
 
 /*-----------------------------------------------------------------------------------------*/
@@ -500,6 +497,7 @@ STDMETHODIMP Clvcbench::CREATE_CONTAINER(int keyContainer, int containerNo, int
     TRACE_METHOD(CREATE_CONTAINER)
         try
     {
+        
         globContainerNo = containerNo;
         if (keyContainer)
         {
@@ -509,6 +507,7 @@ STDMETHODIMP Clvcbench::CREATE_CONTAINER(int keyContainer, int containerNo, int
         {
             CObject::Register(*this, containerNo);
         }
+        
     }
     CATCH_ALL
         return S_OK;
@@ -529,7 +528,7 @@ STDMETHODIMP Clvcbench::CREATE_OBJECTS(OmsTypeInt4 cntObjects, OmsTypeInt4 *mill
     }
     CATCH_ALL
         
-        return S_OK;
+    return S_OK;
 }
 
 /*-----------------------------------------------------------------------------------------*/
@@ -806,15 +805,15 @@ STDMETHODIMP Clvcbench::DELETE_VAROBJECTS()
 STDMETHODIMP Clvcbench::DEREF()
 {
     TRACE_METHOD(DEREF)
-        try
+    try
     {
-        CallInfo callInfo(m_taskId);
-        const CObject* p = m_listHead(*this);
-        while (p)
-        {
-            callInfo.IncOpCount();
-            p = p->m_next(*this);
-        }
+      CallInfo callInfo(m_taskId);
+      const CObject* p = m_listHead(*this);
+      while (p)
+      {
+          callInfo.IncOpCount();
+          p = p->m_next(*this);
+      }
     }
     CATCH_ALL
         return S_OK;
@@ -924,10 +923,12 @@ STDMETHODIMP Clvcbench::MASS_DEREF_KEY(OmsTypeInt4 cntObjects, OmsTypeInt4 packe
 }
 
 /*-----------------------------------------------------------------------------------------*/
+
+
 STDMETHODIMP Clvcbench::DEREFFORUPD()
 {
     TRACE_METHOD(DEREFFORUPD)
-        try
+    try
     {
         CallInfo callInfo(m_taskId);
         CObject* p = m_listHead.omsDeRefForUpd(*this, true);
@@ -1075,6 +1076,77 @@ STDMETHODIMP Clvcbench::UPDATE_OBJECTS()
 
 /*-----------------------------------------------------------------------------------------*/
 
+STDMETHODIMP Clvcbench::CREATE_ARRAY_OBJECTS(OmsTypeInt4 cntObjects, OmsTypeInt4 arraySize)
+{
+  TRACE_METHOD(CREATE_ARRAY_OBJECTS) 
+
+  OmsAllocatorInterface& allocator = omsGetSessionAllocator();
+  if (m_oidOfArrayObjs != NULL){
+    allocator.omsDeallocate(m_oidOfArrayObjs);
+  }
+                      
+  m_oidOfArrayObjs = (OmsArrayObjectOid*)allocator.omsAllocate(cntObjects * sizeof(OmsArrayObjectOid));
+  m_noOfArrayObjs  = cntObjects;
+
+
+  OmsContainerNo cnForSize = OmsArrayObjectType::omsGetContainerNo( globContainerNo, arraySize );
+  OmsArrayObjectType::omsRegisterSize( *this, globSchemaHandle, globContainerNo, arraySize, "int" );
+
+  try {
+    CallInfo callInfo(m_taskId, cntObjects);
+
+    for (int i=0; i<m_noOfArrayObjs; ++i){
+      OmsArrayObjectType *p = new(*this, globSchemaHandle, cnForSize)  OmsArrayObjectType(*this, arraySize);
+      m_oidOfArrayObjs[i] = p->omsGetOid();
+    }
+  }
+  CATCH_ALL
+  
+  return S_OK;
+}
+
+/*-----------------------------------------------------------------------------------------*/
+
+STDMETHODIMP Clvcbench::DEREF_ARRAY_OBJECTS()
+{
+  TRACE_METHOD(DEREF_ARRAY_OBJECTS) 
+
+  try {
+    CallInfo callInfo(m_taskId, m_noOfArrayObjs);
+    for (int i=0; i<m_noOfArrayObjs; ++i){
+      const OmsArrayObjectType *q1 = m_oidOfArrayObjs[i].omsDeRef(*this);
+    }
+  }
+  CATCH_ALL
+    return S_OK;
+}
+/*-----------------------------------------------------------------------------------------*/
+
+STDMETHODIMP Clvcbench::DELETE_ARRAY_OBJECTS()
+{
+  TRACE_METHOD(DELETE_ARRAY_OBJECTS) 
+
+  try {
+    CallInfo callInfo(m_taskId, m_noOfArrayObjs);
+
+    for (int i=0; i<m_noOfArrayObjs; ++i){
+      OmsArrayObjectType *q1 = m_oidOfArrayObjs[i].omsDeRefForUpd(*this);
+      q1->omsDelete(*this);
+    }
+  }
+  CATCH_ALL
+  
+  if (m_oidOfArrayObjs != NULL){
+    OmsAllocatorInterface& allocator = omsGetSessionAllocator();
+    allocator.omsDeallocate(m_oidOfArrayObjs);
+    m_oidOfArrayObjs = NULL;
+    m_noOfArrayObjs  = 0;
+  }
+    
+  return S_OK;
+}
+
+/*-----------------------------------------------------------------------------------------*/
 #define MALLOC_ALIGN_MASK      (7)
 
 inline OmsTypeUInt4 AlignedSize(OmsTypeUInt4 req) 
