@@ -166,6 +166,11 @@ private :
 
 class CallBack;
 
+const int ClsId = 4715;
+typedef OmsArrayObject<int, ClsId> OmsArrayObjectType;
+typedef OmsOid<OmsArrayObjectType> OmsArrayObjectOid;
+
+
 /****************************************************************************/
 /* Clvcbench                                                                */
 class  Clvcbench :
@@ -195,6 +200,9 @@ private:
   CKey               **m_ppKey;     // PTS 1122194
   const CKeyedObject **m_ppKeyObj;  // PTS 1122194
   OmsCallbackInterface  *m_pTransactionInterface; // PTS 1128285
+  OmsArrayObjectOid *m_oidOfArrayObjs;
+  int                m_noOfArrayObjs;
+
 public:
   friend class CallBack;
 	Clvcbench() 
@@ -216,6 +224,8 @@ public:
     , m_ppKey(NULL)     // PTS 1123525  
     , m_ppKeyObj(NULL)  // PTS 1123525
     , m_pTransactionInterface(NULL) // PTS 1128285
+    , m_oidOfArrayObjs(0)
+    , m_noOfArrayObjs(0)
  	{
         IUnknown** pIKernelSink = &m_pIUnknown;
         omsInitSession (pIKernelSink);
@@ -319,6 +329,10 @@ public:
   STDMETHOD(FILL_ARRAY_KEY)(OmsTypeInt4 cntObjects, OmsTypeInt4 startNumber);  // PTS 1122194
   STDMETHOD(MASS_DEREF_KEY)(OmsTypeInt4 cntObjects, OmsTypeInt4 packetSize);   // PTS 1122194 
   STDMETHOD(INIT_AFTER_EOT)();    // PTS 1128285
+  STDMETHOD(CREATE_ARRAY_OBJECTS)(OmsTypeInt4 cntObjects, OmsTypeInt4 arraySize);
+  STDMETHOD(DEREF_ARRAY_OBJECTS)();
+  STDMETHOD(DELETE_ARRAY_OBJECTS)();
+  
   STDMETHOD(Register)();
 };
 
