@@ -223,11 +223,11 @@ ls18RecordDestructor(tsp00_Int2 ColumnCount, tls00_String *& DataArray);
   -----------------------------------------------------------------------------
 */
 inline tsp00_Int4
-ls18CheckValueLength(const tsp00_Int4 ValueLength, tls00_FieldBasics & FieldInfo)
+ls18CheckValueLength(const tsp00_Uint4 ValueLength, tls00_FieldBasics & FieldInfo)
 {
     ROUTINE_DBG_MEO00 ("ls18CheckValueLength");
 
-    return ((ValueLength > (FieldInfo.fbInOutLength_ls00 - 1)) ?
+    return ( (ValueLength > STATIC_CAST(tsp00_Uint4, (FieldInfo.fbLength_ls00)) ) ?
             STATIC_CAST(int, errIncompatibleConst_els98) :
             errOK_els00);
 }
