@@ -340,6 +340,11 @@ typedef enum
                                                 //= -25001
     msgSimpleMsg_els98                          = 0,
 
+    //* Statistics messages given to client upon return
+    statInsertedRejectedRows_els98              = 25201,
+    statUpdatedInvalidRows_els98,               //= 25202,
+    statNumExtractedRecords_els98,              //= 25203,
+
     //*
     //*     WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN
     //*
@@ -437,6 +442,7 @@ const char * const pszErrorLineHeader   = "// E ";
 const char * const pszRemarkLineHeader  = "// R\t"; //!!LogMessage
 const char * const pszInfoLineHeader    = "// M\t";
 const char * const pszWarningLineHeader = "// W ";
+const char * const pszStatisticsMsgDelimiter    = "---\n";
 
 #define ERROR_NUM_BEGIN -26000
 #define ERROR_NUM_END   -25000
@@ -548,6 +554,33 @@ public:
                          const ErrorNumbers lMessageNumber,
                          ...);
 
+
+    /*!
+    -----------------------------------------------------------------------------
+      function:     ls98AppendStatusToString
+    -----------------------------------------------------------------------------
+      description:  Appends an error/status message to the return string.
+
+      arguments:    lLayer         [IN]    - enum parameter des typs LayerNumbers,
+                                             der den layer, in dem eine meldung angelegt
+                                             wurde, identifiziert.
+                                             WIRD Z.Z. NICHT AUSGEWERTET.
+                    pszDestString  [IN]    - zeiger auf den string, in den der msgtext
+                                             kopiert werden soll.
+                    lMessageNumber [IN]    - enum parameter des typs ErrorNumbers
+                                             fehler- bzw. meldungsnummer
+                    more param     [IN]    - variabel viele weitere parameter fuer die
+                                             meldung
+
+      returnvalue:  No
+    -----------------------------------------------------------------------------
+    */
+    void ls98AppendStatusToString(const LayerNumbers  lLayer,
+                                  char*               pszDestString,
+                                  const ErrorNumbers  lMessageNumber,
+                                  ...);
+
+
     /*!
     -----------------------------------------------------------------------------
  
@@ -620,6 +653,7 @@ private:
     int ls98_Write();
     void ls98_Init();
     void ls98_FormatMsg(const ErrorNumbers lMsgNr, bool  bMsgToFileOnly, va_list arglist);
+    void ls98_AppendMsgToString(const ErrorNumbers lMsgNr, bool bFirstMsgToAppend, va_list arglist);
 };
 
 
