@@ -15,14 +15,14 @@
 
   -----------------------------------------------------------------------------
 
-  Copyright (c) 1997-2004 SAP AG-2003
+  Copyright (c) 1997-2005 SAP AG-2003
 
   -----------------------------------------------------------------------------
 
 
 
     ========== licence begin  GPL
-    Copyright (c) 1997-2004 SAP AG
+    Copyright (c) 1997-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -41,6 +41,7 @@
 
 
 
+
 */
 
 
@@ -560,7 +561,7 @@ int ctrlservcommand(void*       SessionData,
         }
         else
         {
-            if (errOK_els00 != pSvrCmd->cmdReqErr_ls00)  // error at processing command
+            if (pSvrCmd->cmdReqErr_ls00 < errOK_els00) // error at processing command
             {
                 memcpy(ReplyData, ProtErrHeader_ls00, ProtHeaderLength_ls00);
             }
