@@ -13,7 +13,7 @@
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1997-2004 SAP AG
+    Copyright (c) 1997-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 #include "gls00.h"
 #include "heo01.h"
@@ -356,6 +357,10 @@ int ls10ExecSQLStmt(tls00_Command *pLoaderCmd, tls00_DBInfo *pDBInfo)
         rc = ls13ExecExtSQLStmt(pDBInfo,
                                 REINTERPRET_CAST(tls00_DBSqlCmd*, pLoaderCmd->cmdScnDat_ls00),
                                 pLoaderCmd->cmdRpyDat_ls00);
+        if (errOK_els00 != rc)  // The function returns the true SQL return code (kernel return code like -4008 or 100);
+        {                       // the Loader returns its code for SQL errors to caller
+            rc = errSimpleSQL_els98;
+        }
     }
     else
     {
