@@ -1373,8 +1373,11 @@ ls21ExecFastload(MetaDataDef *pMetaDataDef, tls00_DBInfo *pDBInfo, tsp00_Addr Er
     // must fit into the length given by the database
 
     //*
-    //*     Ausfuehren von fastload ********************************************
+    //*  execute fastload
     //*
+    tsp00_Int8 _lRejectedRecords = 0;
+    tsp00_Int8 _lInsertedRecords = 0;
+
     if (errOK_els00 == (rc = ls21_ExecBeginLoad(pDBInfo, pFLRec, TableSpec.tsFullTabName_ls00, ErrText)))
     {
         SAPDB_Bool _bRollback = SAPDB_TRUE;
@@ -1390,15 +1393,13 @@ ls21ExecFastload(MetaDataDef *pMetaDataDef, tls00_DBInfo *pDBInfo, tsp00_Addr Er
             if (errOK_els00 == rc2)
             {
                 pMsgObj->ls98PrintMessage(layFastload_els98, msgLastCommInputLine2_els98, pFLRec->flrLastCommLine_ls00);
-
-                tsp00_Int8 lRejectedRows = pDBInfo->dbiSession_ls00.siMaxAdmissibleErrors - pFLRec->flrLRejected_ls00;
-                pMsgObj->ls98PrintMessage(layFastload_els98, msgInsertedRejectedRows2_els98,
-                                                             pFLRec->flrRecordCount_ls00, lRejectedRows);
+                _lInsertedRecords = pFLRec->flrRecordCount_ls00;
+                _lRejectedRecords = pDBInfo->dbiSession_ls00.siMaxAdmissibleErrors - pFLRec->flrLRejected_ls00;
             }
             else
             {
-                pMsgObj->ls98PrintMessage(layFastload_els98, msgInsertedRejectedRows2_els98, STATIC_CAST(tsp00_Int8, 0),
-                                                                                             pFLRec->flrRecordCount_ls00);
+                _lInsertedRecords = 0;
+                _lRejectedRecords = pFLRec->flrRecordCount_ls00;
                 if (errOK_els00 == rc)
                 {
                     rc = rc2;
@@ -1414,13 +1415,15 @@ ls21ExecFastload(MetaDataDef *pMetaDataDef, tls00_DBInfo *pDBInfo, tsp00_Addr Er
 
             pMsgObj->ls98PrintMessage(layFastload_els98, msgLastCommInputLine2_els98, pFLRec->flrLastCommLine_ls00);
 
-            tsp00_Int8 lRejectedRows = pDBInfo->dbiSession_ls00.siMaxAdmissibleErrors - pFLRec->flrLRejected_ls00;
-            pMsgObj->ls98PrintMessage(layFastload_els98, msgInsertedRejectedRows2_els98, STATIC_CAST(tsp00_Int8, 0),
-                                                                                         lRejectedRows);
+            _lInsertedRecords = 0;
+            _lRejectedRecords = pDBInfo->dbiSession_ls00.siMaxAdmissibleErrors - pFLRec->flrLRejected_ls00;
         }
-    }
+        pMsgObj->ls98PrintMessage(layFastload_els98, msgInsertedRejectedRows2_els98, _lInsertedRecords, _lRejectedRecords);
 
+        pMsgObj->ls98AppendStatusToString(layFastload_els98, ErrText, statInsertedRejectedRows_els98, _lInsertedRecords,
+                                                                                                      _lRejectedRecords);
 
+    }   // end if (errOK_els00 == (rc = ls21_ExecBeginLoad(pDBInfo, ...
 
     // Close file
     tsp00_Int4 rc2 = ls30VFClose(*pFLRec->flrpInfile_ls00, ErrText);
