@@ -13,7 +13,7 @@
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 
 #include "gls00.h"
@@ -448,9 +449,9 @@ ls22_PageLoadLoop(tls00_TransformationCmd*  pTransformationCmd,
     if (STOP_NODATA_LS22 == rcFill)
     {                                           
         if (0 == pFloadRec->flrRecordCount_ls00)
-        {   // Nothing sent - error
-            pMsgObj->ls98Msg(layFastload_els98, pszErrText,errEmptyDataFile_els98, pVFile->vfFileName_ls00);
-            rc = errEmptyDataFile_els98;
+        {   // Nothing sent - mark it with a message for the user
+            pMsgObj->ls98Msg(layFastload_els98, pszErrText, msgEmptyDataFile_els98, pVFile->vfFileName_ls00);
+            rc = msgEmptyDataFile_els98;
         }
         else
         {
