@@ -183,7 +183,7 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
     tsp00_Int4 lFailIndex = 0;
     if (true == Format.ffoFormatted_ls00)           // read formatted data
     {
-        rc = ls18GetFormattedValueEx(InputLine.strAddr_ls00,//pFLRec->flrDataSource_ls00.dasInputBuffer.strAddr_ls00,
+        rc = ls18GetFormattedValueEx(InputLine.strAddr_ls00,
                                      InputLine.strLeng_ls00,
                                      &pTransformationCmd->trColSpec_ls00,
                                      pFLRec->flrDataSource_ls00.lReadFieldsCnt_ls00,
@@ -193,12 +193,12 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
     }
     else
     {
-        rc = ls18GetCSVData(InputLine.strAddr_ls00,//pFLRec->flrDataSource_ls00.dasInputBuffer.strAddr_ls00,
+        rc = ls18GetCSVData(InputLine.strAddr_ls00,
                             InputLine.strLeng_ls00,
                             &pFLRec->flrPattern_ls00,
                             pFLRec->flrDataSource_ls00.lReadFieldsCnt_ls00,
                             pFLRec->flrDataSource_ls00.lReadPos_ls00,
-                            pTransformationCmd->trDataFile_ls00.fsFormat_ls00.ffoCodeType_ls00,
+                            ExtEncoding,
                             RawData,
                             lFailIndex);
     }
@@ -246,7 +246,7 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
                  (1            == szMap_CharDataType_ls00[pFI->fiBasics_ls00.fbDataType_ls00]) &&
                  (1            != szMap_BlobDataType_ls00[pFI->fiBasics_ls00.fbDataType_ls00])  )
             {
-                ls18UndoubleDelimitersInCharData(&RawData[i], &pFLRec->flrPattern_ls00, Format.ffoCodeType_ls00);
+                ls18UndoubleDelimitersInCharData(&RawData[i], &pFLRec->flrPattern_ls00, ExtEncoding);
             }
 
             //*
@@ -264,7 +264,7 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
                      ( (NULL != pCol) && (ioChar_els00 == pCol->colFormat_ls00.ffoFormat_ls00) ) )
                 {
                     lTrimLen  = RawData[i].strLeng_ls00;
-                    ls05StrTrimRight(RawData[i].strAddr_ls00, lTrimLen, BLANK_LS00, Format.ffoCodeType_ls00);
+                    ls05StrTrimRight(RawData[i].strAddr_ls00, lTrimLen, BLANK_LS00, ExtEncoding);
                     RawData[i].strLeng_ls00 = STATIC_CAST(tsp00_Int4, lTrimLen);
                 }
             }
@@ -281,7 +281,6 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
                 if ( (errOK_els00 == rc) && (NULL != pCol->colNullCond_ls00) )
                 {                                               
                     rc = ls24GetNILConstants(RawData[i],
-                                             //pFLRec->flrDataSource_ls00.dasInputBuffer,
                                              InputLine,
                                              pFI->fiColMode_ls00,
                                              *pCol->colNullCond_ls00,
@@ -308,12 +307,11 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
             //*
             //*     Convert values to internal encoding (ASCII) for further processing
             //*
-            if ( (ctAscii_els00 != pTransformationCmd->trDataFile_ls00.fsFormat_ls00.ffoCodeType_ls00) &&
-                 (ioChar_els00 == InOutType) )
+            if ( (ctAscii_els00 != ExtEncoding) && (ioChar_els00 == InOutType) )
             {
                 rc = ls20ConvertValue2InternEncoding(RawData[i],
                                                      pFI->fiBasics_ls00.fbDataType_ls00,
-                                                     pTransformationCmd->trDataFile_ls00.fsFormat_ls00.ffoCodeType_ls00,
+                                                     ExtEncoding,
                                                      ErrText);
                 if (errOK_els00 != rc)
                 {
@@ -485,9 +483,38 @@ int ls23BuildRecord(tsp00_Addr               Buffer,
         //* Length of numeric values is checked twice because the first time check is done
         //* when converting to internal number format; shouldn't be a problem
         //*
-        if ( (errOK_els00 == rc) && (INSERT_DEFAULT != RawData[i].strLeng_ls00) && (INSERT_NULL != RawData[i].strLeng_ls00) )
+        if ( (errOK_els00 == rc) &&
+             (INSERT_DEFAULT != RawData[i].strLeng_ls00) &&
+             (INSERT_NULL != RawData[i].strLeng_ls00) &&
+             (0 == szMap_NumberDataType_ls00[pFI->fiBasics_ls00.fbDataType_ls00]) )
         {
-            rc = ls18CheckValueLength(RawData[i].strLeng_ls00, pFI->fiBasics_ls00);
+            tsp00_Uint4 _len = RawData[i].strLeng_ls00;
+
+            if ( (1 == szMap_CharDataType_ls00[pFI->fiBasics_ls00.fbDataType_ls00]) && (ctAscii_els00 != ExtEncoding) )
+            {
+                if (ctUTF8_els00 != ExtEncoding)
+                {
+                    _len /= 2;
+                }
+                else
+                {
+                    unsigned int charLength    = 0;
+                    unsigned int byteLength    = 0;
+                    int          isTerminated  = 0;
+                    int          isCorrupted   = 0;
+                    int          isExhausted   = 0;
+
+                    sp77encodingUTF8->stringInfo(RawData[i].strAddr_ls00,
+                                                 _len,
+                                                 1,
+                                                 &_len,
+                                                 &byteLength,
+                                                 &isTerminated,
+                                                 &isCorrupted,
+                                                 &isExhausted);
+                }
+            }
+            rc = ls18CheckValueLength(_len, pFI->fiBasics_ls00);            
             if (rc != errOK_els00)
             {
                 // error value may only be: errIncompatibleConst_els98
