@@ -13,7 +13,7 @@
   -----------------------------------------------------------------------------
 
     ========== licence begin  GPL
-    Copyright (c) 1999-2004 SAP AG
+    Copyright (c) 1999-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
     ========== licence end
+
 */
 
 #include "gls00.h"
@@ -661,7 +662,14 @@ ls26_InitTabExtrRec(tls00_DBInfo             *pDBInfo,
         pTabExtrRec->terTaskSwitched_ls00 = false;
 
         // session
-        pTabExtrRec->terPgPerPckt_ls00                     = ALIGN_EO00(pDBInfo->dbiPktSize_ls00, 1024) / pDBInfo->dbiPageSize_ls00;
+
+        //  Number of possible pages per packet to receive
+        //  tls00_PktBlock contains packet-, segment- and part header size. Because each packet
+        //  consists of 2 parts the part header has to be substracted again.
+        pTabExtrRec->terPgPerPckt_ls00 = STATIC_CAST( tsp00_Int2, (pDBInfo->dbiPktSize_ls00 - sizeof(tls00_PktBlock)
+                                                                - sizeof(tsp1_part_header)
+                                                                - sizeof(tsp7_bdinfo)) / pDBInfo->dbiPageSize_ls00 );
+
         pTabExtrRec->terPageSize_ls00                      = pDBInfo->dbiPageSize_ls00;
         pTabExtrRec->terSwapKind_ls00                      = pDBInfo->dbiOwnSwap_ls00;          //  Swap behavior
         pTabExtrRec->terpPageBuffer_ls00                   = new _TCHAR[pDBInfo->dbiPageSize_ls00];
