@@ -614,22 +614,24 @@ ls28_SwitchStreams(TransformationDef  *&pTransformationDef,
     //*
     else if (dtypeFile_ls00 == pTransformationCmd->trDataFile_ls00.fsDeviceType_ls00 )
     {
-        if (false == pTransformationCmd->trInternal_ls00 && UNDEFINED_LS00 != pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00  )
+        if (false == pTransformationCmd->trInternal_ls00)
         {
-            //*
-            //*  seek to right position
-            //*
-            if (  pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnu2GB_Blocks_ls00 !=  pInfile->vfFilePos_ls00.lnu2GB_Blocks_ls00 ||
-                  pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00  !=  pInfile->vfFilePos_ls00.lnuRemainder_ls00     )
+            if (UNDEFINED_LS00 != pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00)
             {
-                tls00_LargeNumber lFilePos;
-                lFilePos.lnu2GB_Blocks_ls00 =   pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnu2GB_Blocks_ls00 ;
-                lFilePos.lnuRemainder_ls00  =   pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00  ;
-                rc = ls30VFMoveToStartPosition(*pInfile, &lFilePos, pszErrText);
+                //*
+                //*  seek to right position
+                //*
+                if (pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnu2GB_Blocks_ls00 !=  pInfile->vfFilePos_ls00.lnu2GB_Blocks_ls00 ||
+                    pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00  !=  pInfile->vfFilePos_ls00.lnuRemainder_ls00     )
+                {
+                    tls00_LargeNumber lFilePos;
+                    lFilePos.lnu2GB_Blocks_ls00 =   pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnu2GB_Blocks_ls00 ;
+                    lFilePos.lnuRemainder_ls00  =   pTransformationCmd->trDataFile_ls00.fsExtract_ls00.feStart_ls00.lnuRemainder_ls00  ;
+                    rc = ls30VFMoveToStartPosition(*pInfile, &lFilePos, pszErrText);
+                }
             }
-
         }
-        if (true  == pTransformationCmd->trInternal_ls00 )
+        else
         {
             if ( false == pTransformationDef->m_datastreamname.Empty() &&
                  0     != pTransformationDef->m_datastreamname.Compare("?") &&
@@ -677,28 +679,23 @@ ls28_SwitchStreams(TransformationDef  *&pTransformationDef,
             //*
             //*  seek to right position
             //*
-            if (  errOK_els00 == rc &&
-                (pTransformationDef->m_headerpos.lnu2GB_Blocks_ls00 !=  pInfile->vfFilePos_ls00.lnu2GB_Blocks_ls00 ||
-                 pTransformationDef->m_headerpos.lnuRemainder_ls00  !=  pInfile->vfFilePos_ls00.lnuRemainder_ls00     ))
+            if (errOK_els00 == rc)
             {
-                tls00_LargeNumber lFilePos;
-                lFilePos.lnu2GB_Blocks_ls00 = pTransformationDef->m_headerpos.lnu2GB_Blocks_ls00 ;
-                lFilePos.lnuRemainder_ls00  = pTransformationDef->m_headerpos.lnuRemainder_ls00  ;
-                rc = ls30VFMoveToStartPosition(*pInfile, &lFilePos, pszErrText);
-            }
-            //*
-            //*  seek to right restart position
-            //*
-            if ( (errOK_els00 == rc) && (true == pTabLoadRec->tlrRestart_ls00.rstRestart_ls00) )
-            {
-                rc = ls30VFSeekLong(*pInfile, &pTransformationDef->m_headerpos, pszErrText, sp5vf_seek_begin);
+                if (true == pTabLoadRec->tlrRestart_ls00.rstRestart_ls00)
+                {
+                    //*
+                    //* reset restart flag
+                    //*
+                    pTabLoadRec->tlrRestart_ls00.rstRestart_ls00 = false;
+                }
+
                 //*
-                //* reset restart flag
+                //* Set buffer to new file pos
                 //*
-                pTabLoadRec->tlrRestart_ls00.rstRestart_ls00 = false;
+                pReadBuffer->ls51SetFilePos(pTransformationDef->m_headerpos);
             }
-        }
-    }
+        }   // end else of if (false == pTransformationCmd->trInternal_ls00)
+    }   // end else if (dtypeFile_ls00 == pTransformationCmd->trDataFile_ls00.fsDeviceType_ls00 )
 
 
     //*
@@ -1305,6 +1302,8 @@ ls28_LoadTablePages(MetaDataDef      *&pMetaDataDef,
 
     if (NULL != pReadBuffer)
     {
+        pReadBuffer->ls51ResetFilePos();
+
         delete pReadBuffer;
         pReadBuffer = NULL;
     }
@@ -1559,6 +1558,8 @@ ls28LoadPackageTables(MetaDataDef      *&pMetaDataDef,
 
     if (NULL != pReadBuffer)
     {
+        pReadBuffer->ls51ResetFilePos();
+
         delete pReadBuffer;
         pReadBuffer = NULL;
     }
@@ -1797,28 +1798,18 @@ ls28UpdateTransformationPackage(MetaDataDef              *&pMetaDataDef,
                 pTabLoadRec->tlrTabLoaded_ls00  = false;
 
                 // <DATA_BLOCK>:<DATA_POS>
-                if (dtypeFile_ls00 == pTransformationCmd->trDataFile_ls00.fsDeviceType_ls00)
-                {
-                    readBuffer.ls51ResetFilePos();
+                tls00_LargeNumber NewFilePos;
+                readBuffer.ls51RecalculateFilePos(NewFilePos);
 
+                if (-1 == NewFilePos.lnu2GB_Blocks_ls00)
+                {
                     _itot(STATIC_CAST(tsp00_Int4, _pInFile->vfFilePos_ls00.lnu2GB_Blocks_ls00), DATA_BLOCK, 10);
                     _itot(STATIC_CAST(tsp00_Int4, _pInFile->vfFilePos_ls00.lnuRemainder_ls00), DATA_POS, 10);
                 }
                 else
                 {
-                    tls00_LargeNumber NewFilePos;
-                    readBuffer.ls51RecalculateFilePos(NewFilePos);
-
-                    if (-1 == NewFilePos.lnu2GB_Blocks_ls00)
-                    {
-                        _itot(STATIC_CAST(tsp00_Int4, _pInFile->vfFilePos_ls00.lnu2GB_Blocks_ls00), DATA_BLOCK, 10);
-                        _itot(STATIC_CAST(tsp00_Int4, _pInFile->vfFilePos_ls00.lnuRemainder_ls00), DATA_POS, 10);
-                    }
-                    else
-                    {
-                        _itot(STATIC_CAST(tsp00_Int4, NewFilePos.lnu2GB_Blocks_ls00), DATA_BLOCK, 10);
-                        _itot(STATIC_CAST(tsp00_Int4, NewFilePos.lnuRemainder_ls00), DATA_POS, 10);
-                    }
+                    _itot(STATIC_CAST(tsp00_Int4, NewFilePos.lnu2GB_Blocks_ls00), DATA_BLOCK, 10);
+                    _itot(STATIC_CAST(tsp00_Int4, NewFilePos.lnuRemainder_ls00), DATA_POS, 10);
                 }
 
                 parameter[0] = "0";
