@@ -554,6 +554,47 @@ void LoaderMessages::ls98MsgToString(const LayerNumbers lLayer,
 //  ls98MsgToString()
 
 
+/*
+-----------------------------------------------------------------------------
+  function:     ls98AppendStatusToString
+-----------------------------------------------------------------------------
+*/
+void LoaderMessages::ls98AppendStatusToString(const LayerNumbers  lLayer,
+                                              char*               pszDestString,
+                                              const ErrorNumbers  lMessageNumber,
+                                              ...)
+{
+    // does pszDestSring already contain a message?
+    size_t _len = strlen(pszDestString);
+
+    va_list _arglist;
+    va_start(_arglist, lMessageNumber);
+
+    bool _bFirstMessage = true;
+    if (_len > 0)
+    {
+        // Check if this is the first status message to append
+        if (NULL != strstr(pszDestString, pszStatisticsMsgDelimiter))
+        {
+            _bFirstMessage = false;
+        }
+    }
+    ls98_AppendMsgToString(lMessageNumber, _bFirstMessage, _arglist);
+
+    va_end(_arglist);
+
+    if (_len > 0)
+    {
+        sp77sprintf(pszDestString + _len, MAX_REPLY_LENGTH_LS00 - _len - sizeof(char), "\n%s", m_szMessageForStr);
+    }
+    else
+    {
+        sp77sprintf(pszDestString + _len, MAX_REPLY_LENGTH_LS00 - _len - sizeof(char), "%s", m_szMessageForStr);
+    }
+}
+//  ls98AppendStatusToString()
+
+
 
 /*
 -----------------------------------------------------------------------------
@@ -716,6 +757,33 @@ LoaderMessages::ls98_FormatMsg(const ErrorNumbers lMsgNr,
 //ls98_FormatMsg()
 
 
+void
+LoaderMessages::ls98_AppendMsgToString(const ErrorNumbers lMsgNr,
+                                       bool  bFirstMsgToAppend,
+                                       va_list arglist)
+{
+    ls98_GetMessageText(lMsgNr);        // get the error text
+
+    int   pos1  = 0;
+    short lmyNr = STATIC_CAST(short, lMsgNr);
+
+    if (true == bFirstMsgToAppend)
+    {
+        pos1 = sp77sprintf(m_szMessageForStr, MAX_REPLY_LENGTH_LS00, "%s", pszStatisticsMsgDelimiter);
+    }
+
+    if (lmyNr < 0)      // return strings contain only numbers if errors happened
+    {
+        pos1 += sp77sprintf(m_szMessageForStr + pos1, MAX_REPLY_LENGTH_LS00 - pos1, "%6hd\n", lmyNr);
+    }
+
+    sp77vsprintf(m_szMessageForStr + pos1, (MAX_REPLY_LENGTH_LS00 - pos1), m_pszMsg, arglist);
+
+    return;
+}
+// ls98_AppendMsg()
+
+
 // schreibt letzlich die meldung ins logfile
 int LoaderMessages::ls98_Write()
 {
@@ -1069,6 +1137,11 @@ void LoaderMessages::ls98_GetMessageText(const ErrorNumbers MessageNumber)
 
         {msgSimpleMsg_els98,                    "%s"NEW_LINE"// *"},
 
+        //* STATUS MESSAGES IN RETURN STRINGS
+        {statInsertedRejectedRows_els98,           "Total number of records imported: %qd\nTotal number of records rejected: %qd"},
+        {statUpdatedInvalidRows_els98,             "Total number of records updated : %qd\nTotal number of records rejected: %qd"},
+        {statNumExtractedRecords_els98,            "Total number of records exported            : %qd\nTotal number of records exported with errors: %qd"},
+
         //*
         //*     WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN_WARNUNGEN
         //*
