@@ -406,6 +406,7 @@ void tni33_ABackgroundProcess::InitAndStartBackgroundProcess(const char
                                                              const int                StdErrIsFile)
 {
     Process=AInvalidProcessHandle_ni33;
+    RetCode=InvalidReturnCode_ni33;
 
     #if defined (WIN32)
     Thread=AInvalidProcessHandle_ni33;
@@ -1095,8 +1096,10 @@ int tni33_ABackgroundProcess::Stop()
     if(State==Started)
     {
         #if defined (WIN32)
-        if(TerminateProcess(Process, 0))
+        if(TerminateProcess(Process, 256))  //we use an arbitrary number different from 0 as exit code for the child process, 256 made it, as exit codes on UNIX range only from 0 to 255.
         {
+            Sleep(0); //give up time slice, so that terminated process or OS has a chance to use exit code 256 set above
+
             State=Stopped;
             if(GetExitCodeProcess(Process, &RetCode))
             {
@@ -1131,7 +1134,7 @@ int tni33_ABackgroundProcess::Stop()
                 //if(Process==waitpid(Process,&RCProcess,WNOHANG))
                 ReturnedPID=waitpid(Process, &RCProcess, 0);    // we hope, that the kill signal will end the process so that the waitpid-function will return, when the OS has done it's work of killing the process
             }
-            while(((pid_t)-1)==ReturnedPID && EINTR==errno);    //we are not interested in signals ending waitpid (the kill signal will kill us anyday)
+            while(((pid_t)-1)==ReturnedPID && EINTR==errno);    //we are not interested in signals ending waitpid (the kill signal will kill us any day)
 
             if(Process==ReturnedPID)
             {
