@@ -219,6 +219,8 @@
 // ---- long term move task locks
 #define NEVER_MOVE_TASK                  0x0001
 #define CLIENT_NOT_TASK_MOVE_ENABLED     0x0002
+#define WAITING_FOR_NEW_COMMAND          0x0004
+#define TASK_IS_INACTIVE                 0x0008
 
 //
 // +===============================================================+
@@ -835,6 +837,8 @@ typedef struct task_ctrl_record
    SAPDB_Bool                     fTaskIsWaitingForExclusiveAccess; // ... to a RWRegion
    struct task_ctrl_record       *nextTaskInWaitQueue ;
    void                          *RWRegion;
+   SAPDB_Char                     NameOfSpinlockYieldingFor[20]; /* - pointer to spinlock task is currently yielding for or 0 */
+   SAPDB_Bool                     m_AlreadyYielding; 
 #if defined(_ALPHA_)
    double                         StructureAlignment; // - don't insert any element behind this line!
 #endif
@@ -872,8 +876,6 @@ typedef struct thread_ctrl_header_record
   tsp00_Int4                      ThrdState;
   tsp00_Longuint                  ulStartTime;
   HANDLE                          hComm;
-
-  bool  volatile                  fSemAlreadyPosted;
   HANDLE                          hevSem;             
                                                       
   tsp00_Longuint                  Processor;
@@ -965,14 +967,6 @@ typedef struct ukt_ctrl_record
 
   SAPDB_UInt8                     DispatcherCalls;
 
-  #ifdef SRCH_HAENGER
-   ULONG                          ulReqDispLow;
-   ULONG                          ulReqSleepCnt;
-   ULONG                          ulReqAlreadyPosted;
-   ULONG                          ulReqFromUktInx;
-   PUKT_TO_UKT_QUEUE_REC          ulReqInUkt;
-  #endif
-
 
   LONG                            lExclusive;         // - used to grant exclusive exccess
   ULONG                           ulActInRexQueue;    // - used for LW delay
@@ -993,6 +987,10 @@ typedef struct ukt_ctrl_record
   SAPDB_UInt8                     UKTRunTimeMicroSeconds;
 
   SAPDB_Bool                      TasksAllowedToMoveTo;// specifies that a task is allowed to move to or from this UKT.
+
+  /* used to enforce spinlocks to use giveup timeslice while in dispatcher */
+  SAPDB_Bool                      m_IsWaitingForNextScheduledTask; 
+
   SAPDB_UInt4                     NumOfMovableTasks;
 
   SAPDB_UInt2                     CurrTimeVar;         // Value 0 .. TIME_VAL_ARRAY_SIZE
@@ -1413,6 +1411,7 @@ typedef struct kernel_global_sec_record
   tsp00_Int4                      traceNeedsSaving;
   bool                            dumpDiagFiles;   //PTS 1115180
   SAPDB_Bool                      isHotStandbyConfiguration;
+  SAPDB_UInt8                     symbolResolutionLockCount; /* counts the locks of symbol resolution code */
   } KERNEL_GLOBAL_SEC, tos00k_KernelGlobalSec;
 
 
@@ -1448,6 +1447,7 @@ VOID          sql01k_halt                                ( PSZ pszServerDB );
 // +---------------------------------------------------------------+
 //
 externC VOID           sql50_dump_SEH                   ( PSZ  pszFormatStr, ... );
+externC void           sql50k_resume_tracewriter        ();
 
 externC DWORD          sql50k_excepthandler             ( LPEXCEPTION_POINTERS lpExcPtrs );
 externC LONG           sql50k_disable_error_handling    ( VOID );
