@@ -7,7 +7,7 @@
 \if EMIT_LICENCE
 
     ========== licence begin  GPL
-    Copyright (c) 2001-2004 SAP AG
+    Copyright (c) 2001-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@
     ========== licence end
 
 
+
 \endif
 */
 
@@ -155,6 +156,7 @@ ULONG         sql03u_connect         ( PSZ                    pszServerNode,
                                        PSZ                    pszServerDB,
                                        ULONG                  ulServiceType,
                                        ULONG                  ulPacketCnt,
+									   PULONG                 pulMaxReplyDataLen,
                                        PULONG                 pulMaxCmdDataLen,
                                        PVOID                  pSQLPacketList[],
                                        PULONG                 pulClientRef,
@@ -218,6 +220,7 @@ externC tsp01_CommErr_Enum  SqlPingConnect ( char*                  szServerNode
   tsp01_CommErr_Enum        commError;
   ULONG                     packetSize;
   void*                     packetList;
+  ULONG                     ulMaxReplyDataLen;
 
   DBGIN;
 
@@ -234,6 +237,7 @@ externC tsp01_CommErr_Enum  SqlPingConnect ( char*                  szServerNode
                                                    szServerDB,
                                                    (ULONG) srvPing_esp01,
                                                    1,
+                                                   &ulMaxReplyDataLen,
                                                    &packetSize,
                                                    &packetList,
                                                    reference,
@@ -353,6 +357,7 @@ externC tsp01_CommErr_Enum  SqlAConnect (   char                  *szServerNode,
   #undef  MF__
   #define MF__ MOD__"SqlAConnect"
   tsp01_CommErr_Enum        commError;
+  ULONG                     ulMaxReplyDataLen;
 
   DBGIN;
 
@@ -370,6 +375,7 @@ externC tsp01_CommErr_Enum  SqlAConnect (   char                  *szServerNode,
                                                    szServerDB,
                                                    (ULONG) service,
                                                    (ULONG) packet_cnt,
+                                                   &ulMaxReplyDataLen,
                                                    (PULONG) sql_packet_size,
                                                     sql_packet_list,
                                                     reference,
@@ -385,6 +391,56 @@ externC tsp01_CommErr_Enum  SqlAConnect (   char                  *szServerNode,
   return (commError) ;
   }
 
+/*------------------------------*/
+
+externC tsp01_CommErr_Enum  SqlDBConnect (  char                  *szServerNode,        /* '\0' terminated node or saprouterstring */
+                                            tsp00_DbNamec          szServerDB,          /* '\0' terminated dbname                  */
+                                            tsp01_Service_Enum     service,
+                                            tsp00_Int4             packet_cnt,         
+                                            tsp00_Int4             *reference,
+                                            tsp00_Int4             *max_reply_packet_size,
+                                            tsp00_Int4             *sql_packet_size,
+                                            void                   *sql_packet_list[],  /* tsp00_Array<tsp1_packet_ptr, ...> */
+                                            tsp00_ErrTextc         pErrText )           /* '\0' terminated error string      */
+  {
+  #undef  MF__
+  #define MF__ MOD__"SqlDBConnect"
+  tsp01_CommErr_Enum        commError;
+
+  DBGIN;
+
+  DBG3 (( MF__, "pszServerNode '%s'", szServerNode ));
+  DBG3 (( MF__, "pszServerDB   '%s'", szServerDB.asCharp () ));
+
+
+  if (strlen (szServerDB) >= sizeof (SQL_DBNAMEC))
+  {
+      eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_SERVERDB_NAME_TOO_LONG, 0 );
+      DBGOUT;
+      return commErrNotOk_esp01;
+  }
+
+
+
+  commError = sql03u_connect (szServerNode,
+                              szServerDB,
+                              (ULONG) service,
+                              (ULONG) packet_cnt,
+                              (PULONG)max_reply_packet_size,
+                              (PULONG)sql_packet_size,
+                              sql_packet_list,
+                              reference,
+                              NULL,
+                              NULL,
+                              NULL,
+                              pErrText );
+
+  if ( commError == commErrOk_esp01 )
+    lDumpReference = *reference;
+
+  DBGOUT
+  return (commError) ;
+  }
 /*
  * ========================== GLOBAL FUNCTIONS ================================
  */
@@ -405,6 +461,7 @@ void sqlaconnect (  tsp00_TaskId           pid,
   tsp00_NodeIdc     szServerNode;
   tsp00_DbNamec     szServerDB;
   tsp00_ErrTextc    pErrText;
+  ULONG             ulMaxReplyDataLen;
 
   DBGIN;
 
@@ -424,6 +481,7 @@ void sqlaconnect (  tsp00_TaskId           pid,
                                                 szServerDB,
                                                 (ULONG) service,
                                                 (ULONG) packet_cnt,
+                                                &ulMaxReplyDataLen,
                                                 (PULONG) sql_packet_size,
                                                 sql_packet_list,
                                                 reference,
@@ -818,6 +876,7 @@ VOID sql03u_xconnect (PSZ               pszServerNode,
   {
   #undef  MF__
   #define MF__ MOD__"sql03u_xconnect"
+  ULONG                     ulMaxReplyDataLen;
 
   DBGIN;
 
@@ -825,6 +884,7 @@ VOID sql03u_xconnect (PSZ               pszServerNode,
                           pszServerDB,
                           srvControl_esp01,
                           1,
+                          &ulMaxReplyDataLen,
                           pulMaxCmdDataLen,
                           pSQLPacketList,
                           pulClientRef,
@@ -844,6 +904,7 @@ static ULONG sql03u_connect ( PSZ              pszServerNode,
                               PSZ              pszServerDB,
                               ULONG            ulServiceType,
                               ULONG            ulPacketCnt,
+						      PULONG           pulMaxReplyDataLen,
                               PULONG           pulMaxCmdDataLen,
                               PVOID            pSQLPacketList[],
                               PULONG           pulClientRef,
@@ -1013,6 +1074,7 @@ static ULONG sql03u_connect ( PSZ              pszServerNode,
     pConnInfo->ulMaxCmdDataLen = ConnParam.ulMaxDataLen -
                                  ConnParam.ulMinReplySize;
     *pulMaxCmdDataLen          = pConnInfo->ulMaxCmdDataLen;
+	*pulMaxReplyDataLen        = ConnParam.ulMaxDataLen;
 
     for ( i = 0; i < ulPacketCnt; i++ )
       {
