@@ -52,9 +52,10 @@
 #include "geo007_2.h"
 #include "heo11.h"
 #include "heo11_1.h"
-#include "gos44.h"
-
+#include "RunTime/RTE_EnvironmentVariables.h"
+#include "RunTime/System/RTESys_Time.h"
 
+#include "SAPDBCommon/SAPDB_string.h"
 //
 //  DEFINES
 //
@@ -92,6 +93,11 @@ typedef struct  xp_data_struc
 
 static XP_DATA_STRUC  XpData [ MAX_OPEN_PARAMS ] ;
 
+/*! opening a parameter fail may file when another process is currently accessing the file */
+/*! If this case is detected, just sleep for a given interval and try again */
+#define NUMBER_OF_ATTEMPTS_ON_OPEN_ 600
+/*! the sleep interval between open attempts in 100 milliseconds  */
+#define WAIT_INTERVAL_ON_OPEN_      5
 //
 //  MACROS
 //
@@ -284,8 +290,9 @@ static VOID OpenXParamFile  (   XP_PHFILE   plXParamFd,
     #define MF__ MOD__"OpenXParamFile"
 
 
-    HANDLE           hXParamFile;
+    HANDLE          hXParamFile;
     PATHNAME        szPhysXParamFileName;
+    SAPDB_UInt4     sizeOfPhysXParamFileName = sizeof(szPhysXParamFileName);
     ULONG           ulActionTaken;
 /*
     XP_VALUE_REC    rcXParamHeaderValue;
@@ -296,6 +303,8 @@ static VOID OpenXParamFile  (   XP_PHFILE   plXParamFd,
     BOOLEAN         bCreate = ( OpenMode & XP_OPEN_CREATE_SP11 ) == XP_OPEN_CREATE_SP11 ;
     BOOLEAN         bOverwr = bCreate && (OpenMode & XP_OPEN_BIN_SP11) ==XP_OPEN_BIN_SP11;
 
+    SAPDB_UInt attempts;
+    SAPDB_Bool dummyFlag = false;
 
     DBGIN;
 
@@ -320,34 +329,49 @@ static VOID OpenXParamFile  (   XP_PHFILE   plXParamFd,
     XpData[ lXParamFileID ].Xparams    = (char *)NULL ;
     strcpy ( XpData [ lXParamFileID ].szXParamFile, pszXParamFile )  ;
 
-    sql44c_subst_log_parts ( szPhysXParamFileName, pszXParamFile ) ;
+    RTE_ExpandEnvVars ( pszXParamFile, szPhysXParamFileName, &sizeOfPhysXParamFileName );
 
     // open or create xparm file
     #if defined(_WIN32)
-      if ( bCreate ) {
-          hXParamFile = (HANDLE)CreateFile(szPhysXParamFileName,
-                                          GENERIC_READ | GENERIC_WRITE,
-                                          FILE_SHARE_READ,
-                                          NULL,
-                                bOverwr ? CREATE_ALWAYS : CREATE_NEW ,
-                                          FILE_ATTRIBUTE_NORMAL |
-                                          FILE_FLAG_WRITE_THROUGH,
-                                          NULL);
-          ulActionTaken = FILE_CREATED;
-      }
-      if (!bCreate || hXParamFile==(HANDLE)INVALID_HANDLE_VALUE) {
-          hXParamFile = (HANDLE)CreateFile(szPhysXParamFileName,
-                                          GENERIC_READ | GENERIC_WRITE,
-                                          FILE_SHARE_READ,
-                                          NULL,
-                                          OPEN_EXISTING,
-                                          FILE_ATTRIBUTE_NORMAL  |
-                                          FILE_FLAG_WRITE_THROUGH ,
-                                          NULL);
-          ulActionTaken = FILE_EXISTED;
-      }
-      if (hXParamFile==(HANDLE)INVALID_HANDLE_VALUE) rc = GetLastError();
-      else rc = NO_ERROR;
+        /* make several attempts to open file: it may be open by a dbmsrv    */
+        /* http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1138580 */
+        for(attempts=0;attempts < NUMBER_OF_ATTEMPTS_ON_OPEN_;attempts++)   
+        {
+            if ( bCreate ) {
+                hXParamFile = (HANDLE)CreateFile(szPhysXParamFileName,
+                                                GENERIC_READ | GENERIC_WRITE,
+                                                FILE_SHARE_READ,
+                                                NULL,
+                                        bOverwr ? CREATE_ALWAYS : CREATE_NEW ,
+                                                FILE_ATTRIBUTE_NORMAL |
+                                                FILE_FLAG_WRITE_THROUGH,
+                                                NULL);
+                ulActionTaken = FILE_CREATED;
+            }
+            if (!bCreate || hXParamFile==(HANDLE)INVALID_HANDLE_VALUE) {
+                hXParamFile = (HANDLE)CreateFile(szPhysXParamFileName,
+                                                GENERIC_READ | GENERIC_WRITE,
+                                                FILE_SHARE_READ,
+                                                NULL,
+                                                OPEN_EXISTING,
+                                                FILE_ATTRIBUTE_NORMAL  |
+                                                FILE_FLAG_WRITE_THROUGH ,
+                                                NULL);
+                ulActionTaken = FILE_EXISTED;
+            }
+            if (hXParamFile==(HANDLE)INVALID_HANDLE_VALUE) rc = GetLastError();
+            else rc = NO_ERROR;
+
+            /* If (and only if!) the file is open by another process, wait a little while and try again. */
+            if( rc == ERROR_SHARING_VIOLATION )
+            {
+                RTESys_Timeout(&dummyFlag, WAIT_INTERVAL_ON_OPEN_+1);
+            }
+            else
+            {
+                break;
+            }
+        }
     #else
       if ( bCreate ) {
         rc = DosOpen ( szPhysXParamFileName,
@@ -434,14 +458,14 @@ static BOOLEAN IsParamToFlush ( XP_DATA_STRUC *XpDataStruc )
           { char *ActParam =XpDataStruc->Xparams + XP_PAGE_SIZE * i ;
             if ( !IS_DEL_KEY(ActParam) )
               { if ( i != j )
-                  memcpy (XpDataStruc->Xparams + XP_PAGE_SIZE * j,
+                  SAPDB_memcpy (XpDataStruc->Xparams + XP_PAGE_SIZE * j,
                           ActParam, XP_PAGE_SIZE ) ;
                   if ( !fFlush )
                     { char *OldParam = XpDataStruc->RefXparams + XP_PAGE_SIZE * j ;
                       if ( IS_XP_TYPE_EQ( OldParam, ActParam ) )
                         { XP_VALUE_REC ParamVal1, ParamVal2 ;
-                          memcpy( &ParamVal1, OldParam + sizeof(XP_KEY_TYPE), sizeof(XP_VALUE_REC) ) ;                          
-                          memcpy( &ParamVal2, ActParam + sizeof(XP_KEY_TYPE), sizeof(XP_VALUE_REC) ) ;
+                          SAPDB_memcpy( &ParamVal1, OldParam + sizeof(XP_KEY_TYPE), sizeof(XP_VALUE_REC) ) ;                          
+                          SAPDB_memcpy( &ParamVal2, ActParam + sizeof(XP_KEY_TYPE), sizeof(XP_VALUE_REC) ) ;
                           if ( !IS_XP_VALUE_EQ(ParamVal1, ParamVal2) )
                             fFlush = TRUE ;  
                         }
