@@ -72,11 +72,19 @@
 #define PENDING_SLEEP_TIME            500  // - msec
 #define START_TIME_OUT                180  // - msec
 
+
+#define INFOMSG_CS_COMMON_MSG_TAG             _T("[SAP DBTech] ")
+
+
 /*===========================================================================*
  *  MACROS                                                                   *
  *===========================================================================*/
 
-#define LOG_VERBOSE(_values)       if (ResourceEntry->Params.LogVerbose) (os210_LogEvent)_values
+#if defined (DEBUG_CLU_RES_DLL)
+# define LOG_VERBOSE(_values)       (os210_LogEvent)_values
+#else
+# define LOG_VERBOSE(_values)       if (ResourceEntry->Params.LogVerbose) (os210_LogEvent)_values
+#endif
 
 /*===========================================================================*
  *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
@@ -92,7 +100,7 @@ typedef union t_ResourceParams {
   {
     DWORD  LogVerbose;  // - common parameter
 
-    PWSTR  ServerDB;
+    LPWSTR ServerDB;
     DWORD  AutoRestartShutdown;
   } SERVERDB;
 
@@ -764,7 +772,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
   if ( Status != ERROR_SUCCESS ) 
     return Status;
 
-  LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_RES_CTRL_REQUEST _T("\n") ));
+  LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_RES_CTRL_REQUEST _T("\n")));
 
   if ( ResourceEntry->ResourceType == XSERVER_e  )
     PrivateProperties = os210_XSERVER_PrivateProperties;
@@ -775,6 +783,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
   switch ( ControlCode ) 
   {
   case CLUSCTL_RESOURCE_UNKNOWN:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: CLUSCTL_RESOURCE_UNKNOWN\n")));
     *BytesReturned = 0;
     Status = ERROR_SUCCESS;
     break;
@@ -804,6 +813,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
 */
 
   case CLUSCTL_RESOURCE_ENUM_PRIVATE_PROPERTIES:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: CLUSCTL_RESOURCE_ENUM_PRIVATE_PROPERTIES\n")));
     Status = ResUtilEnumProperties( PrivateProperties,
                                     OutBuffer,
                                     OutBufferSize,
@@ -815,6 +825,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
     break;
  
   case CLUSCTL_RESOURCE_GET_PRIVATE_PROPERTIES:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: CLUSCTL_RESOURCE_GET_PRIVATE_PROPERTIES\n")));
     Status = ResUtilGetAllProperties( ResourceEntry->ParametersKey,
                                       PrivateProperties,
                                       OutBuffer,
@@ -827,6 +838,8 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
     break;
     
   case CLUSCTL_RESOURCE_VALIDATE_PRIVATE_PROPERTIES:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: CLUSCTL_RESOURCE_VALIDATE_PRIVATE_PROPERTIES\n")));
+
     Status = os210_ValidatePrivResProp( PrivateProperties,
                                         ResourceEntry,
                                         InBuffer,
@@ -835,6 +848,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
     break;
     
   case CLUSCTL_RESOURCE_SET_PRIVATE_PROPERTIES:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: CLUSCTL_RESOURCE_SET_PRIVATE_PROPERTIES\n") ));
     Status = os210_SetPrivResProp( PrivateProperties,
                                    ResourceEntry,
                                    InBuffer,
@@ -842,6 +856,7 @@ DWORD WINAPI os210_ResourceControl ( RESID   ResourceId,
     break;
 
   default:
+    LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Control Request: %1!u!\n"), ControlCode ));
     *BytesReturned = 0;
     Status = ERROR_INVALID_FUNCTION;
     break;
@@ -985,6 +1000,11 @@ static RESID os210_Open ( t_ResourceType              ResourceType,
 
   ROUTINE_DBG_MEO60 (_T("os210_Open"));
 
+  if ( ResourceType == XSERVER_e  )
+	(os210_LogEvent)( ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Open X_SERVER request.\n") );
+  else
+	(os210_LogEvent)( ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Open SERVERDB request.\n") );
+
   // --- Open the Parameters registry key for this resource.
   Status = ClusterRegCreateKey( ResourceKey,
                                 _T("Parameters"),
@@ -1031,11 +1051,8 @@ static RESID os210_Open ( t_ResourceType              ResourceType,
           PrivateProperties = os210_SERVERDB_PrivateProperties;
 
       if ( Status == ERROR_SUCCESS ) 
-        Status = ResUtilGetPropertiesToParameterBlock( ResourceEntry->ParametersKey,
-                                                       PrivateProperties,
-                                                       (LPBYTE) &ResourceEntry->Params,
-                                                       false,             // - CheckForRequiredProperties
-                                                       &NameOfPropInError );
+          Status = ResUtilGetDwordValue( ResourceEntry->ParametersKey, REG_MSCS_PARAM_LOG_VERBOSE_OS00,
+                                         &ResourceEntry->Params.LogVerbose, 0 );
       if ( Status == ERROR_SUCCESS ) 
       {
         // --- Read pending timeout parameter.
@@ -1055,13 +1072,10 @@ static RESID os210_Open ( t_ResourceType              ResourceType,
 
   ResID = (RESID)ResourceEntry;
 
-  if ( ResID == 0 ) 
+  if ( ResourceEntry == NULL ) 
   {
     if ( ParametersKey != NULL ) 
       ClusterRegCloseKey( ParametersKey );
-
-    if ( ResourceEntry != NULL ) 
-      LocalFree( ResourceEntry );
   }
   
   if ( Status != ERROR_SUCCESS ) 
@@ -1272,6 +1286,7 @@ static DWORD WINAPI os210_OnlineThread ( PCLUS_WORKER      WorkerPtr,
                                                  (LPBYTE) &ResourceEntry->Params,
                                                  true,             // - CheckForRequiredProperties
                                                  &NameOfPropInError );
+
   if ( Status == ERROR_SUCCESS ) 
   {
     LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_ONLINE_REQUEST _T("\n") ));
@@ -1280,7 +1295,27 @@ static DWORD WINAPI os210_OnlineThread ( PCLUS_WORKER      WorkerPtr,
     {
     case SERVERDB_e:
         if ( ResourceEntry->Params.SERVERDB.ServerDB == NULL )
+        {
+            // 'ResUtilGetPropertiesToParameterBlock' interface error, workaround 
+            ResUtilGetDwordValue( ResourceEntry->ParametersKey, REG_MSCS_PARAM_LOG_VERBOSE_OS00, &ResourceEntry->Params.LogVerbose, 0 );
+            ResUtilGetDwordValue( ResourceEntry->ParametersKey, REG_MSCS_PARAM_AUTO_RES_SHT_OS00, &ResourceEntry->Params.SERVERDB.AutoRestartShutdown, 0 );
+            ResourceEntry->Params.SERVERDB.ServerDB = ResUtilGetSzValue( ResourceEntry->ParametersKey, REG_MSCS_PARAM_SERVERDB_OS00 );
+        }
+
+        LOG_VERBOSE(( ResourceEntry->ResourceHandle, LOG_INFORMATION, INFOMSG_CS_COMMON_MSG_TAG _T("Get Properties - ParametersKey '%1!u!', AutoRestartShutdown '%2!u!', LogVerbose '%3!u!', ServerDB '%4'!\n"), 
+                      &ResourceEntry->ParametersKey, ResourceEntry->Params.SERVERDB.AutoRestartShutdown, 
+	                  ResourceEntry->Params.SERVERDB.LogVerbose, ResourceEntry->Params.SERVERDB.ServerDB  ));
+
+       if ( ResourceEntry->Params.SERVERDB.ServerDB == NULL )
+        {
             Status = ERROR_BAD_ARGUMENTS; // oops ...
+
+            (os210_LogEvent)( ResourceEntry->ResourceHandle, LOG_ERROR,
+                              ERRMSG_CS_ERR_READ_PROPERTY _T("\n"),
+                              REG_MSCS_PARAM_SERVERDB_OS00,
+                              Status );
+
+        }
         else
         {
             // --- Build up service name
@@ -1296,6 +1331,9 @@ static DWORD WINAPI os210_OnlineThread ( PCLUS_WORKER      WorkerPtr,
 
       break;
     case XSERVER_e:
+      // 'ResUtilGetPropertiesToParameterBlock' interface error, workaround  
+      ResUtilGetDwordValue( ResourceEntry->ParametersKey, REG_MSCS_PARAM_LOG_VERBOSE_OS00, &ResourceEntry->Params.LogVerbose, 0 );
+
       // --- Build up service name
       _tcscpy(ResourceEntry->ServiceName, SERVICE_ID_XSERVER);
 
@@ -1303,84 +1341,87 @@ static DWORD WINAPI os210_OnlineThread ( PCLUS_WORKER      WorkerPtr,
       break;
     }
 
-    // --- Start the SERVERDB/XSERVER service
-    if (!(hScM = OpenSCManager(NULL, NULL, SC_MANAGER_CONNECT))         ||
-        !(hS   = OpenService(hScM, ResourceEntry->ServiceName, 
-                             SERVICE_START | SERVICE_QUERY_STATUS ))    ||
-                             !StartService(hS, NumOfArgs, Args))
+    if ( Status == ERROR_SUCCESS ) 
     {
-      Status = GetLastError();
+      // --- Start the SERVERDB/XSERVER service
+      if (!(hScM = OpenSCManager(NULL, NULL, SC_MANAGER_CONNECT))         ||
+          !(hS   = OpenService(hScM, ResourceEntry->ServiceName, 
+                               SERVICE_START | SERVICE_QUERY_STATUS ))    ||
+                               !StartService(hS, NumOfArgs, Args))
+      {
+        Status = GetLastError();
+      
+        if ( hS != NULL )
+          CloseServiceHandle(hS);
+        if ( hScM != NULL )
+          CloseServiceHandle(hScM);
+      }
+      else
+      {
+        Timeout = ( Timeout * 1000 ) / PENDING_SLEEP_TIME;
+        Status  = NO_ERROR;
+      
+        do
+        {
+          SleepEx( PENDING_SLEEP_TIME, false );
+          Timeout--;
+        
+          if ( !QueryServiceStatus( hS, &ssSeviceStatus ))
+            Status = GetLastError();
+          else if ( ssSeviceStatus.dwCurrentState == SERVICE_RUNNING )
+            break;
+          else if (( ssSeviceStatus.dwCurrentState == SERVICE_STOPPED )       ||
+                   ( ssSeviceStatus.dwCurrentState == SERVICE_STOP_PENDING )  ||
+                   ( ssSeviceStatus.dwCurrentState == SERVICE_PAUSE_PENDING ) ||
+                   ( ssSeviceStatus.dwCurrentState == SERVICE_PAUSED ))
+          {
+            Status = ERROR_SERVICE_NOT_ACTIVE;
+            break;
+          }
+        
+          ResourceStatus.ResourceState = ClusterResourceOnlinePending;
+          ResourceStatus.WaitHint      = PENDING_SLEEP_TIME * 2;  // - msec
+          ResourceStatus.CheckPoint++;
+        
+          os210_SetResourceStatus( ResourceEntry->ResourceHandle, &ResourceStatus );
+        
+          if ( Timeout == 0 )
+            Status = ERROR_TIMEOUT;
+        }
+        while ( Status == NO_ERROR );
       
-      if ( hS != NULL )
         CloseServiceHandle(hS);
-      if ( hScM != NULL )
         CloseServiceHandle(hScM);
+      }
+    
+    
+      if ( Status == ERROR_SUCCESS ) 
+      { 
+        ResourceEntry->State = ClusterResourceOnline;
+      }
+      else if ( Status == ERROR_SERVICE_ALREADY_RUNNING ) 
+      {
+        ResourceEntry->State = ClusterResourceOnline;
+        Status               = ERROR_SUCCESS;
+      }
+      else 
+      {
+        ResourceEntry->State = ClusterResourceFailed;
+      
+        (os210_LogEvent)( ResourceEntry->ResourceHandle, LOG_ERROR, 
+                          ERRMSG_CS_STARTING_RESOURCE _T("\n"), 
+                          Status, ResourceEntry->ServiceName );
+      }
     }
     else
-    {
-      Timeout = ( Timeout * 1000 ) / PENDING_SLEEP_TIME;
-      Status  = NO_ERROR;
-      
-      do
-      {
-        SleepEx( PENDING_SLEEP_TIME, false );
-        Timeout--;
-        
-        if ( !QueryServiceStatus( hS, &ssSeviceStatus ))
-          Status = GetLastError();
-        else if ( ssSeviceStatus.dwCurrentState == SERVICE_RUNNING )
-          break;
-        else if (( ssSeviceStatus.dwCurrentState == SERVICE_STOPPED )       ||
-          ( ssSeviceStatus.dwCurrentState == SERVICE_STOP_PENDING )  ||
-          ( ssSeviceStatus.dwCurrentState == SERVICE_PAUSE_PENDING ) ||
-          ( ssSeviceStatus.dwCurrentState == SERVICE_PAUSED ))
-        {
-          Status = ERROR_SERVICE_NOT_ACTIVE;
-          break;
-        }
-        
-        ResourceStatus.ResourceState = ClusterResourceOnlinePending;
-        ResourceStatus.WaitHint      = PENDING_SLEEP_TIME * 2;  // - msec
-        ResourceStatus.CheckPoint++;
-        
-        os210_SetResourceStatus( ResourceEntry->ResourceHandle, &ResourceStatus );
-        
-        if ( Timeout == 0 )
-          Status = ERROR_TIMEOUT;
-      }
-      while ( Status == NO_ERROR );
-      
-      CloseServiceHandle(hS);
-      CloseServiceHandle(hScM);
-    }
-    
-    
-    if ( Status == ERROR_SUCCESS ) 
-    {
-      ResourceEntry->State = ClusterResourceOnline;
-    }
-    else if ( Status == ERROR_SERVICE_ALREADY_RUNNING ) 
-    {
-      ResourceEntry->State = ClusterResourceOnline;
-      Status               = ERROR_SUCCESS;
-    }
-    else 
     {
       ResourceEntry->State = ClusterResourceFailed;
-      
-      (os210_LogEvent)( ResourceEntry->ResourceHandle, LOG_ERROR, 
-                        ERRMSG_CS_STARTING_RESOURCE _T("\n"), 
-                        Status, ResourceEntry->ServiceName );
-    }
-  }
-  else
-  {
-    ResourceEntry->State = ClusterResourceFailed;
 
-    (os210_LogEvent)( ResourceEntry->ResourceHandle, LOG_ERROR,
-                      ERRMSG_CS_ERR_READ_PROPERTY _T("\n"),
-                      (NameOfPropInError == NULL ? _T("") : NameOfPropInError),
-                      Status );
+      (os210_LogEvent)( ResourceEntry->ResourceHandle, LOG_ERROR,
+                        ERRMSG_CS_ERR_READ_PROPERTY _T("\n"),
+                        (NameOfPropInError == NULL ? _T("") : NameOfPropInError),
+                        Status );
+    }
   }
 
 
