@@ -88,7 +88,6 @@
 
 ULONG  sql33c_open_queue_mailslot    ( PSZ                   pszQueName,
                                        BOOL                  fConnectToXServer,
-                                       PID                   *ppidServer,
                                        PHANDLE               phQueMailSlot,
                                        tsp00_ErrTextc             pErrText );
 
@@ -139,7 +138,6 @@ ULONG  sql33c_close_server_process   ( HANDLE                hServerProcess,
 ULONG  sql33c_create_comm_seg        ( ULONG                 ulCSSize,
                                        PSZ                   pszClientObjName,
                                        PSECURITY_ATTRIBUTES  pWorldSA,
-                                       PID                   pidServer,
                                        PHANDLE               phCS,
                                        PCOMM_SEG_HEADER_REC  *ppCSHeader,
                                        tsp00_ErrTextc             pErrText );
@@ -186,6 +184,7 @@ ULONG sql33c_eval_xserv_conn_reply   ( PSHM_CONNECT_INFO_REC pShmConnInfo,
 ULONG sql33c_connect_wait            ( HANDLE                hClientSem,
                                        ULONG                 ulServiceType,
                                        ULONG                 ulTimeOut,
+                                       HANDLE                hServerProcess,
                                        PCOMM_SEG_HEADER_REC  pCSHeader,
                                        tsp00_ErrTextc             pErrText );
 
@@ -200,6 +199,9 @@ ULONG sql33c_init_cleanup_conn_info  ( PSHM_CONNECT_INFO_REC pShmConnInfo,
 ULONG  sql33c_open_server_sems       ( PSHM_CONNECT_INFO_REC pShmConnInfo,
                                        tsp00_ErrTextc             pErrText );
 
+ULONG sql33c_get_kernel_pid_and_version( PSZ                     pszServerDB,
+                                         PID*                    ppidServer,
+                                         tsp100_VersionID2*      pVersion );
 
 /*
  * ========================== GLOBAL FUNCTIONS ================================
@@ -282,6 +284,7 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
   HANDLE                          hFCS;
   FLAG_COMM_SEG                   *pFCS;
   SQL_DBNAMEC                     szServerDB;
+  tsp100_VersionID2               KernelVersion;
 
   DBGIN;
 
@@ -297,6 +300,15 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
     return ( commErrNotOk_esp01 );
     }
 
+   ulCommState = sql33c_get_kernel_pid_and_version ( szServerDB, &pidServer, &KernelVersion );
+
+   if ( ulCommState != commErrOk_esp01 )
+     {
+     DBGOUT;
+     return ( ulCommState );
+     }
+
+
   // --- initialize the connect information record
   ulCommState = sql33c_init_cleanup_conn_info ( pShmConnInfo, pConnParam, pFCS->ulNumOfSemaphores, hFCS, pFCS, pErrText );
 
@@ -342,7 +354,6 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
 
   ulCommState = sql33c_open_queue_mailslot ( pShmConnInfo->szServerDB,
                                              FALSE,
-                                             &pidServer,
                                              &pShmConnInfo->hQueMailSlot,
                                              pErrText );
 
@@ -379,7 +390,6 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
   ulCommState = sql33c_create_comm_seg ( pShmConnInfo->ulCSSize,
                                          pszClientObjName,
                                          pConnParam->pWorldSA,
-                                         pidServer,
                                          &pShmConnInfo->hCS,
                                          &pShmConnInfo->pCSHeader,
                                          pErrText );
@@ -402,11 +412,15 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
                                              pShmConnInfo->ulCSSize,
                                              pErrText );
 
+  if ( ulCommState == commErrOk_esp01 )
+    ulCommState = sql33c_try_open_server_process ( pidServer, &pShmConnInfo->hServerProcess, pErrText );
+
   if ( ulCommState == commErrOk_esp01 )
     {
     ulCommState = sql33c_connect_wait ( pShmConnInfo->hClientSem,
                                         pShmConnInfo->ulServiceType,
                                         pConnParam->ulConnTimeout,
+                                        pShmConnInfo->hServerProcess,
                                         pShmConnInfo->pCSHeader,
                                         pErrText );
     }
@@ -467,10 +481,6 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
   if ( ulCommState == commErrOk_esp01 )
     ulCommState = sql33c_open_server_sems ( pShmConnInfo, pErrText );
 
-  if ( ulCommState == commErrOk_esp01 )
-    ulCommState = sql33c_try_open_server_process ( pShmConnInfo->pCSHeader->pidServerPID,
-                                                   &pShmConnInfo->hServerProcess,
-                                                   pErrText );
   // --- is everthing allright?
   if ( ulCommState != commErrOk_esp01 )
     {
@@ -549,7 +559,6 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
 
    ulCommState = sql33c_open_queue_mailslot ( XSERVER_OBJ_NAME,
                                               TRUE,
-                                              &pidServer,
                                               &pShmConnInfo->hQueMailSlot,
                                               pErrText );
 
@@ -568,7 +577,6 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
    ulCommState = sql33c_create_comm_seg ( pShmConnInfo->ulCSSize,
                                          pszClientObjName,
                                          pConnParam->pWorldSA,
-                                         pidServer,
                                          &pShmConnInfo->hCS,
                                          &pShmConnInfo->pCSHeader,
                                          pErrText );
@@ -591,11 +599,12 @@ ULONG  sql33c_connect ( PCONNECT_PARAM_REC      pConnParam,
                                              pShmConnInfo->ulCSSize,
                                              pErrText );
 
-   if ( ulCommState == commErrOk_esp01 )
+  if ( ulCommState == commErrOk_esp01 )
      {
      ulCommState = sql33c_connect_wait ( pShmConnInfo->hClientSem,
                                          pShmConnInfo->ulServiceType,
                                          pConnParam->ulConnTimeout,
+                                         INVALID_HANDLE_VALUE,
                                          pShmConnInfo->pCSHeader,
                                          pErrText );
      }
@@ -805,8 +814,10 @@ ULONG  sql33c_request ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
   }
 
   // ---  Wake up the UKT?
-  /* Kernel may have corrupted the Communication Segment Header. Therefore we do a range check here. */
+  RTESys_ReadMemoryBarrier();  // to get the correct semaphore
   ulSemaNo = pCSHeader->ulSemaNo; 
+
+  /* Kernel may have corrupted the Communication Segment Header. Therefore we do a range check here. */
   if (ulSemaNo >= pShmConnInfo->ulNumOfServerSems)
   {
       MSGD ((ERR_COMMSEG_HEADER_CORRUPT))
@@ -1262,10 +1273,10 @@ ULONG sql33c_release ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
     // --- close without error handling !
     sql33c_close_queue_mailslot  ( pShmConnInfo->hQueMailSlot, NULL );
     sql33c_close_all_server_sems ( pShmConnInfo, NULL );
+    sql33c_close_server_process ( pShmConnInfo->hServerProcess, NULL );
 
     #if !defined (KERNEL)
      sql33c_close_client_sem     ( pShmConnInfo->hClientSem, NULL );
-     sql33c_close_server_process ( pShmConnInfo->hServerProcess, NULL );
     #endif
     }
 
@@ -1287,12 +1298,14 @@ ULONG sql33c_release ( PSHM_CONNECT_INFO_REC   pShmConnInfo,
 static ULONG sql33c_connect_wait ( HANDLE                hClientSem,
                                    ULONG                 ulServiceType,
                                    ULONG                 ulTimeOut,
+                                   HANDLE                hServerProcess,
                                    PCOMM_SEG_HEADER_REC  pCSHeader,
-                                   tsp00_ErrTextc             pErrText )
+                                   tsp00_ErrTextc        pErrText )
   {
   #undef  MF__
   #define MF__ MOD__"sql33c_connect_wait"
   ULONG                           ulCommState = commErrOk_esp01;
+  ULONG                           ulAliveLookupTime;
   #if defined (KERNEL)
    PUKT_CTRL_REC                  pUKT        = THIS_UKT_CTRL;
    PTASK_CTRL_REC                 pTaskCtrl   = pUKT->pCTask;
@@ -1346,7 +1359,25 @@ static ULONG sql33c_connect_wait ( HANDLE                hClientSem,
    if ( ulTimeOut != (ULONG)UNDEF )
      ulTimeOut *= 1000;
 
-   ulCommState = sql33c_wait_client_sem ( hClientSem, ulTimeOut, pErrText );
+   ulAliveLookupTime = (hServerProcess == INVALID_HANDLE_VALUE) ?  ulTimeOut : (10 * 1000);
+
+   do 
+   {
+     ulCommState = sql33c_wait_client_sem ( hClientSem, ulAliveLookupTime, pErrText );
+ 
+     if ( ulCommState == commErrTimeout_esp01 )
+       {
+       if( WaitForSingleObject( hServerProcess, 0) != WAIT_TIMEOUT )
+         {
+         MSGD (( ERR_CONN_BROKEN ));
+         eo46BuildErrorStringRC ( pErrText, ERRMSG_COM_CONN_BROKEN, GetLastError() );
+         ulCommState = commErrNotOk_esp01;
+         }
+       }
+       if ( ulTimeOut != (ULONG)UNDEF )
+           ulTimeOut = ulTimeOut > ulAliveLookupTime ? ulTimeOut - ulAliveLookupTime : 0;
+     }
+   while (( ulCommState == commErrTimeout_esp01 ) && ulTimeOut );
 
    if ( ulCommState == commErrTimeout_esp01 )
    {
@@ -1367,14 +1398,14 @@ static ULONG sql33c_connect_wait ( HANDLE                hClientSem,
 
 static ULONG  sql33c_open_queue_mailslot ( PSZ                    pszQueName,
                                            BOOL                   fConnectToXServer,
-                                           PID                    *ppidServer,
                                            PHANDLE                phQueMailSlot,
-                                           tsp00_ErrTextc              pErrText )
+                                           tsp00_ErrTextc         pErrText )
   {
   #undef  MF__
   #define MF__ MOD__"sql33c_open_queue_mailslot"
   PSZ        pszPath;
   ULONG      rc = NO_ERROR;
+  PID        pidServerDummy;
 
   DBGIN;
 
@@ -1383,7 +1414,7 @@ static ULONG  sql33c_open_queue_mailslot ( PSZ                    pszQueName,
   //
   pszPath = MAIL_REQ;
 
-  rc = sql41c_open_queue_mailslot ( ppidServer,   // - OS/2
+  rc = sql41c_open_queue_mailslot ( &pidServerDummy,   // - OS/2
                                     phQueMailSlot,
                                     pszPath,
                                     pszQueName );
@@ -1812,8 +1843,8 @@ static ULONG sql33c_close_server_sem ( HANDLE     hServerSem,
 
 /*------------------------------*/
 
-static ULONG  sql33c_try_open_server_process ( PID            pidServerPID,
-                                               PHANDLE        phServerProcess,
+static ULONG  sql33c_try_open_server_process ( PID                 pidServerPID,
+                                               PHANDLE             phServerProcess,
                                                tsp00_ErrTextc      pErrText )
   {
   #undef  MF__
@@ -1887,7 +1918,6 @@ static ULONG sql33c_close_server_process ( HANDLE     hServerProcess,
 static ULONG  sql33c_create_comm_seg( ULONG                 ulCSSize,
                                       PSZ                   pszClientObjName,
                                       PSECURITY_ATTRIBUTES  pWorldSA,
-                                      PID                   pidServer,
                                       PHANDLE               phCS,
                                       PCOMM_SEG_HEADER_REC  *ppCSHeader,
                                       tsp00_ErrTextc             pErrText )
@@ -2556,6 +2586,43 @@ static  ULONG sql33c_init_cleanup_conn_info ( PSHM_CONNECT_INFO_REC pShmConnInfo
   return ( ulCommState );
   }
 
+/*------------------------------*/
+
+static ULONG sql33c_get_kernel_pid_and_version( PSZ                     pszServerDB,
+                                                PID*                    ppidServer,
+                                                tsp100_VersionID2*      pVersion )
+  {
+  #undef  MF__
+  #define MF__ MOD__"sql33c_get_kernel_pid_and_version"
+  ULONG                   rc = NO_ERROR;
+  HANDLE                  hKSS     = 0;
+  KERNEL_SHARED_SEG       *pKSS    = NULL;
+  
+  DBGIN;
+
+
+  //
+  // --- get database version
+  //
+  rc = sql41c_get_named_shrd_mem ( (PPVOID)&pKSS, SHM_KSS, pszServerDB,
+                                   &hKSS );
+
+  if ( rc != NO_ERROR )
+    {
+    DBGOUT;
+    return ( commErrNotOk_esp01 );
+    }
+
+  *pVersion   = pKSS->RTEVersionID;
+  *ppidServer = pKSS->KernelPid;
+
+  sql41c_free_shrd_mem ( pKSS, hKSS );
+
+  DBGOUT;
+  return ( commErrOk_esp01 );
+  }
+
+
 /*
  * =============================== END ========================================
  */
