@@ -332,7 +332,7 @@ externC int eo38_ErrorInExceptionHandler ( LPEXCEPTION_POINTERS lpexceptInfo )
 //  case STATUS_FLOAT_INVALID_OPERATION:    // 0xC0000090L    
 //  case STATUS_FLOAT_STACK_CHECK:          // 0xC0000092L    
 //  case XCPT_ABORT_EXCEPTION:              // 0xE000AFFE  abort       PTS 1110787 FF 
-//  case XCPT_ABORT_EXCEPTION_CRASH_DUMP:   // 0xE000AAAA  crash dump' PTS 1110787 FF 
+//  case XCPT_ABORT_EXCEPTION_MINI_DUMP:    // 0xE000AAAA  mini dump' PTS 1110787 FF 
 //    action = EXCEPTION_CONTINUE_SEARCH;   // exceptions - dump
 //    //CLEARLOCK (DCOM_EXCLUSIVE);                                   /* PTS 1110787 FF */
 //    return action;         /* subsequent handler documents exception PTS 1110787 FF */
@@ -463,10 +463,11 @@ externC int eo38_ErrorInExceptionHandler ( LPEXCEPTION_POINTERS lpexceptInfo )
 
 externC void eo38_Dump_Exception ( LPEXCEPTION_POINTERS lpexceptInfo )
 {
-  char          dmp_buf[132];
-  char          cExceptCode[32];
-  OSVERSIONINFO stOSVI ;
-  BOOL          bRet;
+  char                     dmp_buf[132];
+  char                     cExceptCode[32];
+  OSVERSIONINFO            stOSVI ;
+  BOOL                     bRet;
+  eo670TraceContext        traceContext;
   
   PTASK_CTRL_REC pTaskCtrl = THIS_UKT_CTRL->pCTask;   // CR 1103791
   switch (lpexceptInfo->ExceptionRecord->ExceptionCode)
@@ -565,7 +566,9 @@ externC void eo38_Dump_Exception ( LPEXCEPTION_POINTERS lpexceptInfo )
     };
   }
 
-  eo670_CTraceContextStack(lpexceptInfo->ContextRecord); 
+  traceContext.threadHandle   = GetCurrentThread();
+  traceContext.pThreadContext = lpexceptInfo->ContextRecord;
+  eo670_CTraceContextStack( &traceContext );
 
   sprintf(dmp_buf,"CurrStackPointer: 0x%p  ulTaskStackSize: 0x%8.8X", 
     pTaskCtrl->pCurrStackPointer, pTaskCtrl->ulTaskStackSize); 
