@@ -184,9 +184,9 @@ VOID vgetpid ( PROCESS_ID  *pid )
 #define MF__ MOD__"vgetpid"
 
     PUKT_CTRL_REC                 pUKT      = THIS_UKT_CTRL;
-    if ( !pUKT )
+    if ( !pUKT || !pUKT->pCTask )
     {
-        *pid = 0; /* called from other type of thread */
+        *pid = 0; /* called from other type of thread or not within task */
     }
     else
     {
@@ -462,6 +462,9 @@ VOID vinit ( PRTE_COMM_REC   *rte_comm_ptr,
   // - alter task activ counters
   sql74k_alter_task_cnt( pCurrTask, ADD_ACTIVE_COUNTER );
 
+  /* Remove inactive move lock */
+  sql74k_long_term_move_lock( pCurrTask, TASK_IS_INACTIVE, false ); 
+
   // --- return address of the kernel communication record
   memset ( &pCurrTask->KernelCtrlRecord, 0, sizeof(pCurrTask->KernelCtrlRecord) );
   *rte_comm_ptr              = &pCurrTask->KernelCtrlRecord;
@@ -551,7 +554,7 @@ VOID  vrestart ( PROCESS_ID    pid,
 
 /*------------------------------*/
 /* PTS 1115383 */
-void  voffline ( tsp00_TaskId pid,
+void  voffline ( tsp00_TaskId   pid,
                  SHUTDOWN_MODE  mode )
   {
   #undef  MF__
@@ -579,14 +582,17 @@ void  voffline ( tsp00_TaskId pid,
 
   kgs.fRestarted = FALSE;
 
-  if (mode == SHUTDOWN_KILL)
+  if ( mode == SHUTDOWN_KILL )
   {
       kgs.dumpDiagFiles = true;
+      MSGCD (( INFO_SHUTDOWN_KILL_REQ  ));
+      *kgs.pDBState = SERVER_SHUTDOWNKILL;
+  }
+  else
+  {
+      MSGCD (( INFO_SHUTDOWN_NORMAL_REQ  ));
+      *kgs.pDBState = SERVER_SHUTDOWN;
   }
-
-  MSGCD (( INFO_SHUTDOWN_NORMAL_REQ  ));
-
-  *kgs.pDBState = SERVER_SHUTDOWN;
 
   UPDATE_SERVICE_OR_CONSOLE_STATE(*kgs.pDBState);
 
@@ -617,12 +623,8 @@ VOID sql51k_finish ( VOID )
 
   DBGIN;
 
-  if (( pUKT->pCTask->MoveLock.Type.LongTerm != NEVER_MOVE_TASK ) &&
-      ( pUKT->pCTask->Connectable            == true ))
-  { // don't move this task during release and next startup phase...
-    // move lock will be initialized during next 'vinit' via 'sql70k_init_task_ctrl'!
-    sql74k_temp_move_lock( pUKT->pCTask, 1, true ); 
-  }
+  /* Don't move this task during finish and next startup phase... */
+  sql74k_long_term_move_lock( pCurrTask, TASK_IS_INACTIVE, true ); 
 
   // PTS 1110953
   if ( XPARAM(showMaxStackUse) )
@@ -659,7 +661,9 @@ VOID sql51k_finish ( VOID )
         case SERVER_ABORT :
         case SERVER_KILL :
         case SERVER_STOP :
-          EXITTHREAD( 0, pUKT->ThrdCtrlHeader.hThrd );
+          pUKT->ThrdCtrlHeader.ThrdState = UKT_TERMINATED;
+          pCurrTask->TaskState           = TSK_TERMINATED_EO00;
+          ExitThread( 0 );
           break;
         }
 
