@@ -45,6 +45,7 @@
 #include "heo15.h"
 #include "RunTime/MemoryManagement/RTEMem_PageAllocator.h"
 #include "RunTime/MemoryManagement/RTEMem_AWEAllocator.hpp"
+#include "RunTime/Diagnose/RTEDiag_SymbolResolutionLock.h"
 #include "geo00_1.h"
 
 #if !defined ( WIN32 )
@@ -212,7 +213,12 @@ LONG sql70k_init_control_records (VOID)
     rc = sql70k_init_kgs ( pCluInfo );
 
   if (rc == NO_ERROR)
-    sql70k_init_allocators ( pCluInfo );
+    rc = sql70k_init_allocators ( pCluInfo );
+
+  if ( !RTEDiag_CreatedRegisteredSymbolResolutionLock() )
+  {
+      MSGD (( ERR_CANT_REGISTER_SYMBOL_RESOLUTION_LOCK ));
+  }
 
   if ( pCluInfo != NULL )
     {
@@ -252,7 +258,6 @@ VOID sql70k_init_task_ctrl ( PTASK_CTRL_REC  pCurrTaskCtrl )
   pCurrTaskCtrl->fTimeOut                   = FALSE;
   pCurrTaskCtrl->DevNameWaitingFor          = NULL;
   pCurrTaskCtrl->fDebugTask                 = FALSE;
-  pCurrTaskCtrl->MoveLock.Val               = 0;  // reset lock
 
   switch ( pCurrTaskCtrl->TaskType )
     {
@@ -266,13 +271,6 @@ VOID sql70k_init_task_ctrl ( PTASK_CTRL_REC  pCurrTaskCtrl )
       break;
     }
 
-  if ( pCurrTaskCtrl->TaskType != TT_US )
-    pCurrTaskCtrl->MoveLock.Type.LongTerm  = NEVER_MOVE_TASK;
-    
-  if ( pCurrTaskCtrl->Connectable )
-    pCurrTaskCtrl->MoveLock.Type.Temporary = 1; // Set temporary move lock. Will be removed
-                                                // by the first 'vreceive'
-
   memset ( &pCurrTaskCtrl->RunnableMicroSeconds,    0, sizeof ( pCurrTaskCtrl->RunnableMicroSeconds ) );
   memset ( &pCurrTaskCtrl->MaxRunnableMicroSeconds, 0, sizeof ( pCurrTaskCtrl->MaxRunnableMicroSeconds ) );
 
@@ -953,8 +951,8 @@ static  LONG sql70k_insert_tasks ( PTASK_CTRL_REC  pTaskCtrl,
     sql70k_init_task ( pTaskCtrl, *pulTaskIndex, TaskType, ulTaskStackSize,
                        pUKTCtrl, ppCommCtrl, pulCommFlagNo );
 
-	  if ( pTaskCtrl->MoveLock.Type.LongTerm != NEVER_MOVE_TASK )
-      pUKTCtrl->TasksAllowedToMoveTo = true;
+	  if ( 0 == ( pTaskCtrl->MoveLock.Type.LongTerm & NEVER_MOVE_TASK ))
+          pUKTCtrl->TasksAllowedToMoveTo = true;
 
 #if defined(UNCONNECT_TASK_LIST)
     if (( pTaskCtrl->MoveLock.Type.LongTerm == NEVER_MOVE_TASK ) || 
@@ -1109,7 +1107,7 @@ static LONG sql70k_init_allocators ( teo70k_ClusterInfo  *pCluInfo )
   }
 
   DBGOUT
-  return (rc);
+  return ( NO_ERROR );
   }
 
 /*------------------------------*/
@@ -1469,7 +1467,6 @@ static VOID sql70k_init_thrd_ctrl_header ( PTHREAD_CTRL_HEADER_REC pThrdCtrlHd,
   pThrdCtrlHd->ThrdState          = lThrdState;
   pThrdCtrlHd->ulStartTime        = ulStartTime;
   pThrdCtrlHd->hComm              = INVALID_HANDLE_VALUE;
-  pThrdCtrlHd->fSemAlreadyPosted  = FALSE;
   pThrdCtrlHd->hevSem             = INVALID_HANDLE_VALUE;
   }
 
@@ -1494,7 +1491,13 @@ static  VOID sql70k_init_task ( PTASK_CTRL_REC  pTaskCtrl,
   pTaskCtrl->TaskType        = TaskType;
   pTaskCtrl->ulTaskStackSize = ALIGN( ulTaskStackSize, kgs.ulSystemPageSize);
   pTaskCtrl->pUKT            = pUKTCtrl;
+  pTaskCtrl->MoveLock.Val    = 0;  // reset lock
 
+  pTaskCtrl->MoveLock.Type.LongTerm = TASK_IS_INACTIVE;        // Set move lock. Will be removed
+                                                               // by the first 'vinit'
+  if (   pTaskCtrl->TaskType != TT_US )
+      pTaskCtrl->MoveLock.Type.LongTerm |= NEVER_MOVE_TASK;
+    
   // --- initialize the "dynamic" part
   sql70k_init_task_ctrl      ( pTaskCtrl );
   sql70k_init_task_ctrl_cntr ( pTaskCtrl );
