@@ -87,29 +87,21 @@ VOID  sql72k_wake_kt ( PTHREAD_CTRL_HEADER_REC pThrdCtrlHd )
 
   DBGPAS;
 
-// PTS 1109335  if ( pThrdCtrlHd->fSemAlreadyPosted == FALSE )
+  if ( !SetEvent( (HANDLE)pThrdCtrlHd->hevSem ))
+    rc = GetLastError();
+
+  if (( rc                != NO_ERROR )             &&
+      ( rc                != ERROR_ALREADY_POSTED ) &&
+      ( *kgs.pDBState     < SERVER_SHUTDOWN ))
     {
-    pThrdCtrlHd->fSemAlreadyPosted = TRUE; // --- it prevents the semaphore
-                                           //     to be posted more than once
-
-//  if ( pThrdCtrlHd->ThrdState == KT_SLEEPING )
-      {
-       if ( !SetEvent( (HANDLE)pThrdCtrlHd->hevSem ))
-         rc = GetLastError();
-
-      if (( rc                != NO_ERROR )             &&
-          ( rc                != ERROR_ALREADY_POSTED ) &&
-          ( *kgs.pDBState     < SERVER_SHUTDOWN ))
-        {
-        MSGD (( ERR_POSTING_KT_SEM, pThrdCtrlHd->Tid, rc ));
-        DBG1 (( MF__, "INTERNAL ERROR: on posting semaphore of KT:%u, rc = %d",
-                pThrdCtrlHd->Tid, rc ));
-        ABORT();
-        }
-      }
+    MSGD (( ERR_POSTING_KT_SEM, pThrdCtrlHd->Tid, rc ));
+    DBG1 (( MF__, "INTERNAL ERROR: on posting semaphore of KT:%u, rc = %d",
+            pThrdCtrlHd->Tid, rc ));
+    ABORT();
     }
   }
 
+
 /*------------------------------*/
 
 VOID  sql72k_wake_ukt ( PUKT_CTRL_REC pUKTCtrl )
@@ -117,9 +109,6 @@ VOID  sql72k_wake_ukt ( PUKT_CTRL_REC pUKTCtrl )
   #undef  MF__
   #define MF__ MOD__"sql72k_wake_ukt"
   APIRET  rc = NO_ERROR;
-#ifdef SRCH_HAENGER
-  BOOLEAN fPosted ;
-#endif
 
   DBGPAS;
 
@@ -128,38 +117,20 @@ VOID  sql72k_wake_ukt ( PUKT_CTRL_REC pUKTCtrl )
   if ( pUKTCtrl == NULL )
     return;
 
-#ifdef SRCH_HAENGER
-  fPosted = pUKTCtrl->ThrdCtrlHeader.fSemAlreadyPosted ;
-  pUKTCtrl->ulReqDispLow = pUKTCtrl->ulDispatcherCallsLow;
-  pUKTCtrl->ulReqSleepCnt= pUKTCtrl->SleepTimeStat.ulCount ;
-  pUKTCtrl->ulReqAlreadyPosted = fPosted ;
-  pUKTCtrl->ulReqFromUktInx = THREADID ;
-  if ( !fPosted )
-#endif
-// PTS 1109335  if  ( pUKTCtrl->ThrdCtrlHeader.fSemAlreadyPosted == FALSE )
+  if ( !SetEvent( (HANDLE)pUKTCtrl->ThrdCtrlHeader.hevSem ))
+    rc = GetLastError();
+
+  if (( rc              != NO_ERROR )             &&
+      ( rc              != ERROR_ALREADY_POSTED ) &&
+      ( *kgs.pDBState   != SERVER_SHUTDOWNREINIT) &&
+      ( *kgs.pDBState   != SERVER_SHUTDOWNKILL  ))
     {
-    // --- it prevents the semaphore to be posted more than once
-
-    pUKTCtrl->ThrdCtrlHeader.fSemAlreadyPosted = TRUE;
-
-//  if ( pUKTCtrl->ThrdCtrlHeader.ThrdState == KT_SLEEPING )
-      {
-       if ( !SetEvent( (HANDLE)pUKTCtrl->ThrdCtrlHeader.hevSem ))
-         rc = GetLastError();
-
-      if (( rc              != NO_ERROR )             &&
-          ( rc              != ERROR_ALREADY_POSTED ) &&
-          ( *kgs.pDBState   != SERVER_SHUTDOWNREINIT) &&
-          ( *kgs.pDBState   != SERVER_SHUTDOWNKILL  ))
-        {
-        MSGD (( ERR_POSTING_UKT_SEM, pUKTCtrl->ulUKTIndex, rc ));
-        DBG1 (( MF__, "INTERNAL ERROR: on posting semaphore of UKT:%u, rc = %d",
-                pUKTCtrl->ulUKTIndex, rc ));
-        ABORT();
-        }
-      DBG4 (( MF__, "Waked up UKT:%d", pUKTCtrl->ulUKTIndex ));
-      }
+    MSGD (( ERR_POSTING_UKT_SEM, pUKTCtrl->ulUKTIndex, rc ));
+    DBG1 (( MF__, "INTERNAL ERROR: on posting semaphore of UKT:%u, rc = %d",
+          pUKTCtrl->ulUKTIndex, rc ));
+    ABORT();
     }
+  DBG4 (( MF__, "Waked up UKT:%d", pUKTCtrl->ulUKTIndex ));
   }
 
 /*
