@@ -38,6 +38,7 @@
 #include "geo007_1.h"
 #include "gos00k.h"
 #include "geo002.h"
+#include "RunTime/System/RTESys_MemoryBarrier.h"
 
 /*
  *  DEFINES
@@ -403,7 +404,8 @@ VOID sql73k_UToU_enqu ( PUKT_CTRL_REC   pUKT,
   pUToUQueElem->pFuncToExecute   = pFuncToExecute;
   pUToUQueElem->ulFuncParam      = ulFuncParam;
   pUToUQueElem->pFromTaskCtrl    = pFromTaskCtrl;
-  pUToUQueElem->pTaskCtrl        = MEM_SYNC( pRemoteTaskCtrl );
+  RTESys_WriteMemoryBarrier();
+  pUToUQueElem->pTaskCtrl        = pRemoteTaskCtrl;
   pUToUQueHead->pRequest         = pUToUQueElem->pNextElem;
 
 
