@@ -185,6 +185,8 @@ VOID  sql74k_dispatcher ( PUKT_CTRL_REC   pUKT )
   //     'ulLoopCnt' is used for stack checks
   ULONG                         ulLoopCnt = LOOP_CNT();
 
+  pUKT->m_IsWaitingForNextScheduledTask = true; /* enforce spinlocks to use giveup timeslice while in dispatcher */
+
   // - Signal that it's necessary to post the UKT-semaphore!
   //   This flag is used by the client applications only.
   kgs.pulSemaFlags[pUKT->ulSemaNo] = POST_SEM;
@@ -270,7 +272,10 @@ VOID  sql74k_dispatcher ( PUKT_CTRL_REC   pUKT )
 
       __os74DoLeaveDispatcherTiming(*ppCTask);
 
+      pUKT->m_IsWaitingForNextScheduledTask = false; /* enforce spinlocks to use giveup timeslice while in dispatcher */
+
       DBGOUT_T ((*ppCTask)->ulTaskIndex);
+
       return;
       }
 
@@ -285,8 +290,7 @@ VOID  sql74k_dispatcher ( PUKT_CTRL_REC   pUKT )
     if ( ulTimeOut != MAXTIMEVALUE)
       ulTimeOut = (ulTimeOut - ulCurrTime) * 1000;
 
-    if ((pUKT->ThrdCtrlHeader.fSemAlreadyPosted == FALSE) &&
-        (--ulLoopCnt                            == 0 ))
+    if (--ulLoopCnt == 0 )
       {
       ulLoopCnt = XPARAM(ulDispLoopsBefSemop);
 
@@ -297,7 +301,6 @@ VOID  sql74k_dispatcher ( PUKT_CTRL_REC   pUKT )
 
       pUKT->ThrdCtrlHeader.ThrdState = KT_RUNNING;
       }
-    pUKT->ThrdCtrlHeader.fSemAlreadyPosted = FALSE;
     
     } 
   } /* End of for loop (doubled because SRCH_HAENGER macros) */
@@ -310,7 +313,10 @@ VOID  sql74k_dispatcher ( PUKT_CTRL_REC   pUKT )
 
     __os74DoLeaveDispatcherTiming(*ppCTask);
 
+    pUKT->m_IsWaitingForNextScheduledTask = false; /* enforce spinlocks to use giveup timeslice while in dispatcher */
+
     DBGOUT_T ((*ppCTask)->ulTaskIndex);
+
     return;
   }
 
@@ -799,7 +805,16 @@ _INLINE VOID __os74SearchRUN ( PUKT_CTRL_REC    pUKT,
       if ( pTempTaskCtrl->PrioFlag ) 
         pUKT->ulImmediateDispatch++;
 
-      if ( HighestPrioTask->ulDynPrio < pTempTaskCtrl->ulDynPrio )
+      if ( HighestPrioTask == pTempTaskCtrl )  // More than one queue element for the same task found?
+        {
+        if ( REQ_RESCHEDULE_EO00 == pRUNQue[uldx].pRequest->ulReqType ) // Yield request?
+          {   // We have use the yield element first because the task 
+              // is waiting for the yield request first.
+          HighestPrioTask = pTempTaskCtrl;
+          RunIndex        = uldx;
+          }
+        }
+      else if ( HighestPrioTask->ulDynPrio < pTempTaskCtrl->ulDynPrio ) 
         { 
         HighestPrioTask = pTempTaskCtrl;
         RunIndex        = uldx;
@@ -858,6 +873,8 @@ _INLINE VOID __os74SearchUKTtoUKT ( PUKT_CTRL_REC    pUKT,
         bool   fLoopEnd ;
         ULONG  ulLoopCnt = 0 ;
 
+        RTESys_ReadMemoryBarrier();
+
         pUToUQueElem     = pUToUQueHead->pWork;
 
         do
@@ -865,7 +882,7 @@ _INLINE VOID __os74SearchUKTtoUKT ( PUKT_CTRL_REC    pUKT,
           if (( ((pSvFuncToExecute = pUToUQueElem->pFuncToExecute) == sql74k_remote_func_error ) ||
                  pUToUQueElem->pFromTaskCtrl == NULL ))
             { 
-            MSGD(( INFO_REMOTEFUNC_NOT_SET, (*ppCTask)->ulTaskIndex, pUToUQueElem->ulFuncParam )) ;    
+            MSGD(( ERR_REMOTEFUNC_NOT_SET, (*ppCTask)->ulTaskIndex, pUToUQueElem->ulFuncParam )) ;    
             fLoopEnd = ++ulLoopCnt == 10 ;
             SLEEP(3000) ;
             }
@@ -943,14 +960,14 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
     {
     while ( (pUKT->pCurrReq = pUKTQue->pLastUsedElem->pRequest) != NULL )
       {
+      RTESys_ReadMemoryBarrier();
+
       // --- dequeue the request
       pUKTQue->pLastUsedElem->pRequest = NULL;
       pUKTQue->pLastUsedElem           = pUKTQue->pLastUsedElem->pNextElem;
       *ppCTask                         = pUKT->pCurrReq->pTaskCtrl;
       pCurrReq                         = pUKT->pCurrReq;
 
-      RTESys_ReadMemoryBarrier();
-
       if ( *ppCTask ) 
         { // since REQ_NEW_MOVE_TASK_MEAS_INTERVAL_EO00 and REQ_MOVE_TASK_EO00 no task might be specified
         IGNORE_SOME_REQUESTS_AT_SYSTEM_END( *ppCTask, return );
@@ -987,15 +1004,14 @@ _INLINE VOID __os74SearchUKT ( PUKT_CTRL_REC    pUKT,
 
         case REQ_CONNECT:             // - connect request ?
 
-          // - the request will be evaluated by 'vconnect'.
-          sql73k_DLQ_enqu_nolock (  &(*ppCTask)->DLQ_ConnReq, pCurrReq );
-
-          //
-          // - don't leave the dispatcher if task
-          //   is not waiting for a connection
-          //
           if ( (*ppCTask)->TaskState != TSK_CONNECTWAIT )
+          {
+              // - the request will be evaluated by 'vconnect' later on.
+              sql73k_DLQ_enqu_nolock (  &(*ppCTask)->DLQ_ConnReq, pCurrReq );
+
+            // - don't leave the dispatcher if task is not waiting for a connection
             *ppCTask = NULL;
+          }
 
           // - don't release the freelist element here!
           break;
@@ -1231,6 +1247,9 @@ _INLINE VOID __os74SearchCOM ( PUKT_CTRL_REC    pUKT,
 
         IGNORE_SOME_REQUESTS_AT_SYSTEM_END( *ppCTask, return );
 
+        // remove move lock, lock has been set by vreply
+        sql74k_long_term_move_lock( (*ppCTask), WAITING_FOR_NEW_COMMAND, false );
+
         (*ppCTask)->SpecDLQElem2.pFromTaskCtrl = NULL;
         (*ppCTask)->SpecDLQElem2.ulReqType     = REQ_NEW_COMMAND;
         __os74EnquRUNQueue( pUKT, (*ppCTask), NULL, &(*ppCTask)->SpecDLQElem2, BASE_PRIO_COM) ;
@@ -1265,6 +1284,9 @@ _INLINE VOID __os74SearchCOM ( PUKT_CTRL_REC    pUKT,
 
         IGNORE_SOME_REQUESTS_AT_SYSTEM_END( *ppCTask, return );
 
+        // remove move lock, lock has been set by vreply
+        sql74k_long_term_move_lock( (*ppCTask), WAITING_FOR_NEW_COMMAND, false );
+
         (*ppCTask)->SpecDLQElem2.pFromTaskCtrl = NULL;
         (*ppCTask)->SpecDLQElem2.ulReqType     = REQ_NEW_COMMAND;
         __os74EnquRUNQueue( pUKT, (*ppCTask), NULL, &(*ppCTask)->SpecDLQElem2, BASE_PRIO_COM) ;
