@@ -40,6 +40,7 @@
 #include "gos003.h"
 #include "geo007_2.h"
 #include "gos00k.h"
+#include "RunTime/RTE_DiagPipe.h"
 
 #include <windowsx.h>
 #include <shellapi.h>
@@ -542,6 +543,7 @@ static VOID _System sql80kn_coordinator ( PPROG_ARGS  pArgs )
   strcpy( kgs.szServiceName,     SERVICE_ID);
   strcat( kgs.szServiceName,     pArgs->ppszVal[0] );
 
+  RTE_ConnectToDiagPipe(pArgs->ppszVal[0]);
   rc = sql81k_kernel_main ( pArgs->ppszVal[0],
                             pArgs->ulCount - 1,
                             pArgs->ppszVal + 1 );
