@@ -46,19 +46,20 @@
 #include           "gos44.h"
 #include           "heo15.h"
 #include           "geo43_0.h"
+#include           "heo54k.h"
+#include           "heo670.h"
+#include           "hsp77.h"
 #include           "Trace/Trace_InfoPage.h"
 #include           "RunTime/Diagnose/RTEDiag_ServerCrashHist.h"
 #include           "RunTime/System/RTESys_NTLoadDLLFunc.h"
-#include           "heo54k.h"
 #include           "RunTime/System/RTESys_NTHighResTimer.h"
+#include           "RunTime/System/RTESys_SystemInfo.h"
 #include           "RunTime/RTE_KernelMain.h"
 #include           "RunTime/Threading/RTEThread_Console.h"
 #include           "RunTime/RTE_KSS.h"
-#include           "hsp77.h"
 #include           "RunTime/Configuration/RTEConf_ParameterAccessKernelInterface.h"
 #include           "RunTime/Configuration/RTEConf_ParameterAccessSimple.h"
 #include           "SAPDBCommon/SAPDB_Names.h"
-#include           "heo670.h"
 
 #if defined(_FASTCAP)
 # include "fastcap.h"   /* nocheck */
@@ -395,7 +396,7 @@ BOOL sql81k_hibernation_enabled( VOID )
  * ========================== LOCAL FUNCTIONS =================================
  */
 
-static void sql81PrintStartUpInformation ( SYSTEM_INFO           *SystemInfo)
+static void sql81PrintStartUpInformation ( )
   {
   #undef  MF__
   #define MF__ MOD__"sql81PrintStartUpInformation"
@@ -405,6 +406,7 @@ static void sql81PrintStartUpInformation ( SYSTEM_INFO           *SystemInfo)
   teo00_Int8             TotalVirtual;
   PSZ                    ProductSuite;
   ULONG                  majorVersion;
+  ULONG                  ulNumOfPhysicalProcessors;
 
   MSGD (( INFO_DB_START_SERVERDB,   kgs.szServerDB ));
   /* PTS 1116151 */
@@ -456,7 +458,12 @@ static void sql81PrintStartUpInformation ( SYSTEM_INFO           *SystemInfo)
   if ( ProductSuite )
     MSGD (( INFO_DB_START_PRODUCT_SUITE, ProductSuite));
 
-  MSGD (( INFO_DB_START_NUM_POROCESSORS,       (ULONG) SystemInfo->dwNumberOfProcessors ));
+  ulNumOfPhysicalProcessors = RTESys_NumberOfPhysicalCPUs( );
+  if ( kgs.ulNumOfProcessors != ulNumOfPhysicalProcessors )
+    MSGD (( INFO_DB_START_NUM_LOGICAL_PROCESSORS, ulNumOfPhysicalProcessors, kgs.ulNumOfProcessors ))
+  else
+    MSGD (( INFO_DB_START_NUM_POROCESSORS, kgs.ulNumOfProcessors ));
+
   MSGD (( INFO_DB_START_FIBER, XPARAM(fUseFibers) ? "YES" : "NO" ));
   MSGD (( INFO_DB_START_MAX_ADDRESS,           TotalVirtual >> 20 ));
   MSGD (( INFO_DB_START_PHYSICAL_MEMORY_TOTAL, TotalPhys    >> 20 ));
@@ -611,7 +618,10 @@ static LONG sql81k_startup ( PSZ   pszServerDB )
   kgs.ulSystemPageSize  = (ULONG) SystemInfo.dwPageSize;
   kgs.ulNumOfProcessors = (ULONG) SystemInfo.dwNumberOfProcessors;
 
-  sql81PrintStartUpInformation (&SystemInfo);
+  if ( false == XPARAM(fUseFibers) )
+     XPARAM(uLoadBalancingCheck) = 0;
+
+  sql81PrintStartUpInformation( );
 
   // Memory allocation limit etc...
   RTEConf_HandleSpecialParametersWithMessageOutput();
@@ -1371,26 +1381,7 @@ VOID sql81k_death ( VOID )
       ( kgs.pfTraceFlag    != NULL )            &&
       ( kgs.pTW->TaskState != TSK_INITIALIZED ))
     {
-        SAPDB_Int4      LastTWAlive;
-
-        // --- send a resume tracewriter request
-        SHUTDOWN_RESUME_TRACEWRITER(kgs.pTW);
-
-        kgs.ulTerminationTimeOut = sql50k_get_termination_timeout();
-        MSGD (( INFO_TW_TERM_TIMEOUT, kgs.ulTerminationTimeOut ));
-
-        do
-          {
-          LastTWAlive = kgs.pTW->TaskAlive;
-
-          // --- wait for termination of the tracewriter thread
-          WAIT_THREAD( kgs.pTW->pUKT->ThrdCtrlHeader.hThrd,
-                       kgs.ulTerminationTimeOut );
-
-          // Updating service hint counter to signal we are alive
-          UPDATE_SERVICE_OR_CONSOLE_STATE(*kgs.pDBState);
-          }
-        while ( kgs.pTW->TaskAlive != LastTWAlive );
+        sql50k_resume_tracewriter();
 
         if ( *kgs.pfDump == TRUE )
           vdump_rte();
