@@ -88,7 +88,8 @@ typedef struct
                                    /* PTS 1104224                          */
     UWORD        *arrayStatusPtr;  /* All: Points to array of row/parameter*/
                                    /* status values                        */
-    SDWORD       *bindOffsetPtr;   /* APD/ARD: Pointer to bind offset      */
+  /* http://pts:1080/webpts?wptsdetail=yes&ErrorType=0&ErrorID=1136588 */
+    SQLLEN       *bindOffsetPtr;   /* APD/ARD: Pointer to bind offset      */
     SDWORD        bindType;        /* APD/ARD: Column- or row-wise binding */
     UDWORD       *rowsProcessedPtr;/* IPD/IRD: No of rows processed        */
 } tpa20DescHeader;
@@ -893,13 +894,13 @@ API_RETCODE pa20AllocLong( tpa20Desc *desc_ptr,
  * we dereference BindOffsetPtr and add the value to the dataPtr,
  * octetLengthPtr and indicatorPtr descriptor record fields */
 
-#define PA20_BINDOFFSET(rec) (UDWORD) \
+#define PA20_BINDOFFSET(rec) (SQLLEN) \
  ((rec->bound && rec->parentDesc->header.bindOffsetPtr != NULL) ? \
    *(rec->parentDesc->header.bindOffsetPtr) : 0)
 
 /* for debugging: replace macro with function */
 /*
-UDWORD pa20BindOffset (tpa21DescRecord *rec); 
+SQLLEN pa20BindOffset (tpa21DescRecord *rec); 
 #define PA20_BINDOFFSET(rec) pa20BindOffset(rec) 
 */
 
