@@ -90,9 +90,8 @@ UDWORD pa60_ComputePosition (UDWORD           long_pos,
                              UWORD           *terminatorSize);
 tsp00_Int pa60_ComputeKernelPosition (UDWORD           long_pos,
                                       tpa21DescRecord *impl_rec_ptr);
-
 int pa60_isConnected (tpa40DBC *dbc_block_ptr);
-
+void pa60_initFetchChunk(sqlmfentry *fChunk);
 /*!**********************************************************************
 
   Chapter: ODBC functions
@@ -1020,6 +1019,17 @@ SQLRETURN pa60_DropOneStmt( SQLHSTMT hstmt )
                     state = API_STMT_ALLOCATED;	       
                 }
             }; /* switch */
+
+				    if (stmt_block_ptr->FetchChunk.mfBufinit != cpr_is_false)
+						{
+							apdfree (stmt_block_ptr->FetchChunk.mfrecpointer);
+							apdfree (stmt_block_ptr->FetchChunk.mfBufpointer);
+							stmt_block_ptr->FetchChunk.mfrecpointer = NULL;
+							stmt_block_ptr->FetchChunk.mfBufpointer = NULL;
+					    stmt_block_ptr->FetchChunk.mfrecptrlen = 0;
+							stmt_block_ptr->FetchChunk.mfBufinit = cpr_is_false;
+						}
+
             pa60DropParseIds( stmt_block_ptr );
             stmt_block_ptr -> number_rows = 0;
             stmt_block_ptr -> reconnect_status = API_FALSE;
@@ -2050,6 +2060,7 @@ API_RETCODE pa60apmastmt( SQLHDBC hdbc, SQLHSTMT *phstmt )
     pa06InitNullParseId( stmt_block_ptr->fetch_prior_parsid );
     pa06InitNullParseId( stmt_block_ptr->fetch_relative_parsid );
     pa06InitNullParseId( stmt_block_ptr->fetch_absolute_parsid );
+    pa60_initFetchChunk(&(stmt_block_ptr -> FetchChunk));
     
     if (next_hstmt !=0) {
        stmt_block_ptr = (tpa60Stmt FAR *) apdlock (next_hstmt);
@@ -2213,6 +2224,8 @@ API_RETCODE pa60CloseCursor( tpa40DBC  *dbc_block_ptr,
              stmt_block_ptr -> cursor_name,
              dbc_block_ptr,
              stmt_block_ptr);
+             
+    pa60_initFetchChunk(&(stmt_block_ptr -> FetchChunk));
 
     return TRUE;
 } /* pa60CloseCursor */
@@ -2333,7 +2346,38 @@ int pa60_isConnected (tpa40DBC *dbc_block_ptr)
 
 #endif  /* of _UNICODE_ODBC */
 
-
+static void pa60_initFetchChunk(sqlmfentry *fChunk){
+/*    pr01TracePrintf(sqlca->sqlrap, "mfIndex init      0");*/
+    fChunk->mfInit = 1;
+    fChunk->mfSelectno = 0;
+    fChunk->mfBuflen = 0;
+    pr06ParseIdCopy(&(fChunk->mfSelparsid), ParseIdNull_cpr00);
+    fChunk->mfRecpos = 0;
+    fChunk->mfReclen = 0;
+    fChunk->mfRownotfound = 0;
+    fChunk->mfRecposbeg = 0;
+    fChunk->mfPrevfaspec = 0;
+    fChunk->mfLastfaspec = 0;
+    fChunk->mfMaxselrec = 0;
+    fChunk->mfLastrecno = 0;
+    fChunk->mfBufbegno = 0;
+    fChunk->mfBufendno = 0;
+    fChunk->mfLongcolpos = 0;
+    fChunk->mfFetchget = 0;
+    fChunk->mfsumanzrec = 0;
+    fChunk->mffetchkind = 1;
+    fChunk->mfopendata = 0;
+    fChunk->mfPrecomindex = 0;
+    fChunk->mfActualPos = 0;
+    fChunk->mfNextLoopCnt = -1;
+    fChunk->mfAllRecordsRead = 0;
+    if ((int ) fChunk->mfBufinit == cpr_is_false) {
+        fChunk->mfrecptrlen = 0;
+        fChunk->mfrecpointer= 0;
+    } else {
+       fChunk->mfBufinit = cpr_is_init;
+    }
+}
 /*!**********************************************************************
 
   EndChapter: internal functions
