@@ -249,6 +249,7 @@ void p01version(sqlcatype *sqlca, sqlxatype *sqlxa, tsp00_Int2 kano);
 void p01_katyp_get(sqlcatype *sqlca, sqlxatype *sqlxa);
 void p01usenewparsinfo (sqlcatype *sqlca, sqlxatype *sqlxa, sqlkaentry *ka, sqlorentry *ore, sqlcuentry *cu);
 sqlkaentry *pr01cDupKa(sqlkaentry *kae);
+void pr01cCopyKa(sqlkaentry *dest, sqlkaentry *kae);
 void pr01cFreeKa(sqlkaentry *kae);
 void p01verstrace (sqlcatype *sqlca, sqlxatype *sqlxa, tsp00_Int2 art, tsp00_C40 VAR_ARRAY_REF vers);
 void p01putversion (sqlcatype *sqlca, sqlxatype *sqlxa, int vaind, tsp00_Int4 len, tsp00_C40 VAR_ARRAY_REF vers,  tpr_runtime_errors_Enum *error, void *ptr);
@@ -257,4 +258,8 @@ void pr01cSetLastDataReceived (struct tpr01_SQLDesc *SQLDesc, tsp00_Int4 aValue)
 tsp00_Int4 pr01cGetVaIndex(sqlxatype *sqlxa, tsp00_Int4 index, tsp00_Uint1** pAddr);
 void p01canctrace(sqlcatype *sqlca, sqlxatype *sqlxa, tsp00_Int2 Session);
 void pr01AbortSession (struct tpr01_SQLDesc *SQLDesc);
+tsp00_Int2 pr01cmfentryget(sqlcatype *sqlca, tpr00_ParseId *selparsid , tsp00_Int2 startindex);
+sqlmfentry* pr01getFetchChunk(sqlcatype *sqlca, sqlxatype *sqlxa);
+void pr01setmfetch(sqlcatype *sqlca, sqlxatype *sqlxa, sqlgaentry *ga, sqlfaentry *fa_entry,unsigned char opendata, tsp00_Int4 sqcrowcount);
+void p01bonerecget(sqlcatype *sqlca, sqlxatype *sqlxa, sqlgaentry *ga, sqlmfentry *mfentry);
 #endif
