@@ -121,6 +121,8 @@ static void dumpKey ( tpr09HashValue data_p, char* praefix){
 */
 #endif 
 
+static void initFetchChunk(sqlmfentry *fChunk);
+static void closeFetchChunk(sqlmfentry *fChunk);
 /*==================================================================*
  *  CODE                                                            *
  *==================================================================*/
@@ -291,7 +293,7 @@ static tpr01_CursorDesc *pr01CursorAddDesc(tpr01_CursorContainer *Cursor, tpr05_
                                     sizeof(tpr01_CursorDesc_CursorID),
                                     (tpr09HashValue*)CursorDesc);
 #endif 
-
+    initFetchChunk(&(CursorDesc->FetchChunk));
     CursorDesc->SetAttr = pr01CursorSetAttr;
     CursorDesc->GetAttr = pr01CursorGetAttr;
     pr01CursorInitAttr (CursorDesc);
@@ -318,6 +320,15 @@ static void pr01CursorDeleteDesc(tpr01_CursorDesc *CursorDesc)
     if (CursorDesc->cue) {
       pr03mFree(CursorDesc->cue, "CursorDesc->cue");
     }
+    if (CursorDesc->FetchChunk.mfBufinit != cpr_is_false)
+		{
+			pr03mFree (CursorDesc->FetchChunk.mfrecpointer, "mfrecpointer");
+			pr03mFree (CursorDesc->FetchChunk.mfBufpointer, "mfBufPointer");
+			CursorDesc->FetchChunk.mfrecpointer = NULL;
+			CursorDesc->FetchChunk.mfBufpointer = NULL;
+	    CursorDesc->FetchChunk.mfrecptrlen = 0;
+			CursorDesc->FetchChunk.mfBufinit = cpr_is_false;
+		}
     /*delete cursor name and release memory*/
 #ifdef DYNAHASH  
     pr09DeleteHashItem(CursorDesc->Cursor->Desc, 
@@ -343,7 +354,7 @@ static tpr01_CursorDesc *pr01CursorFindDesc(tpr01_CursorContainer *Cursor, tpr05
   M90TRACE(M90_TR_ENTRY, "pr01CursorFindDesc", 0);
   {
     tpr01_CursorDesc *CursorDesc = NULL;
-    pr01CursorResetIterator(Cursor);
+/*    pr01CursorResetIterator(Cursor); */
     Cursor->cachedCursorID.cursorName = CursorName;
     Cursor->cachedCursorID.UniqueID   = UniqueID;
     CursorDesc = (tpr01_CursorDesc *)pr09FindHashItem(  Cursor->Desc, 
@@ -400,7 +411,7 @@ static void pr01CursorClose(tpr01_CursorDesc *CursorDesc)
       tpr01_CursorContainer *Cursor = CursorDesc->Cursor;
       if (CursorDesc->OpenKa) 
       {
-        pr01cFreeKa(CursorDesc->OpenKa);
+/*        pr01cFreeKa(CursorDesc->OpenKa);*/
         CursorDesc->OpenKa = NULL; 
       }
       if (CursorDesc->FetchKa) 
@@ -410,10 +421,10 @@ static void pr01CursorClose(tpr01_CursorDesc *CursorDesc)
         sqlxatype *sqlxa = CursorDesc->ConDesc->sqlxa;
         sqlgaentry *ga   = CursorDesc->ConDesc->ga;
         sqlkaentry *ka   = CursorDesc->FetchKa;  
-        p01bdrop_parsid (sqlca, sqlxa, ka->kaParseInfo.ParseId);
         pr06ParseIdDrop(sqlca, sqlxa, ga, (tpr06_ParseIDCache *)CursorDesc->ConDesc->ParseIdCache, &ka->kaParseInfo.ParseId);
-        pr01cFreeKa(CursorDesc->FetchKa);
-	CursorDesc->FetchKa = NULL;
+        initFetchChunk(&(CursorDesc->FetchChunk));
+        /*pr01cFreeKa(CursorDesc->FetchKa);*/
+	      CursorDesc->FetchKa = NULL;
       }
       if (CursorDesc->CloseKa) 
       {
@@ -437,7 +448,9 @@ static void pr01CursorPrepareOpen(tpr01_CursorDesc *CursorDesc, sqlkaentry *ka)
     /* PTS 1110677 */
     Cursor->Close(CursorDesc);
     if (!CursorDesc->OpenKa) {
-      CursorDesc->OpenKa = pr01cDupKa(ka);
+/*      CursorDesc->OpenKa = pr01cDupKa(ka);*/
+        CursorDesc->OpenKa = &(CursorDesc->OpenKaStruct);
+        pr01cCopyKa(CursorDesc->OpenKa, ka);
       if (CursorDesc->StmtNameDesc) {
 	tpr01_StmtNameDesc *StmtNameDesc = CursorDesc->StmtNameDesc;
 	if (StmtNameDesc->ka->kapacount > 0) {
@@ -470,15 +483,18 @@ static void pr01CursorPrepareFetch(tpr01_CursorDesc *CursorDesc, struct tpr01_St
   PR07_CHECKDESC(CursorDesc, CursorDesc_epr01);
   PR07_CHECKDESC(StmtNameDesc, StmtNameDesc_epr01);
   {
-    if (!CursorDesc->FetchKa) {
-      CursorDesc->FetchKa = pr01cDupKa(StmtNameDesc->ka);
-    }
     if (CursorDesc->FetchStmtNameDesc != StmtNameDesc) {
-        pr01cFreeKa(CursorDesc->FetchKa);
-        CursorDesc->FetchKa = pr01cDupKa(StmtNameDesc->ka);
+        /*pr01cFreeKa(CursorDesc->FetchKa);*/
+        CursorDesc->FetchKa = NULL; 
+    }
+    if (!CursorDesc->FetchKa) {
+/*      CursorDesc->FetchKa = pr01cDupKa(StmtNameDesc->ka);*/
+      CursorDesc->FetchKa = &(CursorDesc->FetchKaStruct); 
+      pr01cCopyKa(CursorDesc->FetchKa, StmtNameDesc->ka);
     }
     CursorDesc->FetchStmtNameDesc = StmtNameDesc;
-    CursorDesc->FetchKa->kacuindex = CursorDesc->OpenKa->kacuindex;
+    if (CursorDesc->OpenKa)
+      CursorDesc->FetchKa->kacuindex = CursorDesc->OpenKa->kacuindex;
   }
   M90TRACE(M90_TR_EXIT, "pr01CursorPrepareFetch", 0);
 }
@@ -593,7 +609,7 @@ void pr01CursorAlterParseid (tpr01_SQLDesc *SQLDesc)
         ) {
          if ( CursorDesc ) {
            CursorDesc->GetAttr (CursorDesc, useNewParseInfo_epr01Cursor, &useNewParseInfo, &sz);
-           if (   pr06ParseIdIsEqual(&ka->kaParseInfo.ParseId, ParseIdNull_cpr00)
+           if (   pr06ParseIdIsNull(&ka->kaParseInfo.ParseId)
                || useNewParseInfo ) {
              pr06ParseInfoCopy(&ka->kaParseInfo, &StmtNameDesc->ka->kaParseInfo);
              useNewParseInfo = FALSE;
@@ -757,4 +773,45 @@ static tpr09HashIndex pr01Cursor_hashFunc (const tpr09HashKey HashKey, tsp00_Uin
     return ((tpr09HashIndex)cursorID->UniqueID%cbHashTabLen);
   }  
 }
+
 #endif 
+
+static void closeFetchChunk(sqlmfentry *fChunk){
+     fChunk->mfInit = 0;
+     fChunk->mfSelectno = 0;
+     pr06ParseIdCopy(&(fChunk->mfSelparsid), ParseIdNull_cpr00);
+}
+
+static void initFetchChunk(sqlmfentry *fChunk){
+/*    pr01TracePrintf(sqlca->sqlrap, "mfIndex init      0");*/
+    fChunk->mfInit = 1;
+    fChunk->mfSelectno = 0;
+    fChunk->mfBuflen = 0;
+    pr06ParseIdCopy(&(fChunk->mfSelparsid), ParseIdNull_cpr00);
+    fChunk->mfRecpos = 0;
+    fChunk->mfReclen = 0;
+    fChunk->mfRownotfound = 0;
+    fChunk->mfRecposbeg = 0;
+    fChunk->mfPrevfaspec = 0;
+    fChunk->mfLastfaspec = 0;
+    fChunk->mfMaxselrec = 0;
+    fChunk->mfLastrecno = 0;
+    fChunk->mfBufbegno = 0;
+    fChunk->mfBufendno = 0;
+    fChunk->mfLongcolpos = 0;
+    fChunk->mfFetchget = 0;
+    fChunk->mfsumanzrec = 0;
+    fChunk->mffetchkind = 1;
+    fChunk->mfopendata = 0;
+    fChunk->mfPrecomindex = 0;
+    fChunk->mfActualPos = 0;
+    fChunk->mfNextLoopCnt = -1;
+    fChunk->mfAllRecordsRead = 0;
+    if ((int ) fChunk->mfBufinit == cpr_is_false) {
+        fChunk->mfrecptrlen = 0;
+        fChunk->mfrecpointer= 0;
+    } else {
+       fChunk->mfBufinit = cpr_is_init;
+    }
+}
+
