@@ -13,7 +13,7 @@
 
 
     ========== licence begin  GPL
-    Copyright (c) 2000-2004 SAP AG
+    Copyright (c) 2000-2005 SAP AG
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@
 
 
 
+
  ===================================================================*/
 
 #ifndef __VPR01_CURSOR_H__
@@ -80,10 +81,13 @@ typedef struct tpr01_CursorDesc {
   struct tpr01_StmtNameDesc    *StmtNameDesc;
   struct tpr01_ConDesc         *ConDesc;
   sqlkaentry *OpenKa;
+  sqlkaentry OpenKaStruct;
   struct tpr01_StmtNameDesc    *FetchStmtNameDesc;
   sqlkaentry *FetchKa;
+  sqlkaentry FetchKaStruct;
   sqlkaentry *CloseKa;
   tpr01_CursorAttribute Attribute;
+  sqlmfentry FetchChunk;
   BOOLEAN (*SetAttr) (struct tpr01_CursorDesc *CursorDesc, epr01Cursor_Attr Attr, 
 		      void *pAttr, tsp00_Int4 cbLen);
   void    (*GetAttr) (struct tpr01_CursorDesc *CursorDesc, epr01Cursor_Attr Attr, 
