@@ -310,7 +310,7 @@ static tsp00_Int4 pr01ParseInfoDeleteDesc(tpr01_ParseInfoDesc *ParseInfoDesc, ts
            sqlxatype *sqlxa = ConDesc->sqlxa;
            sqlcatype *sqlca = ConDesc->sqlca;
            sqlgaentry *ga = ConDesc->ga;
-           p01bdrop_parsid (sqlca, sqlxa, (ParseInfoDesc->ParseInfos.ParseId));
+/*           p01bdrop_parsid (sqlca, sqlxa, (ParseInfoDesc->ParseInfos.ParseId));*/
            pr06ParseIdDropIntoCache(sqlca, sqlxa, ga, (tpr06_ParseIDCache *)ConDesc->ParseIdCache, &(ParseInfoDesc->ParseInfos.ParseId));
          }
          pr01ParseInfo_ParseInfosDelete(ParseInfoDesc);
