@@ -703,8 +703,7 @@ static void pr01StmtNameDropParsId(tpr01_StmtNameDesc *StmtNameDesc, tpr01_SQLDe
     sqlxatype *sqlxa = SQLDesc->ConDesc->sqlxa;
     sqlgaentry *ga   = SQLDesc->ConDesc->ga;
     sqlkaentry *ka = StmtNameDesc->ka;  
-    if (!pr06ParseIdIsEqual(&ka->kaParseInfo.ParseId, ParseIdNull_cpr00)) {    
-      p01bdrop_parsid (sqlca, sqlxa, ka->kaParseInfo.ParseId);
+    if (!pr06ParseIdIsNull(&ka->kaParseInfo.ParseId)) {    
       pr06ParseIdDrop(sqlca, sqlxa, ga, (tpr06_ParseIDCache *)SQLDesc->ConDesc->ParseIdCache, &ka->kaParseInfo.ParseId);
       StmtNameDesc->ka->kastate = cpr_state_empty;
       StmtNameDesc->ka->kaParseInfo.sp1rFunctionCode = csp1_nil_fc;  
