@@ -724,7 +724,7 @@ void pr01cEnd(tpr01_SQLDesc *SQLDesc)
           {
             p01pparsidtrace(sqlca, sqlxa, ka, ka->kaParseInfo.ParseId, TraceParseIDAgain_epr00);
           }
-        p01bdrop_parsid (sqlca, sqlxa, ka->kaParseInfo.ParseId);
+/*        p01bdrop_parsid (sqlca, sqlxa, ka->kaParseInfo.ParseId); */
         if (SQLDesc->ConDesc->ParseIdCache)
           {
             pr06ParseIdDrop(sqlca, sqlxa, gae, (tpr06_ParseIDCache *)SQLDesc->ConDesc->ParseIdCache, &ka->kaParseInfo.ParseId);
@@ -908,7 +908,7 @@ void pr01cDynmfetch(tpr01_SQLDesc *SQLDesc)
               }
 	    else
               {
-	        *sqlloop = sqlpa->lo.paloopmin;
+	        *sqlloop = (sqlpa->lo.paloopmin==0) ? 1 : sqlpa->lo.paloopmin;
               }
           }
         else
@@ -1204,8 +1204,10 @@ tsp00_Int4 pr01cParse(tpr01_SQLDesc *SQLDesc, tsp00_Int2 *cmdfetch, tsp00_Int4 *
       p04sfi (sqlca, sqlxa, Describe_Params_epr00);
       if ((sqlca->sqldbmode != cpr_kind_internal) && SQLDesc->CursorDesc)
         p01resallocinfo(sqlca, sqlxa, ka, SQLDesc->CursorDesc->StmtNameDesc->ore);
-      /*looking for a corresponding mfetch buffer, adding a new buffer if not found*/
+      /*looking for a corresponding mfetch buffer, adding a new buffer if not found
       p01baparsen (sqlca, sqlxa, gae, ka, cmdfetch);
+      */
+      sqlca->sqlmfetch = 1; /*mass fetch enabled*/
     }
     /*consistence checks for select direct fast*/
     if (ka->kapacount < -3) {
@@ -1263,12 +1265,36 @@ sqlkaentry *pr01cDupKa(sqlkaentry *kae)
   return kaedup;
 }
 
+void pr01cCopyKa(sqlkaentry *dest, sqlkaentry *kae)
+{
+  if (kae && dest) {
+    memcpy(dest, kae, sizeof(sqlkaentry));
+    if (kae->kafaindex > 0) {
+      if (dest->kafae == NULL) { 
+        dest->kafae = pr03mAllocat(sizeof(sqlfaentry), "kae->kafae");
+        memset(dest->kafae, 0, sizeof(sqlfaentry));
+      } 
+    }
+    else {
+      if (dest->kafae == NULL) { 
+        pr03mFree(kae->kafae, "kae->kafae");
+      }  
+      dest->kafae = NULL;
+    }
+  }
+  else {
+    memset(dest, 0, sizeof(sqlkaentry));
+  }
+}
+
 void pr01cFreeKa(sqlkaentry *kae)
 {
-  if (kae->kafae) {
-    pr03mFree(kae->kafae, "kae->kafae");
+  if (kae){
+      if (kae->kafae) {
+        pr03mFree(kae->kafae, "kae->kafae");
+      }
+      pr03mFree(kae, "kae");
   }
-  pr03mFree(kae, "kae");
 }
 
 /*!
@@ -1329,7 +1355,7 @@ tsp00_Int4 pr01cResultNameGet(sqlratype *sqlrap, sqlgaentry *gae, tsp00_Byte *sz
    Geandert werden muessen zusaetzlich die Shortfieldinfos in der or Area */
 void pr01cUseNewParseInfo(tpr01_SQLDesc *SQLDesc)
 {
-  tsp00_Int2 mfindex;
+  sqlmfentry *mfentry;
 
   if (SQLDesc) {
     tpr01_SQLContainer *SQL = SQLDesc->SQL;
@@ -1346,9 +1372,9 @@ void pr01cUseNewParseInfo(tpr01_SQLDesc *SQLDesc)
     p01pparsidtrace (sqlca, sqlxa, SQLDesc->ka,
                      OldParseInfo.ParseId, TraceParseIDChange_epr00);
     p01pparsidtrace (sqlca, sqlxa, SQLDesc->ka, NewParseInfo.ParseId, TraceParseIDNew_epr00);
-    mfindex = p01bmfentryget(sqlca, sqlxa, OldParseInfo.ParseId);
-    if  (mfindex > 0) {
-      memcpy(&sqlca->sqlmfp->mfentry[mfindex-1].mfSelparsid, &NewParseInfo.ParseId, ParseId_mxpr00 );
+    mfentry = pr01getFetchChunk(sqlca, sqlxa) ;
+    if  (mfentry) {
+      memcpy(&(mfentry->mfSelparsid), &NewParseInfo.ParseId, ParseId_mxpr00 );
     }
     pr06ParseInfoCopy(&SQLDesc->ka->kaParseInfo, &NewParseInfo);
 
@@ -1469,19 +1495,15 @@ static void p01copendata(sqlcatype* sqlca, sqlxatype* sqlxa, sqlkaentry* kae, sq
       
     }
     if (selparsid) {
-      if ( ! pr06ParseIdIsEqual(selparsid, (tpr00_ParseId*)CPR_PARSIDNULL) ) {
-        int i= 1;
+      if ( ! pr06ParseIdIsNull(selparsid)) {
+        mfentry = pr01getFetchChunk(sqlca, sqlxa);
         p01pparsidtrace(sqlca, sqlxa, kae, *selparsid, TraceParseIDSelect_epr00);
-        for (i=1; i <= sqlca->sqlmfetch; i++) {
-          /*looking for corresponding mfentry in mass fetch buffer*/
-          mfentry = &(sqlca->sqlmfp->mfentry[i + -1]);
-          if (   pr06ParseIdIsEqual((tpr00_ParseId*)&(mfentry->mfSelparsid) , selparsid)
-               &&mfentry->mfopendata == 1) {
+
+        if (mfentry &&mfentry->mfopendata == 1){
             datafound = 1;
             kae->kaopendata = 1;
             faentry = (sqlfaentry *) kae->kafae;
             faentry->faselectno = mfentry->mfSelectno;
-            faentry->famfindex = (short ) i;
             faentry->fapos = 0;
             faentry->faspec = 3;
             faentry->fafetch = 1;
@@ -1490,9 +1512,8 @@ static void p01copendata(sqlcatype* sqlca, sqlxatype* sqlxa, sqlkaentry* kae, sq
               segptr = &( ((tsp1_packet*)mfentry->mfBufpointer)->variant.C_2.sp1_segm_F);
               segptr->sp1s_segm_header.sp1r_function_code = csp1_mfetch_next_fc;
             }
-            break;  
-          }
         }
+          
       }
       if (datafound) {
         ore = pr01cFromOpenGetOr(sqlxa->xaSQLDesc);
@@ -1573,3 +1594,250 @@ tsp00_Int4 pr01cGetVaIndex(sqlxatype *sqlxa, tsp00_Int4 index, tsp00_Uint1** pAd
   return vaind-1;
 }
 
+/*---------------------------------------------------------------------------*/
+#ifndef SQLODBC  
+sqlmfentry* pr01getFetchChunk(sqlcatype *sqlca, sqlxatype *sqlxa){
+  tpr01_CursorDesc* CursorDesc = (tpr01_CursorDesc*)sqlxa->xaSQLDesc->CursorDesc;
+  if (CursorDesc){  
+    return &(CursorDesc->FetchChunk);
+  } else {
+    return NULL;
+  }
+}
+#else
+sqlmfentry* pr01getFetchChunk(sqlcatype *sqlca, sqlxatype *sqlxa){
+  return sqlca->sqlmfp->mfFetchChunk;
+}
+#endif
+/*---------------------------------------------------------------------------*/
+void pr01xballocate(sqlcatype *sqlca, sqlgaentry *ga, sqlmfentry *mfentry){
+    tsp00_Int4 len;
+    tsp00_Int4 oldlen;
+    char ok;
+
+    if ((int ) mfentry->mfBufinit == cpr_is_false || ! mfentry->mfBufpointer)  {
+      ok = 1;
+      len = ((tsp1_packet*)ga->garecptr)->sp1_header.sp1h_varpart_size + (long)sizeof(tsp1_packet_header );
+      mfentry->mfBufpointer = pr03mAllocat (len, "mfBufPointer");
+      if (! mfentry->mfBufpointer)  {
+         ok = 0;
+      }
+/*      if (ok){
+//        mfentry->mfrecptrlen = (int ) mfentry->mfReclen;
+//        if ((int ) mfentry->mfReclen > 0){
+//          mfentry->mfrecpointer = pr03mAllocat (mfentry->mfrecptrlen, "mfrecpointer");
+//          if (!mfentry->mfrecpointer)  {
+//            ok = 0;
+//          }
+//        }else {
+//           mfentry->mfrecpointer = 0;
+//           ok = 1;
+//        }
+//      }
+*/
+    } else {
+      ok = 1;
+      len = ((tsp1_packet*)ga->garecptr)->sp1_header.sp1h_varpart_size + (long)sizeof(tsp1_packet_header );
+      oldlen = ((tsp1_packet*)mfentry->mfBufpointer)->sp1_header.sp1h_varpart_size + (long)sizeof(tsp1_packet_header );
+      if (oldlen < len) {
+        pr03mFree(mfentry->mfBufpointer , "mfBufpointer");
+        mfentry->mfBufpointer = pr03mAllocat (len, "mfBufPointer");
+        if (! mfentry->mfBufpointer) {
+          ok = 0;
+        }
+      }
+/*      if (ok) {
+//        if (mfentry->mfrecptrlen < (int ) mfentry->mfReclen) {
+//          pr03mFree(mfentry->mfrecpointer , "mfrecpointer");
+//          mfentry->mfrecptrlen = (int ) mfentry->mfReclen;
+//          mfentry->mfrecpointer = pr03mAllocat (mfentry->mfrecptrlen, "mfrecpointer");
+//        }
+//      }
+*/
+    }
+    if (ok) {
+       mfentry->mfBufinit = cpr_is_true;
+    }
+
+
+}
+
+/*---------------------------------------------------------------------------*/
+
+void pr01setmfetch(sqlcatype *sqlca, sqlxatype *sqlxa, sqlgaentry *ga, sqlfaentry *fa_entry,unsigned char opendata, tsp00_Int4 sqcrowcount)    {
+ 
+ /*
+    tsp00_Int4 lint;
+    tsp_num_error res;
+    int i;
+    tsp_name nam;
+    tsp_knl_identifier resname;
+    tsp1_packet_header var_tsp1_packet_header;
+*/ 
+    int anz;
+    tpr00_ParseId parsid;
+    tsp1_part_ptr part_ptr;
+    tsp00_Int4 headerlen;
+    sqlmfentry* mfentry1 = pr01getFetchChunk(sqlca , sqlxa);
+    
+    if (sqlca->sqlemp->ereturncode != 0){
+      return;
+    }
+    
+    if (!opendata) {
+        p03gselparsid(sqlca->sqlrap , sqlca->sqlemp , parsid , &(*ga).gaKnlSessionID);
+        if (pr06ParseIdIsNull(&parsid)) {
+            p08runtimeerror(&(*sqlca) , &(*sqlxa) , cpr_select_parsid_missing);
+            return; 
+        }
+    } else {   
+        p03cresultcount(sqlca->sqlrap , &sqlca->sqlerrd[2], &part_ptr);
+        if (sqlca->sqlerrd[2] != 1)  {
+          if (part_ptr){
+            memcpy (part_ptr->sp1p_buf+1, CPR_NUMB1, MXPR_NUMB);
+            part_ptr->sp1p_buf[0] = (unsigned char)'\0';
+          }
+        }
+    }
+    mfentry1->mfBuflen = 0;
+    mfentry1->mfActualPos = 0;
+    mfentry1->mfNextLoopCnt = -1;
+    mfentry1->mfAllRecordsRead = 0;
+    anz = 0;
+    p03find_part(sqlca->sqlrap , sp1pk_data , &part_ptr);
+    if (part_ptr)  {
+      mfentry1->mfBuflen = part_ptr->sp1p_part_header.sp1p_buf_len;
+      anz = part_ptr->sp1p_part_header.sp1p_arg_count;
+      if (1 && (part_ptr->sp1p_part_header.sp1p_attributes[0] & 1) != 0 && opendata) {
+          mfentry1->mfMaxselrec = (int ) part_ptr->sp1p_part_header.sp1p_arg_count;
+      } else {
+        if (mfentry1->mfMaxselrec > 0) {
+          mfentry1->mfMaxselrec = mfentry1->mfMaxselrec + anz;
+        }else {
+          mfentry1->mfMaxselrec = anz;
+        }
+      }
+    }
+    mfentry1->mfFetchget = 2;
+    mfentry1->mfRecpos = 1;
+    mfentry1->mfRecposbeg = mfentry1->mfRecpos;
+/*    _ptoc_ASSIGN(unsigned char , 16, mfentry1->mfSelparsid, parsid)*/
+    if (anz == 0) {
+      sqlca->sqlerrd[2] = 0;
+      sqlca->sqlemp->ereturncode = 100;
+      memcpy(sqlca->sqlemp->etext,"ROW NOT FOUND     ",18);  
+      sqlca->sqlemp->etextlen = 18;
+      mfentry1->mfRownotfound = 1;
+      mfentry1->mfBufbegno = 0;
+      mfentry1->mfBufendno = 0;
+      mfentry1->mfLastrecno = 0;
+    } else {
+        mfentry1->mfRownotfound = 0;
+        mfentry1->mfReclen = fa_entry->fareclen;
+        mfentry1->mfLongcolpos = mfentry1->mfReclen * anz + 1;
+        if (mfentry1->mfBuflen + mfentry1->mfReclen <= part_ptr->sp1p_part_header.sp1p_buf_size 
+            && sqcrowcount != anz) {
+           if (mfentry1->mfLastfaspec == 0 && mfentry1->mfMaxselrec < 0) {
+             if (fa_entry->faspec == 7 || fa_entry->faspec == 8) {
+               mfentry1->mfMaxselrec = fa_entry->fapos + anz + -1;
+             } else {
+               mfentry1->mfMaxselrec = mfentry1->mfBufendno + anz;
+             }
+           }
+        }
+        switch (fa_entry->faspec){
+          case CPR_FE_FETCH :
+          case CPR_FE_NEXT : {
+              mfentry1->mfBufbegno = mfentry1->mfBufendno + 1;
+              mfentry1->mfBufendno = anz + mfentry1->mfBufbegno + -1;
+              mfentry1->mfLastrecno = mfentry1->mfBufbegno + -1;
+              break;
+          }    
+          case CPR_FE_FIRST : {
+              mfentry1->mfBufbegno = 1;
+              mfentry1->mfBufendno = anz + mfentry1->mfBufbegno + -1;
+              mfentry1->mfLastrecno = mfentry1->mfBufbegno + -1;
+              break;
+          }    
+          case CPR_FE_LAST : {
+              mfentry1->mfLastfaspec = 4;
+              mfentry1->mfBufendno = -1;
+              mfentry1->mfBufbegno = mfentry1->mfBufendno - anz + 1;
+              mfentry1->mfLastrecno = mfentry1->mfBufendno + -1;
+              mfentry1->mfRecpos = mfentry1->mfRecpos + (anz + -1) * (int ) mfentry1->mfReclen;
+              mfentry1->mfActualPos = mfentry1->mfRecpos + -1;
+              break;
+          }
+          case CPR_FE_PREV : {
+            if ( mfentry1->mfLastfaspec == 0 && mfentry1->mfBufendno != 0) {
+              mfentry1->mfBufendno = mfentry1->mfBufbegno + -1;
+            } else {
+              mfentry1->mfBufendno = anz;
+            }
+            mfentry1->mfBufbegno = mfentry1->mfBufendno - anz + 1;
+            mfentry1->mfLastrecno = mfentry1->mfBufendno + -1;
+            mfentry1->mfRecpos = mfentry1->mfRecpos + (anz + -1) * (int ) mfentry1->mfReclen;
+            mfentry1->mfActualPos = mfentry1->mfRecpos + -1;
+            break;
+          }    
+          case CPR_FE_SAME : {
+            if ((int ) mfentry1->mfLastfaspec == 0 && mfentry1->mfBufendno != 0){
+              mfentry1->mfBufbegno = mfentry1->mfBufendno;
+            } else {
+              mfentry1->mfBufbegno = 1;
+            }
+            mfentry1->mfBufendno = anz + mfentry1->mfBufbegno + -1;
+            mfentry1->mfLastrecno = mfentry1->mfBufbegno + -1;
+            break;
+          }
+          case CPR_FE_POSC :
+          case CPR_FE_POSV : {
+            mfentry1->mfBufbegno = fa_entry->fapos;
+            mfentry1->mfBufendno = anz + mfentry1->mfBufbegno + -1;
+            mfentry1->mfLastrecno = mfentry1->mfBufbegno + -1;
+            break;
+          }   
+          case CPR_FE_RELC :
+          case CPR_FE_RELV : {
+            if (fa_entry->fapos >= 0) {
+              mfentry1->mfBufbegno = mfentry1->mfBufendno + fa_entry->fapos;
+            } else {
+              mfentry1->mfBufbegno = mfentry1->mfBufbegno + fa_entry->fapos;
+            }
+            mfentry1->mfBufendno = anz + mfentry1->mfBufbegno + -1;
+            mfentry1->mfLastrecno = mfentry1->mfBufbegno + -1;
+            break;
+          }    
+          default : {
+              p08runtimeerror(&(*sqlca) , &(*sqlxa) , cpr_select_parsid_missing);
+              break;
+          } 
+        }
+        pr01xballocate(sqlca, ga, mfentry1);
+        if (mfentry1->mfBufpointer == 0){
+          p08runtimeerror(&(*sqlca) , &(*sqlxa) , cpr_memory_allocation_faild);
+        } else {
+          headerlen = (long)sizeof(tsp1_packet_header );
+		      memcpy (mfentry1->mfBufpointer, 
+		              ga->garecptr, 
+		              ((tsp1_packet*)ga->garecptr)->sp1_header.sp1h_varpart_len + headerlen );
+
+/*     		  memcpy (mfentry1->mfrecpointer, part_ptr->sp1p_buf, mfentry1->mfReclen );*/
+          ga->garecptr = mfentry1->mfBufpointer;
+          sqlca->sqlrap->rasegptr = &((tsp1_packet*)mfentry1->mfBufpointer)->sp1_segm;
+          p03partptrinit(sqlca->sqlrap);
+          memcpy (mfentry1->mfsegmpartptr, sqlca->sqlrap->rasegmpartptr, sizeof(tpr00_PartCache));
+        }
+        if (!opendata)    {
+          p01bonerecget(sqlca, sqlxa,ga, mfentry1);
+          mfentry1->mfRecpos = mfentry1->mfRecpos + (int ) mfentry1->mfReclen;
+          mfentry1->mfLastrecno = mfentry1->mfLastrecno + 1;
+          mfentry1->mfPrevfaspec = fa_entry->faspec;
+          if (sqlca->sqldbmode == CPR_KIND_ORACLE || (int ) sqlca->sqldbmode == CPR_KIND_SAPR3) {
+            sqlca->sqlerrd[2] = mfentry1->mfLastrecno;
+          } else {
+            sqlca->sqlerrd[2] = 1;
+          }
+        }
+      }
+    }
