@@ -467,13 +467,14 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
     ka = sqlxa->xaSQLDesc->ka;
 
     da->sqloffset = 0;
-    da->sqlloop = (ka->kapaindex == 0) ? 0 : (ka->kapaindex < 0)
+    da->sqlloop = (ka->kapaindex == 0) ? 1 : (ka->kapaindex < 0)
       ? 2 : (p08runtimeerror (sqlca, sqlxa, cpr_not_implemented), 0);
   }
   p04mode (sqlca, gae);
   if (lp->lpfirsti == cpr_is_true) {
     datapart->sp1p_part_header.sp1p_attributes[0] |= 1 << sp1pa_first_packet;
     lp->lpfirsti = cpr_is_false;
+    lp->lpcnt = 1;
     if (da->sqlloop != 0) {
       if (sqlca->sqlrap->ralang != CPR_LA_CALL) {
 	da->sqloffset = lp->lpindi;
@@ -492,7 +493,7 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
       else {
 	trfirst = 1;
 	lp->lpcnt = lpcnt;
-	pr04oPutResultCount(cnt, 0);
+	pr04oPutResultCount(cnt, lpcnt);
       }
     }
   }
@@ -516,11 +517,6 @@ p04oradin (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, sqlcuentry *cu
 	|| *pid == csp1_p_for_upd_mselect_found
 	|| *pid == csp1_p_reuse_upd_mselect_found)
       *pid -= csp1_p_mass_command;
-    else {
-      if (sqlca->sqlrap->ralang != CPR_LA_CALL)
-	if (*pid == csp1_p_mfetch_found)
-	  *pid = csp1_p_fetch_found;
-    }
     /*bf 11.4.96 "parse mfetch" nur dynamisch internal-mode */
     if (sqlca->sqlrap->ralang == CPR_LA_CALL) {
       if ((*pid == csp1_p_mfetch_found)
@@ -747,9 +743,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
   tsp00_Int2       *ldmaxo = &ldp->ldmaxo;
   tsp00_Int2       *ldcolkind = &ldp->ldcolkind;
   tsp00_Int2        dbmode = sqlca->sqlrap->rakamode;
-  tsp00_Int2       kafaindex;
-  tsp00_Int2       famfindex;
-  tsp00_Int4       temppos = 0;
+  tsp00_Int4        temppos = 0;
   tsp00_Int4       *lppos = &temppos;
   /* ADIS 1001733	*/
   tsp00_Int4       *lpRecpos = &temppos;
@@ -772,6 +766,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
   tsp00_Uint1 *data;
   tsp00_Int4 *nextlpcnt = NULL;
   tsp00_Int4 *lastrecord = NULL;
+  sqlmfentry *mf = NULL;
 
   if (da->sqlrow.oreclen == 0 || sqlca->sqlcode != 0) {
     return;
@@ -836,6 +831,7 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
       lpcnt = da->sqlloop;
     }
   }
+/*
   if (sqlca->sqlrap->ralang != CPR_LA_CALL) {
     kafaindex = sqlxa->xaSQLDesc->ka->kafaindex;
     if (kafaindex > 0)
@@ -845,8 +841,9 @@ p04oradout (sqlcatype * sqlca, sqlxatype * sqlxa, sqlgaentry *gae, void *sqlda,
   }
   else
     famfindex = da->sqlkano;
-  if (famfindex > 0) {
-    sqlmfentry *mf = &sqlca->sqlmfp->mfentry[famfindex-1];
+*/
+  mf = pr01getFetchChunk(sqlca, sqlxa);
+  if (mf && mf->mfBufinit == cpr_is_true) {
     nextlpcnt = &mf->mfNextLoopCnt;
     lppos = &mf->mfActualPos;
     lastrecord = &mf->mfAllRecordsRead;
