@@ -23,6 +23,7 @@
 */
 package com.sap.dbtech.jdbc;
 
+import java.sql.ParameterMetaData;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
@@ -517,9 +518,15 @@ public class DatabaseMetaDataMaxDB
                         ps.setString(pcount, tablepattern);
                         ++pcount;
                 }
+                ParameterMetaData pmd = ps.getParameterMetaData();
                 if(types != null) {
                         for(int k=0; k<types.length; ++k) {
-                                ps.setString(pcount, types[k]);
+                        		if(types[k].length() > 
+                        			pmd.getPrecision(pcount)) {
+                        			ps.setNull(pcount, Types.CHAR);
+                        		} else {
+                        			ps.setString(pcount, types[k]);
+                        		}
                                 ++pcount;
                         }
                 }
