@@ -25,7 +25,6 @@
 package com.sap.dbtech.jdbc;
 
 import java.io.*;
-//import java.security.MessageDigest;
 import java.sql.*;
 import com.sap.dbtech.util.*;
 import com.sap.dbtech.rte.comm.*;
@@ -42,7 +41,7 @@ public class DriverSapDB
     static public boolean isJDBC20 = detectJDBC20 ();
     static VersionInfo jdbcDriverVersion;
     static final String protocolName_C = "jdbc:sapdb:";
-    static final String dllName_C = "sapdbcbin";
+    static final public String nativeCommunication_dllName_C = "sapdbcbin";
     static final String loadbinProperty_C = "com.sap.dbtech.jdbc.loadbin";
     static final String osNameProperty_C = "os.name";
     static final String osLinuxString_C = "Linux";
@@ -63,7 +62,6 @@ public class DriverSapDB
         try {
             String vers = System.getProperty("java.version");
             int startpos=vers.indexOf('1');
-            int verslen=vers.length();
             if(startpos==-1) {
                 return JAVA_1_3;
             }
@@ -108,6 +106,8 @@ public class DriverSapDB
     static final String communicationtimeout_C = "communicationtimeout";
     static final String authentication_C = "authentication";
     static final String encrytption_C = "encryption";
+    static final String useDefaultValueForUpdatableRS_C = "useDefaultValueForUpdatableRS";
+    static final String connecttype_C = "connecttype";
 
     // internal information about connection
     static final String dburlName_C = "dburl";
@@ -174,7 +174,8 @@ public class DriverSapDB
             return null;
         }
         url = this.parseURLProperties (url, info);
-        wrapSession = this.openTrace (url, info);
+        wrapSession = openTrace (url, info);
+        Tracer.print ("new Connection '"+ url+"'", info);
         try {
             session = this.openByURL (url, info);
         }
@@ -201,7 +202,7 @@ public class DriverSapDB
     /**
      *
      */
-    final private boolean
+    final static public boolean
         openTrace (
         String url,
         java.util.Properties info)
@@ -225,12 +226,17 @@ public class DriverSapDB
 //        if (trace == null) {
 //            String context = Thread.currentThread().getContextClassLoader().toString();
 //            try {
-//                MessageDigest md5 = MessageDigest.getInstance("MD5");
+//                java.security.MessageDigest md5 = java.security.MessageDigest.getInstance("MD5");
 //                byte [] data = md5.digest(context.getBytes());
-//                context = data.toString();
+//                context = Tracer.Hex2String(data);
 //            } catch (Exception e) {
 //            }
-//            trace="C://temp/jdbc_trace/MaxDBJDBCTrace_"+context+".prt";
+//            String osName = System.getProperty ("os.name", "<unknown>").toUpperCase();     
+//            if ((osName != null) && osName.startsWith("WINDOWS")) {
+//                trace="c://temp/MaxDBJDBCTrace_"+context+".prt";
+//            } else{
+//              trace="/tmp/MaxDBJDBCTrace_"+context+".prt";
+//            }  
 //        }
         if (trace != null) {
             result = true;
@@ -246,8 +252,7 @@ public class DriverSapDB
               java_version = System.getProperty ("java.version", "<unknown>");
             }
             catch (java.security.AccessControlException ignore) {}
-            Tracer.println (this.getVersionString () + " on Java " + java_version);
-            Tracer.print ("new Connection '"+ url+"'", info);
+            Tracer.println (getVersionString () + " on Java " + java_version);
         }
         /*
          * extended trace for specific bugs
@@ -370,7 +375,7 @@ public class DriverSapDB
      *
      * @return java.lang.String
      */
-    final String getVersionString () {
+    final public static String getVersionString () {
         return getStaticVersion ();
     }
     /**
@@ -646,7 +651,6 @@ public class DriverSapDB
         String host;
         String dbname;
         String dburl;
-        boolean niConnect = false;
         int urlLength = url.length ();
 
         slashPos = protocolName_C.length ();
@@ -688,7 +692,6 @@ public class DriverSapDB
         String url,
         java.util.Properties info)
     {
-        String result;
         int questionPos;
 
         questionPos = url.indexOf ('?');
@@ -717,24 +720,27 @@ public class DriverSapDB
         if (getBooleanProperty(info, encrytption_C, false)){
           transport = "secure";
         } else {
-          transport = info.getProperty (transportName_C, null);
+          transport = info.getProperty (transportName_C, "socket");
         }
-        if (transport == null) {
-            factory = commFactory;
-        }
-        else if (transport.equals ("socket")) {
+
+        if (transport.equals ("native")) {
+            try {
+              if (loadNativeCommunication() == nativeCommunication_enabled){
+                  factory = NativeComm.factory;
+              } else {
+                  transport = "socket";                  
+              }
+            }  catch (Error linkErr) {
+                throw new RTEException(MessageTranslator.translate
+                    (MessageKey.ERROR_LIBRARYNOTLOADED, nativeCommunication_dllName_C, linkErr.toString()), -10899);
+            }
+            factory = NativeComm.factory;
+        } else if (transport.equals ("socket")) {
             if (getBooleanProperty(info, niconnect_C, false)){
                 factory = NiCommunication.factory;
             } else {
                 factory = SocketComm.factory;
             }
-//            TimeoutException.println("Use socket");
-//            System.out.println("Use socket");
-        }
-        else if (transport.equals ("native")) {
-            factory = NativeComm.factory;
-//            TimeoutException.println("Use native");
-//            System.out.println("Use native");
         }
         else if(transport.equals ("secure")) {
             factory = SecureCommunication.factory;
@@ -745,11 +751,10 @@ public class DriverSapDB
                                    -10899);
         }
         try {
-        	// String commtimeout = info.getProperty(communicationtimeout_C, null);
             result = factory.open (host, dbname, info);
         }  catch (UnsatisfiedLinkError linkErr) {
             throw new RTEException(MessageTranslator.translate
-                (MessageKey.ERROR_LIBRARYNOTLOADED, dllName_C), -10899);
+                (MessageKey.ERROR_LIBRARYNOTLOADED, nativeCommunication_dllName_C, linkErr.toString()), -10899);
         }
         return result;
     }
@@ -832,47 +837,43 @@ public class DriverSapDB
     {
         //getDriverVersion
         jdbcDriverVersion = new com.sap.dbtech.util.VersionInfo(
-            "com.sap.dbtech.jdbc", "package com.sap.dbtech.jdbc, SAP DB JDBC Driver, SAP AG, ");
-
-        // default to 100% Java
-        commFactory = SocketComm.factory;
-
-        try {
-            String osName = null;
-            String loadbin = null;
-            try {
-              osName = System.getProperty(osNameProperty_C);
-              loadbin = System.getProperty(loadbinProperty_C);
-            } catch (java.security.AccessControlException ignore) {}
-
-            if ((osName != null) && osName.equalsIgnoreCase(osLinuxString_C)) {
-                // don't try loading so to prevent message
-                commFactory = SocketComm.factory;
-            }
-            if ((loadbin != null) && loadbin.equals ("no")) {
-                commFactory = SocketComm.factory;
-            }
-            else {
-                try {
-                    System.loadLibrary (dllName_C);
-                    commFactory = NativeComm.factory;
-                }
-                catch (Error e) {
-                    // load of library failed, default to 100% Java
-                }
-            }
-        }
-        catch (java.security.AccessControlException exc) {
-            // ignore, probably in Applet
-        }
+           "com.sap.dbtech.jdbc", "package com.sap.dbtech.jdbc, SAP DB JDBC Driver, SAP AG, ");
         try {
             DriverManager.registerDriver (driver);
         }
         catch (SQLException sqlExc) {
             // ignore
         }
-        // System.runFinalizersOnExit (true);
-
+    }
+    
+    final static public int nativeCommunication_notInit = 1;
+    final static public int nativeCommunication_enabled  = 2;
+    final static public int nativeCommunication_disabled = 3;
+    
+    static private int nativeCommunication = nativeCommunication_notInit;
+    
+    static public int loadNativeCommunication() {
+        if (nativeCommunication != nativeCommunication_notInit){
+          return nativeCommunication;  
+        }
+        try {
+            System.loadLibrary(nativeCommunication_dllName_C);
+            nativeCommunication = nativeCommunication_enabled;
+        } catch (java.security.AccessControlException exc) {
+            nativeCommunication = nativeCommunication_disabled;
+        } catch (java.lang.UnsatisfiedLinkError err) {
+            try {
+                System.loadLibrary(nativeCommunication_dllName_C + "32");
+                nativeCommunication = nativeCommunication_enabled;
+            } catch (Error e) {
+                nativeCommunication = nativeCommunication_disabled;
+                throw e;
+            }
+        } catch (Error e) {
+            nativeCommunication = nativeCommunication_disabled;
+            throw e;  
+        }
+        return nativeCommunication;
     }
     /**
      *
