@@ -41,7 +41,7 @@ public class StatementSapDB
     protected int               rowsAffected = -1;
     protected String            cursorName;
     protected String            defaultCursorName;
-    protected int               resultSetType = defaultResultSetType_C;
+    protected int               resultSetType = ResultSet.TYPE_FORWARD_ONLY;
     protected int               resultSetConcurrency = defaultConcurrency_C;
     protected int               resultSetHoldability = defaultHoldability_C;
     protected int               fetchDirection = java.sql.ResultSet.FETCH_FORWARD;
@@ -52,6 +52,8 @@ public class StatementSapDB
     protected int               queryTimeout = 0;
     protected boolean           setWithInfo = false;
     protected boolean           hasRowCount = false;
+    protected boolean           canceled = false;
+    protected boolean           packetEncodingUnicode = false;
     protected int               cursorUsage; // flag for use of cursor.
 
     static final int Cursor_not_used = 0; // 0 - not used
@@ -61,8 +63,13 @@ public class StatementSapDB
     static final int Cursor_Resurrected = 4; // 4 - Resurrected cursor that should be dropped in case it is not a query.
     static final int Cursor_forward_only = 5; // 5 - Select/Fetch optimized - must not be dropped if the last chunk was alredy fetched.
 
+    protected int               statementType; // flag for use of cursor.
+    static final int Statement_User = 0; // statement used by a JDBC application
+    static final int Statement_Internal = 1; // internal statement
+    static final int Statement_UpdatableResultSet = 2; // internal statement used for UpdatableresultSet
+
+
     // Constants
-    protected static final int defaultResultSetType_C = java.sql.ResultSet.TYPE_FORWARD_ONLY;
     protected static final int defaultConcurrency_C = java.sql.ResultSet.CONCUR_READ_ONLY;
     protected static final int defaultHoldability_C = java.sql.ResultSet.HOLD_CURSORS_OVER_COMMIT;
     public static final int BATCH_SUCCESS_NO_INFO_C = -2;  /*in JDBC 3.0 Part of standard*/
@@ -73,11 +80,9 @@ public class StatementSapDB
      */
     StatementSapDB (ConnectionSapDB connection) throws SQLException{
         this(connection,
-             (connection.isKernelFeaturesupported(Feature.sp1f_check_scrollableoption))?
-             ResultSet.TYPE_FORWARD_ONLY:StatementSapDB.defaultResultSetType_C,
+             ResultSet.TYPE_FORWARD_ONLY,
              defaultConcurrency_C,
              connection.getHoldability());
-             java.sql.Statement st = null;
     }
 
     /**
@@ -98,9 +103,14 @@ public class StatementSapDB
         }
         switch (resultSetConcurrency) {
             case java.sql.ResultSet.CONCUR_READ_ONLY:
-            case java.sql.ResultSet.CONCUR_UPDATABLE:
                 // OK
                 break;
+            case java.sql.ResultSet.CONCUR_UPDATABLE:{
+                if (resultSetType == java.sql.ResultSet.TYPE_FORWARD_ONLY){
+                    resultSetType = java.sql.ResultSet.TYPE_SCROLL_SENSITIVE;  
+                }
+                break;
+            }
             default:
                 throw  new InvalidArgumentValue("resultSetConcurrency", "CONCUR_READ_ONLY, CONCUR_UPDATABLE");
         }
@@ -115,7 +125,7 @@ public class StatementSapDB
         this.resultSetType = resultSetType;
         this.resultSetConcurrency = resultSetConcurrency;
         this.resultSetHoldability = resultSetHoldability;
-
+        this.statementType = StatementSapDB.Statement_User;
 
         /*adding the new stmt to the statement container of the corresponding connection*/
         if (this.resultSetHoldability == java.sql.ResultSet.CLOSE_CURSORS_AT_COMMIT){
@@ -146,6 +156,10 @@ public class StatementSapDB
      */
     public void cancel() throws SQLException {
         this.assertOpen ();
+        this.canceled = true;
+        if (this.currentResultSet != null){
+            ((ResultSetSapDB)this.currentResultSet).cancel();
+        }
         this.connection.cancel (this);
     }
         /**
@@ -227,14 +241,13 @@ public class StatementSapDB
         int resultSetConcurrency)
     throws SQLException
     {
+      try{
+        this.canceled = false; 
         clearWarnings();
 
         this.assertOpen ();
-        RequestPacket requestPacket;
         ReplyPacket replyPacket;
         boolean isQuery;
-        String actualSQL = sql;
-        boolean touchedCommand = false;
         boolean inTrans = this.connection.isInTransaction ();
 
         if (sql == null) {
@@ -259,6 +272,9 @@ public class StatementSapDB
             }
         }
         return isQuery;
+      } finally{
+        this.canceled = false;  
+      }  
     }
     /**
      *
@@ -267,7 +283,7 @@ public class StatementSapDB
      throws SQLException{
         String tabname = null;
         byte[] parseid = null;
-        RequestPacket requestPacket = this.connection.getRequestPacket();
+        RequestPacket requestPacket = this.connection.getRequestPacket(this.packetEncodingUnicode);
         requestPacket.initParseCommand (sqlCmd+ " FOR UPDATE OF ", true, false);
         ReplyPacket replyPacket = this.connection.execute (requestPacket, this, ConnectionSapDB.GC_ALLOWED);
         PartEnumeration enume = replyPacket.partEnumeration ();
@@ -312,18 +328,35 @@ public class StatementSapDB
         java.util.Vector items = this.batchItems;
         this.batchItems = null;
         try {
-            RequestPacket requestPacket = this.connection.getRequestPacket();
+            this.canceled = false;
             ReplyPacket replyPacket;
             int inputCursor = 0;
             int receiveCursor = 0;
 
+            this.packetEncodingUnicode = false;
             while (inputCursor < count) {
-                requestPacket.initDbsCommand (this.connection.autocommit, (String) items.elementAt(inputCursor), ResultSet.TYPE_FORWARD_ONLY);
+                RequestPacket requestPacket = this.connection.getRequestPacket(this.packetEncodingUnicode);
+                try{
+                    requestPacket.initDbsCommand (this.connection.autocommit, (String) items.elementAt(inputCursor), ResultSet.TYPE_FORWARD_ONLY);
+                } catch (ConversionExceptionSapDB e) {
+                    this.connection.freeRequestPacket(requestPacket);
+                    requestPacket = this.connection.getRequestPacket (true);
+                    this.packetEncodingUnicode = true;
+                    requestPacket.initDbsCommand (this.connection.autocommit, (String) items.elementAt(inputCursor), ResultSet.TYPE_FORWARD_ONLY);
+                }
                 requestPacket.setMaxSegment(Short.MAX_VALUE);
                 ++inputCursor;
-                while ((inputCursor < count)
-                       && requestPacket.initDbsCommand( (String) items.elementAt(inputCursor), false, this.connection.autocommit, ResultSet.TYPE_FORWARD_ONLY)) {
-                    ++inputCursor;
+                try {
+                    while ((inputCursor < count)
+                            && requestPacket.initDbsCommand((String) items
+                                    .elementAt(inputCursor), false,
+                                    this.connection.autocommit,
+                                    ResultSet.TYPE_FORWARD_ONLY)) {
+                        ++inputCursor;
+                    }
+                } catch (ConversionExceptionSapDB e) {
+                    requestPacket.dropSegment();
+                    this.packetEncodingUnicode = true;
                 }
                 replyPacket = this.connection.execute(requestPacket, true, false, this,
                                                       ConnectionSapDB.GC_DELAYED);
@@ -368,6 +401,8 @@ public class StatementSapDB
                 this.batchItems = items;
                 return this.executeBatch ();
             }
+        } finally{
+            this.canceled = false;
         }
     }
     /**
@@ -393,7 +428,7 @@ public class StatementSapDB
      */
     public int executeUpdate(String sql) throws SQLException {
         this.setWithInfo = false;
-        boolean isQuery = this.execute (sql, false, defaultResultSetType_C, defaultConcurrency_C);
+        boolean isQuery = this.execute (sql, false, ResultSet.TYPE_FORWARD_ONLY, defaultConcurrency_C);
         if (isQuery)
           throw new SQLExceptionSapDB (MessageTranslator.translate(MessageKey.ERROR_SQLSTATEMENT_RESULTSET));
         if(this.hasRowCount) {
@@ -722,7 +757,7 @@ public class StatementSapDB
         FetchInfo result;
 
         result = new FetchInfo (this.connection,
-                cursorName, infos, columnNames);
+                cursorName, infos, columnNames, this.packetEncodingUnicode);
         return result;
     }
     /**
@@ -771,9 +806,18 @@ public class StatementSapDB
         }
         try{
           if (touchedCommand) {
-              requestPacket = this.connection.getRequestPacket ();
+              requestPacket = this.connection.getRequestPacket (false);
+              this.packetEncodingUnicode = false;
               try {
-                  replyPacket = this.sendCommand (requestPacket, actualSQL, ConnectionSapDB.GC_ALLOWED, parseAgain);
+                  try{
+                      replyPacket = this.sendCommand (requestPacket, actualSQL, ConnectionSapDB.GC_ALLOWED, parseAgain);
+                      this.packetEncodingUnicode = false;
+                  } catch (ConversionExceptionSapDB e) {
+                      this.connection.freeRequestPacket(requestPacket);
+                      requestPacket = this.connection.getRequestPacket (true);
+                      this.packetEncodingUnicode = true;
+                      replyPacket = this.sendCommand (requestPacket, actualSQL, ConnectionSapDB.GC_ALLOWED, parseAgain);
+                  }
               }
               catch (SQLException sqlExc) {
                   if (false) {
@@ -781,13 +825,21 @@ public class StatementSapDB
                       throw new NotImplemented(MessageTranslator.translate(MessageKey.ERROR_NOTUPDATABLE));
                   }
                   // if (this.connection.getReplyPacket ().functionCode () != FunctionCode.Select_FC) {
-                  requestPacket = this.connection.getRequestPacket ();
+                  requestPacket = this.connection.getRequestPacket (this.packetEncodingUnicode);
                   replyPacket = this.sendCommand (requestPacket, sql, ConnectionSapDB.GC_ALLOWED, parseAgain);
               }
           }
           else {
-              requestPacket = this.connection.getRequestPacket ();
-              replyPacket = this.sendCommand (requestPacket, sql, ConnectionSapDB.GC_ALLOWED, parseAgain);
+            requestPacket = this.connection.getRequestPacket (false);
+            try {
+                replyPacket = this.sendCommand (requestPacket, sql, ConnectionSapDB.GC_ALLOWED, parseAgain);
+                this.packetEncodingUnicode = false;
+            } catch (ConversionExceptionSapDB e) {
+                this.connection.freeRequestPacket(requestPacket);
+                requestPacket = this.connection.getRequestPacket (true);
+                this.packetEncodingUnicode = true;
+                replyPacket = this.sendCommand (requestPacket, sql, ConnectionSapDB.GC_ALLOWED, parseAgain);
+            }
           }
         }
         catch (ArrayIndexOutOfBoundsException ex) {
@@ -1182,4 +1234,8 @@ public class StatementSapDB
     public int getResultSetHoldability () throws java.sql.SQLException {
         return  this.resultSetHoldability;
     }
+    
+    public boolean isPacketEncodingUnicode(){
+        return this.packetEncodingUnicode;
+    }
 }
