@@ -24,14 +24,17 @@
 
 package com.sap.dbtech.jdbc;
 
-import java.sql.SQLException;
 import java.sql.Blob;
 import java.sql.Clob;
+import java.sql.SQLException;
+import java.sql.Types;
 
-import com.sap.dbtech.jdbc.exceptions.*;
-import com.sap.dbtech.jdbc.translators.*;
-import com.sap.dbtech.util.MessageTranslator;
+import com.sap.dbtech.jdbc.exceptions.DatabaseException;
+import com.sap.dbtech.jdbc.exceptions.InternalJDBCError;
+import com.sap.dbtech.jdbc.exceptions.SQLExceptionSapDB;
+import com.sap.dbtech.jdbc.translators.DBTechTranslator;
 import com.sap.dbtech.util.MessageKey;
+import com.sap.dbtech.util.MessageTranslator;
 
 /**
  *
@@ -56,11 +59,6 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
 
     private int currentMode = MODE_READ;
 
-    /**
-     * constant that signals that no current-cached record was updated
-     */
-    private static final int noUpdatedRecordInCache_C = -1;
-
     /**
      */
     UpdatableResultSetSapDB(ConnectionSapDB connection,
@@ -216,13 +214,18 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
         this.assertNotClosed();
         this.prepareUpdate ();
         int result = 0;
+        boolean outOfBoundExceptionCatched = false;
         try {
             result = this.updateColMapping [colIndex];
         }
         catch (ArrayIndexOutOfBoundsException exc) {
-            throw new com.sap.dbtech.jdbc.exceptions.InvalidColumnException (colIndex, this);
+            outOfBoundExceptionCatched = true;
         }
-        if (result == 0) {
+        if (result == 0 || outOfBoundExceptionCatched) {
+            if (colIndex > 0 && colIndex < this.getColInfo().length){
+                throw new SQLExceptionSapDB (MessageTranslator.translate(MessageKey.ERROR_UPDATEROW_COLUMNNOTUPDATABLE,
+                        this.getColInfo()[colIndex-1].getColumnName()));
+            }
             throw new com.sap.dbtech.jdbc.exceptions.InvalidColumnException (colIndex, this);
         }
         return result;
@@ -410,6 +413,7 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
             String sqlCmd = prelude + columns + finale;
             try {
                 result = (CallableStatementSapDB) this.getConnection().prepareCall(sqlCmd);
+                result.statementType = StatementSapDB.Statement_UpdatableResultSet;
             }
             catch (DatabaseException sqlExc) {
                 if (sqlExc.getErrorCode()==-7032)
@@ -429,11 +433,20 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
         }
         int count = validColumns.size ();
         this.updateColMapping = new int [colinfo_length + 1];
+        boolean useDefaultValue = DriverSapDB.getBooleanProperty(this.connection.getConnectProperties(),
+                DriverSapDB.useDefaultValueForUpdatableRS_C, false);
         for (int i = 0; i < count; ++i) {
-            com.sap.dbtech.jdbc.translators.DBTechTranslator current =
-                this.findColumnInfo ((String) validColumns.elementAt(i));
+            com.sap.dbtech.jdbc.translators.DBTechTranslator current = this
+                    .findColumnInfo((String) validColumns.elementAt(i));
             current.allowWrites();
-            this.updateColMapping [current.getColIndex () + 1] = i + 1;
+            this.updateColMapping[current.getColIndex() + 1] = i + 1;
+            if (mode == MODE_INSERT) {
+                if (useDefaultValue) {
+                    result.setDefault(i + 1);
+                } else {
+                    result.setNull(i + 1, Types.OTHER);
+                }
+            }
         }
         return result;
     }
@@ -448,16 +461,16 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
             }
             this.currentChangeCmd = this.updateCmd;
             this.currentMode = MODE_UPDATE;
-            int columns=this.numberOfColumns();
-            for (int i = 0; i < columns; ++i) {
-                int colIndex = i + 1;
-                try {
-                    this.updateCmd.setObject(this.findUpdateColumn(colIndex), this.getObject (colIndex));
-                }
-                catch (com.sap.dbtech.jdbc.exceptions.InvalidColumnException exc) {
-                    // ignore
-                }
-            }
+//            int columns=this.numberOfColumns();
+//            for (int i = 0; i < columns; ++i) {
+//                int colIndex = i + 1;
+//                try {
+//                    this.updateCmd.setObject(this.findUpdateColumn(colIndex), this.getObject (colIndex));
+//                }
+//                catch (com.sap.dbtech.jdbc.exceptions.InvalidColumnException exc) {
+//                    // ignore
+//                }
+//            }
         }
     }
 
@@ -963,6 +976,16 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
         int updIndex = this.findUpdateColumn (columnName);
         this.currentChangeCmd.setNull (updIndex, 0);
     }
+
+    public void updateDefault(String columnName) throws SQLException {
+        int updIndex = this.findUpdateColumn (columnName);
+        this.currentChangeCmd.setDefault(updIndex);
+    }
+
+    public void updateDefault(int columnIndex) throws SQLException {
+        int updIndex = this.findUpdateColumn (columnIndex);
+        this.currentChangeCmd.setDefault(updIndex);
+    }
     /**
      * JDBC 2.0
      *
@@ -1046,6 +1069,41 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
         this.currentChangeCmd.setObject (updIndex, x, scale);
     }
 
+    private CallableStatementSapDB generatePartialUpdateStatement()
+            throws SQLException {
+        StringBuffer tmpStmtString = new StringBuffer("UPDATE "
+                + this.tableName + " SET \"");
+        Object args[] = this.updateCmd.getInputArgs();
+        DBTechTranslator[] colInfo = this.getColInfo();
+        String delimiter = "";
+        for (int i = 1; i < this.updateColMapping.length; i++) {
+            int colind = this.updateColMapping[i];
+            if (colind != 0 && this.updateCmd.isParameterSet(colind)) {
+                tmpStmtString.append(delimiter);
+                tmpStmtString.append(colInfo[i - 1].getColumnName());
+                delimiter = "\" = ?, \"";
+            }
+        }
+
+        tmpStmtString.append("\" = ? WHERE POS OF \"" + this.getCursorName()
+                + "\" IS ? ");
+        CallableStatementSapDB updCmd = null;
+        try {
+            updCmd = (CallableStatementSapDB) this.connection
+                    .prepareCall(tmpStmtString.toString());
+        } catch (DatabaseException sql) {
+            throw new InternalJDBCError(MessageTranslator
+                    .translate(MessageKey.ERROR_INTERNAL_PREPAREHELPER), sql);
+        }
+        Object newargs[] = updCmd.getInputArgs();
+        for (int i = 0, j = 0; i < args.length; i++) {
+            if (this.updateCmd.isParameterSet(i + 1)) {
+                newargs[j++] = args[i];
+            }
+        }
+        return updCmd;
+    }
+
     /**
      * JDBC 2.0
      *
@@ -1057,6 +1115,7 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
      */
     public void updateRow() throws java.sql.SQLException {
 
+        CallableStatementSapDB updCmd=this.updateCmd;
         int safeCurrentMode=this.currentMode;
         CallableStatementSapDB saveCurrentChangeCmd=this.currentChangeCmd;
         this.currentChangeCmd=null;
@@ -1070,10 +1129,26 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
             throw new SQLExceptionSapDB(MessageTranslator.translate(MessageKey.ERROR_UPDATEROW_NOROW));
         }
         if (this.currentMode == MODE_UPDATE) {
+            Object args[] = this.updateCmd.getInputArgs();
+            boolean needPartialUpdate = false;
+            for (int i = 1; i < args.length; i++) {
+               if (! this.updateCmd.isParameterSet(i)) {
+                   needPartialUpdate = true;
+                   break;
+               }  
+            }
+            if (needPartialUpdate){
+                updCmd = this.generatePartialUpdateStatement();
+                this.currentChangeCmd = updCmd;
+            } 
+            
             /*set update position in current rowset -
               last parameter of update command*/
-            this.updateCmd.setInt(this.updateCmd.parseinfo.inputCount, internal);
-            this.updateCmd.executeUpdate();
+            updCmd.setInt(updCmd.parseinfo.inputCount, internal);
+            updCmd.executeUpdate();
+            if (needPartialUpdate){
+                this.currentChangeCmd = saveCurrentChangeCmd;
+            } 
             absolute(internal);
             this.currentMode= MODE_READ;
             modifiedKernelPos=internal; // the kernel position has changed to the current row.
@@ -1251,4 +1326,10 @@ public class UpdatableResultSetSapDB extends ResultSetSapDB {
         int updIndex = this.findUpdateColumn (columnName);
         this.currentChangeCmd.setClob (updIndex, x);
      }
+     /**
+      * cancel method comment.
+      */
+     public void cancel() throws SQLException {
+         this.currentChangeCmd.cancel();
+     }
 }
