@@ -63,6 +63,8 @@ public abstract class DBTechTranslator
     public final static int specialNullValueDefineByte = 2;
     public final static int unknownDefineByte = -1;
 
+    public final static String DefaultValue = "DefaultValue";
+
     /**
      *
      * @param mode int
@@ -893,6 +895,8 @@ public abstract class DBTechTranslator
         if (this.ioType != ParamInfo.Output_C) {
             if (data == null) {
                 dataPart.putNull(this.bufpos, this.physicalLength - 1);
+            } else if (data == DefaultValue){
+                dataPart.putDefault(this.bufpos, this.physicalLength - 1);
             }
             else {
                 this.putSpecific (dataPart, data);
@@ -908,6 +912,8 @@ public abstract class DBTechTranslator
         if (this.ioType != ParamInfo.Input_C) {
             if (data == null) {
                 dataPart.putNull(this.bufpos, this.physicalLength - 1);
+            } else if (data == DefaultValue){
+                dataPart.putDefault(this.bufpos, this.physicalLength - 1);
             }
             else {
                 this.putSpecific (dataPart, data);
