@@ -127,6 +127,12 @@ public class RteC {
     public final static int SQL_DISTRIBUTION_C           =      3;
     public final static int SQL_CONTROL_C                =      4;
     public final static int SQL_EVENT_C                  =      5;
+    public final static int SQL_STREAM_C                 =      6;
+    public final static int SQL_PING_C                   =      7;
+    public final static int SQL_LVCUSER_C                =      8;
+    public final static int SQL_OLTPUSER_C               =      9;
+    public final static int SQL_CONSOLE_C                =      10;
+    
     // Type RTE_HEADER_REC -> Header
     public final static int Header_ActSendLen_O          =      0;   // INT4
     public final static int Header_ProtocolID_O          =      4;   // INT1
