@@ -24,6 +24,8 @@
 
 package com.sap.dbtech.util;
 
+import com.sap.dbtech.jdbc.translators.ConversionExceptionSapDB;
+
 /**
  *
  */
@@ -223,5 +225,8 @@ implements StructuredMem, Traceable
     public void traceOn (java.io.PrintStream outstream, int from, int to) {
         this.mem.traceOn (outstream, from, to);
     }
+    public int putStringThrowExc(String value, int offset) throws ConversionExceptionSapDB {
+        return this.mem.putStringThrowExc(value, offset);
+    }
 
 }
