@@ -26,6 +26,8 @@ package com.sap.dbtech.util;
 
 import java.io.*;
 
+import com.sap.dbtech.jdbc.translators.ConversionExceptionSapDB;
+
 /**
  *
  *
@@ -517,9 +519,9 @@ public class StructuredBytes
      * @param value java.lang.String
      * @param offset int
      */
-    public int putString (
+    public int putStringThrowExc (
         String value,
-        int offset)
+        int offset) throws ConversionExceptionSapDB
     {
         // encoding default is ISO8859_1
         // other encodings are not supported (now).
@@ -533,13 +535,41 @@ public class StructuredBytes
             if(c <= 255 ) {
                 data[ofs++]=(byte) c;
             } else {
-                data[ofs++]=63; // '?'
+//                data[ofs++]=63; // '?'
+               throw new ConversionExceptionSapDB(MessageTranslator.translate(MessageKey.ERROR_UNICODETOASCII,value));
             }
         }
         
         return strlen;
     }
     
+    /**
+    *
+    * @param value java.lang.String
+    * @param offset int
+    */
+   public int putString (
+       String value,
+       int offset)
+   {
+       // encoding default is ISO8859_1
+       // other encodings are not supported (now).
+       
+       int ofs=offset+this.ptrOffs;
+       char[] ca=value.toCharArray();
+       int strlen=ca.length;
+       
+       for(int i=0; i<strlen; ++i) {
+           char c=ca[i];
+           if(c <= 255 ) {
+               data[ofs++]=(byte) c;
+           } else {
+               data[ofs++]=63; // '?'
+           }
+       }
+       
+       return strlen;
+   }
     /**
      *
      * @return int
