@@ -25,6 +25,8 @@
 package com.sap.dbtech.util;
 
 import java.io.*;
+
+import com.sap.dbtech.jdbc.translators.ConversionExceptionSapDB;
 /**
  *
  */
@@ -282,5 +284,8 @@ public interface StructuredMem
 	 * @param offset
 	 */
 	public abstract void putInt8(long lval, int offset);
-
+    
+    public abstract int putStringThrowExc (
+            String value,
+            int offset) throws ConversionExceptionSapDB;
 }
