@@ -93,7 +93,10 @@ inlined_uc_addr (ucontext_t *uc, int reg, uint8_t *nat_bitnr)
     case UNW_IA64_NAT + 12:
       addr = &uc->uc_mcontext.sc_nat;
       reg_addr = (unw_word_t) &uc->uc_mcontext.sc_gr[reg - UNW_IA64_NAT];
-      *nat_bitnr = reg - UNW_IA64_NAT;
+      if ( nat_bitnr )
+      {
+	  *nat_bitnr = reg - UNW_IA64_NAT;
+      }
       break;
 
     case UNW_IA64_BR + 1 ... UNW_IA64_BR + 5:
